@@ -1,7 +1,7 @@
 from collections import namedtuple
 from functools import partial
 
-from pcs.cli.common.console_report import error
+from pcs.cli.reports.output import error
 
 
 def build(*middleware_list):
@@ -11,8 +11,10 @@ def build(*middleware_list):
             next_in_line = partial(next_command, next_in_line)
 
         return next_in_line(env, *args, **kwargs)
+
     return run
 
+
 def cib(filename, touch_cib_file):
     """
     return configured middleware that cares about local cib
@@ -20,6 +22,7 @@ def cib(filename, touch_cib_file):
     callable load_cib_content returns local cib content, take no params
     callable write_cib put content of cib to required place
     """
+
     def apply(next_in_line, env, *args, **kwargs):
         if filename:
             touch_cib_file(filename)
@@ -28,9 +31,8 @@ def cib(filename, touch_cib_file):
                     original_content = cib_file.read()
             except EnvironmentError as e:
                 raise error(
-                    "Cannot read cib file '{0}': '{1}'"
-                    .format(filename, str(e))
-                )
+                    "Cannot read cib file '{0}': '{1}'".format(filename, str(e))
+                ) from e
             env.cib_data = original_content
 
         result_of_next = next_in_line(env, *args, **kwargs)
@@ -41,23 +43,27 @@ def cib(filename, touch_cib_file):
                     cib_file.write(env.cib_data)
             except EnvironmentError as e:
                 raise error(
-                    "Cannot write cib file '{0}': '{1}'"
-                    .format(filename, str(e))
-                )
+                    "Cannot write cib file '{0}': '{1}'".format(
+                        filename, str(e)
+                    )
+                ) from e
 
         return result_of_next
+
     return apply
 
+
 def corosync_conf_existing(local_file_path):
     def apply(next_in_line, env, *args, **kwargs):
         if local_file_path:
             try:
                 env.corosync_conf_data = open(local_file_path).read()
             except EnvironmentError as e:
-                raise error("Unable to read {0}: {1}".format(
-                    local_file_path,
-                    e.strerror
-                ))
+                raise error(
+                    "Unable to read {0}: {1}".format(
+                        local_file_path, e.strerror
+                    )
+                ) from e
 
         result_of_next = next_in_line(env, *args, **kwargs)
 
@@ -67,11 +73,13 @@ def corosync_conf_existing(local_file_path):
                 file.write(env.corosync_conf_data)
                 file.close()
             except EnvironmentError as e:
-                raise error("Unable to write {0}: {1}".format(
-                    local_file_path,
-                    e.strerror
-                ))
+                raise error(
+                    "Unable to write {0}: {1}".format(
+                        local_file_path, e.strerror
+                    )
+                ) from e
         return result_of_next
+
     return apply
 
 
@@ -79,4 +87,4 @@ def create_middleware_factory(**kwargs):
     """
     Commandline options: no options
     """
-    return namedtuple('MiddlewareFactory', kwargs.keys())(**kwargs)
+    return namedtuple("MiddlewareFactory", kwargs.keys())(**kwargs)
