@@ -1,3 +1,9 @@
+from typing import (
+    Mapping,
+    Iterable,
+    Union,
+)
+
 from pcs.cli.common.errors import (
     CmdLineInputError,
     HINT_SYNTAX_CHANGE,
@@ -7,6 +13,7 @@ from pcs.common.str_tools import (
     format_plural,
 )
 
+ModifierValueType = Union[None, bool, str]
 
 ARG_TYPE_DELIMITER = "%"
 
@@ -20,6 +27,7 @@ PCS_LONG_OPTIONS = [
     "fullhelp",
     "force",
     "skip-offline",
+    # TODO remove, deprecated command 'pcs config import-cman'
     "interactive",
     "autodelete",
     "simulate",
@@ -66,8 +74,14 @@ PCS_LONG_OPTIONS = [
     "groups",
     # "pcs resource clear --expired" - only clear expired moves and bans
     "expired",
+    # disable evaluating whether rules are expired
+    "no-expire-check",
     # allow overwriting existing files, currently meant for / used in CLI only
     "overwrite",
+    # output format of commands, e.g: json, cmd, text, ...
+    "output-format=",
+    # auth token
+    "token=",
 ]
 
 
@@ -90,7 +104,8 @@ def split_list_by_any_keywords(arg_list, keyword_label):
     if "=" in arg_list[0]:
         raise CmdLineInputError(
             "Invalid character '=' in {} '{}'".format(
-                keyword_label, arg_list[0],
+                keyword_label,
+                arg_list[0],
             )
         )
     current_keyword = None
@@ -321,12 +336,20 @@ def parse_typed_arg(arg, allowed_types, default_type):
     return arg_type, arg_value
 
 
-def is_num(arg):
+def _is_num(arg):
     return arg.isdigit() or arg.lower() == "infinity"
 
 
-def is_negative_num(arg):
-    return arg.startswith("-") and is_num(arg[1:])
+def _is_float(arg: str) -> bool:
+    try:
+        float(arg)
+        return True
+    except ValueError:
+        return False
+
+
+def _is_negative_num(arg: str) -> bool:
+    return arg.startswith("-") and (_is_num(arg[1:]) or _is_float(arg))
 
 
 def is_short_option_expecting_value(arg):
@@ -351,47 +374,75 @@ def is_option_expecting_value(arg):
     ) or is_long_option_expecting_value(arg)
 
 
+# DEPRECATED
+# TODO remove
+# This function is called only by deprecated code for parsing argv containing
+# negative numbers without -- prepending them.
 def filter_out_non_option_negative_numbers(arg_list):
     """
     Return arg_list without non-option negative numbers.
     Negative numbers following the option expecting value are kept.
 
-    There is the problematic legacy.
-    Argumet "--" has special meaning: can be used to signal that no more
+    There is the problematic legacy:
+    Argument "--" has special meaning: it can be used to signal that no more
     options will follow. This would solve the problem with negative numbers in
     a standard way: there would be no special approach to negative numbers,
-    everything would be left in the hands of users. But now it would be
-    backward incompatible change.
+    everything would be left in the hands of users.
+
+    We cannot use "--" as it would be a backward incompatible change:
+    * "pcs ... -infinity" would not work any more, users would have to switch
+      to "pcs ... -- ... -infinity"
+    * previously, position of some --options mattered, for example
+      "--clone <clone options>", this syntax would not be possible with the "--"
+      in place
+
+    Currently used --options, which may be problematic when switching to "--":
+    * --group <group name>, --before | --after <resource id>
+      * pcs resource | stonith create, pcs resource group add, pcs tag update
+      * They have a single argument, so they would work even with --. But the
+        command may look weird:
+        pcs resource create --group G --after R2 -- R3 ocf:pacemaker:Dummy
+        vs. current command
+        pcs resource create R3 ocf:pacemaker:Dummy --group G --after R2
 
     list arg_list contains command line arguments
     """
     args_without_negative_nums = []
+    args_filtered_out = []
     for i, arg in enumerate(arg_list):
         prev_arg = arg_list[i - 1] if i > 0 else ""
-        if not is_negative_num(arg) or is_option_expecting_value(prev_arg):
+        if not _is_negative_num(arg) or is_option_expecting_value(prev_arg):
             args_without_negative_nums.append(arg)
+        else:
+            args_filtered_out.append(arg)
 
-    return args_without_negative_nums
+    return args_without_negative_nums, args_filtered_out
 
 
+# DEPRECATED
+# TODO remove
+# This function is called only by deprecated code for parsing argv containing
+# negative numbers without -- prepending them.
 def filter_out_options(arg_list):
     """
     Return arg_list without options and its negative numbers.
 
+    See a comment in filter_out_non_option_negative_numbers.
+
     list arg_list contains command line arguments
     """
     args_without_options = []
     for i, arg in enumerate(arg_list):
         prev_arg = arg_list[i - 1] if i > 0 else ""
         if not is_option_expecting_value(prev_arg) and (
-            not arg.startswith("-") or arg == "-" or is_negative_num(arg)
+            not arg.startswith("-") or arg == "-" or _is_negative_num(arg)
         ):
             args_without_options.append(arg)
     return args_without_options
 
 
 class InputModifiers:
-    def __init__(self, options):
+    def __init__(self, options: Mapping[str, ModifierValueType]):
         self._defined_options = set(options.keys())
         self._options = dict(options)
         self._options.update(
@@ -413,12 +464,14 @@ class InputModifiers:
                 # used only in deprecated 'pcs resource|stonith show'
                 "--groups": "--groups" in options,
                 "--hide-inactive": "--hide-inactive" in options,
+                # TODO remove, deprecated command 'pcs config import-cman'
                 "--interactive": "--interactive" in options,
                 "--local": "--local" in options,
                 "--master": "--master" in options,
                 "--monitor": "--monitor" in options,
                 "--no-default-ops": "--no-default-ops" in options,
                 "--nodesc": "--nodesc" in options,
+                "--no-expire-check": "--no-expire-check" in options,
                 "--no-keys-sync": "--no-keys-sync" in options,
                 "--no-strict": "--no-strict" in options,
                 "--no-watchdog-validation": "--no-watchdog-validation"
@@ -441,8 +494,10 @@ class InputModifiers:
                 "--group": options.get("--group", None),
                 "--name": options.get("--name", None),
                 "--node": options.get("--node", None),
+                "--output-format": options.get("--output-format", "text"),
                 "--request-timeout": options.get("--request-timeout", None),
                 "--to": options.get("--to", None),
+                "--token": options.get("--token", None),
                 "--wait": options.get("--wait", False),
                 "-f": options.get("-f", None),
                 "-p": options.get("-p", None),
@@ -458,7 +513,7 @@ class InputModifiers:
         return InputModifiers(opt_dict)
 
     def ensure_only_supported(
-        self, *supported_options, hint_syntax_changed=False
+        self, *supported_options, hint_syntax_changed: bool = False
     ):
         unsupported_options = (
             # --debug is supported in all commands
@@ -501,16 +556,18 @@ class InputModifiers:
                 )
             )
 
-    def is_specified(self, option):
+    def is_specified(self, option: str) -> bool:
         return option in self._defined_options
 
-    def is_specified_any(self, option_list):
+    def is_specified_any(self, option_list: Iterable[str]) -> bool:
         for option in option_list:
             if self.is_specified(option):
                 return True
         return False
 
-    def get(self, option, default=None):
+    def get(
+        self, option: str, default: ModifierValueType = None
+    ) -> ModifierValueType:
         if option in self._defined_options:
             return self._options[option]
         if default is not None:
