@@ -9,9 +9,11 @@ def prepare_resource_sets(cmdline_args):
             "options": parse_args.prepare_options(
                 [opt for opt in args if "=" in opt]
             ),
-        } for args in parse_args.split_list(cmdline_args, "set")
+        }
+        for args in parse_args.split_list(cmdline_args, "set")
     ]
 
+
 def prepare_set_args(argv):
     if argv.count("setoptions") > 1:
         raise CmdLineInputError(
@@ -20,17 +22,16 @@ def prepare_set_args(argv):
 
     resource_set_args, constraint_options_args = (
         parse_args.split_list(argv, "setoptions")
-        if "setoptions" in argv else (argv, [])
+        if "setoptions" in argv
+        else (argv, [])
     )
 
     if not resource_set_args:
         raise CmdLineInputError()
 
     resource_set_list = prepare_resource_sets(resource_set_args)
-    if(
-        not resource_set_list
-        or
-        not all(resource_set["ids"] for resource_set in resource_set_list)
+    if not resource_set_list or not all(
+        resource_set["ids"] for resource_set in resource_set_list
     ):
         raise CmdLineInputError()
 
