@@ -1,6 +1,6 @@
 from pcs.cli.common.errors import CmdLineInputError
 from pcs.cli.constraint import command
-from pcs.cli.constraint_colocation import console_report
+from pcs.common.reports import constraints
 
 
 def create_with_set(lib, argv, modifiers):
@@ -23,6 +23,7 @@ def create_with_set(lib, argv, modifiers):
         modifiers,
     )
 
+
 def show(lib, argv, modifiers):
     """
     show all colocation constraints
@@ -37,9 +38,13 @@ def show(lib, argv, modifiers):
     modifiers.ensure_only_supported("-f", "--full")
     if argv:
         raise CmdLineInputError()
-    print("\n".join(command.show(
-         "Colocation Constraints:",
-        lib.constraint_colocation.show,
-        console_report.constraint_plain,
-        modifiers,
-    )))
+    print(
+        "\n".join(
+            command.show(
+                "Colocation Constraints:",
+                lib.constraint_colocation.show,
+                constraints.colocation_plain,
+                modifiers,
+            )
+        )
+    )
