@@ -1,7 +1,9 @@
 from pcs.cli.common.errors import CmdLineInputError
 from pcs.cli.constraint import command
-from pcs.cli.constraint_ticket import parse_args, console_report
-from pcs.cli.common.console_report import error
+from pcs.cli.constraint_ticket import parse_args
+from pcs.cli.reports.output import error
+from pcs.common.reports import constraints
+
 
 def create_with_set(lib, argv, modifiers):
     """
@@ -23,6 +25,7 @@ def create_with_set(lib, argv, modifiers):
         modifiers,
     )
 
+
 def add(lib, argv, modifiers):
     """
     create ticket constraint
@@ -41,7 +44,7 @@ def add(lib, argv, modifiers):
     if "rsc-role" in options:
         raise CmdLineInputError(
             "Resource role must not be specified among options"
-            +", specify it before resource id"
+            + ", specify it before resource id"
         )
 
     if resource_role:
@@ -55,6 +58,7 @@ def add(lib, argv, modifiers):
         duplication_alowed=modifiers.get("--force"),
     )
 
+
 def remove(lib, argv, modifiers):
     """
     Options:
@@ -67,6 +71,7 @@ def remove(lib, argv, modifiers):
     if not lib.constraint_ticket.remove(ticket, resource_id):
         raise error("no matching ticket constraint found")
 
+
 def show(lib, argv, modifiers):
     """
     show all ticket constraints
@@ -81,9 +86,13 @@ def show(lib, argv, modifiers):
     modifiers.ensure_only_supported("-f", "--full")
     if argv:
         raise CmdLineInputError()
-    print("\n".join(command.show(
-        "Ticket Constraints:",
-        lib.constraint_ticket.show,
-        console_report.constraint_plain,
-        modifiers,
-    )))
+    print(
+        "\n".join(
+            command.show(
+                "Ticket Constraints:",
+                lib.constraint_ticket.show,
+                constraints.ticket_plain,
+                modifiers,
+            )
+        )
+    )
