@@ -1,5 +1,5 @@
 from pcs.cli.common.parse_args import group_by_keywords, prepare_options
-from pcs.cli.common.errors import CmdLineInputError, HINT_SYNTAX_CHANGE
+from pcs.cli.common.errors import CmdLineInputError, SEE_MAN_CHANGES
 
 
 def parse_create_simple(arg_list):
@@ -11,16 +11,52 @@ def parse_create_simple(arg_list):
     )
 
     parts = {
-        "meta":  prepare_options(groups.get("meta", [])),
-        "options":  prepare_options(groups.get("options", [])),
+        "meta": prepare_options(groups.get("meta", [])),
+        "options": prepare_options(groups.get("options", [])),
         "op": [
-            prepare_options(op)
-            for op in build_operations(groups.get("op", []))
+            prepare_options(op) for op in build_operations(groups.get("op", []))
         ],
     }
 
     return parts
 
+
+def parse_clone(arg_list, promotable=False):
+    parts = {
+        "clone_id": None,
+        "meta": {},
+    }
+    allowed_keywords = set(["op", "meta"])
+    if (
+        arg_list
+        and arg_list[0] not in allowed_keywords
+        and "=" not in arg_list[0]
+    ):
+        parts["clone_id"] = arg_list.pop(0)
+    groups = group_by_keywords(
+        arg_list,
+        allowed_keywords,
+        implicit_first_group_key="options",
+        group_repeated_keywords=["op"],
+        only_found_keywords=True,
+    )
+    if "op" in groups:
+        raise CmdLineInputError(
+            "op settings must be changed on base resource, not the clone",
+        )
+    parts["meta"] = prepare_options(
+        groups.get("options", []) + groups.get("meta", []),
+    )
+    if promotable:
+        if "promotable" in parts["meta"]:
+            raise CmdLineInputError(
+                "you cannot specify both promotable option and promotable "
+                "keyword"
+            )
+        parts["meta"]["promotable"] = "true"
+    return parts
+
+
 def parse_create(arg_list):
     groups = group_by_keywords(
         arg_list,
@@ -32,8 +68,8 @@ def parse_create(arg_list):
 
     try:
         parts = {
-            "meta":  prepare_options(groups.get("meta", [])),
-            "options":  prepare_options(groups.get("options", [])),
+            "meta": prepare_options(groups.get("meta", [])),
+            "options": prepare_options(groups.get("options", [])),
             "op": [
                 prepare_options(op)
                 for op in build_operations(groups.get("op", []))
@@ -41,8 +77,12 @@ def parse_create(arg_list):
         }
 
         if "clone" in groups:
+            if groups["clone"] and "=" not in groups["clone"][0]:
+                parts["clone_id"] = groups["clone"].pop(0)
             parts["clone"] = prepare_options(groups["clone"])
         if "promotable" in groups:
+            if groups["promotable"] and "=" not in groups["promotable"][0]:
+                parts["clone_id"] = groups["promotable"].pop(0)
             parts["promotable"] = prepare_options(groups["promotable"])
         if "bundle" in groups:
             parts["bundle"] = groups["bundle"]
@@ -51,11 +91,19 @@ def parse_create(arg_list):
         # manpage.
         # To be removed in the next significant version.
         if e.message == "missing value of 'master' option":
-            raise CmdLineInputError(message=e.message, hint=HINT_SYNTAX_CHANGE)
-        raise e
+            raise CmdLineInputError(
+                message=e.message,
+                hint=(
+                    "Master/Slave resources have been renamed to promotable "
+                    "clones, please use the 'promotable' keyword instead of "
+                    "'master'. " + SEE_MAN_CHANGES
+                ),
+            ) from e
+        raise
 
     return parts
 
+
 def _parse_bundle_groups(arg_list):
     """
     Commandline options: no options
@@ -84,6 +132,7 @@ def _parse_bundle_groups(arg_list):
                 )
     return groups
 
+
 def parse_bundle_create_options(arg_list):
     """
     Commandline options: no options
@@ -98,17 +147,17 @@ def parse_bundle_create_options(arg_list):
         "container": prepare_options(container_options),
         "network": prepare_options(groups.get("network", [])),
         "port_map": [
-            prepare_options(port_map)
-            for port_map in groups.get("port-map", [])
+            prepare_options(port_map) for port_map in groups.get("port-map", [])
         ],
         "storage_map": [
             prepare_options(storage_map)
             for storage_map in groups.get("storage-map", [])
         ],
-        "meta": prepare_options(groups.get("meta", []))
+        "meta": prepare_options(groups.get("meta", [])),
     }
     return parts
 
+
 def parse_bundle_reset_options(arg_list):
     """
     Commandline options: no options
@@ -119,17 +168,17 @@ def parse_bundle_reset_options(arg_list):
         "container": prepare_options(container_options),
         "network": prepare_options(groups.get("network", [])),
         "port_map": [
-            prepare_options(port_map)
-            for port_map in groups.get("port-map", [])
+            prepare_options(port_map) for port_map in groups.get("port-map", [])
         ],
         "storage_map": [
             prepare_options(storage_map)
             for storage_map in groups.get("storage-map", [])
         ],
-        "meta": prepare_options(groups.get("meta", []))
+        "meta": prepare_options(groups.get("meta", [])),
     }
     return parts
 
+
 def _split_bundle_map_update_op_and_options(
     map_arg_list, result_parts, map_name
 ):
@@ -146,6 +195,7 @@ def _split_bundle_map_update_op_and_options(
     else:
         raise _bundle_map_update_not_valid(map_name)
 
+
 def _bundle_map_update_not_valid(map_name):
     """
     Commandline options: no options
@@ -157,6 +207,7 @@ def _bundle_map_update_not_valid(map_name):
         ).format(map=map_name)
     )
 
+
 def parse_bundle_update_options(arg_list):
     """
     Commandline options: no options
@@ -164,9 +215,7 @@ def parse_bundle_update_options(arg_list):
     groups = _parse_bundle_groups(arg_list)
     port_map = {"add": [], "remove": []}
     for map_group in groups.get("port-map", []):
-        _split_bundle_map_update_op_and_options(
-            map_group, port_map, "port-map"
-        )
+        _split_bundle_map_update_op_and_options(map_group, port_map, "port-map")
     storage_map = {"add": [], "remove": []}
     for map_group in groups.get("storage-map", []):
         _split_bundle_map_update_op_and_options(
@@ -179,10 +228,11 @@ def parse_bundle_update_options(arg_list):
         "port_map_remove": port_map["remove"],
         "storage_map_add": storage_map["add"],
         "storage_map_remove": storage_map["remove"],
-        "meta": prepare_options(groups.get("meta", []))
+        "meta": prepare_options(groups.get("meta", [])),
     }
     return parts
 
+
 def build_operations(op_group_list):
     """
     Return a list of dicts. Each dict represents one operation.
@@ -194,11 +244,11 @@ def build_operations(op_group_list):
     """
     operation_list = []
     for op_group in op_group_list:
-        #empty operation is not allowed
+        # empty operation is not allowed
         if not op_group:
             raise __not_enough_parts_in_operation()
 
-        #every operation group needs to start with operation name
+        # every operation group needs to start with operation name
         if "=" in op_group[0]:
             raise __every_operation_needs_name()
 
@@ -208,19 +258,22 @@ def build_operations(op_group_list):
             else:
                 operation_list[-1].append(arg)
 
-    #every operation needs at least name and one option
-    #there can be more than one operation in op_group: check is after processing
+    # every operation needs at least name and one option
+    # there can be more than one operation in op_group: check is after
+    # processing
     if any([len(operation) < 2 for operation in operation_list]):
         raise __not_enough_parts_in_operation()
 
     return operation_list
 
+
 def __not_enough_parts_in_operation():
     return CmdLineInputError(
         "When using 'op' you must specify an operation name"
         " and at least one option"
     )
 
+
 def __every_operation_needs_name():
     return CmdLineInputError(
         "When using 'op' you must specify an operation name after 'op'"
