@@ -14,8 +14,22 @@ cluster_cmd = create_router(
     {
         "help": lambda lib, argv, modifiers: usage.cluster(argv),
         "setup": cluster.cluster_setup,
+        "config": create_router(
+            {
+                "show": cluster.config_show,
+                "update": cluster.config_update,
+            },
+            ["cluster", "config"],
+            default_cmd="show",
+        ),
+        "authkey": create_router(
+            {"corosync": cluster.authkey_corosync},
+            ["cluster", "authkey"],
+        ),
         "sync": create_router(
-            {"corosync": cluster.sync_nodes,},
+            {
+                "corosync": cluster.sync_nodes,
+            },
             ["cluster", "sync"],
             default_cmd="corosync",
         ),
