@@ -1,10 +1,6 @@
-from __future__ import (
-    absolute_import,
-    division,
-    print_function,
-)
-
 import sys
+
+# pylint: disable=wildcard-import, unused-wildcard-import
 from pycurl import *
 
 # This package defines constants which are not present in some older versions
