@@ -11,19 +11,20 @@ from pcs import (
     usage,
     utils,
 )
-from pcs.cli import (
-    constraint_colocation,
-    constraint_order,
-)
 from pcs.cli.common import parse_args
-from pcs.cli.common.console_report import warn
 from pcs.cli.common.errors import CmdLineInputError
-from pcs.cli.common.reports import process_library_reports
 import pcs.cli.constraint_colocation.command as colocation_command
 import pcs.cli.constraint_order.command as order_command
 from pcs.cli.constraint_ticket import command as ticket_command
-from pcs.common import report_codes
-from pcs.lib import reports
+from pcs.cli.reports import process_library_reports
+from pcs.cli.reports.output import warn
+from pcs.common import reports
+from pcs.common.reports import ReportItem
+from pcs.common.reports.constraints import (
+    colocation as colocation_format,
+    order as order_format,
+)
+from pcs.common.tools import Version
 from pcs.lib.cib.constraint import resource_set
 from pcs.lib.cib.constraint.order import ATTRIB as order_attrib
 from pcs.lib.node import get_existing_nodes_names
@@ -61,6 +62,7 @@ RULE_EXPIRED = "expired"
 RULE_NOT_IN_EFFECT = "not yet in effect"
 RULE_UNKNOWN_STATUS = "unknown status"
 
+
 class CrmRuleReturnCode(Enum):
     IN_EFFECT = 0
     EXPIRED = 110
@@ -109,9 +111,7 @@ def constraint_order_cmd(lib, argv, modifiers):
         else:
             order_start(lib, [sub_cmd] + argv, modifiers)
     except CmdLineInputError as e:
-        utils.exit_on_cmdline_input_errror(
-            e, "constraint", ["order", sub_cmd]
-        )
+        utils.exit_on_cmdline_input_errror(e, "constraint", ["order", sub_cmd])
 
 
 def constraint_show(lib, argv, modifiers):
@@ -143,18 +143,16 @@ def colocation_rm(lib, argv, modifiers):
     resource1 = argv[0]
     resource2 = argv[1]
 
-    for co_loc in constraintsElement.getElementsByTagName('rsc_colocation')[:]:
+    for co_loc in constraintsElement.getElementsByTagName("rsc_colocation")[:]:
         if (
             co_loc.getAttribute("rsc") == resource1
-            and
-            co_loc.getAttribute("with-rsc") == resource2
+            and co_loc.getAttribute("with-rsc") == resource2
         ):
             constraintsElement.removeChild(co_loc)
             elementFound = True
         if (
             co_loc.getAttribute("rsc") == resource2
-            and
-            co_loc.getAttribute("with-rsc") == resource1
+            and co_loc.getAttribute("with-rsc") == resource1
         ):
             constraintsElement.removeChild(co_loc)
             elementFound = True
@@ -166,11 +164,15 @@ def colocation_rm(lib, argv, modifiers):
 
 
 def _validate_constraint_resource(cib_dom, resource_id):
-    resource_valid, resource_error, dummy_correct_id \
-        = utils.validate_constraint_resource(cib_dom, resource_id)
+    (
+        resource_valid,
+        resource_error,
+        dummy_correct_id,
+    ) = utils.validate_constraint_resource(cib_dom, resource_id)
     if not resource_valid:
         utils.err(resource_error)
 
+
 # Syntax: colocation add [role] <src> with [role] <tgt> [score] [options]
 # possible commands:
 #        <src> with        <tgt> [score] [options]
@@ -183,6 +185,7 @@ def colocation_add(lib, argv, modifiers):
       * -f - CIB file
       * --force - allow constraint on any resource, allow duplicate constraints
     """
+
     def _parse_score_options(argv):
         # When passed an array of arguments if the first argument doesn't have
         # an '=' then it's the score, otherwise they're all arguments. Return a
@@ -205,8 +208,7 @@ def colocation_add(lib, argv, modifiers):
         if role_cleaned not in RESOURCE_ROLES:
             utils.err(
                 "invalid role value '{0}', allowed values are: '{1}'".format(
-                    role,
-                    "', '".join(RESOURCE_ROLES)
+                    role, "', '".join(RESOURCE_ROLES)
                 )
             )
         return role_cleaned
@@ -236,7 +238,7 @@ def colocation_add(lib, argv, modifiers):
                 "Use the 'pcs constraint colocation set' command if you want "
                 "to create a constraint for more than two resources."
             ),
-            show_both_usage_and_message=True
+            show_both_usage_and_message=True,
         )
 
     if not argv:
@@ -252,7 +254,6 @@ def colocation_add(lib, argv, modifiers):
 
     score, nv_pairs = _parse_score_options(argv)
 
-
     cib_dom = utils.get_cib_dom()
     _validate_constraint_resource(cib_dom, resource1)
     _validate_constraint_resource(cib_dom, resource2)
@@ -260,7 +261,7 @@ def colocation_add(lib, argv, modifiers):
     id_in_nvpairs = None
     for name, value in nv_pairs:
         if name == "id":
-            id_valid, id_error = utils.validate_xml_id(value, 'constraint id')
+            id_valid, id_error = utils.validate_xml_id(value, "constraint id")
             if not id_valid:
                 utils.err(id_error)
             if utils.does_id_exist(cib_dom, value):
@@ -270,13 +271,15 @@ def colocation_add(lib, argv, modifiers):
                 )
             id_in_nvpairs = True
     if not id_in_nvpairs:
-        nv_pairs.append((
-            "id",
-            utils.find_unique_id(
-                cib_dom,
-                "colocation-%s-%s-%s" % (resource1, resource2, score)
+        nv_pairs.append(
+            (
+                "id",
+                utils.find_unique_id(
+                    cib_dom,
+                    "colocation-%s-%s-%s" % (resource1, resource2, score),
+                ),
             )
-        ))
+        )
 
     (dom, constraintsElement) = getCurrentConstraints(cib_dom)
 
@@ -300,23 +303,25 @@ def colocation_add(lib, argv, modifiers):
         if duplicates:
             utils.err(
                 "duplicate constraint already exists, use --force to override\n"
-                + "\n".join([
-                    "  "
-                    +
-                    constraint_colocation.console_report.constraint_plain(
-                        {"options": dict(dup.attributes.items())},
-                        True
-                    )
-                    for dup in duplicates
-                ])
+                + "\n".join(
+                    [
+                        "  "
+                        + colocation_format.constraint_plain(
+                            {"options": dict(dup.attributes.items())}, True
+                        )
+                        for dup in duplicates
+                    ]
+                )
             )
     constraintsElement.appendChild(element)
     utils.replace_cib_configuration(dom)
 
+
 def colocation_find_duplicates(dom, constraint_el):
     """
     Commandline options: no options
     """
+
     def normalize(const_el):
         return (
             const_el.getAttribute("rsc"),
@@ -330,10 +335,11 @@ def colocation_find_duplicates(dom, constraint_el):
         other_el
         for other_el in dom.getElementsByTagName("rsc_colocation")
         if not other_el.getElementsByTagName("resource_set")
-            and constraint_el is not other_el
-            and normalized_el == normalize(other_el)
+        and constraint_el is not other_el
+        and normalized_el == normalize(other_el)
     ]
 
+
 def order_rm(lib, argv, modifiers):
     """
     Options:
@@ -348,17 +354,16 @@ def order_rm(lib, argv, modifiers):
     (dom, constraintsElement) = getCurrentConstraints()
 
     for resource in argv:
-        for ord_loc in constraintsElement.getElementsByTagName('rsc_order')[:]:
+        for ord_loc in constraintsElement.getElementsByTagName("rsc_order")[:]:
             if (
                 ord_loc.getAttribute("first") == resource
-                or
-                ord_loc.getAttribute("then") == resource
+                or ord_loc.getAttribute("then") == resource
             ):
                 constraintsElement.removeChild(ord_loc)
                 elementFound = True
 
         resource_refs_to_remove = []
-        for ord_set in constraintsElement.getElementsByTagName('resource_ref'):
+        for ord_set in constraintsElement.getElementsByTagName("resource_ref"):
             if ord_set.getAttribute("id") == resource:
                 resource_refs_to_remove.append(ord_set)
                 elementFound = True
@@ -368,9 +373,9 @@ def order_rm(lib, argv, modifiers):
             res_order = res_set.parentNode
 
             res_ref.parentNode.removeChild(res_ref)
-            if not res_set.getElementsByTagName('resource_ref'):
+            if not res_set.getElementsByTagName("resource_ref"):
                 res_set.parentNode.removeChild(res_set)
-                if not res_order.getElementsByTagName('resource_set'):
+                if not res_order.getElementsByTagName("resource_set"):
                     res_order.parentNode.removeChild(res_order)
 
     if elementFound:
@@ -378,6 +383,7 @@ def order_rm(lib, argv, modifiers):
     else:
         utils.err("No matching resources found in ordering list")
 
+
 def order_start(lib, argv, modifiers):
     """
     Options:
@@ -422,13 +428,14 @@ def order_start(lib, argv, modifiers):
                 "Use the 'pcs constraint order set' command if you want to "
                 "create a constraint for more than two resources."
             ),
-            show_both_usage_and_message=True
+            show_both_usage_and_message=True,
         )
 
-    order_options.append("first-action="+first_action)
-    order_options.append("then-action="+then_action)
+    order_options.append("first-action=" + first_action)
+    order_options.append("then-action=" + then_action)
     _order_add(resource1, resource2, order_options, modifiers)
 
+
 def _order_add(resource1, resource2, options_list, modifiers):
     """
     Commandline options:
@@ -451,8 +458,7 @@ def _order_add(resource1, resource2, options_list, modifiers):
             name, value = parse_args.split_option(arg, allow_empty_value=False)
             if name == "id":
                 id_valid, id_error = utils.validate_xml_id(
-                    value,
-                    'constraint id'
+                    value, "constraint id"
                 )
                 if not id_valid:
                     utils.err(id_error)
@@ -478,11 +484,13 @@ def _order_add(resource1, resource2, options_list, modifiers):
 
     options = ""
     if order_options:
-        options = " (Options: %s)" % " ".join([
-            "%s=%s" % (name, value)
+        options = " (Options: %s)" % " ".join(
+            [
+                "%s=%s" % (name, value)
                 for name, value in order_options
-                    if name not in ("kind", "score")
-        ])
+                if name not in ("kind", "score")
+            ]
+        )
 
     scorekind = "kind: Mandatory"
     id_suffix = "mandatory"
@@ -513,29 +521,42 @@ def _order_add(resource1, resource2, options_list, modifiers):
         if duplicates:
             utils.err(
                 "duplicate constraint already exists, use --force to override\n"
-                + "\n".join([
-                    "  " + constraint_order.console_report.constraint_plain(
-                            {"options": dict(dup.attributes.items())},
-                            True
-                        ) for dup in duplicates
-                ])
+                + "\n".join(
+                    [
+                        "  "
+                        + order_format.constraint_plain(
+                            {"options": dict(dup.attributes.items())}, True
+                        )
+                        for dup in duplicates
+                    ]
+                )
             )
     print(
-        "Adding " + resource1 + " " + resource2 + " ("+scorekind+")" + options
+        "Adding "
+        + resource1
+        + " "
+        + resource2
+        + " ("
+        + scorekind
+        + ")"
+        + options
     )
 
     utils.replace_cib_configuration(dom)
 
+
 def order_find_duplicates(dom, constraint_el):
     """
     Commandline options: no options
     """
+
     def normalize(constraint_el):
         # pylint: disable=line-too-long
         return (
             constraint_el.getAttribute("first"),
             constraint_el.getAttribute("then"),
-            constraint_el.getAttribute("first-action").lower() or DEFAULT_ACTION,
+            constraint_el.getAttribute("first-action").lower()
+            or DEFAULT_ACTION,
             constraint_el.getAttribute("then-action").lower() or DEFAULT_ACTION,
         )
 
@@ -544,10 +565,11 @@ def order_find_duplicates(dom, constraint_el):
         other_el
         for other_el in dom.getElementsByTagName("rsc_order")
         if not other_el.getElementsByTagName("resource_set")
-            and constraint_el is not other_el
-            and normalized_el == normalize(other_el)
+        and constraint_el is not other_el
+        and normalized_el == normalize(other_el)
     ]
 
+
 # Show the currently configured location constraints by node or resource
 def location_show(lib, argv, modifiers):
     """
@@ -571,7 +593,7 @@ def location_show(lib, argv, modifiers):
                 parse_args.parse_typed_arg(
                     arg,
                     [RESOURCE_TYPE_RESOURCE, RESOURCE_TYPE_REGEXP],
-                    RESOURCE_TYPE_RESOURCE
+                    RESOURCE_TYPE_RESOURCE,
                 )
                 for arg in argv[1:]
             ]
@@ -579,17 +601,26 @@ def location_show(lib, argv, modifiers):
         valid_noderes = []
 
     (dummy_dom, constraintsElement) = getCurrentConstraints()
-    print("\n".join(location_lines(
-        constraintsElement,
-        showDetail=modifiers.get("--full"),
-        byNode=by_node,
-        valid_noderes=valid_noderes,
-        show_expired=modifiers.get("--all"),
-    )))
+    print(
+        "\n".join(
+            location_lines(
+                constraintsElement,
+                showDetail=modifiers.get("--full"),
+                byNode=by_node,
+                valid_noderes=valid_noderes,
+                show_expired=modifiers.get("--all"),
+            )
+        )
+    )
+
 
 def location_lines(
-    constraintsElement, showDetail=False, byNode=False, valid_noderes=None,
-    show_expired=False, verify_expiration=True
+    constraintsElement,
+    showDetail=False,
+    byNode=False,
+    valid_noderes=None,
+    show_expired=False,
+    verify_expiration=True,
 ):
     """
     Commandline options: no options
@@ -601,7 +632,7 @@ def location_lines(
     rschashoff = {}
     ruleshash = defaultdict(list)
     all_loc_constraints = constraintsElement.getElementsByTagName(
-        'rsc_location'
+        "rsc_location"
     )
     cib = utils.get_cib()
 
@@ -631,8 +662,8 @@ def location_lines(
             if child.nodeType == child.ELEMENT_NODE and child.tagName == "rule":
                 ruleshash[lc_rsc].append(child)
 
-# NEED TO FIX FOR GROUP LOCATION CONSTRAINTS (where there are children of
-# rsc_location)
+        # NEED TO FIX FOR GROUP LOCATION CONSTRAINTS (where there are children
+        # of # rsc_location)
         if lc_score == "":
             lc_score = "0"
 
@@ -679,8 +710,8 @@ def location_lines(
                 RESOURCE_TYPE_RESOURCE: 1,
                 RESOURCE_TYPE_REGEXP: 0,
             }[item[0]],
-            item[1]
-        )
+            item[1],
+        ),
     )
 
     if byNode:
@@ -692,14 +723,17 @@ def location_lines(
 
             nodehash_label = (
                 (nodehashon, "    Allowed to run:"),
-                (nodehashoff, "    Not allowed to run:")
+                (nodehashoff, "    Not allowed to run:"),
             )
             all_lines += _hashtable_to_lines(
                 nodehash_label, "rsc_label", node, showDetail
             )
         all_lines += _show_location_rules(
-            ruleshash, cib, show_detail=showDetail, show_expired=show_expired,
-            verify_expiration=verify_expiration
+            ruleshash,
+            cib,
+            show_detail=showDetail,
+            show_expired=show_expired,
+            verify_expiration=verify_expiration,
         )
     else:
         for rsc in rsclist:
@@ -730,6 +764,7 @@ def location_lines(
                 all_lines += rsc_lines
     return all_lines
 
+
 def _hashtable_to_lines(hash_label, hash_type, hash_key, show_detail):
     hash_lines = []
     for hashtable, label in hash_label:
@@ -739,10 +774,12 @@ def _hashtable_to_lines(hash_label, hash_type, hash_key, show_detail):
                 # Skips nodeless constraints and prints nodes/resources
                 if not options[hash_type]:
                     continue
-                line_parts = ["      {0}{1}".format(
-                    "Node: " if hash_type == "node" else "",
-                    options[hash_type]
-                )]
+                line_parts = [
+                    "      {0}{1}".format(
+                        "Node: " if hash_type == "node" else "",
+                        options[hash_type],
+                    )
+                ]
                 line_parts.append(f"(score:{options['score']})")
                 if options["role"]:
                     line_parts.append(f"(role:{options['role']})")
@@ -760,9 +797,14 @@ def _hashtable_to_lines(hash_label, hash_type, hash_key, show_detail):
             hash_lines += labeled_lines
     return hash_lines
 
+
 def _show_location_rules(
-        ruleshash, cib, show_detail, show_expired=False, verify_expiration=True,
-        noheader=False
+    ruleshash,
+    cib,
+    show_detail,
+    show_expired=False,
+    verify_expiration=True,
+    noheader=False,
 ):
     """
     Commandline options: no options
@@ -776,8 +818,8 @@ def _show_location_rules(
                 RESOURCE_TYPE_RESOURCE: 1,
                 RESOURCE_TYPE_REGEXP: 0,
             }[item[0]],
-            item[1]
-        )
+            item[1],
+        ),
     ):
         constrainthash = defaultdict(list)
         if not noheader:
@@ -788,16 +830,14 @@ def _show_location_rules(
             constraint_options[constraint_id] = []
             if rule.parentNode.getAttribute("resource-discovery"):
                 constraint_options[constraint_id].append(
-                    "resource-discovery=%s" % rule.parentNode.getAttribute(
-                        "resource-discovery"
-                    )
+                    "resource-discovery=%s"
+                    % rule.parentNode.getAttribute("resource-discovery")
                 )
 
         for constraint_id in sorted(constrainthash.keys()):
             if (
                 constraint_id in constraint_options
-                and
-                constraint_options[constraint_id]
+                and constraint_options[constraint_id]
             ):
                 constraint_option_info = (
                     " (" + " ".join(constraint_options[constraint_id]) + ")"
@@ -817,12 +857,14 @@ def _show_location_rules(
                     if rule_status != RULE_EXPIRED:
                         is_constraint_expired = False
 
-                rule_lines.append(rule_utils.ExportDetailed().get_string(
-                    rule,
-                    rule_status == RULE_EXPIRED and show_expired,
-                    show_detail,
-                    indent="      "
-                ))
+                rule_lines.append(
+                    rule_utils.ExportDetailed().get_string(
+                        rule,
+                        rule_status == RULE_EXPIRED and show_expired,
+                        show_detail,
+                        indent="      ",
+                    )
+                )
 
             if not show_expired and is_constraint_expired:
                 continue
@@ -831,32 +873,36 @@ def _show_location_rules(
                 "    Constraint{0}: {1}{2}".format(
                     " (expired)" if is_constraint_expired else "",
                     constraint_id,
-                    constraint_option_info
+                    constraint_option_info,
                 )
             )
             all_lines += rule_lines
     return all_lines
 
+
 def _verify_node_name(node, existing_nodes):
     report_list = []
     if node not in existing_nodes:
-        report_list.append(reports.node_not_found(
-            node,
-            forceable=report_codes.FORCE_NODE_DOES_NOT_EXIST
-        ))
+        report_list.append(
+            ReportItem.error(
+                reports.messages.NodeNotFound(node),
+                force_code=reports.codes.FORCE_NODE_DOES_NOT_EXIST,
+            )
+        )
     return report_list
 
+
 def _verify_score(score):
     if not utils.is_score(score):
         utils.err(
-            "invalid score '%s', use integer or INFINITY or -INFINITY"
-            % score
+            "invalid score '%s', use integer or INFINITY or -INFINITY" % score
         )
 
+
 def _get_rule_status(rule_id, cib):
     _, _, retval = utils.cmd_runner().run(
-        [settings.crm_rule, "--check", "--rule=" + rule_id, "-X-"],
-        cib
+        [settings.crm_rule, "--check", "--rule", rule_id, "--xml-text", "-"],
+        cib,
     )
     translation_map = {
         CrmRuleReturnCode.IN_EFFECT.value: RULE_IN_EFFECT,
@@ -865,6 +911,7 @@ def _get_rule_status(rule_id, cib):
     }
     return translation_map.get(retval, RULE_UNKNOWN_STATUS)
 
+
 def location_prefer(lib, argv, modifiers):
     """
     Options:
@@ -878,7 +925,7 @@ def location_prefer(lib, argv, modifiers):
     dummy_rsc_type, rsc_value = parse_args.parse_typed_arg(
         rsc,
         [RESOURCE_TYPE_RESOURCE, RESOURCE_TYPE_REGEXP],
-        RESOURCE_TYPE_RESOURCE
+        RESOURCE_TYPE_RESOURCE,
     )
 
     if prefer_option == "prefers":
@@ -922,12 +969,14 @@ def location_prefer(lib, argv, modifiers):
                 else:
                     score = "-" + score
 
-        parameters_list.append([
-            sanitize_id(f"location-{rsc_value}-{node}-{score}"),
-            rsc,
-            node,
-            score
-        ])
+        parameters_list.append(
+            [
+                sanitize_id(f"location-{rsc_value}-{node}-{score}"),
+                rsc,
+                node,
+                score,
+            ]
+        )
 
     if report_list:
         process_library_reports(report_list)
@@ -953,7 +1002,7 @@ def location_add(lib, argv, modifiers, skip_score_and_node_check=False):
     rsc_type, rsc_value = parse_args.parse_typed_arg(
         argv.pop(0),
         [RESOURCE_TYPE_RESOURCE, RESOURCE_TYPE_REGEXP],
-        RESOURCE_TYPE_RESOURCE
+        RESOURCE_TYPE_RESOURCE,
     )
     node = argv.pop(0)
     score = argv.pop(0)
@@ -961,14 +1010,12 @@ def location_add(lib, argv, modifiers, skip_score_and_node_check=False):
     # For now we only allow setting resource-discovery
     if argv:
         for arg in argv:
-            if '=' in arg:
-                options.append(arg.split('=', 1))
+            if "=" in arg:
+                options.append(arg.split("=", 1))
             else:
                 raise CmdLineInputError(f"bad option '{arg}'")
-            if (
-                options[-1][0] != "resource-discovery"
-                and
-                not modifiers.get("--force")
+            if options[-1][0] != "resource-discovery" and not modifiers.get(
+                "--force"
             ):
                 utils.err(
                     "bad option '%s', use --force to override" % options[-1][0]
@@ -989,7 +1036,7 @@ def location_add(lib, argv, modifiers, skip_score_and_node_check=False):
                 process_library_reports(report_list)
         _verify_score(score)
 
-    id_valid, id_error = utils.validate_xml_id(constraint_id, 'constraint id')
+    id_valid, id_error = utils.validate_xml_id(constraint_id, "constraint id")
     if not id_valid:
         utils.err(id_error)
 
@@ -1005,9 +1052,11 @@ def location_add(lib, argv, modifiers, skip_score_and_node_check=False):
         dom = utils.get_cib_dom()
 
     if rsc_type == RESOURCE_TYPE_RESOURCE:
-        rsc_valid, rsc_error, dummy_correct_id = (
-            utils.validate_constraint_resource(dom, rsc_value)
-        )
+        (
+            rsc_valid,
+            rsc_error,
+            dummy_correct_id,
+        ) = utils.validate_constraint_resource(dom, rsc_value)
         if not rsc_valid:
             utils.err(rsc_error)
 
@@ -1016,26 +1065,18 @@ def location_add(lib, argv, modifiers, skip_score_and_node_check=False):
     dummy_dom, constraintsElement = getCurrentConstraints(dom)
     elementsToRemove = []
     # If the id matches, or the rsc & node match, then we replace/remove
-    for rsc_loc in constraintsElement.getElementsByTagName('rsc_location'):
+    for rsc_loc in constraintsElement.getElementsByTagName("rsc_location"):
         # pylint: disable=too-many-boolean-expressions
-        if (
-            rsc_loc.getAttribute("id") == constraint_id
-            or
-            (
-                rsc_loc.getAttribute("node") == node
-                and
+        if rsc_loc.getAttribute("id") == constraint_id or (
+            rsc_loc.getAttribute("node") == node
+            and (
                 (
-                    (
-                        RESOURCE_TYPE_RESOURCE == rsc_type
-                        and
-                        rsc_loc.getAttribute("rsc") == rsc_value
-                    )
-                    or
-                    (
-                        RESOURCE_TYPE_REGEXP == rsc_type
-                        and
-                        rsc_loc.getAttribute("rsc-pattern") == rsc_value
-                    )
+                    RESOURCE_TYPE_RESOURCE == rsc_type
+                    and rsc_loc.getAttribute("rsc") == rsc_value
+                )
+                or (
+                    RESOURCE_TYPE_REGEXP == rsc_type
+                    and rsc_loc.getAttribute("rsc-pattern") == rsc_value
                 )
             )
         ):
@@ -1057,6 +1098,7 @@ def location_add(lib, argv, modifiers, skip_score_and_node_check=False):
 
     utils.replace_cib_configuration(dom)
 
+
 def location_remove(lib, argv, modifiers):
     """
     Options:
@@ -1079,7 +1121,7 @@ def location_remove(lib, argv, modifiers):
     dom, constraintsElement = getCurrentConstraints()
 
     elementsToRemove = []
-    for rsc_loc in constraintsElement.getElementsByTagName('rsc_location'):
+    for rsc_loc in constraintsElement.getElementsByTagName("rsc_location"):
         if constraint_id == rsc_loc.getAttribute("id"):
             elementsToRemove.append(rsc_loc)
 
@@ -1090,6 +1132,7 @@ def location_remove(lib, argv, modifiers):
 
     utils.replace_cib_configuration(dom)
 
+
 def location_rule(lib, argv, modifiers):
     """
     Options:
@@ -1106,22 +1149,32 @@ def location_rule(lib, argv, modifiers):
     rsc_type, rsc_value = parse_args.parse_typed_arg(
         argv.pop(0),
         [RESOURCE_TYPE_RESOURCE, RESOURCE_TYPE_REGEXP],
-        RESOURCE_TYPE_RESOURCE
+        RESOURCE_TYPE_RESOURCE,
     )
-    argv.pop(0) # pop "rule"
+    argv.pop(0)  # pop "rule"
     options, rule_argv = rule_utils.parse_argv(
         argv,
         {
             "constraint-id": None,
             "resource-discovery": None,
-        }
+        },
     )
     resource_discovery = (
-        "resource-discovery" in options
-        and
-        options["resource-discovery"]
+        "resource-discovery" in options and options["resource-discovery"]
     )
 
+    try:
+        # Parse the rule to see if we need to upgrade CIB schema. All errors
+        # would be properly reported by a validator called bellow, so we can
+        # safely ignore them here.
+        parsed_rule = rule_utils.RuleParser().parse(
+            rule_utils.TokenPreprocessor().run(rule_argv)
+        )
+        if rule_utils.has_node_attr_expr_with_type_integer(parsed_rule):
+            utils.checkAndUpgradeCIB(3, 5, 0)
+    except (rule_utils.ParserException, rule_utils.CibBuilderException):
+        pass
+
     required_version = None
     if resource_discovery:
         required_version = 2, 2, 0
@@ -1134,9 +1187,11 @@ def location_rule(lib, argv, modifiers):
         dom = utils.get_cib_dom()
 
     if rsc_type == RESOURCE_TYPE_RESOURCE:
-        rsc_valid, rsc_error, dummy_correct_id = (
-            utils.validate_constraint_resource(dom, rsc_value)
-        )
+        (
+            rsc_valid,
+            rsc_error,
+            dummy_correct_id,
+        ) = utils.validate_constraint_resource(dom, rsc_value)
         if not rsc_valid:
             utils.err(rsc_error)
 
@@ -1151,7 +1206,7 @@ def location_rule(lib, argv, modifiers):
     constraints.appendChild(lc)
     if options.get("constraint-id"):
         id_valid, id_error = utils.validate_xml_id(
-            options["constraint-id"], 'constraint id'
+            options["constraint-id"], "constraint id"
         )
         if not id_valid:
             utils.err(id_error)
@@ -1165,17 +1220,20 @@ def location_rule(lib, argv, modifiers):
     else:
         lc.setAttribute(
             "id",
-            utils.find_unique_id(dom, sanitize_id("location-" + rsc_value))
+            utils.find_unique_id(dom, sanitize_id("location-" + rsc_value)),
         )
     if rsc_type == RESOURCE_TYPE_RESOURCE:
         lc.setAttribute("rsc", rsc_value)
     elif rsc_type == RESOURCE_TYPE_REGEXP:
         lc.setAttribute("rsc-pattern", rsc_value)
 
-    rule_utils.dom_rule_add(lc, options, rule_argv)
+    rule_utils.dom_rule_add(
+        lc, options, rule_argv, Version(*utils.getValidateWithVersion(cib))
+    )
     location_rule_check_duplicates(constraints, lc, modifiers.get("--force"))
     utils.replace_cib_configuration(cib)
 
+
 def location_rule_check_duplicates(dom, constraint_el, force):
     """
     Commandline options: no options
@@ -1187,35 +1245,36 @@ def location_rule_check_duplicates(dom, constraint_el, force):
             for dup in duplicates:
                 lines.append("  Constraint: %s" % dup.getAttribute("id"))
                 for dup_rule in utils.dom_get_children_by_tag_name(dup, "rule"):
-                    lines.append(rule_utils.ExportDetailed().get_string(
-                        dup_rule, False, True, indent="    "
-                    ))
+                    lines.append(
+                        rule_utils.ExportDetailed().get_string(
+                            dup_rule, False, True, indent="    "
+                        )
+                    )
             utils.err(
                 "duplicate constraint already exists, use --force to override\n"
                 + "\n".join(lines)
             )
 
+
 def location_rule_find_duplicates(dom, constraint_el):
     """
     Commandline options: no options
     """
+
     def normalize(constraint_el):
         if constraint_el.hasAttribute("rsc-pattern"):
             rsc = (
                 RESOURCE_TYPE_REGEXP,
-                constraint_el.getAttribute("rsc-pattern")
+                constraint_el.getAttribute("rsc-pattern"),
             )
         else:
-            rsc = (
-                RESOURCE_TYPE_RESOURCE,
-                constraint_el.getAttribute("rsc")
-            )
+            rsc = (RESOURCE_TYPE_RESOURCE, constraint_el.getAttribute("rsc"))
         return (
             rsc,
             [
                 rule_utils.ExportAsExpression().get_string(rule_el, True)
                 for rule_el in constraint_el.getElementsByTagName("rule")
-            ]
+            ],
         )
 
     normalized_el = normalize(constraint_el)
@@ -1223,10 +1282,11 @@ def location_rule_find_duplicates(dom, constraint_el):
         other_el
         for other_el in dom.getElementsByTagName("rsc_location")
         if other_el.getElementsByTagName("rule")
-            and constraint_el is not other_el
-            and normalized_el == normalize(other_el)
+        and constraint_el is not other_el
+        and normalized_el == normalize(other_el)
     ]
 
+
 # Grabs the current constraints and returns the dom and constraint element
 def getCurrentConstraints(passed_dom=None):
     """
@@ -1236,21 +1296,26 @@ def getCurrentConstraints(passed_dom=None):
     if passed_dom:
         dom = passed_dom
     else:
-        current_constraints_xml = utils.get_cib_xpath('//constraints')
+        current_constraints_xml = utils.get_cib_xpath("//constraints")
         if current_constraints_xml == "":
             utils.err("unable to process cib")
         # Verify current constraint doesn't already exist
         # If it does we replace it with the new constraint
         dom = parseString(current_constraints_xml)
 
-    constraintsElement = dom.getElementsByTagName('constraints')[0]
+    constraintsElement = dom.getElementsByTagName("constraints")[0]
     return (dom, constraintsElement)
 
+
 # If returnStatus is set, then we don't error out, we just print the error
 # and return false
 def constraint_rm(
-    lib, argv, modifiers,
-    returnStatus=False, constraintsElement=None, passed_dom=None,
+    lib,
+    argv,
+    modifiers,
+    returnStatus=False,
+    constraintsElement=None,
+    passed_dom=None,
 ):
     """
     Options:
@@ -1333,6 +1398,7 @@ def constraint_ref(lib, argv, modifiers):
             for constraint in sorted(set_constraints):
                 print("  " + constraint)
 
+
 def remove_constraints_containing(
     resource_id, output=False, constraints_element=None, passed_dom=None
 ):
@@ -1343,16 +1409,19 @@ def remove_constraints_containing(
     lib = utils.get_library_wrapper()
     modifiers = utils.get_input_modifiers()
     constraints, set_constraints = find_constraints_containing(
-        resource_id,
-        passed_dom
+        resource_id, passed_dom
     )
     for c in constraints:
         if output:
             print("Removing Constraint - " + c)
         if constraints_element is not None:
             constraint_rm(
-                lib, [c], modifiers, True, constraints_element,
-                passed_dom=passed_dom
+                lib,
+                [c],
+                modifiers,
+                True,
+                constraints_element,
+                passed_dom=passed_dom,
             )
         else:
             constraint_rm(lib, [c], modifiers, passed_dom=passed_dom)
@@ -1383,6 +1452,7 @@ def remove_constraints_containing(
         utils.replace_cib_configuration(dom)
     return None
 
+
 def find_constraints_containing(resource_id, passed_dom=None):
     """
     Commandline options:
@@ -1405,12 +1475,10 @@ def find_constraints_containing(resource_id, passed_dom=None):
     if resource_match:
         if (
             resource_match.parentNode.tagName == "master"
-            or
-            resource_match.parentNode.tagName == "clone"
+            or resource_match.parentNode.tagName == "clone"
         ):
             constraints_found, set_constraints = find_constraints_containing(
-                resource_match.parentNode.getAttribute("id"),
-                dom
+                resource_match.parentNode.getAttribute("id"), dom
             )
 
     constraints = dom.getElementsByTagName("constraints")
@@ -1438,6 +1506,7 @@ def find_constraints_containing(resource_id, passed_dom=None):
     set_constraints = list(set(set_constraints))
     return constraints_found, set_constraints
 
+
 def remove_constraints_containing_node(dom, node, output=False):
     """
     Commandline options: no options
@@ -1448,6 +1517,7 @@ def remove_constraints_containing_node(dom, node, output=False):
         constraint.parentNode.removeChild(constraint)
     return dom
 
+
 def find_constraints_containing_node(dom, node):
     """
     Commandline options: no options
@@ -1455,9 +1525,10 @@ def find_constraints_containing_node(dom, node):
     return [
         constraint
         for constraint in dom.getElementsByTagName("rsc_location")
-            if constraint.getAttribute("node") == node
+        if constraint.getAttribute("node") == node
     ]
 
+
 # Re-assign any constraints referencing a resource to its parent (a clone
 # or master)
 def constraint_resource_update(old_id, dom):
@@ -1480,6 +1551,7 @@ def constraint_resource_update(old_id, dom):
                     constraint.setAttribute(attr, new_id)
     return dom
 
+
 def constraint_rule(lib, argv, modifiers):
     """
     Options:
@@ -1495,26 +1567,39 @@ def constraint_rule(lib, argv, modifiers):
     found = False
     command = argv.pop(0)
 
-
     constraint_id = None
 
     if command == "add":
         modifiers.ensure_only_supported("-f", "--force")
         constraint_id = argv.pop(0)
+        options, rule_argv = rule_utils.parse_argv(argv)
+        try:
+            # Parse the rule to see if we need to upgrade CIB schema. All errors
+            # would be properly reported by a validator called bellow, so we can
+            # safely ignore them here.
+            parsed_rule = rule_utils.RuleParser().parse(
+                rule_utils.TokenPreprocessor().run(rule_argv)
+            )
+            if rule_utils.has_node_attr_expr_with_type_integer(parsed_rule):
+                utils.checkAndUpgradeCIB(3, 5, 0)
+        except (rule_utils.ParserException, rule_utils.CibBuilderException):
+            pass
         cib = utils.get_cib_dom()
         constraint = utils.dom_get_element_with_id(
             cib.getElementsByTagName("constraints")[0],
             "rsc_location",
-            constraint_id
+            constraint_id,
         )
         if not constraint:
             utils.err("Unable to find constraint: " + constraint_id)
-        options, rule_argv = rule_utils.parse_argv(argv)
-        rule_utils.dom_rule_add(constraint, options, rule_argv)
-        location_rule_check_duplicates(
-            cib,
+        rule_utils.dom_rule_add(
             constraint,
-            modifiers.get("--force")
+            options,
+            rule_argv,
+            Version(*utils.getValidateWithVersion(cib)),
+        )
+        location_rule_check_duplicates(
+            cib, constraint, modifiers.get("--force")
         )
         utils.replace_cib_configuration(cib)
 
@@ -1522,8 +1607,8 @@ def constraint_rule(lib, argv, modifiers):
         modifiers.ensure_only_supported("-f")
         cib = utils.get_cib_etree()
         temp_id = argv.pop(0)
-        constraints = cib.find('.//constraints')
-        loc_cons = cib.findall(str('.//rsc_location'))
+        constraints = cib.find(".//constraints")
+        loc_cons = cib.findall(str(".//rsc_location"))
 
         for loc_con in loc_cons:
             for rule in loc_con:
