@@ -1,5 +1,8 @@
-from pcs.common import file_type_codes
-from pcs.lib import reports as common_reports
+from pcs.common import (
+    file_type_codes,
+    reports,
+)
+from pcs.common.reports.item import ReportItem
 from pcs.lib.booth import (
     config_validators,
     constants,
@@ -9,7 +12,7 @@ from pcs.lib.file.instance import FileInstance
 from pcs.lib.errors import LibraryError
 
 
-class BoothEnv():
+class BoothEnv:
     def __init__(self, instance_name, booth_files_data):
         """
         Create a new BoothEnv
@@ -19,24 +22,26 @@ class BoothEnv():
         """
         if (
             "config_data" in booth_files_data
-            and
-            "key_data" not in booth_files_data
+            and "key_data" not in booth_files_data
         ):
             raise LibraryError(
-                common_reports.live_environment_not_consistent(
-                    [file_type_codes.BOOTH_CONFIG],
-                    [file_type_codes.BOOTH_KEY],
+                ReportItem.error(
+                    reports.messages.LiveEnvironmentNotConsistent(
+                        [file_type_codes.BOOTH_CONFIG],
+                        [file_type_codes.BOOTH_KEY],
+                    )
                 )
             )
         if (
             "config_data" not in booth_files_data
-            and
-            "key_data" in booth_files_data
+            and "key_data" in booth_files_data
         ):
             raise LibraryError(
-                common_reports.live_environment_not_consistent(
-                    [file_type_codes.BOOTH_KEY],
-                    [file_type_codes.BOOTH_CONFIG],
+                ReportItem.error(
+                    reports.messages.LiveEnvironmentNotConsistent(
+                        [file_type_codes.BOOTH_KEY],
+                        [file_type_codes.BOOTH_CONFIG],
+                    )
                 )
             )
 
@@ -47,11 +52,11 @@ class BoothEnv():
 
         self._config_file = FileInstance.for_booth_config(
             f"{self._instance_name}.conf",
-            **self._init_file_data(booth_files_data, "config_data")
+            **self._init_file_data(booth_files_data, "config_data"),
         )
         self._key_file = FileInstance.for_booth_key(
             f"{self._instance_name}.key",
-            **self._init_file_data(booth_files_data, "key_data")
+            **self._init_file_data(booth_files_data, "key_data"),
         )
         if isinstance(self._key_file.raw_file, raw_file.GhostFile):
             self._key_path = booth_files_data.get("key_path", "")
@@ -106,8 +111,7 @@ class BoothEnv():
 
     def create_facade(self, site_list, arbitrator_list):
         return self._config_file.toolbox.facade.create(
-            site_list,
-            arbitrator_list
+            site_list, arbitrator_list
         )
 
     def export(self):
