@@ -1,9 +1,10 @@
 from functools import partial
 from lxml import etree
 
-from pcs.common import report_codes
-from pcs.lib import reports
-from pcs.lib.errors import ReportItemSeverity as Severities
+from pcs.common import reports
+from pcs.common.reports import ReportProcessor
+from pcs.common.reports.item import ReportItem
+from pcs.lib.errors import LibraryError
 from pcs.lib.cib.nvpair import get_nvset
 from pcs.lib.cib.tools import (
     check_new_id_applicable,
@@ -20,6 +21,7 @@ TAG_RECIPIENT = "recipient"
 find_alert = partial(find_element_by_tag_and_id, TAG_ALERT)
 find_recipient = partial(find_element_by_tag_and_id, TAG_RECIPIENT)
 
+
 def _update_optional_attribute(element, attribute, value):
     """
     Update optional attribute of element. Remove existing element if value
@@ -36,8 +38,13 @@ def _update_optional_attribute(element, attribute, value):
     elif attribute in element.attrib:
         del element.attrib[attribute]
 
+
 def ensure_recipient_value_is_unique(
-    reporter, alert, recipient_value, recipient_id="", allow_duplicity=False
+    reporter: ReportProcessor,
+    alert,
+    recipient_value,
+    recipient_id="",
+    allow_duplicity=False,
 ):
     """
     Ensures that recipient_value is unique in alert.
@@ -55,15 +62,20 @@ def ensure_recipient_value_is_unique(
         )
     )
     if recipient_list:
-        reporter.process(reports.cib_alert_recipient_already_exists(
-            alert.get("id", None),
-            recipient_value,
-            Severities.WARNING if allow_duplicity else Severities.ERROR,
-            forceable=(
-                None if allow_duplicity
-                else report_codes.FORCE_ALERT_RECIPIENT_VALUE_NOT_UNIQUE
+        reporter.report(
+            ReportItem(
+                severity=reports.item.get_severity(
+                    reports.codes.FORCE_ALERT_RECIPIENT_VALUE_NOT_UNIQUE,
+                    allow_duplicity,
+                ),
+                message=reports.messages.CibAlertRecipientAlreadyExists(
+                    alert.get("id", None),
+                    recipient_value,
+                ),
             )
-        ))
+        )
+        if reporter.has_errors:
+            raise LibraryError()
 
 
 def create_alert(tree, alert_id, path, description=""):
@@ -119,13 +131,13 @@ def remove_alert(tree, alert_id):
 
 
 def add_recipient(
-    reporter,
+    reporter: ReportProcessor,
     tree,
     alert_id,
     recipient_value,
     recipient_id=None,
     description="",
-    allow_same_value=False
+    allow_same_value=False,
 ):
     """
     Add recipient to alert with specified id. Returns added recipient element.
@@ -154,18 +166,18 @@ def add_recipient(
     )
 
     if description:
-        recipient.set("description", description)
+        recipient.attrib["description"] = description
 
     return recipient
 
 
 def update_recipient(
-    reporter,
+    reporter: ReportProcessor,
     tree,
     recipient_id,
     recipient_value=None,
     description=None,
-    allow_same_value=False
+    allow_same_value=False,
 ):
     """
     Update specified recipient. Returns updated recipient element.
@@ -186,7 +198,7 @@ def update_recipient(
             recipient.getparent(),
             recipient_value,
             recipient_id=recipient_id,
-            allow_duplicity=allow_same_value
+            allow_duplicity=allow_same_value,
         )
         recipient.set("value", recipient_value)
     _update_optional_attribute(recipient, "description", description)
@@ -222,17 +234,19 @@ def get_all_recipients(alert):
     """
     recipient_list = []
     for recipient in alert.findall("./recipient"):
-        recipient_list.append({
-            "id": recipient.get("id"),
-            "value": recipient.get("value"),
-            "description": recipient.get("description", ""),
-            "instance_attributes": get_nvset(
-                get_sub_element(recipient, "instance_attributes")
-            ),
-            "meta_attributes": get_nvset(
-                get_sub_element(recipient, "meta_attributes")
-            )
-        })
+        recipient_list.append(
+            {
+                "id": recipient.get("id"),
+                "value": recipient.get("value"),
+                "description": recipient.get("description", ""),
+                "instance_attributes": get_nvset(
+                    get_sub_element(recipient, "instance_attributes")
+                ),
+                "meta_attributes": get_nvset(
+                    get_sub_element(recipient, "meta_attributes")
+                ),
+            }
+        )
     return recipient_list
 
 
@@ -254,16 +268,18 @@ def get_all_alerts(tree):
     """
     alert_list = []
     for alert in get_alerts(tree).findall("./alert"):
-        alert_list.append({
-            "id": alert.get("id"),
-            "path": alert.get("path"),
-            "description": alert.get("description", ""),
-            "instance_attributes": get_nvset(
-                get_sub_element(alert, "instance_attributes")
-            ),
-            "meta_attributes": get_nvset(
-                get_sub_element(alert, "meta_attributes")
-            ),
-            "recipient_list": get_all_recipients(alert)
-        })
+        alert_list.append(
+            {
+                "id": alert.get("id"),
+                "path": alert.get("path"),
+                "description": alert.get("description", ""),
+                "instance_attributes": get_nvset(
+                    get_sub_element(alert, "instance_attributes")
+                ),
+                "meta_attributes": get_nvset(
+                    get_sub_element(alert, "meta_attributes")
+                ),
+                "recipient_list": get_all_recipients(alert),
+            }
+        )
     return alert_list
