@@ -2,14 +2,12 @@ from functools import partial
 from lxml import etree
 
 from pcs.lib.cib.tools import create_subelement_id
-from pcs.lib.xml_tools import (
-    get_sub_element,
-    append_when_useful
-)
+from pcs.lib.xml_tools import get_sub_element, append_when_useful
 
 META_ATTRIBUTES_TAG = "meta_attributes"
 INSTANCE_ATTRIBUTES_TAG = "instance_attributes"
 
+
 def _append_new_nvpair(nvset_element, name, value, id_provider):
     """
     Create nvpair with name and value as subelement of nvset_element.
@@ -24,9 +22,10 @@ def _append_new_nvpair(nvset_element, name, value, id_provider):
         "nvpair",
         id=create_subelement_id(nvset_element, name, id_provider),
         name=name,
-        value=value
+        value=value,
     )
 
+
 def set_nvpair_in_nvset(nvset_element, name, value, id_provider):
     """
     Update nvpair, create new if it doesn't yet exist or remove existing
@@ -47,6 +46,7 @@ def set_nvpair_in_nvset(nvset_element, name, value, id_provider):
         else:
             nvset_element.remove(nvpair)
 
+
 def arrange_first_nvset(
     tag_name, context_element, nvpair_dict, id_provider, new_id=None
 ):
@@ -71,18 +71,20 @@ def arrange_first_nvset(
     nvset_element = get_sub_element(
         context_element,
         tag_name,
-        new_id=(new_id if new_id else create_subelement_id(
-            context_element, tag_name, id_provider
-        )),
-        append_if_missing=False
+        new_id=(
+            new_id
+            if new_id
+            else create_subelement_id(context_element, tag_name, id_provider)
+        ),
+        append_if_missing=False,
     )
     update_nvset(nvset_element, nvpair_dict, id_provider)
     append_when_useful(context_element, nvset_element, index=0)
 
+
 def append_new_nvset(
-        tag_name, context_element, nvpair_dict, id_provider,
-        enforce_append=False
-    ):
+    tag_name, context_element, nvpair_dict, id_provider, enforce_append=False
+):
     """
     Append new nvset_element comprising nvpairs children (corresponding
     nvpair_dict) to the context_element
@@ -95,9 +97,7 @@ def append_new_nvset(
     """
     nvset_element = etree.Element(
         tag_name,
-        {
-            "id": create_subelement_id(context_element, tag_name, id_provider)
-        }
+        {"id": create_subelement_id(context_element, tag_name, id_provider)},
     )
     for name, value in sorted(nvpair_dict.items()):
         _append_new_nvpair(nvset_element, name, value, id_provider)
@@ -106,6 +106,7 @@ def append_new_nvset(
     else:
         append_when_useful(context_element, nvset_element)
 
+
 append_new_instance_attributes = partial(
     append_new_nvset,
     INSTANCE_ATTRIBUTES_TAG,
@@ -116,6 +117,7 @@ append_new_meta_attributes = partial(
     META_ATTRIBUTES_TAG,
 )
 
+
 def update_nvset(nvset_element, nvpair_dict, id_provider):
     """
     Add, remove or update nvpairs according to nvpair_dict into nvset_element
@@ -133,6 +135,7 @@ def update_nvset(nvset_element, nvpair_dict, id_provider):
     for name, value in sorted(nvpair_dict.items()):
         set_nvpair_in_nvset(nvset_element, name, value, id_provider)
 
+
 def get_nvset(nvset):
     """
     Returns nvset element as list of nvpairs with format:
@@ -149,13 +152,16 @@ def get_nvset(nvset):
     """
     nvpair_list = []
     for nvpair in nvset.findall("./nvpair"):
-        nvpair_list.append({
-            "id": nvpair.get("id"),
-            "name": nvpair.get("name"),
-            "value": nvpair.get("value", "")
-        })
+        nvpair_list.append(
+            {
+                "id": nvpair.get("id"),
+                "name": nvpair.get("name"),
+                "value": nvpair.get("value", ""),
+            }
+        )
     return nvpair_list
 
+
 def get_value(tag_name, context_element, name, default=None):
     """
     Return value from nvpair.
@@ -167,7 +173,8 @@ def get_value(tag_name, context_element, name, default=None):
     etree.Element context_element is searched element
     string name specify nvpair name
     """
-    value_list = context_element.xpath("""
+    value_list = context_element.xpath(
+        """
         ./{0}
         /nvpair[
             @name="{1}"
@@ -175,9 +182,13 @@ def get_value(tag_name, context_element, name, default=None):
             string-length(@value) > 0
         ]
         /@value
-    """.format(tag_name, name))
+    """.format(
+            tag_name, name
+        )
+    )
     return value_list[0] if value_list else default
 
+
 def get_nvset_as_dict(tag_name, context_element):
     """
     Returns nvset with specified tag_name in context_element as dictionary
@@ -193,6 +204,7 @@ def get_nvset_as_dict(tag_name, context_element):
         )
     }
 
+
 def has_meta_attribute(resource_el, name):
     """
     Return if the element contains meta attribute 'name'
@@ -200,9 +212,15 @@ def has_meta_attribute(resource_el, name):
     etree.Element resource_el is researched element
     string name specifies attribute
     """
-    return len(resource_el.xpath(
-        './{0}/nvpair[@name="{1}"]'.format(META_ATTRIBUTES_TAG, name)
-    )) > 0
+    return (
+        len(
+            resource_el.xpath(
+                './{0}/nvpair[@name="{1}"]'.format(META_ATTRIBUTES_TAG, name)
+            )
+        )
+        > 0
+    )
+
 
 arrange_first_meta_attributes = partial(
     arrange_first_nvset,
