@@ -1,7 +1,8 @@
 from lxml import etree
 
-from pcs.common import report_codes
-from pcs.lib import reports, validate
+from pcs.common import reports
+from pcs.common.reports.item import ReportItem
+from pcs.lib import validate
 from pcs.lib.cib.nvpair import (
     append_new_meta_attributes,
     arrange_first_meta_attributes,
@@ -9,10 +10,7 @@ from pcs.lib.cib.nvpair import (
 )
 from pcs.lib.cib.resource.primitive import TAG as TAG_PRIMITIVE
 from pcs.lib.cib.tools import ElementSearcher
-from pcs.lib.errors import (
-    LibraryError,
-    ReportItemSeverity,
-)
+from pcs.lib.errors import LibraryError
 from pcs.lib.pacemaker.values import sanitize_id
 from pcs.lib.xml_tools import (
     append_when_useful,
@@ -25,45 +23,61 @@ TAG = "bundle"
 
 GENERIC_CONTAINER_TYPES = {"docker", "podman", "rkt"}
 
-GENERIC_CONTAINER_OPTIONS = frozenset((
-    "image",
-    "masters",
-    "network",
-    "options",
-    "promoted-max",
-    "run-command",
-    "replicas",
-    "replicas-per-host",
-))
+GENERIC_CONTAINER_OPTIONS = frozenset(
+    (
+        "image",
+        "masters",
+        "network",
+        "options",
+        "promoted-max",
+        "run-command",
+        "replicas",
+        "replicas-per-host",
+    )
+)
 
-NETWORK_OPTIONS = frozenset((
-    "control-port",
-    "host-interface",
-    "host-netmask",
-    "ip-range-start",
-))
+NETWORK_OPTIONS = frozenset(
+    (
+        "control-port",
+        "host-interface",
+        "host-netmask",
+        "ip-range-start",
+    )
+)
 
-PORT_MAP_OPTIONS = frozenset((
-    "id",
-    "port",
-    "internal-port",
-    "range",
-))
+PORT_MAP_OPTIONS = frozenset(
+    (
+        "id",
+        "port",
+        "internal-port",
+        "range",
+    )
+)
+
+STORAGE_MAP_OPTIONS = frozenset(
+    (
+        "id",
+        "options",
+        "source-dir",
+        "source-dir-root",
+        "target-dir",
+    )
+)
 
-STORAGE_MAP_OPTIONS = frozenset((
-    "id",
-    "options",
-    "source-dir",
-    "source-dir-root",
-    "target-dir",
-))
 
 def is_bundle(resource_el):
     return resource_el.tag == TAG
 
+
 def validate_new(
-    id_provider, bundle_id, container_type, container_options, network_options,
-    port_map, storage_map, force_options=False
+    id_provider,
+    bundle_id,
+    container_type,
+    container_options,
+    network_options,
+    port_map,
+    storage_map,
+    force_options=False,
 ):
     """
     Validate new bundle parameters, return list of report items
@@ -82,21 +96,25 @@ def validate_new(
             "id",
             option_name_for_report="bundle name",
             # with id_provider it validates that the id is available as well
-            id_provider=id_provider
+            id_provider=id_provider,
         ).validate({"id": bundle_id})
-        +
-        _validate_container(container_type, container_options, force_options)
-        +
-        _validate_network_options_new(network_options, force_options)
-        +
-        _validate_port_map_list(port_map, id_provider, force_options)
-        +
-        _validate_storage_map_list(storage_map, id_provider, force_options)
+        + _validate_container(container_type, container_options, force_options)
+        + _validate_network_options_new(network_options, force_options)
+        + _validate_port_map_list(port_map, id_provider, force_options)
+        + _validate_storage_map_list(storage_map, id_provider, force_options)
     )
 
+
 def append_new(
-    parent_element, id_provider, bundle_id, container_type, container_options,
-    network_options, port_map, storage_map, meta_attributes
+    parent_element,
+    id_provider,
+    bundle_id,
+    container_type,
+    container_options,
+    network_options,
+    port_map,
+    storage_map,
+    meta_attributes,
 ):
     # pylint: disable=too-many-arguments
     """
@@ -128,9 +146,15 @@ def append_new(
         append_new_meta_attributes(bundle_element, meta_attributes, id_provider)
     return bundle_element
 
+
 def validate_reset(
-    id_provider, bundle_el, container_options, network_options, port_map,
-    storage_map, force_options=False
+    id_provider,
+    bundle_el,
+    container_options,
+    network_options,
+    port_map,
+    storage_map,
+    force_options=False,
 ):
     """
     Validate bundle parameters, return list of report items
@@ -145,14 +169,12 @@ def validate_reset(
     """
     return (
         _validate_container_reset(bundle_el, container_options, force_options)
-        +
-        _validate_network_options_new(network_options, force_options)
-        +
-        _validate_port_map_list(port_map, id_provider, force_options)
-        +
-        _validate_storage_map_list(storage_map, id_provider, force_options)
+        + _validate_network_options_new(network_options, force_options)
+        + _validate_port_map_list(port_map, id_provider, force_options)
+        + _validate_storage_map_list(storage_map, id_provider, force_options)
     )
 
+
 def validate_reset_to_minimal(bundle_element):
     """
     Validate removing configuration of bundle_element and keep the minimal one.
@@ -163,6 +185,7 @@ def validate_reset_to_minimal(bundle_element):
         return [_get_report_unsupported_container(bundle_element)]
     return []
 
+
 def reset_to_minimal(bundle_element):
     """
     Remove configuration of bundle_element and keep the minimal one.
@@ -188,16 +211,26 @@ def reset_to_minimal(bundle_element):
             # be set.
             reset_element(child, keep_attrs=["image"])
 
+
 def _get_report_unsupported_container(bundle_el):
-    return reports.resource_bundle_unsupported_container_type(
-        bundle_el.get("id"),
-        GENERIC_CONTAINER_TYPES,
+    return ReportItem.error(
+        reports.messages.ResourceBundleUnsupportedContainerType(
+            bundle_el.get("id"),
+            sorted(GENERIC_CONTAINER_TYPES),
+        )
     )
 
+
 def validate_update(
-    id_provider, bundle_el, container_options, network_options,
-    port_map_add, port_map_remove, storage_map_add, storage_map_remove,
-    force_options=False
+    id_provider,
+    bundle_el,
+    container_options,
+    network_options,
+    port_map_add,
+    port_map_remove,
+    storage_map_add,
+    storage_map_remove,
+    force_options=False,
 ):
     # pylint: disable=too-many-arguments
     """
@@ -218,26 +251,30 @@ def validate_update(
     # not sooner.
     return (
         _validate_container_update(bundle_el, container_options, force_options)
-        +
-        _validate_network_update(bundle_el, network_options, force_options)
-        +
-        _validate_port_map_list(port_map_add, id_provider, force_options)
-        +
-        _validate_storage_map_list(storage_map_add, id_provider, force_options)
-        +
-        _validate_map_ids_exist(
+        + _validate_network_update(bundle_el, network_options, force_options)
+        + _validate_port_map_list(port_map_add, id_provider, force_options)
+        + _validate_storage_map_list(
+            storage_map_add, id_provider, force_options
+        )
+        + _validate_map_ids_exist(
             bundle_el, "port-mapping", "port-map", port_map_remove
         )
-        +
-        _validate_map_ids_exist(
+        + _validate_map_ids_exist(
             bundle_el, "storage-mapping", "storage-map", storage_map_remove
         )
     )
 
+
 def update(
-    id_provider, bundle_el, container_options, network_options,
-    port_map_add, port_map_remove, storage_map_add, storage_map_remove,
-    meta_attributes
+    id_provider,
+    bundle_el,
+    container_options,
+    network_options,
+    port_map_add,
+    port_map_remove,
+    storage_map_add,
+    storage_map_remove,
+    meta_attributes,
 ):
     # pylint: disable=too-many-arguments, too-many-locals
     """
@@ -262,14 +299,11 @@ def update(
 
     bundle_id = bundle_el.get("id")
     update_attributes_remove_empty(
-        _get_container_element(bundle_el),
-        container_options
+        _get_container_element(bundle_el), container_options
     )
 
     network_element = get_sub_element(
-        bundle_el,
-        "network",
-        append_if_missing=False
+        bundle_el, "network", append_if_missing=False
     )
     if network_options:
         update_attributes_remove_empty(network_element, network_options)
@@ -280,8 +314,7 @@ def update(
     # possibly the old mapping would be removed)
     if port_map_remove:
         _remove_map_elements(
-            network_element.findall("port-mapping"),
-            port_map_remove
+            network_element.findall("port-mapping"), port_map_remove
         )
     if port_map_add:
         for port_map_options in port_map_add:
@@ -291,15 +324,12 @@ def update(
     append_when_useful(bundle_el, network_element)
 
     storage_element = get_sub_element(
-        bundle_el,
-        "storage",
-        append_if_missing=False
+        bundle_el, "storage", append_if_missing=False
     )
     # See the comment above about removing port maps prior to adding new ones.
     if storage_map_remove:
         _remove_map_elements(
-            storage_element.findall("storage-mapping"),
-            storage_map_remove
+            storage_element.findall("storage-mapping"), storage_map_remove
         )
     if storage_map_add:
         for storage_map_options in storage_map_add:
@@ -309,11 +339,8 @@ def update(
     append_when_useful(bundle_el, storage_element)
 
     if meta_attributes:
-        arrange_first_meta_attributes(
-            bundle_el,
-            meta_attributes,
-            id_provider
-        )
+        arrange_first_meta_attributes(bundle_el, meta_attributes, id_provider)
+
 
 def is_pcmk_remote_accessible(bundle_element):
     """
@@ -332,6 +359,7 @@ def is_pcmk_remote_accessible(bundle_element):
             return True
     return False
 
+
 def add_resource(bundle_element, primitive_element):
     """
     Add an existing resource to an existing bundle
@@ -343,31 +371,39 @@ def add_resource(bundle_element, primitive_element):
     # a bundle may currently contain at most one primitive resource
     inner_primitive = bundle_element.find(TAG_PRIMITIVE)
     if inner_primitive is not None:
-        raise LibraryError(reports.resource_bundle_already_contains_a_resource(
-            bundle_element.get("id"), inner_primitive.get("id")
-        ))
+        raise LibraryError(
+            ReportItem.error(
+                reports.messages.ResourceBundleAlreadyContainsAResource(
+                    bundle_element.get("id"),
+                    inner_primitive.get("id"),
+                )
+            )
+        )
     bundle_element.append(primitive_element)
 
+
 def get_inner_resource(bundle_el):
     resources = bundle_el.xpath("./primitive")
     if resources:
         return resources[0]
     return None
 
+
 def _is_supported_container(container_el):
     return (
-        container_el is not None
-        and
-        container_el.tag in GENERIC_CONTAINER_TYPES
+        container_el is not None and container_el.tag in GENERIC_CONTAINER_TYPES
     )
 
+
 def _validate_container(container_type, container_options, force_options=False):
     if container_type not in GENERIC_CONTAINER_TYPES:
         return [
-            reports.invalid_option_value(
-                "container type",
-                container_type,
-                GENERIC_CONTAINER_TYPES,
+            ReportItem.error(
+                reports.messages.InvalidOptionValue(
+                    "container type",
+                    container_type,
+                    GENERIC_CONTAINER_TYPES,
+                )
             )
         ]
     return _validate_generic_container_options(container_options, force_options)
@@ -378,7 +414,9 @@ def _validate_generic_container_options(container_options, force_options=False):
         validate.NamesIn(
             GENERIC_CONTAINER_OPTIONS,
             option_type="container",
-            **validate.set_warning(report_codes.FORCE_OPTIONS, force_options)
+            severity=reports.item.get_severity(
+                reports.codes.FORCE_OPTIONS, force_options
+            ),
         ),
         validate.IsRequiredAll(["image"], option_type="container"),
         validate.ValueNotEmpty("image", "image name"),
@@ -395,29 +433,31 @@ def _validate_generic_container_options(container_options, force_options=False):
     deprecation_reports = []
     if "masters" in container_options:
         deprecation_reports.append(
-            reports.deprecated_option(
-                "masters", ["promoted-max"], "container",
-                severity=ReportItemSeverity.WARNING
+            ReportItem.warning(
+                reports.messages.DeprecatedOption(
+                    "masters",
+                    ["promoted-max"],
+                    "container",
+                )
             )
         )
 
     return (
         validate.ValidatorAll(validators).validate(container_options)
-        +
-        deprecation_reports
+        + deprecation_reports
     )
 
+
 def _validate_container_reset(bundle_el, container_options, force_options):
     # Unlike in the case of update, in reset empty options are not necessary
     # valid - user MUST set everything (including required options e.g. image).
-    if (
-        container_options
-        and
-        not _is_supported_container(_get_container_element(bundle_el))
+    if container_options and not _is_supported_container(
+        _get_container_element(bundle_el)
     ):
         return [_get_report_unsupported_container(bundle_el)]
     return _validate_generic_container_options(container_options, force_options)
 
+
 def _validate_container_update(bundle_el, options, force_options):
     # Validate container options only if they are being updated. Empty options
     # are valid - user DOESN'T NEED to change anything.
@@ -431,6 +471,7 @@ def _validate_container_update(bundle_el, options, force_options):
         container_el, options, force_options
     )
 
+
 def _validate_generic_container_options_update(
     container_el, options, force_options
 ):
@@ -447,10 +488,12 @@ def _validate_generic_container_options_update(
             # allow to remove options even if they are not allowed
             GENERIC_CONTAINER_OPTIONS | _options_to_remove(options),
             option_type="container",
-            **validate.set_warning(report_codes.FORCE_OPTIONS, force_options)
+            severity=reports.item.get_severity(
+                reports.codes.FORCE_OPTIONS, force_options
+            ),
         ),
         # image is a mandatory attribute and cannot be removed
-        validate.ValueNotEmpty("image", "image name")
+        validate.ValueNotEmpty("image", "image name"),
     ] + validators_optional_options
 
     # CIB does not allow both to be set. Deleting both is not a problem,
@@ -458,8 +501,7 @@ def _validate_generic_container_options_update(
     # checked bellow.
     if not (
         options.get("masters", "") == ""
-        or
-        options.get("promoted-max", "") == ""
+        or options.get("promoted-max", "") == ""
     ):
         validators.append(
             validate.MutuallyExclusive(
@@ -474,9 +516,12 @@ def _validate_generic_container_options_update(
         # deprecated. They may be removing it because they just found out it is
         # deprecated.
         deprecation_reports.append(
-            reports.deprecated_option(
-                "masters", ["promoted-max"], "container",
-                severity=ReportItemSeverity.WARNING
+            ReportItem.warning(
+                reports.messages.DeprecatedOption(
+                    "masters",
+                    ["promoted-max"],
+                    "container",
+                )
             )
         )
     # Do not allow to set masters if promoted-max is set unless promoted-max is
@@ -484,43 +529,52 @@ def _validate_generic_container_options_update(
     # only allows one of them to be set.
     if (
         options.get("masters")
-        and
-        container_el.get("promoted-max") and options.get("promoted-max") != ""
+        and container_el.get("promoted-max")
+        and options.get("promoted-max") != ""
     ):
         deprecation_reports.append(
-            reports.prerequisite_option_must_not_be_set(
-                "masters", "promoted-max", "container", "container"
+            ReportItem.error(
+                reports.messages.PrerequisiteOptionMustNotBeSet(
+                    "masters", "promoted-max", "container", "container"
+                )
             )
         )
     if (
         options.get("promoted-max")
-        and
-        container_el.get("masters") and options.get("masters") != ""
+        and container_el.get("masters")
+        and options.get("masters") != ""
     ):
         deprecation_reports.append(
-            reports.prerequisite_option_must_not_be_set(
-                "promoted-max", "masters", "container", "container"
+            ReportItem.error(
+                reports.messages.PrerequisiteOptionMustNotBeSet(
+                    "promoted-max", "masters", "container", "container"
+                )
             )
         )
 
     return (
         validate.ValidatorAll(validators).validate(options)
-        +
-        deprecation_reports
+        + deprecation_reports
     )
 
+
 def _validate_network_options_new(options, force_options):
-    kwargs = validate.set_warning(report_codes.FORCE_OPTIONS, force_options)
+    severity = reports.item.get_severity(
+        reports.codes.FORCE_OPTIONS, force_options
+    )
     validators = [
         # TODO add validators for other keys (ip-range-start - IPv4)
-        validate.NamesIn(NETWORK_OPTIONS, option_type="network", **kwargs),
+        validate.NamesIn(
+            NETWORK_OPTIONS, option_type="network", severity=severity
+        ),
         validate.ValuePortNumber("control-port"),
         # Leaving a possibility to force this validation for the case pacemaker
         # starts supporting IPv6 or other format of the netmask.
-        ValueHostNetmask("host-netmask", **kwargs),
+        ValueHostNetmask("host-netmask", severity=severity),
     ]
     return validate.ValidatorAll(validators).validate(options)
 
+
 def _is_pcmk_remote_acccessible_after_update(network_el, options):
     port_name = "control-port"
     ip_name = "ip-range-start"
@@ -539,6 +593,7 @@ def _is_pcmk_remote_acccessible_after_update(network_el, options):
 
     return not (case1 or case2 or case3)
 
+
 def _validate_network_update(bundle_el, options, force_options):
     network_el = bundle_el.find("network")
     if network_el is None:
@@ -547,6 +602,7 @@ def _validate_network_update(bundle_el, options, force_options):
         bundle_el, network_el, options, force_options
     )
 
+
 def _validate_network_options_update(
     bundle_el, network_el, options, force_options
 ):
@@ -554,26 +610,30 @@ def _validate_network_options_update(
     inner_primitive = get_inner_resource(bundle_el)
     if (
         inner_primitive is not None
-        and
-        not _is_pcmk_remote_acccessible_after_update(network_el, options)
+        and not _is_pcmk_remote_acccessible_after_update(network_el, options)
     ):
         report_list.append(
-            reports.get_problem_creator(
-                report_codes.FORCE_OPTIONS, force_options
-            )(
-                reports.resource_in_bundle_not_accessible,
-                bundle_el.get("id"),
-                inner_primitive.get("id")
+            ReportItem(
+                severity=reports.item.get_severity(
+                    reports.codes.FORCE_OPTIONS,
+                    force_options,
+                ),
+                message=reports.messages.ResourceInBundleNotAccessible(
+                    bundle_el.get("id"),
+                    inner_primitive.get("id"),
+                ),
             )
         )
 
-    kwargs = validate.set_warning(report_codes.FORCE_OPTIONS, force_options)
+    severity = reports.item.get_severity(
+        reports.codes.FORCE_OPTIONS, force_options
+    )
     validators_optional_options = [
         # TODO add validators for other keys (ip-range-start - IPv4)
         validate.ValuePortNumber("control-port"),
         # Leaving a possibility to force this validation for the case pacemaker
         # starts supporting IPv6 or other format of the netmask.
-        ValueHostNetmask("host-netmask", **kwargs),
+        ValueHostNetmask("host-netmask", severity=severity),
     ]
     for val in validators_optional_options:
         val.empty_string_valid = True
@@ -582,33 +642,36 @@ def _validate_network_options_update(
             # allow to remove options even if they are not allowed
             NETWORK_OPTIONS | _options_to_remove(options),
             option_type="network",
-            **kwargs
+            severity=severity,
         )
     ] + validators_optional_options
 
-    return (
-        report_list
-        +
-        validate.ValidatorAll(validators).validate(options)
-    )
+    return report_list + validate.ValidatorAll(validators).validate(options)
+
 
 def _validate_port_map_list(options_list, id_provider, force_options):
-    kwargs = validate.set_warning(report_codes.FORCE_OPTIONS, force_options)
+    severity = reports.item.get_severity(
+        reports.codes.FORCE_OPTIONS, force_options
+    )
     option_type = "port-map"
     validators = [
-        validate.NamesIn(PORT_MAP_OPTIONS, option_type=option_type, **kwargs),
+        validate.NamesIn(
+            PORT_MAP_OPTIONS, option_type=option_type, severity=severity
+        ),
         validate.ValueId(
             "id", option_name_for_report="port-map id", id_provider=id_provider
         ),
         validate.DependsOnOption(
-            ["internal-port"], "port",
-            option_type=option_type, prerequisite_type=option_type,
+            ["internal-port"],
+            "port",
+            option_type=option_type,
+            prerequisite_type=option_type,
         ),
         validate.IsRequiredSome(["port", "range"], option_type=option_type),
         validate.MutuallyExclusive(["port", "range"], option_type=option_type),
         validate.ValuePortNumber("port"),
         validate.ValuePortNumber("internal-port"),
-        validate.ValuePortRange("range", **kwargs),
+        validate.ValuePortRange("range", severity=severity),
     ]
     validator_all = validate.ValidatorAll(validators)
 
@@ -617,17 +680,20 @@ def _validate_port_map_list(options_list, id_provider, force_options):
         report_list.extend(validator_all.validate(options))
     return report_list
 
+
 def _validate_storage_map_list(options_list, id_provider, force_options):
-    kwargs = validate.set_warning(report_codes.FORCE_OPTIONS, force_options)
+    severity = reports.item.get_severity(
+        reports.codes.FORCE_OPTIONS, force_options
+    )
     option_type = "storage-map"
     validators = [
         validate.NamesIn(
-            STORAGE_MAP_OPTIONS, option_type=option_type, **kwargs
+            STORAGE_MAP_OPTIONS, option_type=option_type, severity=severity
         ),
         validate.ValueId(
             "id",
             option_name_for_report="storage-map id",
-            id_provider=id_provider
+            id_provider=id_provider,
         ),
         validate.IsRequiredSome(
             ["source-dir", "source-dir-root"],
@@ -646,6 +712,7 @@ def _validate_storage_map_list(options_list, id_provider, force_options):
         report_list.extend(validator_all.validate(options))
     return report_list
 
+
 def _validate_map_ids_exist(bundle_el, map_type, map_label, id_list):
     report_list = []
     for _id in id_list:
@@ -656,6 +723,7 @@ def _validate_map_ids_exist(bundle_el, map_type, map_label, id_list):
             report_list.extend(searcher.get_errors())
     return report_list
 
+
 class ValueHostNetmask(validate.ValuePredicateBase):
     def _is_valid(self, value):
         return validate.is_integer(value, 1, 32)
@@ -663,6 +731,7 @@ class ValueHostNetmask(validate.ValuePredicateBase):
     def _get_allowed_values(self):
         return "a number of bits of the mask (1..32)"
 
+
 def _append_container(bundle_element, container_type, container_options):
     # Do not add options with empty values. When updating, an empty value means
     # remove the option.
@@ -671,6 +740,7 @@ def _append_container(bundle_element, container_type, container_options):
         container_options,
     )
 
+
 def _append_network(
     bundle_element, id_provider, id_base, network_options, port_map
 ):
@@ -683,6 +753,7 @@ def _append_network(
             network_element, id_provider, id_base, port_map_options
         )
 
+
 def _append_port_map(parent_element, id_provider, id_base, port_map_options):
     if "id" not in port_map_options:
         id_suffix = None
@@ -700,6 +771,7 @@ def _append_port_map(parent_element, id_provider, id_base, port_map_options):
     update_attributes_remove_empty(port_map_element, port_map_options)
     return port_map_element
 
+
 def _append_storage(bundle_element, id_provider, id_base, storage_map):
     storage_element = etree.SubElement(bundle_element, "storage")
     for storage_map_options in storage_map:
@@ -710,6 +782,7 @@ def _append_storage(bundle_element, id_provider, id_base, storage_map):
             storage_map_options,
         )
 
+
 def _append_storage_map(
     parent_element, id_provider, id_base, storage_map_options
 ):
@@ -724,6 +797,7 @@ def _append_storage_map(
     update_attributes_remove_empty(storage_map_element, storage_map_options)
     return storage_map_element
 
+
 def _get_container_element(bundle_el):
     container_el = None
     for container_type in GENERIC_CONTAINER_TYPES:
@@ -732,13 +806,16 @@ def _get_container_element(bundle_el):
             return container_el
     return None
 
+
 def _remove_map_elements(element_list, id_to_remove_list):
     for el in element_list:
         if el.get("id", "") in id_to_remove_list:
             el.getparent().remove(el)
 
+
 def _options_to_remove(options):
     return {
-        name for name, value in options.items()
+        name
+        for name, value in options.items()
         if validate.is_empty_string(value)
     }
