@@ -1,13 +1,11 @@
 from collections import namedtuple
 from typing import (
-    cast,
     Iterable,
     List,
     Optional,
     Set,
     Tuple,
 )
-from xml.etree.ElementTree import Element
 
 from lxml.etree import _Element
 
@@ -63,131 +61,53 @@ def is_clone_deactivated_by_meta(meta_attributes):
     )
 
 
-def find_one_resource_and_report(
-    context_element,
-    resource_id,
-    report_list,
-    additional_search=None,
-    resource_tags=None,
-):
+def find_one_resource(
+    context_element: _Element,
+    resource_id: str,
+    resource_tags: Optional[Iterable[str]] = None,
+) -> Tuple[Optional[_Element], ReportItemList]:
     """
-    Find a single resource or return None if not found, report errors
+    Find a single resource or return None if not found
 
-    etree context_element -- an element to be searched in
-    string resource_id -- id of an element to find
-    list report_list -- report items will be put in here
-    function additional_search -- None of a func to find resources
-    iterable resource_tags -- types of resources to look for, default all types
+    context_element -- an element to be searched in
+    resource_id -- id of an element to find
+    resource_tags -- types of resources to look for, default all types
     """
-    resource_el_list = find_resources_and_report(
+    resource_el_list, report_list = find_resources(
         context_element,
         [resource_id],
-        report_list,
-        additional_search=additional_search,
         resource_tags=resource_tags,
     )
-    return resource_el_list[0] if resource_el_list else None
+    resource = resource_el_list[0] if resource_el_list else None
+    return resource, report_list
 
 
-def find_resources_and_report(
-    context_element,
-    resource_ids,
-    report_list,
-    additional_search=None,
-    resource_tags=None,
-):
+def find_resources(
+    context_element: _Element,
+    resource_ids: Iterable[str],
+    resource_tags: Optional[Iterable[str]] = None,
+) -> Tuple[List[_Element], ReportItemList]:
     """
-    Find a list of resource, report errors
+    Find a list of resource
 
-    etree context_element -- an element to be searched in
-    string resource_id -- id of an element to find
-    list report_list -- report items will be put in here
-    function additional_search -- None of a func to find resources
-    iterable resource_tags -- types of resources to look for, default all types
+    context_element -- an element to be searched in
+    resource_id -- id of an element to find
+    resource_tags -- types of resources to look for, default all types
     """
-    if not additional_search:
-        additional_search = lambda x: [x]
+    report_list: ReportItemList = []
     if resource_tags is None:
         resource_tags = ALL_RESOURCE_XML_TAGS
     resource_el_list = []
     for res_id in resource_ids:
         searcher = ElementSearcher(resource_tags, res_id, context_element)
         if searcher.element_found():
-            resource_el_list.extend(additional_search(searcher.get_element()))
+            resource_el_list.append(searcher.get_element())
         else:
             report_list.extend(searcher.get_errors())
-    return resource_el_list
+    return resource_el_list, report_list
 
 
-def expand_tags_to_resources(
-    resources_section: Element, resource_or_tag_el_list: Iterable[Element],
-) -> List[Element]:
-    """
-    Substitute tag elements in the given list with resource elements which tags
-    refer to.
-
-    resources_section -- element resources of a cib tree
-    resource_or_tag_el_list -- element list which contains tag or resource
-        elements
-    """
-    only_resources_set = set()
-    for el in resource_or_tag_el_list:
-        if el.tag == "tag":
-            for _id in [
-                obj_ref.get("id", "") for obj_ref in el.findall("obj_ref")
-            ]:
-                searcher = ElementSearcher(
-                    ALL_RESOURCE_XML_TAGS, _id, resources_section,
-                )
-                if searcher.element_found():
-                    only_resources_set.add(searcher.get_element())
-        else:
-            only_resources_set.add(el)
-    return list(only_resources_set)
-
-
-def find_resources_or_tags(
-    cib: Element, id_list: Iterable[str],
-) -> Tuple[List[Element], ReportItemList]:
-    """
-    Find resource elements by using resource or tag ids.
-
-    cib -- cib element
-    id_list -- resource or tag ids
-    """
-    resource_or_tag_el_list = []
-    not_found_id_list: List[str] = []
-    for _id in set(id_list):
-        xpath_result = cast(_Element, cib).xpath(
-            """
-            /cib/configuration/resources//*[{resource_tags}][@id="{_id}"]
-            |
-            /cib/configuration/tags/tag[@id="{_id}"]
-            """.format(
-                _id=_id,
-                resource_tags=" or ".join(
-                    f"self::{tag}" for tag in ALL_RESOURCE_XML_TAGS
-                ),
-            )
-        )
-        if xpath_result:
-            resource_or_tag_el_list.append(cast(List[Element], xpath_result)[0])
-        else:
-            not_found_id_list.append(_id)
-
-    report_list: ReportItemList = []
-    for _id in sorted(not_found_id_list):
-        report_list.append(
-            ReportItem.error(
-                reports.messages.IdNotFound(
-                    _id, sorted(ALL_RESOURCE_XML_TAGS + ["tag"]),
-                ),
-            ),
-        )
-    return resource_or_tag_el_list, report_list
-
-
-def find_primitives(resource_el: Element) -> List[Element]:
+def find_primitives(resource_el: _Element) -> List[_Element]:
     """
     Get list of primitives contained in a given resource
     etree resource_el -- resource element
@@ -204,7 +124,7 @@ def find_primitives(resource_el: Element) -> List[Element]:
     return []
 
 
-def get_all_inner_resources(resource_el: Element) -> Set[Element]:
+def get_all_inner_resources(resource_el: _Element) -> Set[_Element]:
     """
     Return all inner resources (both direct and indirect) of a resource
     Example: for a clone containing a group, this function will return both
@@ -212,7 +132,7 @@ def get_all_inner_resources(resource_el: Element) -> Set[Element]:
 
     resource_el -- resource element to get its inner resources
     """
-    all_inner: Set[Element] = set()
+    all_inner: Set[_Element] = set()
     to_process = set([resource_el])
     while to_process:
         new_inner = get_inner_resources(to_process.pop())
@@ -221,7 +141,7 @@ def get_all_inner_resources(resource_el: Element) -> Set[Element]:
     return all_inner
 
 
-def get_inner_resources(resource_el: Element) -> List[Element]:
+def get_inner_resources(resource_el: _Element) -> List[_Element]:
     """
     Return list of inner resources (direct descendants) of a resource
     specified as resource_el.
@@ -240,7 +160,7 @@ def get_inner_resources(resource_el: Element) -> List[Element]:
     return []
 
 
-def is_wrapper_resource(resource_el: Element) -> bool:
+def is_wrapper_resource(resource_el: _Element) -> bool:
     """
     Return True for resource_el of types that can contain other resource(s)
     (these are: group, bundle, clone) and False otherwise.
@@ -254,7 +174,7 @@ def is_wrapper_resource(resource_el: Element) -> bool:
     )
 
 
-def get_parent_resource(resource_el: Element) -> Optional[Element]:
+def get_parent_resource(resource_el: _Element) -> Optional[_Element]:
     """
     Return a direct ancestor of a specified resource or None if the resource
     has no ancestor.
@@ -263,7 +183,7 @@ def get_parent_resource(resource_el: Element) -> Optional[Element]:
 
     resource_el -- resource element of which parent resource should be returned
     """
-    parent_el = cast(Element, cast(_Element, resource_el).getparent())
+    parent_el = resource_el.getparent()
     if parent_el is not None and is_wrapper_resource(parent_el):
         return parent_el
     return None
@@ -297,7 +217,11 @@ def enable(resource_el, id_provider):
     etree resource_el -- resource element
     """
     nvpair.arrange_first_meta_attributes(
-        resource_el, {"target-role": "",}, id_provider
+        resource_el,
+        {
+            "target-role": "",
+        },
+        id_provider,
     )
 
 
@@ -307,7 +231,11 @@ def disable(resource_el, id_provider):
     etree resource_el -- resource element
     """
     nvpair.arrange_first_meta_attributes(
-        resource_el, {"target-role": "Stopped",}, id_provider
+        resource_el,
+        {
+            "target-role": "Stopped",
+        },
+        id_provider,
     )
 
 
@@ -413,7 +341,11 @@ def manage(resource_el, id_provider):
     etree resource_el -- resource element
     """
     nvpair.arrange_first_meta_attributes(
-        resource_el, {"is-managed": "",}, id_provider
+        resource_el,
+        {
+            "is-managed": "",
+        },
+        id_provider,
     )
 
 
@@ -423,11 +355,15 @@ def unmanage(resource_el, id_provider):
     etree resource_el -- resource element
     """
     nvpair.arrange_first_meta_attributes(
-        resource_el, {"is-managed": "false",}, id_provider
+        resource_el,
+        {
+            "is-managed": "false",
+        },
+        id_provider,
     )
 
 
-def find_resources_to_delete(resource_el: Element) -> List[Element]:
+def find_resources_to_delete(resource_el: _Element) -> List[_Element]:
     """
     Get resources to delete, children and parents of the given resource if
     necessary.
@@ -495,17 +431,20 @@ def validate_move(resource_element, master):
         )
         return report_list
 
-    if not master and (
-        analysis.is_promotable_clone or analysis.is_in_promotable_clone
-    ):
-        # We assume users want to move master role. Still we require them to
-        # actually specify that. 1) To be consistent with command for bannig
-        # resources. 2) To prevent users from accidentally move slave role.
-        # This check can be removed if someone requests it.
+    # Allow moving both promoted and demoted instances of promotable clones
+    # (analysis.is_promotable_clone). Do not allow to move promoted instances
+    # of promotables' inner resources (analysis.is_in_promotable_clone) as that
+    # would create a constraint for the promoted role of a group or a primitve
+    # which would not make sense if the group or primitive is later moved out
+    # of its promotable clone. To be consistent, we do not allow to move
+    # demoted instances of promotables' inner resources either. See
+    # rhbz#1875301 for details.
+    if not master and analysis.is_in_promotable_clone:
         report_list.append(
             ReportItem.error(
-                reports.messages.CannotMoveResourcePromotableNotMaster(
-                    resource_element.get("id"), analysis.promotable_clone_id,
+                reports.messages.CannotMoveResourcePromotableInner(
+                    resource_element.get("id"),
+                    analysis.promotable_clone_id,
                 )
             )
         )
