@@ -2,7 +2,8 @@
 This module defines madatory and optional cib sections. It provides function for
 getting existing section from the cib (lxml) tree.
 """
-from pcs.lib import reports
+from pcs.common import reports
+from pcs.common.reports.item import ReportItem
 from pcs.lib.errors import LibraryError
 from pcs.lib.xml_tools import get_sub_element
 
@@ -18,6 +19,7 @@ ALERTS = "alerts"
 FENCING_TOPOLOGY = "fencing-topology"
 OP_DEFAULTS = "op_defaults"
 RSC_DEFAULTS = "rsc_defaults"
+TAGS = "tags"
 
 __MANDATORY_SECTIONS = [
     CONFIGURATION,
@@ -33,8 +35,10 @@ __OPTIONAL_SECTIONS = [
     FENCING_TOPOLOGY,
     OP_DEFAULTS,
     RSC_DEFAULTS,
+    TAGS,
 ]
 
+
 def get(tree, section_name):
     """
     Return the element which represents section 'section_name' in the tree.
@@ -52,13 +56,18 @@ def get(tree, section_name):
         section = tree.find(".//{0}".format(section_name))
         if section is not None:
             return section
-        raise LibraryError(reports.cib_missing_mandatory_section(section_name))
+        raise LibraryError(
+            ReportItem.error(
+                reports.messages.CibCannotFindMandatorySection(section_name)
+            )
+        )
 
     if section_name in __OPTIONAL_SECTIONS:
         return get_sub_element(get(tree, CONFIGURATION), section_name)
 
     raise AssertionError("Unknown cib section '{0}'".format(section_name))
 
+
 def exists(tree, section_name):
     if section_name not in __MANDATORY_SECTIONS + __OPTIONAL_SECTIONS:
         raise AssertionError("Unknown cib section '{0}'".format(section_name))
