@@ -1,9 +1,15 @@
 import re
-from xml.etree.ElementTree import Element
+from typing import (
+    cast,
+    List,
+    Set,
+)
+
+from lxml.etree import _Element
 
 from pcs.common import reports
 from pcs.common.reports import codes as report_codes
-from pcs.common.reports.item import ReportItem
+from pcs.common.reports.item import ReportItem, ReportItemList
 from pcs.common.tools import Version
 from pcs.lib.cib import sections
 from pcs.lib.errors import LibraryError
@@ -21,26 +27,26 @@ class IdProvider:
     Book ids for future use in the CIB and generate new ids accordingly
     """
 
-    def __init__(self, cib_element):
+    def __init__(self, cib_element: _Element):
         """
-        etree cib_element -- any element of the xml to being check against
+        cib_element -- any element of the xml to check against
         """
         self._cib = get_root(cib_element)
-        self._booked_ids = set()
+        self._booked_ids: Set[str] = set()
 
-    def allocate_id(self, proposed_id):
+    def allocate_id(self, proposed_id: str) -> str:
         """
         Generate a new unique id based on the proposal and keep track of it
+
         string proposed_id -- requested id
         """
         final_id = find_unique_id(self._cib, proposed_id, self._booked_ids)
         self._booked_ids.add(final_id)
         return final_id
 
-    def book_ids(self, *id_list):
+    def book_ids(self, *id_list: str) -> ReportItemList:
         """
         Check if the ids are not already used and reserve them for future use
-        strings *id_list -- ids
         """
         reported_ids = set()
         report_list = []
@@ -133,11 +139,12 @@ class ElementSearcher:
                 "Improper usage: cannot report errors when there are none"
             )
 
-        element = get_root(self._context_element).find(
-            f'.//*[@id="{self._element_id}"]'
+        element_list = get_configuration_elements_by_id(
+            self._context_element, self._element_id
         )
 
-        if element is not None:
+        if element_list:
+            element = element_list[0]
             if element.tag in self._tag_list:
                 return [
                     ReportItem.error(
@@ -175,21 +182,27 @@ class ElementSearcher:
         self._executed = True
         for tag in self._tag_list:
             element_list = self._context_element.xpath(
-                f'.//{tag}[@id="{self._element_id}"]'
+                ".//*[local-name()=$tag_name and @id=$element_id]",
+                tag_name=tag,
+                element_id=self._element_id,
             )
             if element_list:
                 self._element = element_list[0]
                 return
 
 
-# DEPRECATED, use IdProvider instead
-def does_id_exist(tree, check_id):
-    """
-    Checks to see if id exists in the xml dom passed
-    tree cib etree node
-    check_id id to check
+def get_configuration_elements_by_id(
+    tree: _Element, check_id: str
+) -> List[_Element]:
     """
+    Return any configuration elements (not in status section of cib) with value
+    of attribute id specified as 'check_id'; skip any and all elements having id
+    attribute which does not actually serve as an id.
 
+    tree -- any element in xml tree, whole tree (not only its subtree) will be
+        searched
+    check_id -- id to find
+    """
     # do not search in /cib/status, it may contain references to previously
     # existing and deleted resources and thus preventing creating them again
 
@@ -197,37 +210,52 @@ def does_id_exist(tree, check_id):
     # connection, which will be named the same as the value of the remote-node
     # attribute of the explicit resource. So the value of nvpair named
     # "remote-node" is considered to be id
-    existing = get_root(tree).xpath(
-        """
-        (
-            /cib/*[name()!="status"]
-            |
-            /*[name()!="cib"]
-        )
-        //*[
+    return cast(
+        List[_Element],
+        get_root(tree).xpath(
+            """
             (
-                name()!="acl_target"
-                and
-                name()!="role"
-                and
-                @id="{0}"
-            ) or (
-                name()="primitive"
-                and
-                meta_attributes[
-                    nvpair[
-                        @name="remote-node"
-                        and
-                        @value="{0}"
-                    ]
-                ]
+                /cib/*[name()!="status"]
+                |
+                /*[name()!="cib"]
             )
-        ]
-    """.format(
-            check_id
-        )
+            //*[
+                (
+                    name()!="acl_target"
+                    and
+                    name()!="role"
+                    and
+                    name()!="obj_ref"
+                    and
+                    name()!="resource_ref"
+                    and
+                    @id=$check_id
+                ) or (
+                    name()="primitive"
+                    and
+                    meta_attributes[
+                        nvpair[
+                            @name="remote-node"
+                            and
+                            @value=$check_id
+                        ]
+                    ]
+                )
+            ]
+            """,
+            check_id=check_id,
+        ),
     )
-    return len(existing) > 0
+
+
+# DEPRECATED, use IdProvider instead
+def does_id_exist(tree, check_id):
+    """
+    Checks to see if id exists in the xml dom passed
+    tree cib -- etree node
+    check_id -- id to check
+    """
+    return len(get_configuration_elements_by_id(tree, check_id)) > 0
 
 
 # DEPRECATED, use IdProvider instead
@@ -294,9 +322,11 @@ def find_element_by_tag_and_id(
     return None
 
 
-def create_subelement_id(context_element, suffix, id_provider):
+def create_subelement_id(
+    context_element: _Element, suffix: str, id_provider: IdProvider
+) -> str:
     proposed_id = sanitize_id(
-        "{0}-{1}".format(context_element.get("id"), suffix)
+        "{0}-{1}".format(context_element.get("id", context_element.tag), suffix)
     )
     return id_provider.allocate_id(proposed_id)
 
@@ -332,7 +362,7 @@ def get_alerts(tree):
     return sections.get(tree, sections.ALERTS)
 
 
-def get_constraints(tree):
+def get_constraints(tree: _Element) -> _Element:
     """
     Return 'constraint' element from tree
     tree cib etree node
@@ -340,7 +370,7 @@ def get_constraints(tree):
     return sections.get(tree, sections.CONSTRAINTS)
 
 
-def get_crm_config(tree: Element) -> Element:
+def get_crm_config(tree: _Element) -> _Element:
     """
     Return 'crm_config' element from tree, raise LibraryError if missing
 
@@ -365,7 +395,7 @@ def get_nodes(tree):
     return sections.get(tree, sections.NODES)
 
 
-def get_resources(tree: Element) -> Element:
+def get_resources(tree: _Element) -> _Element:
     """
     Return the 'resources' element from the tree
 
@@ -382,7 +412,7 @@ def get_status(tree):
     return get_sub_element(tree, "status")
 
 
-def get_tags(tree: Element) -> Element:
+def get_tags(tree: _Element) -> _Element:
     """
     Return 'tags' element from tree, create a new one if missing
     tree -- cib etree node
