@@ -1,8 +1,18 @@
+from typing import (
+    Iterable,
+    Mapping,
+    Optional,
+    Union,
+)
+
 from pcs import settings
-from pcs.common import report_codes
+from pcs.common import reports
 from pcs.common.file import RawFileError
-from pcs.common.reports import SimpleReportProcessor
-from pcs.lib import reports, node_communication_format
+from pcs.common.reports import (
+    ReportItem,
+    ReportProcessor,
+)
+from pcs.lib import node_communication_format
 from pcs.lib.tools import generate_binary_key
 from pcs.lib.cib.resource import guest_node, primitive, remote_node
 from pcs.lib.cib.tools import (
@@ -10,6 +20,10 @@ from pcs.lib.cib.tools import (
     ElementSearcher,
     get_resources,
 )
+
+# TODO lib.commands should never import each other. This is to be removed when
+# the 'resource create' commands are overhauled.
+from pcs.lib.commands.resource import get_required_cib_version_for_primitive
 from pcs.lib.communication.nodes import (
     DistributeFiles,
     GetHostInfo,
@@ -21,95 +35,130 @@ from pcs.lib.communication.tools import (
     run as run_com,
     run_and_raise,
 )
-from pcs.lib.node import get_existing_nodes_names_addrs
+from pcs.lib.corosync.config_facade import ConfigFacade as CorosyncConfigFacade
+from pcs.lib.env import LibraryEnvironment
 from pcs.lib.errors import LibraryError
 from pcs.lib.file.instance import FileInstance
 from pcs.lib.file.raw_file import raw_file_error_report
+from pcs.lib.node import get_existing_nodes_names_addrs
 from pcs.lib.pacemaker import state
 from pcs.lib.pacemaker.live import remove_node
 
+
+WaitType = Union[None, bool, int]
+
+
 def _reports_skip_new_node(new_node_name, reason_type):
     assert reason_type in {"unreachable", "not_live_cib"}
     return [
-        reports.files_distribution_skipped(
-            reason_type,
-            ["pacemaker authkey"],
-            [new_node_name]
+        ReportItem.info(
+            reports.messages.FilesDistributionSkipped(
+                reason_type, ["pacemaker authkey"], [new_node_name]
+            )
         ),
-        reports.service_commands_on_nodes_skipped(
-            reason_type,
-            ["pacemaker_remote start", "pacemaker_remote enable"],
-            [new_node_name]
+        ReportItem.info(
+            reports.messages.ServiceCommandsOnNodesSkipped(
+                reason_type,
+                ["pacemaker_remote start", "pacemaker_remote enable"],
+                [new_node_name],
+            )
         ),
     ]
 
+
 def _get_targets_for_add(
-    target_factory, report_processor, existing_nodes_names, new_nodes_names,
-    skip_offline_nodes
+    target_factory,
+    report_processor,
+    existing_nodes_names,
+    new_nodes_names,
+    skip_offline_nodes,
 ):
     # Get targets for all existing nodes and report unknown (not-authorized)
     # nodes.
-    target_report_list, existing_target_list = (
-        target_factory.get_target_list_with_reports(
-            existing_nodes_names,
-            skip_non_existing=skip_offline_nodes
-        )
+    (
+        target_report_list,
+        existing_target_list,
+    ) = target_factory.get_target_list_with_reports(
+        existing_nodes_names, skip_non_existing=skip_offline_nodes
     )
     report_processor.report_list(target_report_list)
     # Get a target for the new node.
-    target_report_list, new_target_list = (
-        target_factory.get_target_list_with_reports(
-            new_nodes_names,
-            skip_non_existing=skip_offline_nodes,
-            # continue even if the new node is unknown when skip is True
-            report_none_host_found=False
-        )
+    (
+        target_report_list,
+        new_target_list,
+    ) = target_factory.get_target_list_with_reports(
+        new_nodes_names,
+        skip_non_existing=skip_offline_nodes,
+        # continue even if the new node is unknown when skip is True
+        report_none_host_found=False,
     )
     report_processor.report_list(target_report_list)
     return existing_target_list, new_target_list
 
+
 def _host_check_remote_node(host_info_dict):
     # Version of services may not be the same across the existing cluster
     # nodes, so it's not easy to make this check properly.
     report_list = []
     required_service_list = ["pacemaker_remote"]
-    required_as_stopped_service_list = (
-        required_service_list + ["pacemaker", "corosync"]
-    )
+    required_as_stopped_service_list = required_service_list + [
+        "pacemaker",
+        "corosync",
+    ]
     for host_name, host_info in host_info_dict.items():
         try:
             services = host_info["services"]
             missing_service_list = [
-                service for service in required_service_list
+                service
+                for service in required_service_list
                 if not services[service]["installed"]
             ]
             if missing_service_list:
-                report_list.append(reports.service_not_installed(
-                    host_name, missing_service_list
-                ))
+                report_list.append(
+                    ReportItem.error(
+                        reports.messages.ServiceNotInstalled(
+                            host_name, sorted(missing_service_list)
+                        )
+                    )
+                )
             cannot_be_running_service_list = [
-                service for service in required_as_stopped_service_list
+                service
+                for service in required_as_stopped_service_list
                 if service in services and services[service]["running"]
             ]
             if cannot_be_running_service_list:
                 report_list.append(
-                    reports.host_already_in_cluster_services(
-                        host_name,
-                        cannot_be_running_service_list,
+                    ReportItem.error(
+                        reports.messages.HostAlreadyInClusterServices(
+                            host_name,
+                            sorted(cannot_be_running_service_list),
+                        )
                     )
                 )
             if host_info["cluster_configuration_exists"]:
                 report_list.append(
-                    reports.host_already_in_cluster_config(host_name)
+                    ReportItem.error(
+                        reports.messages.HostAlreadyInClusterConfig(host_name)
+                    )
                 )
         except (KeyError, TypeError):
-            report_list.append(reports.invalid_response_format(host_name))
+            report_list.append(
+                ReportItem.error(
+                    reports.messages.InvalidResponseFormat(host_name)
+                )
+            )
     return report_list
 
+
 def _prepare_pacemaker_remote_environment(
-    env, report_processor, existing_nodes_target_list, new_node_target,
-    new_node_name, skip_offline_nodes, allow_incomplete_distribution,
-    allow_fails
+    env,
+    report_processor,
+    existing_nodes_target_list,
+    new_node_target,
+    new_node_name,
+    skip_offline_nodes,
+    allow_incomplete_distribution,
+    allow_fails,
 ):
     if new_node_target:
         com_cmd = GetOnlineTargets(
@@ -171,101 +220,150 @@ def _prepare_pacemaker_remote_environment(
     if online_new_target_list:
         com_cmd = ServiceAction(
             report_processor,
-            node_communication_format.create_pcmk_remote_actions([
-                "start",
-                "enable",
-            ]),
+            node_communication_format.create_pcmk_remote_actions(
+                [
+                    "start",
+                    "enable",
+                ]
+            ),
             allow_fails=allow_fails,
         )
         com_cmd.set_targets(online_new_target_list)
         run_and_raise(env.get_node_communicator(), com_cmd)
 
-def _ensure_resource_running(env, resource_id):
-    env.report_processor.process(
+
+def _ensure_resource_running(env: LibraryEnvironment, resource_id):
+    if env.report_processor.report(
         state.ensure_resource_running(env.get_cluster_state(), resource_id)
-    )
+    ).has_errors:
+        raise LibraryError()
+
 
 def node_add_remote(
-    env, node_name, node_addr, operations, meta_attributes, instance_attributes,
-    skip_offline_nodes=False,
-    allow_incomplete_distribution=False,
-    allow_pacemaker_remote_service_fail=False,
-    allow_invalid_operation=False,
-    allow_invalid_instance_attributes=False,
-    use_default_operations=True,
-    wait=False,
+    env: LibraryEnvironment,
+    node_name: str,
+    node_addr: Optional[str],
+    operations: Iterable[Mapping[str, str]],
+    meta_attributes: Mapping[str, str],
+    instance_attributes: Mapping[str, str],
+    skip_offline_nodes: bool = False,
+    allow_incomplete_distribution: bool = False,
+    allow_pacemaker_remote_service_fail: bool = False,
+    allow_invalid_operation: bool = False,
+    allow_invalid_instance_attributes: bool = False,
+    use_default_operations: bool = True,
+    wait: WaitType = False,
 ):
-    # pylint: disable=too-many-arguments, too-many-branches, too-many-locals
+    # pylint: disable=too-many-arguments
+    # pylint: disable=too-many-branches
+    # pylint: disable=too-many-locals
+    # pylint: disable=too-many-statements
     """
     create an ocf:pacemaker:remote resource and use it as a remote node
 
-    LibraryEnvironment env -- provides all for communication with externals
-    string node_name -- the name of the new node
-    mixed node_addr -- the address of the new node or None for default
-    list of dict operations -- attributes for each entered operation
-    dict meta_attributes -- attributes for primitive/meta_attributes
-    dict instance_attributes -- attributes for primitive/instance_attributes
-    bool skip_offline_nodes -- if True, ignore when some nodes are offline
-    bool allow_incomplete_distribution -- if True, allow this command to
+    env -- provides all for communication with externals
+    node_name -- the name of the new node
+    node_addr -- the address of the new node or None for default
+    operations -- attributes for each entered operation
+    meta_attributes -- attributes for primitive/meta_attributes
+    instance_attributes -- attributes for primitive/instance_attributes
+    skip_offline_nodes -- if True, ignore when some nodes are offline
+    allow_incomplete_distribution -- if True, allow this command to
         finish successfully even if file distribution did not succeed
-    bool allow_pacemaker_remote_service_fail -- if True, allow this command to
+    allow_pacemaker_remote_service_fail -- if True, allow this command to
         finish successfully even if starting/enabling pacemaker_remote did not
         succeed
-    bool allow_invalid_operation -- if True, allow to use operations that
+    allow_invalid_operation -- if True, allow to use operations that
         are not listed in a resource agent metadata
-    bool allow_invalid_instance_attributes -- if True, allow to use instance
+    allow_invalid_instance_attributes -- if True, allow to use instance
         attributes that are not listed in a resource agent metadata and allow to
         omit required instance_attributes
-    bool use_default_operations -- if True, add operations specified in
+    use_default_operations -- if True, add operations specified in
         a resource agent metadata to the resource
-    mixed wait -- a flag for controlling waiting for pacemaker idle mechanism
+    wait -- a flag for controlling waiting for pacemaker idle mechanism
     """
     env.ensure_wait_satisfiable(wait)
 
-    report_processor = SimpleReportProcessor(env.report_processor)
-    cib = env.get_cib()
+    report_processor = env.report_processor
+    cib = env.get_cib(
+        minimal_version=get_required_cib_version_for_primitive(operations)
+    )
     id_provider = IdProvider(cib)
     if env.is_cib_live:
-        corosync_conf = env.get_corosync_conf()
+        corosync_conf: Optional[CorosyncConfigFacade] = env.get_corosync_conf()
     else:
         corosync_conf = None
         report_processor.report(
-            reports.corosync_node_conflict_check_skipped("not_live_cib")
+            ReportItem.info(
+                reports.messages.CorosyncNodeConflictCheckSkipped(
+                    reports.const.REASON_NOT_LIVE_CIB,
+                )
+            )
         )
-    existing_nodes_names, existing_nodes_addrs, report_list = (
-        get_existing_nodes_names_addrs(corosync_conf, cib)
-    )
+    (
+        existing_nodes_names,
+        existing_nodes_addrs,
+        report_list,
+    ) = get_existing_nodes_names_addrs(corosync_conf, cib)
     if env.is_cib_live:
         # We just reported corosync checks are going to be skipped so we
         # shouldn't complain about errors related to corosync nodes
         report_processor.report_list(report_list)
 
     resource_agent = remote_node.get_agent(
-        env.report_processor,
-        env.cmd_runner()
+        env.report_processor, env.cmd_runner()
     )
 
     existing_target_list = []
     if env.is_cib_live:
         target_factory = env.get_node_target_factory()
         existing_target_list, new_target_list = _get_targets_for_add(
-            target_factory, report_processor, existing_nodes_names, [node_name],
-            skip_offline_nodes
+            target_factory,
+            report_processor,
+            existing_nodes_names,
+            [node_name],
+            skip_offline_nodes,
         )
         new_target = new_target_list[0] if new_target_list else None
         # default node_addr to an address from known-hosts
         if node_addr is None:
-            node_addr = new_target.first_addr if new_target else node_name
+            if new_target:
+                node_addr = new_target.first_addr
+                node_addr_source = (
+                    reports.const.DEFAULT_ADDRESS_SOURCE_KNOWN_HOSTS
+                )
+            else:
+                node_addr = node_name
+                node_addr_source = (
+                    reports.const.DEFAULT_ADDRESS_SOURCE_HOST_NAME
+                )
             report_processor.report(
-                reports.using_known_host_address_for_host(node_name, node_addr)
+                ReportItem.info(
+                    reports.messages.UsingDefaultAddressForHost(
+                        node_name, node_addr, node_addr_source
+                    )
+                )
             )
     else:
         # default node_addr to an address from known-hosts
         if node_addr is None:
             known_hosts = env.get_known_hosts([node_name])
-            node_addr = known_hosts[0].dest.addr if known_hosts else node_name
+            if known_hosts:
+                node_addr = known_hosts[0].dest.addr
+                node_addr_source = (
+                    reports.const.DEFAULT_ADDRESS_SOURCE_KNOWN_HOSTS
+                )
+            else:
+                node_addr = node_name
+                node_addr_source = (
+                    reports.const.DEFAULT_ADDRESS_SOURCE_HOST_NAME
+                )
             report_processor.report(
-                reports.using_known_host_address_for_host(node_name, node_addr)
+                ReportItem.info(
+                    reports.messages.UsingDefaultAddressForHost(
+                        node_name, node_addr, node_addr_source
+                    )
+                )
             )
 
     # validate inputs
@@ -275,8 +373,10 @@ def node_add_remote(
         resource_agent,
         node_name,
         node_addr,
-        instance_attributes
+        instance_attributes,
     )
+    if report_processor.report_list(report_list).has_errors:
+        raise LibraryError()
     # validation + cib setup
     # TODO extract the validation to a separate function
     try:
@@ -295,24 +395,25 @@ def node_add_remote(
             use_default_operations,
         )
     except LibraryError as e:
-        #Check unique id conflict with check against nodes. Until validation
-        #resource create is not separated, we need to make unique post
-        #validation.
+        # Check unique id conflict with check against nodes. Until validation
+        # resource create is not separated, we need to make unique post
+        # validation.
         already_exists = []
         unified_report_list = []
-        for report in report_list + list(e.args):
-            if report.code not in (
-                report_codes.ID_ALREADY_EXISTS,
-                report_codes.RESOURCE_INSTANCE_ATTR_VALUE_NOT_UNIQUE,
+        for report_item in report_list + list(e.args):
+            # pylint: disable=no-member
+            dto_obj = report_item.message.to_dto()
+            if dto_obj.code not in (
+                reports.codes.ID_ALREADY_EXISTS,
+                reports.codes.RESOURCE_INSTANCE_ATTR_VALUE_NOT_UNIQUE,
             ):
-                unified_report_list.append(report)
+                unified_report_list.append(report_item)
             elif (
-                "id" in report.info
-                and
-                report.info["id"] not in already_exists
+                "id" in dto_obj.payload
+                and dto_obj.payload["id"] not in already_exists
             ):
-                unified_report_list.append(report)
-                already_exists.append(report.info["id"])
+                unified_report_list.append(report_item)
+                already_exists.append(dto_obj.payload["id"])
         report_list = unified_report_list
 
     report_processor.report_list(report_list)
@@ -340,14 +441,20 @@ def node_add_remote(
     if wait:
         _ensure_resource_running(env, remote_resource_element.attrib["id"])
 
+
 def node_add_guest(
-    env, node_name, resource_id, options,
+    env,
+    node_name,
+    resource_id,
+    options,
     skip_offline_nodes=False,
     allow_incomplete_distribution=False,
     allow_pacemaker_remote_service_fail=False,
     wait=False,
 ):
+    # pylint: disable=too-many-branches
     # pylint: disable=too-many-locals
+    # pylint: disable=too-many-statements
     """
     Make a guest node from the specified resource
 
@@ -366,7 +473,7 @@ def node_add_guest(
     """
     env.ensure_wait_satisfiable(wait)
 
-    report_processor = SimpleReportProcessor(env.report_processor)
+    report_processor = env.report_processor
     cib = env.get_cib()
     id_provider = IdProvider(cib)
     if env.is_cib_live:
@@ -374,11 +481,17 @@ def node_add_guest(
     else:
         corosync_conf = None
         report_processor.report(
-            reports.corosync_node_conflict_check_skipped("not_live_cib")
+            ReportItem.info(
+                reports.messages.CorosyncNodeConflictCheckSkipped(
+                    reports.const.REASON_NOT_LIVE_CIB,
+                )
+            )
         )
-    existing_nodes_names, existing_nodes_addrs, report_list = (
-        get_existing_nodes_names_addrs(corosync_conf, cib)
-    )
+    (
+        existing_nodes_names,
+        existing_nodes_addrs,
+        report_list,
+    ) = get_existing_nodes_names_addrs(corosync_conf, cib)
     if env.is_cib_live:
         # We just reported corosync checks are going to be skipped so we
         # shouldn't complain about errors related to corosync nodes
@@ -388,34 +501,55 @@ def node_add_guest(
     if env.is_cib_live:
         target_factory = env.get_node_target_factory()
         existing_target_list, new_target_list = _get_targets_for_add(
-            target_factory, report_processor, existing_nodes_names, [node_name],
-            skip_offline_nodes
+            target_factory,
+            report_processor,
+            existing_nodes_names,
+            [node_name],
+            skip_offline_nodes,
         )
         new_target = new_target_list[0] if new_target_list else None
         # default remote-addr to an address from known-hosts
         if "remote-addr" not in options or options["remote-addr"] is None:
-            new_addr = new_target.first_addr if new_target else node_name
+            if new_target:
+                new_addr = new_target.first_addr
+                new_addr_source = (
+                    reports.const.DEFAULT_ADDRESS_SOURCE_KNOWN_HOSTS
+                )
+            else:
+                new_addr = node_name
+                new_addr_source = reports.const.DEFAULT_ADDRESS_SOURCE_HOST_NAME
             options["remote-addr"] = new_addr
             report_processor.report(
-                reports.using_known_host_address_for_host(node_name, new_addr)
+                ReportItem.info(
+                    reports.messages.UsingDefaultAddressForHost(
+                        node_name, new_addr, new_addr_source
+                    )
+                )
             )
     else:
         # default remote-addr to an address from known-hosts
         if "remote-addr" not in options or options["remote-addr"] is None:
             known_hosts = env.get_known_hosts([node_name])
-            new_addr = known_hosts[0].dest.addr if known_hosts else node_name
+            if known_hosts:
+                new_addr = known_hosts[0].dest.addr
+                new_addr_source = (
+                    reports.const.DEFAULT_ADDRESS_SOURCE_KNOWN_HOSTS
+                )
+            else:
+                new_addr = node_name
+                new_addr_source = reports.const.DEFAULT_ADDRESS_SOURCE_HOST_NAME
             options["remote-addr"] = new_addr
             report_processor.report(
-                reports.using_known_host_address_for_host(node_name, new_addr)
+                ReportItem.info(
+                    reports.messages.UsingDefaultAddressForHost(
+                        node_name, new_addr, new_addr_source
+                    )
+                )
             )
 
     # validate inputs
     report_list = guest_node.validate_set_as_guest(
-        cib,
-        existing_nodes_names,
-        existing_nodes_addrs,
-        node_name,
-        options
+        cib, existing_nodes_names, existing_nodes_addrs, node_name, options
     )
     searcher = ElementSearcher(primitive.TAG, resource_id, get_resources(cib))
     if searcher.element_found():
@@ -458,38 +592,55 @@ def node_add_guest(
     if wait:
         _ensure_resource_running(env, resource_id)
 
+
 def _find_resources_to_remove(
-    cib, report_processor,
-    node_type, node_identifier, allow_remove_multiple_nodes,
-    find_resources
+    cib,
+    report_processor: ReportProcessor,
+    node_type,
+    node_identifier,
+    allow_remove_multiple_nodes,
+    find_resources,
 ):
     resource_element_list = find_resources(get_resources(cib), node_identifier)
 
     if not resource_element_list:
-        raise LibraryError(reports.node_not_found(node_identifier, node_type))
-
-    if len(resource_element_list) > 1:
-        report_processor.process(
-            reports.get_problem_creator(
-                report_codes.FORCE_REMOVE_MULTIPLE_NODES,
-                allow_remove_multiple_nodes
-            )(
-                reports.multiple_result_found,
-                "resource",
-                [resource.attrib["id"] for resource in resource_element_list],
-                node_identifier
+        raise LibraryError(
+            ReportItem.error(
+                reports.messages.NodeNotFound(node_identifier, [node_type])
             )
         )
 
+    if len(resource_element_list) > 1:
+        if report_processor.report(
+            ReportItem(
+                severity=reports.item.get_severity(
+                    reports.codes.FORCE_REMOVE_MULTIPLE_NODES,
+                    allow_remove_multiple_nodes,
+                ),
+                message=reports.messages.MultipleResultsFound(
+                    "resource",
+                    [
+                        resource.attrib["id"]
+                        for resource in resource_element_list
+                    ],
+                    node_identifier,
+                ),
+            )
+        ).has_errors:
+            raise LibraryError()
+
     return resource_element_list
 
+
 def _destroy_pcmk_remote_env(
     env, node_names_list, skip_offline_nodes, allow_fails
 ):
-    actions = node_communication_format.create_pcmk_remote_actions([
-        "stop",
-        "disable",
-    ])
+    actions = node_communication_format.create_pcmk_remote_actions(
+        [
+            "stop",
+            "disable",
+        ]
+    )
     files = {
         "pacemaker_remote authkey": {"type": "pcmk_remote_authkey"},
     }
@@ -516,25 +667,33 @@ def _destroy_pcmk_remote_env(
     com_cmd.set_targets(target_list)
     run_and_raise(env.get_node_communicator(), com_cmd)
 
+
 def _report_skip_live_parts_in_remove(node_names_list):
     return [
-        reports.service_commands_on_nodes_skipped(
-            "not_live_cib",
-            ["pacemaker_remote stop", "pacemaker_remote disable"],
-            node_names_list
+        ReportItem.info(
+            reports.messages.ServiceCommandsOnNodesSkipped(
+                reports.const.REASON_NOT_LIVE_CIB,
+                ["pacemaker_remote stop", "pacemaker_remote disable"],
+                node_names_list,
+            )
+        ),
+        ReportItem.info(
+            reports.messages.FilesRemoveFromNodesSkipped(
+                reports.const.REASON_NOT_LIVE_CIB,
+                ["pacemaker authkey"],
+                node_names_list,
+            )
         ),
-        reports.files_remove_from_nodes_skipped(
-            "not_live_cib",
-            ["pacemaker authkey"],
-            node_names_list
-        )
     ]
 
+
 def node_remove_remote(
-    env, node_identifier, remove_resource,
+    env,
+    node_identifier,
+    remove_resource,
     skip_offline_nodes=False,
     allow_remove_multiple_nodes=False,
-    allow_pacemaker_remote_service_fail=False
+    allow_pacemaker_remote_service_fail=False,
 ):
     """
     remove a resource representing remote node and destroy remote node
@@ -560,13 +719,15 @@ def node_remove_remote(
         remote_node.find_node_resources,
     )
 
-    node_names_list = sorted({
-        remote_node.get_node_name_from_resource(node_element)
-        for node_element in resource_element_list
-    })
+    node_names_list = sorted(
+        {
+            remote_node.get_node_name_from_resource(node_element)
+            for node_element in resource_element_list
+        }
+    )
 
     if not env.is_cib_live:
-        env.report_processor.process_list(
+        env.report_processor.report_list(
             _report_skip_live_parts_in_remove(node_names_list)
         )
     else:
@@ -574,19 +735,21 @@ def node_remove_remote(
             env,
             node_names_list,
             skip_offline_nodes,
-            allow_pacemaker_remote_service_fail
+            allow_pacemaker_remote_service_fail,
         )
 
-    #remove node from pcmk caches is currently integrated in remove_resource
-    #function
+    # remove node from pcmk caches is currently integrated in remove_resource
+    # function
     for resource_element in resource_element_list:
         remove_resource(
             resource_element.attrib["id"],
             is_remove_remote_context=True,
         )
 
+
 def node_remove_guest(
-    env, node_identifier,
+    env,
+    node_identifier,
     skip_offline_nodes=False,
     allow_remove_multiple_nodes=False,
     allow_pacemaker_remote_service_fail=False,
@@ -616,13 +779,15 @@ def node_remove_guest(
         guest_node.find_node_resources,
     )
 
-    node_names_list = sorted({
-        guest_node.get_node_name_from_resource(node_element)
-        for node_element in resource_element_list
-    })
+    node_names_list = sorted(
+        {
+            guest_node.get_node_name_from_resource(node_element)
+            for node_element in resource_element_list
+        }
+    )
 
     if not env.is_cib_live:
-        env.report_processor.process_list(
+        env.report_processor.report_list(
             _report_skip_live_parts_in_remove(node_names_list)
         )
     else:
@@ -630,7 +795,7 @@ def node_remove_guest(
             env,
             node_names_list,
             skip_offline_nodes,
-            allow_pacemaker_remote_service_fail
+            allow_pacemaker_remote_service_fail,
         )
 
     for resource_element in resource_element_list:
@@ -638,7 +803,7 @@ def node_remove_guest(
 
     env.push_cib(wait=wait)
 
-    #remove node from pcmk caches
+    # remove node from pcmk caches
     if env.is_cib_live:
         for node_name in node_names_list:
             remove_node(env.cmd_runner(), node_name)
