@@ -2,6 +2,7 @@
 from contextlib import contextmanager
 from functools import partial
 from typing import (
+    cast,
     Any,
     Callable,
     Iterable,
@@ -12,19 +13,23 @@ from typing import (
     Tuple,
     Union,
 )
-from xml.etree.ElementTree import Element
+
+from lxml.etree import _Element
 
 from pcs.common import file_type_codes
 from pcs.common.interface import dto
 from pcs.common import reports
 from pcs.common.reports import ReportItemList
 from pcs.common.reports.item import ReportItem
-from pcs.common.reports.processor import ReportProcessor
 from pcs.common.tools import Version
 from pcs.lib.cib import (
     resource,
     status as cib_status,
 )
+from pcs.lib.cib.tag import (
+    expand_tag,
+    TAG_TAG,
+)
 from pcs.lib.cib.tools import (
     find_element_by_tag_and_id,
     get_resources,
@@ -61,6 +66,9 @@ from pcs.lib.resource_agent import (
 from pcs.lib.validate import ValueTimeInterval
 
 
+WaitType = Union[None, bool, int]
+
+
 @contextmanager
 def resource_environment(
     env,
@@ -76,10 +84,10 @@ def resource_environment(
 
 def _push_cib_wait(
     env: LibraryEnvironment,
-    wait: Optional[Union[bool, int]] = False,
+    wait: WaitType = False,
     wait_for_resource_ids: Optional[Iterable[str]] = None,
     resource_state_reporter: Callable[
-        [Element, str], ReportItem
+        [_Element, str], ReportItem
     ] = info_resource_state,
 ) -> None:
     env.push_cib(wait=wait)
@@ -262,44 +270,43 @@ def _get_required_cib_version_for_container(
 
 
 def create(
-    env,
-    resource_id,
-    resource_agent_name,
-    operation_list,
-    meta_attributes,
-    instance_attributes,
-    allow_absent_agent=False,
-    allow_invalid_operation=False,
-    allow_invalid_instance_attributes=False,
-    use_default_operations=True,
-    ensure_disabled=False,
-    wait=False,
-    allow_not_suitable_command=False,
+    env: LibraryEnvironment,
+    resource_id: str,
+    resource_agent_name: str,
+    operation_list: Iterable[Mapping[str, str]],
+    meta_attributes: Mapping[str, str],
+    instance_attributes: Mapping[str, str],
+    allow_absent_agent: bool = False,
+    allow_invalid_operation: bool = False,
+    allow_invalid_instance_attributes: bool = False,
+    use_default_operations: bool = True,
+    ensure_disabled: bool = False,
+    wait: WaitType = False,
+    allow_not_suitable_command: bool = False,
 ):
     # pylint: disable=too-many-arguments, too-many-locals
     """
-    Create resource in a cib.
+    Create a primitive resource in a cib.
 
-    LibraryEnvironment env provides all for communication with externals
-    string resource_id is identifier of resource
-    string resource_agent_name contains name for the identification of agent
-    list of dict operation_list contains attributes for each entered operation
-    dict meta_attributes contains attributes for primitive/meta_attributes
-    dict instance_attributes contains attributes for
-        primitive/instance_attributes
-    bool allow_absent_agent is a flag for allowing agent that is not installed
+    env -- provides all for communication with externals
+    resource_id -- is identifier of resource
+    resource_agent_name -- contains name for the identification of agent
+    operation_list -- contains attributes for each entered operation
+    meta_attributes -- contains attributes for primitive/meta_attributes
+    instance_attributes -- contains attributes for primitive/instance_attributes
+    allow_absent_agent -- is a flag for allowing agent that is not installed
         in a system
-    bool allow_invalid_operation is a flag for allowing to use operations that
+    allow_invalid_operation -- is a flag for allowing to use operations that
         are not listed in a resource agent metadata
-    bool allow_invalid_instance_attributes is a flag for allowing to use
+    allow_invalid_instance_attributes -- is a flag for allowing to use
         instance attributes that are not listed in a resource agent metadata
         or for allowing to not use the instance_attributes that are required in
         resource agent metadata
-    bool use_default_operations is a flag for stopping stopping of adding
+    use_default_operations -- is a flag for stopping stopping of adding
         default cib operations (specified in a resource agent)
-    bool ensure_disabled is flag that keeps resource in target-role "Stopped"
-    mixed wait is flag for controlling waiting for pacemaker idle mechanism
-    bool allow_not_suitable_command -- flag for FORCE_NOT_SUITABLE_COMMAND
+    ensure_disabled -- is flag that keeps resource in target-role "Stopped"
+    wait -- is flag for controlling waiting for pacemaker idle mechanism
+    allow_not_suitable_command -- flag for FORCE_NOT_SUITABLE_COMMAND
     """
     resource_agent = get_agent(
         env.report_processor,
@@ -315,6 +322,9 @@ def create(
             ensure_disabled
             or resource.common.are_meta_disabled(meta_attributes)
         ),
+        required_cib_version=get_required_cib_version_for_primitive(
+            operation_list
+        ),
     ) as resources_section:
         id_provider = IdProvider(resources_section)
         _check_special_cases(
@@ -345,46 +355,48 @@ def create(
 
 
 def create_as_clone(
-    env,
-    resource_id,
-    resource_agent_name,
-    operation_list,
-    meta_attributes,
-    instance_attributes,
-    clone_meta_options,
-    allow_absent_agent=False,
-    allow_invalid_operation=False,
-    allow_invalid_instance_attributes=False,
-    use_default_operations=True,
-    ensure_disabled=False,
-    wait=False,
-    allow_not_suitable_command=False,
+    env: LibraryEnvironment,
+    resource_id: str,
+    resource_agent_name: str,
+    operation_list: Iterable[Mapping[str, str]],
+    meta_attributes: Mapping[str, str],
+    instance_attributes: Mapping[str, str],
+    clone_meta_options: Mapping[str, str],
+    clone_id: Optional[str] = None,
+    allow_absent_agent: bool = False,
+    allow_invalid_operation: bool = False,
+    allow_invalid_instance_attributes: bool = False,
+    use_default_operations: bool = True,
+    ensure_disabled: bool = False,
+    wait: WaitType = False,
+    allow_not_suitable_command: bool = False,
 ):
     # pylint: disable=too-many-arguments, too-many-locals
     """
-    Create resource in a clone
+    Create a primitive resource in a clone
 
-    LibraryEnvironment env provides all for communication with externals
-    string resource_id is identifier of resource
-    string resource_agent_name contains name for the identification of agent
-    list of dict operation_list contains attributes for each entered operation
-    dict meta_attributes contains attributes for primitive/meta_attributes
-    dict instance_attributes contains attributes for
-        primitive/instance_attributes
-    dict clone_meta_options contains attributes for clone/meta_attributes
-    bool allow_absent_agent is a flag for allowing agent that is not installed
+    env -- provides all for communication with externals
+    resource_id -- is identifier of resource
+    resource_agent_name -- contains name for the identification of agent
+    operation_list -- contains attributes for each entered operation
+    meta_attributes -- contains attributes for primitive/meta_attributes
+    instance_attributes -- contains attributes for primitive/instance_attributes
+    clone_meta_options -- contains attributes for clone/meta_attributes
+    clone_id -- optional custom clone id, if not set then clone id is generated
+        from primitive resource or group id
+    allow_absent_agent -- is a flag for allowing agent that is not installed
         in a system
-    bool allow_invalid_operation is a flag for allowing to use operations that
+    allow_invalid_operation -- is a flag for allowing to use operations that
         are not listed in a resource agent metadata
-    bool allow_invalid_instance_attributes is a flag for allowing to use
+    allow_invalid_instance_attributes -- is a flag for allowing to use
         instance attributes that are not listed in a resource agent metadata
         or for allowing to not use the instance_attributes that are required in
         resource agent metadata
-    bool use_default_operations is a flag for stopping stopping of adding
+    use_default_operations -- is a flag for stopping stopping of adding
         default cib operations (specified in a resource agent)
-    bool ensure_disabled is flag that keeps resource in target-role "Stopped"
-    mixed wait is flag for controlling waiting for pacemaker idle mechanism
-    bool allow_not_suitable_command -- flag for FORCE_NOT_SUITABLE_COMMAND
+    ensure_disabled -- is flag that keeps resource in target-role "Stopped"
+    wait -- is flag for controlling waiting for pacemaker idle mechanism
+    allow_not_suitable_command -- flag for FORCE_NOT_SUITABLE_COMMAND
     """
     resource_agent = get_agent(
         env.report_processor,
@@ -401,6 +413,9 @@ def create_as_clone(
             or resource.common.are_meta_disabled(meta_attributes)
             or resource.common.is_clone_deactivated_by_meta(clone_meta_options)
         ),
+        required_cib_version=get_required_cib_version_for_primitive(
+            operation_list
+        ),
     ) as resources_section:
         id_provider = IdProvider(resources_section)
         _check_special_cases(
@@ -426,60 +441,67 @@ def create_as_clone(
             allow_invalid_instance_attributes,
             use_default_operations,
         )
+        if clone_id is not None:
+            if env.report_processor.report_list(
+                resource.clone.validate_clone_id(clone_id, id_provider),
+            ).has_errors:
+                raise LibraryError()
         clone_element = resource.clone.append_new(
             resources_section,
             id_provider,
             primitive_element,
             clone_meta_options,
+            clone_id=clone_id,
         )
         if ensure_disabled:
             resource.common.disable(clone_element, id_provider)
 
 
 def create_in_group(
-    env,
-    resource_id,
-    resource_agent_name,
-    group_id,
-    operation_list,
-    meta_attributes,
-    instance_attributes,
-    allow_absent_agent=False,
-    allow_invalid_operation=False,
-    allow_invalid_instance_attributes=False,
-    use_default_operations=True,
-    ensure_disabled=False,
-    adjacent_resource_id=None,
-    put_after_adjacent=False,
-    wait=False,
-    allow_not_suitable_command=False,
+    env: LibraryEnvironment,
+    resource_id: str,
+    resource_agent_name: str,
+    group_id: str,
+    operation_list: Iterable[Mapping[str, str]],
+    meta_attributes: Mapping[str, str],
+    instance_attributes: Mapping[str, str],
+    allow_absent_agent: bool = False,
+    allow_invalid_operation: bool = False,
+    allow_invalid_instance_attributes: bool = False,
+    use_default_operations: bool = True,
+    ensure_disabled: bool = False,
+    adjacent_resource_id: Optional[str] = None,
+    put_after_adjacent: bool = False,
+    wait: WaitType = False,
+    allow_not_suitable_command: bool = False,
 ):
     # pylint: disable=too-many-arguments, too-many-locals
     """
     Create resource in a cib and put it into defined group
 
-    LibraryEnvironment env provides all for communication with externals
-    string resource_id is identifier of resource
-    string resource_agent_name contains name for the identification of agent
-    string group_id is identificator for group to put primitive resource inside
-    list of dict operation_list contains attributes for each entered operation
-    dict meta_attributes contains attributes for primitive/meta_attributes
-    bool allow_absent_agent is a flag for allowing agent that is not installed
+    env -- provides all for communication with externals
+    resource_id -- is identifier of resource
+    resource_agent_name -- contains name for the identification of agent
+    group_id -- is identificator for group to put primitive resource inside
+    operation_list -- contains attributes for each entered operation
+    meta_attributes -- contains attributes for primitive/meta_attributes
+    instance_attributes -- contains attributes for primitive/instance_attributes
+    allow_absent_agent -- is a flag for allowing agent that is not installed
         in a system
-    bool allow_invalid_operation is a flag for allowing to use operations that
+    allow_invalid_operation -- is a flag for allowing to use operations that
         are not listed in a resource agent metadata
-    bool allow_invalid_instance_attributes is a flag for allowing to use
+    allow_invalid_instance_attributes -- is a flag for allowing to use
         instance attributes that are not listed in a resource agent metadata
         or for allowing to not use the instance_attributes that are required in
         resource agent metadata
-    bool use_default_operations is a flag for stopping stopping of adding
+    use_default_operations -- is a flag for stopping stopping of adding
         default cib operations (specified in a resource agent)
-    bool ensure_disabled is flag that keeps resource in target-role "Stopped"
-    string adjacent_resource_id identify neighbor of a newly created resource
-    bool put_after_adjacent is flag to put a newly create resource befor/after
+    ensure_disabled -- is flag that keeps resource in target-role "Stopped"
+    adjacent_resource_id -- identify neighbor of a newly created resource
+    put_after_adjacent -- is flag to put a newly create resource befor/after
         adjacent resource
-    mixed wait is flag for controlling waiting for pacemaker idle mechanism
-    bool allow_not_suitable_command -- flag for FORCE_NOT_SUITABLE_COMMAND
+    wait -- is flag for controlling waiting for pacemaker idle mechanism
+    allow_not_suitable_command -- flag for FORCE_NOT_SUITABLE_COMMAND
     """
     resource_agent = get_agent(
         env.report_processor,
@@ -495,6 +517,9 @@ def create_in_group(
             ensure_disabled
             or resource.common.are_meta_disabled(meta_attributes)
         ),
+        required_cib_version=get_required_cib_version_for_primitive(
+            operation_list
+        ),
     ) as resources_section:
         id_provider = IdProvider(resources_section)
         _check_special_cases(
@@ -532,48 +557,48 @@ def create_in_group(
 
 
 def create_into_bundle(
-    env,
-    resource_id,
-    resource_agent_name,
-    operation_list,
-    meta_attributes,
-    instance_attributes,
-    bundle_id,
-    allow_absent_agent=False,
-    allow_invalid_operation=False,
-    allow_invalid_instance_attributes=False,
-    use_default_operations=True,
-    ensure_disabled=False,
-    wait=False,
-    allow_not_suitable_command=False,
-    allow_not_accessible_resource=False,
+    env: LibraryEnvironment,
+    resource_id: str,
+    resource_agent_name: str,
+    operation_list: Iterable[Mapping[str, str]],
+    meta_attributes: Mapping[str, str],
+    instance_attributes: Mapping[str, str],
+    bundle_id: str,
+    allow_absent_agent: bool = False,
+    allow_invalid_operation: bool = False,
+    allow_invalid_instance_attributes: bool = False,
+    use_default_operations: bool = True,
+    ensure_disabled: bool = False,
+    wait: WaitType = False,
+    allow_not_suitable_command: bool = False,
+    allow_not_accessible_resource: bool = False,
 ):
     # pylint: disable=too-many-arguments, too-many-locals
     """
     Create a new resource in a cib and put it into an existing bundle
 
-    LibraryEnvironment env provides all for communication with externals
-    string resource_id is identifier of resource
-    string resource_agent_name contains name for the identification of agent
-    list of dict operation_list contains attributes for each entered operation
-    dict meta_attributes contains attributes for primitive/meta_attributes
-    dict instance_attributes contains attributes for
+    env -- provides all for communication with externals
+    resource_id -- is identifier of resource
+    resource_agent_name -- contains name for the identification of agent
+    operation_list -- contains attributes for each entered operation
+    meta_attributes -- contains attributes for primitive/meta_attributes
+    instance_attributes -- contains attributes for
         primitive/instance_attributes
-    string bundle_id is id of an existing bundle to put the created resource in
-    bool allow_absent_agent is a flag for allowing agent that is not installed
+    bundle_id -- is id of an existing bundle to put the created resource in
+    allow_absent_agent -- is a flag for allowing agent that is not installed
         in a system
-    bool allow_invalid_operation is a flag for allowing to use operations that
+    allow_invalid_operation -- is a flag for allowing to use operations that
         are not listed in a resource agent metadata
-    bool allow_invalid_instance_attributes is a flag for allowing to use
+    allow_invalid_instance_attributes -- is a flag for allowing to use
         instance attributes that are not listed in a resource agent metadata
         or for allowing to not use the instance_attributes that are required in
         resource agent metadata
-    bool use_default_operations is a flag for stopping stopping of adding
+    use_default_operations -- is a flag for stopping stopping of adding
         default cib operations (specified in a resource agent)
-    bool ensure_disabled is flag that keeps resource in target-role "Stopped"
-    mixed wait is flag for controlling waiting for pacemaker idle mechanism
-    bool allow_not_suitable_command -- flag for FORCE_NOT_SUITABLE_COMMAND
-    bool allow_not_accessible_resource -- flag for
+    ensure_disabled -- is flag that keeps resource in target-role "Stopped"
+    wait -- is flag for controlling waiting for pacemaker idle mechanism
+    allow_not_suitable_command -- flag for FORCE_NOT_SUITABLE_COMMAND
+    allow_not_accessible_resource -- flag for
         FORCE_RESOURCE_IN_BUNDLE_NOT_ACCESSIBLE
     """
     resource_agent = get_agent(
@@ -582,6 +607,11 @@ def create_into_bundle(
         resource_agent_name,
         allow_absent_agent,
     )
+    required_cib_version = get_required_cib_version_for_primitive(
+        operation_list
+    )
+    if not required_cib_version:
+        required_cib_version = Version(2, 8, 0)
     with resource_environment(
         env,
         wait,
@@ -590,7 +620,7 @@ def create_into_bundle(
             ensure_disabled
             or resource.common.are_meta_disabled(meta_attributes)
         ),
-        required_cib_version=Version(2, 8, 0),
+        required_cib_version=required_cib_version,
     ) as resources_section:
         id_provider = IdProvider(resources_section)
         _check_special_cases(
@@ -628,7 +658,8 @@ def create_into_bundle(
                         allow_not_accessible_resource,
                     ),
                     message=reports.messages.ResourceInBundleNotAccessible(
-                        bundle_id, resource_id,
+                        bundle_id,
+                        resource_id,
                     ),
                 )
             ).has_errors:
@@ -680,7 +711,8 @@ def bundle_create(
             or resource.common.are_meta_disabled(meta_attributes)
         ),
         required_cib_version=_get_required_cib_version_for_container(
-            container_options, container_type,
+            container_options,
+            container_type,
         ),
     ) as resources_section:
         # no need to run validations related to remote and guest nodes as those
@@ -876,11 +908,14 @@ def bundle_update(
 
 
 def _disable_validate_and_edit_cib(
-    env: LibraryEnvironment, cib: Element, resource_or_tag_ids: Iterable[str],
-) -> List[Element]:
-    resource_el_list = _find_resources_expand_tags_or_raise(
-        env.report_processor, cib, resource_or_tag_ids
+    env: LibraryEnvironment,
+    cib: _Element,
+    resource_or_tag_ids: Iterable[str],
+) -> List[_Element]:
+    resource_el_list, report_list = _find_resources_expand_tags(
+        cib, resource_or_tag_ids
     )
+    env.report_processor.report_list(report_list)
     if env.report_processor.report_list(
         _resource_list_enable_disable(
             resource_el_list,
@@ -894,7 +929,7 @@ def _disable_validate_and_edit_cib(
 
 
 def _disable_get_element_ids(
-    disabled_resource_el_list: Iterable[Element],
+    disabled_resource_el_list: Iterable[_Element],
 ) -> Tuple[Set[str], Set[str]]:
     """
     Turn a list of elements asked by a user to be disabled to a list of their
@@ -906,10 +941,10 @@ def _disable_get_element_ids(
     inner_resource_id_set = set()
     disabled_resource_id_set = set()
     for resource_el in disabled_resource_el_list:
-        disabled_resource_id_set.add(resource_el.get("id"))
+        disabled_resource_id_set.add(cast(Optional[str], resource_el.get("id")))
         inner_resource_id_set.update(
             {
-                inner_resource_el.get("id")
+                cast(Optional[str], inner_resource_el.get("id"))
                 for inner_resource_el in resource.common.get_all_inner_resources(
                     resource_el
                 )
@@ -925,7 +960,7 @@ def _disable_get_element_ids(
 
 def _disable_run_simulate(
     cmd_runner: CommandRunner,
-    cib: Element,
+    cib: _Element,
     disabled_resource_ids: Set[str],
     inner_resource_ids: Set[str],
     strict: bool,
@@ -960,7 +995,7 @@ def _disable_run_simulate(
 def disable(
     env: LibraryEnvironment,
     resource_or_tag_ids: Iterable[str],
-    wait: Optional[Union[bool, int]],
+    wait: WaitType = False,
 ):
     """
     Disallow specified resources to be started by the cluster
@@ -981,7 +1016,7 @@ def disable_safe(
     env: LibraryEnvironment,
     resource_or_tag_ids: Iterable[str],
     strict: bool,
-    wait: Optional[Union[bool, int]],
+    wait: WaitType = False,
 ):
     """
     Disallow specified resources to be started by the cluster only if there is
@@ -1072,7 +1107,7 @@ def disable_simulate(
 def enable(
     env: LibraryEnvironment,
     resource_or_tag_ids: Iterable[str],
-    wait: Optional[Union[bool, int]],
+    wait: WaitType = False,
 ):
     """
     Allow specified resources to be started by the cluster
@@ -1084,9 +1119,11 @@ def enable(
     """
     env.ensure_wait_satisfiable(wait)
     cib = env.get_cib()
-    resource_el_list = _find_resources_expand_tags_or_raise(
-        env.report_processor, cib, resource_or_tag_ids
+    resource_el_list, report_list = _find_resources_expand_tags(
+        cib, resource_or_tag_ids
     )
+    env.report_processor.report_list(report_list)
+
     to_enable_set = set()
     for el in resource_el_list:
         to_enable_set.update(resource.common.find_resources_to_enable(el))
@@ -1103,7 +1140,7 @@ def enable(
     _push_cib_wait(
         env,
         wait,
-        [el.get("id", "") for el in resource_el_list],
+        [str(el.get("id", "")) for el in resource_el_list],
         _ensure_disabled_after_wait(False),
     )
 
@@ -1148,14 +1185,15 @@ def unmanage(
     with_monitor -- disable resources' monitor operations
     """
     cib = env.get_cib()
-    to_unmanage_set = set()
-    for el in _find_resources_expand_tags_or_raise(
-        env.report_processor, cib, resource_or_tag_ids
-    ):
-        to_unmanage_set.update(resource.common.find_resources_to_unmanage(el))
+    resource_el_list, report_list = _find_resources_expand_tags(
+        cib, resource_or_tag_ids, resource.common.find_resources_to_unmanage
+    )
+    env.report_processor.report_list(report_list)
+    if env.report_processor.has_errors:
+        raise LibraryError()
 
     primitives_set = set()
-    for resource_el in to_unmanage_set:
+    for resource_el in resource_el_list:
         resource.common.unmanage(resource_el, IdProvider(cib))
         if with_monitor:
             primitives_set.update(resource.common.find_primitives(resource_el))
@@ -1182,18 +1220,13 @@ def manage(
     with_monitor -- enable resources' monitor operations
     """
     cib = env.get_cib()
-    report_list: ReportItemList = []
 
-    to_manage_set = set()
-    for resource_el in _find_resources_expand_tags_or_raise(
-        env.report_processor, cib, resource_or_tag_ids
-    ):
-        to_manage_set.update(
-            resource.common.find_resources_to_manage(resource_el),
-        )
+    resource_el_list, report_list = _find_resources_expand_tags(
+        cib, resource_or_tag_ids, resource.common.find_resources_to_manage
+    )
 
     primitives_set = set()
-    for resource_el in to_manage_set:
+    for resource_el in resource_el_list:
         resource.common.manage(resource_el, IdProvider(cib))
         primitives_set.update(resource.common.find_primitives(resource_el))
 
@@ -1217,7 +1250,7 @@ def manage(
                 report_list.append(
                     ReportItem.warning(
                         reports.messages.ResourceManagedNoMonitorEnabled(
-                            resource_el.get("id", "")
+                            str(resource_el.get("id", ""))
                         )
                     )
                 )
@@ -1396,9 +1429,8 @@ class _MoveBanTemplate:
         # validate
         env.ensure_wait_satisfiable(wait)  # raises on error
 
-        report_list = []
-        resource_el = resource.common.find_one_resource_and_report(
-            get_resources(env.get_cib()), resource_id, report_list,
+        resource_el, report_list = resource.common.find_one_resource(
+            get_resources(env.get_cib()), resource_id
         )
         if resource_el is not None:
             report_list.extend(self._validate(resource_el, master))
@@ -1475,7 +1507,9 @@ class _Move(_MoveBanTemplate):
     def _report_action_pcmk_success(self, resource_id, stdout, stderr):
         return ReportItem.info(
             reports.messages.ResourceMovePcmkSuccess(
-                resource_id, stdout, stderr,
+                resource_id,
+                stdout,
+                stderr,
             )
         )
 
@@ -1498,12 +1532,14 @@ class _Move(_MoveBanTemplate):
             severity = reports.item.ReportItemSeverity.error()
         if not resource_running_on_after:
             return ReportItem(
-                severity, reports.messages.ResourceDoesNotRun(resource_id),
+                severity,
+                reports.messages.ResourceDoesNotRun(resource_id),
             )
         return ReportItem(
             severity,
             reports.messages.ResourceRunningOnNodes(
-                resource_id, resource_running_on_after,
+                resource_id,
+                resource_running_on_after,
             ),
         )
 
@@ -1530,7 +1566,10 @@ class _Ban(_MoveBanTemplate):
         )
 
     def _report_action_pcmk_success(
-        self, resource_id: str, stdout: str, stderr: str,
+        self,
+        resource_id: str,
+        stdout: str,
+        stderr: str,
     ) -> ReportItem:
         return ReportItem.info(
             reports.messages.ResourceBanPcmkSuccess(resource_id, stdout, stderr)
@@ -1556,12 +1595,14 @@ class _Ban(_MoveBanTemplate):
             severity = reports.item.ReportItemSeverity.error()
         if not resource_running_on_after:
             return ReportItem(
-                severity, reports.messages.ResourceDoesNotRun(resource_id),
+                severity,
+                reports.messages.ResourceDoesNotRun(resource_id),
             )
         return ReportItem(
             severity,
             reports.messages.ResourceRunningOnNodes(
-                resource_id, resource_running_on_after,
+                resource_id,
+                resource_running_on_after,
             ),
         )
 
@@ -1582,9 +1623,8 @@ def unmove_unban(
     # validate
     env.ensure_wait_satisfiable(wait)  # raises on error
 
-    report_list = []
-    resource_el = resource.common.find_one_resource_and_report(
-        get_resources(env.get_cib()), resource_id, report_list,
+    resource_el, report_list = resource.common.find_one_resource(
+        get_resources(env.get_cib()), resource_id
     )
     if resource_el is not None:
         report_list.extend(
@@ -1631,7 +1671,8 @@ def unmove_unban(
 
 
 def get_resource_relations_tree(
-    env: LibraryEnvironment, resource_id: str,
+    env: LibraryEnvironment,
+    resource_id: str,
 ) -> Mapping[str, Any]:
     """
     Return a dict representing tree-like structure of resources and their
@@ -1642,7 +1683,13 @@ def get_resource_relations_tree(
         tree
     """
     cib = env.get_cib()
-    _find_resources_or_raise(get_resources(cib), [resource_id])
+
+    dummy_resource_el, report_list = resource.common.find_one_resource(
+        get_resources(cib), resource_id
+    )
+    if env.report_processor.report_list(report_list).has_errors:
+        raise LibraryError()
+
     (
         resources_dict,
         relations_dict,
@@ -1658,34 +1705,37 @@ def get_resource_relations_tree(
     )
 
 
-def _find_resources_or_raise(
-    context_element, resource_ids, additional_search=None, resource_tags=None
-):
-    report_list = []
-    resource_el_list = resource.common.find_resources_and_report(
-        context_element,
-        resource_ids,
-        report_list,
-        additional_search=additional_search,
-        resource_tags=resource_tags,
-    )
-    if report_list:
-        raise LibraryError(*report_list)
-    return resource_el_list
-
-
-def _find_resources_expand_tags_or_raise(
-    report_processor: ReportProcessor,
-    cib: Element,
+def _find_resources_expand_tags(
+    cib: _Element,
     resource_or_tag_ids: Iterable[str],
-):
-    resources_section = get_resources(cib)
-    (
-        resource_or_tag_el_list,
-        report_list,
-    ) = resource.common.find_resources_or_tags(cib, resource_or_tag_ids)
-    if report_processor.report_list(report_list).has_errors:
-        raise LibraryError()
-    return resource.common.expand_tags_to_resources(
-        resources_section, resource_or_tag_el_list,
+    additional_search: Optional[Callable[[_Element], List[_Element]]] = None,
+) -> Tuple[List[_Element], ReportItemList]:
+    rsc_or_tag_el_list, report_list = resource.common.find_resources(
+        cib,
+        resource_or_tag_ids,
+        resource_tags=resource.common.ALL_RESOURCE_XML_TAGS + [TAG_TAG],
     )
+
+    resource_set = set()
+    for el in rsc_or_tag_el_list:
+        resource_set.update(
+            expand_tag(
+                el, only_expand_types=resource.common.ALL_RESOURCE_XML_TAGS
+            )
+        )
+    if not additional_search:
+        return list(resource_set), report_list
+
+    final_set = set()
+    for el in resource_set:
+        final_set.update(additional_search(el))
+    return list(final_set), report_list
+
+
+def get_required_cib_version_for_primitive(
+    op_list: Iterable[Mapping[str, str]]
+) -> Optional[Version]:
+    for op in op_list:
+        if op.get("on-fail", "") == "demote":
+            return Version(3, 4, 0)
+    return None
