@@ -1,23 +1,26 @@
+import os.path
 from typing import (
     Iterable,
     List,
     Mapping,
     NamedTuple,
 )
-from xml.etree.ElementTree import Element
 
-from pcs.common import file_type_codes
-from pcs.common.node_communicator import Communicator
-from pcs.common.reports import (
-    SimpleReportProcessor,
-    SimpleReportProcessorInterface,
+from lxml.etree import _Element
+
+from pcs import settings
+from pcs.common import (
+    file_type_codes,
+    reports,
 )
-from pcs.common.tools import (
+from pcs.common.node_communicator import Communicator
+from pcs.common.reports import ReportProcessor
+from pcs.common.reports.item import ReportItem
+from pcs.common.str_tools import (
     format_list,
     indent,
 )
-from pcs.lib import reports
-from pcs.lib.cib import stonith
+from pcs.lib.cib import nvpair, stonith
 from pcs.lib.cib.tools import get_crm_config, get_resources
 from pcs.lib.communication.nodes import CheckReachability
 from pcs.lib.communication.tools import run as run_communication
@@ -37,12 +40,14 @@ from pcs.lib.pacemaker.live import (
 from pcs.lib.resource_agent import STONITH_ACTION_REPLACED_BY
 from pcs.lib.sbd import get_sbd_service_name
 
+
 class _ServiceStatus(NamedTuple):
     service: str
     display_always: bool
     enabled: bool
     running: bool
 
+
 def full_cluster_status_plaintext(
     env: LibraryEnvironment,
     hide_inactive_resources: bool = False,
@@ -57,26 +62,31 @@ def full_cluster_status_plaintext(
     """
     # pylint: disable=too-many-branches
     # pylint: disable=too-many-locals
+    # pylint: disable=too-many-statements
 
     # validation
     if not env.is_cib_live and env.is_corosync_conf_live:
         raise LibraryError(
-            reports.live_environment_not_consistent(
-                [file_type_codes.CIB],
-                [file_type_codes.COROSYNC_CONF],
+            ReportItem.error(
+                reports.messages.LiveEnvironmentNotConsistent(
+                    [file_type_codes.CIB],
+                    [file_type_codes.COROSYNC_CONF],
+                )
             )
         )
     if env.is_cib_live and not env.is_corosync_conf_live:
         raise LibraryError(
-            reports.live_environment_not_consistent(
-                [file_type_codes.COROSYNC_CONF],
-                [file_type_codes.CIB],
+            ReportItem.error(
+                reports.messages.LiveEnvironmentNotConsistent(
+                    [file_type_codes.COROSYNC_CONF],
+                    [file_type_codes.CIB],
+                )
             )
         )
 
     # initialization
     runner = env.cmd_runner()
-    report_processor = SimpleReportProcessor(env.report_processor)
+    report_processor = env.report_processor
     live = env.is_cib_live and env.is_corosync_conf_live
     is_sbd_running = False
 
@@ -84,12 +94,18 @@ def full_cluster_status_plaintext(
     status_text, warning_list = get_cluster_status_text(
         runner, hide_inactive_resources, verbose
     )
-    corosync_conf = env.get_corosync_conf()
+    corosync_conf = None
+    # If we are live on a remote node, we have no corosync.conf.
+    # TODO Use the new file framework so the path is not exposed.
+    if not live or os.path.exists(settings.corosync_conf_file):
+        corosync_conf = env.get_corosync_conf()
     cib = env.get_cib()
     if verbose:
-        ticket_status_text, ticket_status_stderr, ticket_status_retval = (
-            get_ticket_status_text(runner)
-        )
+        (
+            ticket_status_text,
+            ticket_status_stderr,
+            ticket_status_retval,
+        ) = get_ticket_status_text(runner)
     # get extra info if live
     if live:
         try:
@@ -97,7 +113,7 @@ def full_cluster_status_plaintext(
         except LibraryError:
             pass
         local_services_status = _get_local_services_status(runner)
-        if verbose:
+        if verbose and corosync_conf:
             node_name_list, node_names_report_list = get_existing_nodes_names(
                 corosync_conf
             )
@@ -117,8 +133,15 @@ def full_cluster_status_plaintext(
     if report_processor.has_errors:
         raise LibraryError()
 
+    cluster_name = (
+        corosync_conf.get_cluster_name()
+        if corosync_conf
+        else nvpair.get_value(
+            "cluster_property_set", get_crm_config(cib), "cluster-name", ""
+        )
+    )
     parts = []
-    parts.append(f"Cluster name: {corosync_conf.get_cluster_name()}")
+    parts.append(f"Cluster name: {cluster_name}")
     if warning_list:
         parts.extend(["", "WARNINGS:"] + warning_list + [""])
     parts.append(status_text)
@@ -136,27 +159,29 @@ def full_cluster_status_plaintext(
         else:
             parts.extend(indent(ticket_status_text.splitlines()))
     if live:
-        if verbose:
+        if verbose and corosync_conf:
             parts.extend(["", "PCSD Status:"])
-            parts.extend(indent(
-                _format_node_reachability(node_name_list, node_reachability)
-            ))
+            parts.extend(
+                indent(
+                    _format_node_reachability(node_name_list, node_reachability)
+                )
+            )
         parts.extend(["", "Daemon Status:"])
-        parts.extend(indent(
-            _format_local_services_status(local_services_status)
-        ))
+        parts.extend(
+            indent(_format_local_services_status(local_services_status))
+        )
     return "\n".join(parts)
 
-def _stonith_warnings(
-    cib: Element,
-    is_sbd_running: bool
-) -> List[str]:
+
+def _stonith_warnings(cib: _Element, is_sbd_running: bool) -> List[str]:
     warning_list = []
 
     is_stonith_enabled = stonith.is_stonith_enabled(get_crm_config(cib))
-    stonith_all, stonith_with_action, stonith_with_method_cycle = (
-        stonith.get_misconfigured_resources(get_resources(cib))
-    )
+    (
+        stonith_all,
+        stonith_with_action,
+        stonith_with_method_cycle,
+    ) = stonith.get_misconfigured_resources(get_resources(cib))
 
     if is_stonith_enabled and not stonith_all and not is_sbd_running:
         warning_list.append(
@@ -169,8 +194,10 @@ def _stonith_warnings(
                 "Following stonith devices have the 'action' option set, "
                 "it is recommended to set {0} instead: {1}"
             ).format(
-                format_list(STONITH_ACTION_REPLACED_BY),
-                format_list([x.get("id", "") for x in stonith_with_action]),
+                format_list(list(STONITH_ACTION_REPLACED_BY)),
+                format_list(
+                    [str(x.get("id", "")) for x in stonith_with_action]
+                ),
             )
         )
 
@@ -179,17 +206,16 @@ def _stonith_warnings(
             "Following stonith devices have the 'method' option set "
             "to 'cycle' which is potentially dangerous, please consider using "
             "'onoff': {0}".format(
-                format_list([
-                    x.get("id", "") for x in stonith_with_method_cycle
-                ]),
+                format_list(
+                    [str(x.get("id", "")) for x in stonith_with_method_cycle]
+                ),
             )
         )
 
     return warning_list
 
-def _get_local_services_status(
-    runner: CommandRunner
-) -> List[_ServiceStatus]:
+
+def _get_local_services_status(runner: CommandRunner) -> List[_ServiceStatus]:
     service_def = [
         # (service name, display even if not enabled nor running)
         ("corosync", True),
@@ -201,16 +227,19 @@ def _get_local_services_status(
     service_status_list = []
     for service, display_always in service_def:
         try:
-            service_status_list.append(_ServiceStatus(
-                service,
-                display_always,
-                is_service_enabled(runner, service),
-                is_service_running(runner, service),
-            ))
+            service_status_list.append(
+                _ServiceStatus(
+                    service,
+                    display_always,
+                    is_service_enabled(runner, service),
+                    is_service_running(runner, service),
+                )
+            )
         except LibraryError:
             pass
     return service_status_list
 
+
 def _format_local_services_status(
     service_status_list: Iterable[_ServiceStatus],
 ) -> List[str]:
@@ -218,30 +247,32 @@ def _format_local_services_status(
         "{service}: {active}/{enabled}".format(
             service=status.service,
             active=("active" if status.running else "inactive"),
-            enabled=("enabled" if status.enabled else "disabled")
+            enabled=("enabled" if status.enabled else "disabled"),
         )
         for status in service_status_list
         if status.display_always or status.enabled or status.running
     ]
 
+
 def _get_node_reachability(
     node_target_factory: NodeTargetLibFactory,
     node_communicator: Communicator,
-    report_processor: SimpleReportProcessorInterface,
+    report_processor: ReportProcessor,
     node_name_list: Iterable[str],
 ) -> Mapping[str, str]:
     # we are not interested in reports telling the user which nodes are
     # unknown since we display that info in the list of nodes
-    dummy_report_list, target_list = (
-        node_target_factory.get_target_list_with_reports(node_name_list)
-    )
+    (
+        dummy_report_list,
+        target_list,
+    ) = node_target_factory.get_target_list_with_reports(node_name_list)
     com_cmd = CheckReachability(report_processor)
     com_cmd.set_targets(target_list)
     return run_communication(node_communicator, com_cmd)
 
+
 def _format_node_reachability(
-    node_name_list: Iterable[str],
-    node_reachability: Mapping[str, str]
+    node_name_list: Iterable[str], node_reachability: Mapping[str, str]
 ) -> List[str]:
     translate = {
         CheckReachability.REACHABLE: "Online",
@@ -253,7 +284,7 @@ def _format_node_reachability(
             node=node_name,
             status=translate[
                 node_reachability.get(node_name, CheckReachability.UNAUTH)
-            ]
+            ],
         )
         for node_name in sorted(node_name_list)
     ]
