@@ -1,25 +1,34 @@
-from pcs.lib import reports
+from typing import Optional
+
+from pcs.common import reports
+from pcs.common.reports.item import ReportItem
 from pcs.lib.cib import resource
 from pcs.lib.cib.resource.common import are_meta_disabled
 from pcs.lib.cib.tools import IdProvider
 from pcs.lib.commands.resource import (
     _ensure_disabled_after_wait,
-    resource_environment
+    resource_environment,
 )
+from pcs.lib.env import LibraryEnvironment
 from pcs.lib.errors import LibraryError
 from pcs.lib.pacemaker.live import (
     FenceHistoryCommandErrorException,
     fence_history_cleanup,
     fence_history_text,
     fence_history_update,
-    is_fence_history_supported,
+    is_fence_history_supported_management,
 )
 from pcs.lib.pacemaker.values import validate_id
 from pcs.lib.resource_agent import find_valid_stonith_agent_by_name as get_agent
 
+
 def create(
-    env, stonith_id, stonith_agent_name,
-    operations, meta_attributes, instance_attributes,
+    env,
+    stonith_id,
+    stonith_agent_name,
+    operations,
+    meta_attributes,
+    instance_attributes,
     allow_absent_agent=False,
     allow_invalid_operation=False,
     allow_invalid_instance_attributes=False,
@@ -66,7 +75,7 @@ def create(
         [stonith_id],
         _ensure_disabled_after_wait(
             ensure_disabled or are_meta_disabled(meta_attributes),
-        )
+        ),
     ) as resources_section:
         id_provider = IdProvider(resources_section)
         stonith_element = resource.primitive.create(
@@ -81,14 +90,20 @@ def create(
             allow_invalid_operation=allow_invalid_operation,
             allow_invalid_instance_attributes=allow_invalid_instance_attributes,
             use_default_operations=use_default_operations,
-            resource_type="stonith"
+            resource_type="stonith",
         )
         if ensure_disabled:
             resource.common.disable(stonith_element, id_provider)
 
+
 def create_in_group(
-    env, stonith_id, stonith_agent_name, group_id,
-    operations, meta_attributes, instance_attributes,
+    env,
+    stonith_id,
+    stonith_agent_name,
+    group_id,
+    operations,
+    meta_attributes,
+    instance_attributes,
     allow_absent_agent=False,
     allow_invalid_operation=False,
     allow_invalid_instance_attributes=False,
@@ -141,13 +156,18 @@ def create_in_group(
         [stonith_id],
         _ensure_disabled_after_wait(
             ensure_disabled or are_meta_disabled(meta_attributes),
-        )
+        ),
     ) as resources_section:
         id_provider = IdProvider(resources_section)
         stonith_element = resource.primitive.create(
-            env.report_processor, resources_section, id_provider,
-            stonith_id, stonith_agent,
-            operations, meta_attributes, instance_attributes,
+            env.report_processor,
+            resources_section,
+            id_provider,
+            stonith_id,
+            stonith_agent,
+            operations,
+            meta_attributes,
+            instance_attributes,
             allow_invalid_operation,
             allow_invalid_instance_attributes,
             use_default_operations,
@@ -162,52 +182,76 @@ def create_in_group(
             put_after_adjacent,
         )
 
-def history_get_text(env, node=None):
+
+def history_get_text(env: LibraryEnvironment, node: Optional[str] = None):
     """
     Get full fencing history in plain text
 
-    LibraryEnvironment env
-    string node -- get history for the specified node or all nodes if None
+    env
+    node -- get history for the specified node or all nodes if None
     """
-    if not is_fence_history_supported():
-        raise LibraryError(reports.fence_history_not_supported())
-
-    try:
-        return fence_history_text(env.cmd_runner(), node)
-    except FenceHistoryCommandErrorException as e:
+    runner = env.cmd_runner()
+    if not is_fence_history_supported_management(runner):
         raise LibraryError(
-            reports.fence_history_command_error(str(e), "show")
+            ReportItem.error(reports.messages.FenceHistoryNotSupported())
         )
 
-def history_cleanup(env, node=None):
+    try:
+        return fence_history_text(runner, node)
+    except FenceHistoryCommandErrorException as e:
+        raise LibraryError(
+            ReportItem.error(
+                reports.messages.FenceHistoryCommandError(
+                    str(e), reports.const.FENCE_HISTORY_COMMAND_SHOW
+                )
+            )
+        ) from e
+
+
+def history_cleanup(env: LibraryEnvironment, node: Optional[str] = None):
     """
     Clear fencing history
 
-    LibraryEnvironment env
-    string node -- clear history for the specified node or all nodes if None
+    env
+    node -- clear history for the specified node or all nodes if None
     """
-    if not is_fence_history_supported():
-        raise LibraryError(reports.fence_history_not_supported())
-
-    try:
-        return fence_history_cleanup(env.cmd_runner(), node)
-    except FenceHistoryCommandErrorException as e:
+    runner = env.cmd_runner()
+    if not is_fence_history_supported_management(runner):
         raise LibraryError(
-            reports.fence_history_command_error(str(e), "cleanup")
+            ReportItem.error(reports.messages.FenceHistoryNotSupported())
         )
 
-def history_update(env):
+    try:
+        return fence_history_cleanup(runner, node)
+    except FenceHistoryCommandErrorException as e:
+        raise LibraryError(
+            ReportItem.error(
+                reports.messages.FenceHistoryCommandError(
+                    str(e), reports.const.FENCE_HISTORY_COMMAND_CLEANUP
+                )
+            )
+        ) from e
+
+
+def history_update(env: LibraryEnvironment):
     """
     Update fencing history in a cluster (sync with other nodes)
 
-    LibraryEnvironment env
+    env
     """
-    if not is_fence_history_supported():
-        raise LibraryError(reports.fence_history_not_supported())
+    runner = env.cmd_runner()
+    if not is_fence_history_supported_management(runner):
+        raise LibraryError(
+            ReportItem.error(reports.messages.FenceHistoryNotSupported())
+        )
 
     try:
-        return fence_history_update(env.cmd_runner())
+        return fence_history_update(runner)
     except FenceHistoryCommandErrorException as e:
         raise LibraryError(
-            reports.fence_history_command_error(str(e), "update")
-        )
+            ReportItem.error(
+                reports.messages.FenceHistoryCommandError(
+                    str(e), reports.const.FENCE_HISTORY_COMMAND_UPDATE
+                )
+            )
+        ) from e
