@@ -1,17 +1,16 @@
-from pcs.common import report_codes
+from pcs.common import reports
+from pcs.common.reports.item import ReportItem
 from pcs.common.node_communicator import Request
-from pcs.lib import reports
+from pcs.common.reports import ReportItemSeverity
 from pcs.lib.node_communication import response_to_report_item
-from pcs.lib.errors import (
-    LibraryError,
-    ReportItemSeverity,
-)
+from pcs.lib.errors import LibraryError
 
 
 class CommunicationCommandInterface:
     """
     Interface for all communication commands.
     """
+
     def get_initial_request_list(self):
         """
         Returns an initial list of Request object.
@@ -40,9 +39,9 @@ class CommunicationCommandInterface:
         raise NotImplementedError()
 
     @property
-    def error_list(self):
+    def has_errors(self):
         """
-        List of errors which occured during running the requests.
+        Has an error occured during running the requests.
         """
         raise NotImplementedError()
 
@@ -75,7 +74,7 @@ def run_and_raise(communicator, cmd):
     CommunicationCommandInterface cmd
     """
     to_return = run(communicator, cmd)
-    if cmd.error_list:
+    if cmd.has_errors:
         raise LibraryError()
     return to_return
 
@@ -85,12 +84,13 @@ class RunRemotelyBase(CommunicationCommandInterface):
     Abstract class for communication commands. This class provides methods for
     reporting.
     """
+
     # pylint: disable=abstract-method
     _report_pcsd_too_old_on_404 = False
 
     def __init__(self, report_processor):
         self.__report_processor = report_processor
-        self._error_list = []
+        self.__has_errors = False
 
     def _get_response_report(self, response):
         """
@@ -110,9 +110,14 @@ class RunRemotelyBase(CommunicationCommandInterface):
 
         list report_list -- list of ReportItem objects
         """
-        self._error_list.extend(
-            self.__report_processor.report_list(report_list)
-        )
+
+        self.__report_processor.report_list(report_list)
+        if self.has_errors:
+            return
+        for report_item in report_list:
+            if report_item.severity.level == reports.ReportItemSeverity.ERROR:
+                self.__has_errors = True
+                return
 
     def _report(self, report):
         """
@@ -143,8 +148,8 @@ class RunRemotelyBase(CommunicationCommandInterface):
         pass
 
     @property
-    def error_list(self):
-        return self._error_list
+    def has_errors(self):
+        return self.__has_errors
 
 
 class StrategyBase:
@@ -152,6 +157,7 @@ class StrategyBase:
     Abstract base class of the communication strategies. Always use at most one
     strategy mixin in the communication commands classes.
     """
+
     def _prepare_initial_requests(self):
         """
         Returns list of all Request objects which should be run. Full
@@ -173,7 +179,8 @@ class OneByOneStrategyMixin(StrategyBase):
     one request from _prepare_initial_requests is chosen as initial request
     list. Other requests are then available by calling method _get_next_list.
     """
-    #pylint: disable=abstract-method
+
+    # pylint: disable=abstract-method
     __iter = None
     __successful = False
 
@@ -201,7 +208,8 @@ class AllAtOnceStrategyMixin(StrategyBase):
     Communication strategy in which all requests are executed at once in
     parallel.
     """
-    #pylint: disable=abstract-method
+
+    # pylint: disable=abstract-method
     def get_initial_request_list(self):
         return self._prepare_initial_requests()
 
@@ -214,7 +222,11 @@ class MarkSuccessfulMixin:
 
     def on_complete(self):
         if not self.__successful:
-            self._report(reports.unable_to_perform_operation_on_any_node())
+            self._report(
+                ReportItem.error(
+                    reports.messages.UnableToPerformOperationOnAnyNode()
+                )
+            )
 
 
 class AllSameDataMixin:
@@ -222,6 +234,7 @@ class AllSameDataMixin:
     Communication command mixin which adds common methods for commands where
     requests to all targets have the same data.
     """
+
     __targets = None
 
     def _get_request_data(self):
@@ -270,13 +283,13 @@ class AllSameDataMixin:
         return [target.label for target in self.__target_list]
 
 
-
 class SimpleResponseProcessingMixin:
     """
     Communication command mixin which adds common response processing. When
     request fails error/warning will be reported. Otherwise _get_success_report
     will be reported.
     """
+
     def _get_success_report(self, node_label):
         """
         Returns ReportItem which should be reported when request was
@@ -298,6 +311,7 @@ class SimpleResponseProcessingNoResponseOnSuccessMixin:
     Communication command mixin which adds common response processing. When
     request fails error/warning will be reported.
     """
+
     def _process_response(self, response):
         report = self._get_response_report(response)
         if report is not None:
@@ -312,12 +326,15 @@ class SkipOfflineMixin:
     returned from _get_response_report is set accordingly to value of
     skip_offline_targets.
     """
+
     _failure_severity = ReportItemSeverity.ERROR
     _failure_forceable = None
     _report_pcsd_too_old_on_404: bool
 
     def _set_skip_offline(
-        self, skip_offline_targets, force_code=report_codes.SKIP_OFFLINE_NODES
+        self,
+        skip_offline_targets,
+        force_code=reports.codes.SKIP_OFFLINE_NODES,
     ):
         """
         Set value of skip_offline_targets flag.
