@@ -1,72 +1,30 @@
-from typing import List
+from typing import (
+    cast,
+    Dict,
+    Iterable,
+    List,
+    Mapping,
+    Optional,
+)
 
 from pcs import settings
 from pcs.common import reports
 from pcs.common.reports.item import ReportItem
 from pcs.lib.corosync import config_parser, constants, node
 from pcs.lib.errors import LibraryError
+from pcs.lib.interface.config import FacadeInterface
 
 
-class ConfigFacade:
+_KNET_COMPRESSION_OPTIONS_PREFIX = "knet_compression_"
+_KNET_CRYPTO_OPTIONS_PREFIX = "crypto_"
+
+
+class ConfigFacade(FacadeInterface):
     # pylint: disable=too-many-public-methods
     """
     Provides high level access to a corosync config file
     """
 
-    @classmethod
-    def from_string(cls, config_string):
-        """
-        Parse corosync config and create a facade around it
-        config_string corosync config text
-        """
-        try:
-            return cls(config_parser.parse_string(config_string))
-        except config_parser.MissingClosingBraceException:
-            raise LibraryError(
-                ReportItem.error(
-                    reports.messages.ParseErrorCorosyncConfMissingClosingBrace()
-                )
-            )
-        except config_parser.UnexpectedClosingBraceException:
-            # pylint: disable=line-too-long
-            raise LibraryError(
-                ReportItem.error(
-                    reports.messages.ParseErrorCorosyncConfUnexpectedClosingBrace()
-                )
-            )
-        except config_parser.MissingSectionNameBeforeOpeningBraceException:
-            # pylint: disable=line-too-long
-            raise LibraryError(
-                ReportItem.error(
-                    reports.messages.ParseErrorCorosyncConfMissingSectionNameBeforeOpeningBrace()
-                )
-            )
-        except config_parser.ExtraCharactersAfterOpeningBraceException:
-            # pylint: disable=line-too-long
-            raise LibraryError(
-                ReportItem.error(
-                    reports.messages.ParseErrorCorosyncConfExtraCharactersAfterOpeningBrace()
-                )
-            )
-        except config_parser.ExtraCharactersBeforeOrAfterClosingBraceException:
-            # pylint: disable=line-too-long
-            raise LibraryError(
-                ReportItem.error(
-                    reports.messages.ParseErrorCorosyncConfExtraCharactersBeforeOrAfterClosingBrace()
-                )
-            )
-        except config_parser.LineIsNotSectionNorKeyValueException:
-            # pylint: disable=line-too-long
-            raise LibraryError(
-                ReportItem.error(
-                    reports.messages.ParseErrorCorosyncConfLineIsNotSectionNorKeyValue()
-                )
-            )
-        except config_parser.CorosyncConfParserException:
-            raise LibraryError(
-                ReportItem.error(reports.messages.ParseErrorCorosyncConf())
-            )
-
     @classmethod
     def create(cls, cluster_name, node_list, transport):
         """
@@ -113,16 +71,12 @@ class ConfigFacade:
         Create a facade around a parsed corosync config file
         parsed_config parsed corosync config
         """
-        self._config = parsed_config
+        super().__init__(parsed_config)
         # set to True if changes cannot be applied on running cluster
         self._need_stopped_cluster = False
         # set to True if qdevice reload is required to apply changes
         self._need_qdevice_reload = False
 
-    @property
-    def config(self):
-        return self._config
-
     @property
     def need_stopped_cluster(self):
         return self._need_stopped_cluster
@@ -132,10 +86,7 @@ class ConfigFacade:
         return self._need_qdevice_reload
 
     def get_cluster_name(self) -> str:
-        name = ""
-        for totem in self.config.get_sections("totem"):
-            name = totem.get_attribute_value("cluster_name", name)
-        return name
+        return cast(str, self._get_option_value("totem", "cluster_name", ""))
 
     # To get a list of nodenames use pcs.lib.node.get_existing_nodes_names
 
@@ -267,7 +218,9 @@ class ConfigFacade:
                 try:
                     available_link_numbers.remove(int(link["linknumber"]))
                 except ValueError as e:
-                    raise AssertionError("Invalid link number: {}".format(e))
+                    raise AssertionError(
+                        "Invalid link number: {}".format(e)
+                    ) from e
                 links.append(dict(link))
             else:
                 linknumber_missing.append(link)
@@ -279,7 +232,7 @@ class ConfigFacade:
             except IndexError as e:
                 raise AssertionError(
                     "Link number no longer available: {}".format(e)
-                )
+                ) from e
             links.append(link)
 
         for link in sorted(links, key=lambda item: item["linknumber"]):
@@ -446,22 +399,62 @@ class ConfigFacade:
         }
 
     def get_transport(self):
-        transport = None
-        for totem in self.config.get_sections("totem"):
-            transport = totem.get_attribute_value("transport", transport)
+        transport = self._get_option_value("totem", "transport")
         return transport if transport else constants.TRANSPORT_DEFAULT
 
     def get_ip_version(self):
-        ip_version = None
-        for totem in self.config.get_sections("totem"):
-            ip_version = totem.get_attribute_value("ip_version", ip_version)
+        ip_version = self._get_option_value("totem", "ip_version")
         if ip_version:
             return ip_version
         if self.get_transport() == "udp":
             return constants.IP_VERSION_4
         return constants.IP_VERSION_64
 
-    def set_transport_udp_options(self, options):
+    def _get_option_value(
+        self, section: str, option: str, default: Optional[str] = None
+    ) -> Optional[str]:
+        for sec in self.config.get_sections(section):
+            default = sec.get_attribute_value(option, default)
+        return default
+
+    def _is_changed(
+        self, section: str, option_name: str, new_value: Optional[str]
+    ) -> bool:
+        if new_value is None:
+            return False
+        old_value = self._get_option_value(section, option_name)
+        # old_value is not present or empty and new_value is empty
+        if not old_value and not new_value:
+            return False
+        return old_value != new_value
+
+    def set_transport_options(
+        self,
+        transport_options: Mapping[str, str],
+        compression_options: Mapping[str, str],
+        crypto_options: Mapping[str, str],
+    ) -> None:
+        """
+        Set transport options for transport type currently used
+
+        generic_options -- generic transport options
+        compression_options -- compression options
+        crypto_options -- crypto options
+        """
+        if any(
+            self._is_changed("totem", opt, transport_options.get(opt))
+            for opt in constants.TRANSPORT_RUNTIME_CHANGE_BANNED_OPTIONS
+        ):
+            self._need_stopped_cluster = True
+        transport_type = self.get_transport()
+        if transport_type in constants.TRANSPORTS_KNET:
+            self._set_transport_knet_options(
+                transport_options, compression_options, crypto_options
+            )
+        elif transport_type in constants.TRANSPORTS_UDP:
+            self._set_transport_udp_options(transport_options)
+
+    def _set_transport_udp_options(self, options):
         """
         Set transport options for udp transports
 
@@ -469,9 +462,9 @@ class ConfigFacade:
         """
         totem_section_list = self.__ensure_section(self.config, "totem")
         self.__set_section_options(totem_section_list, options)
-        self._need_stopped_cluster = True
+        self.__remove_empty_sections(self.config)
 
-    def set_transport_knet_options(
+    def _set_transport_knet_options(
         self, generic_options, compression_options, crypto_options
     ):
         """
@@ -485,14 +478,68 @@ class ConfigFacade:
         self.__set_section_options(totem_section_list, generic_options)
         self.__set_section_options(
             totem_section_list,
-            _add_prefix_to_dict_keys("knet_compression_", compression_options),
+            _add_prefix_to_dict_keys(
+                _KNET_COMPRESSION_OPTIONS_PREFIX, compression_options
+            ),
         )
         self.__set_section_options(
             totem_section_list,
-            _add_prefix_to_dict_keys("crypto_", crypto_options),
+            _add_prefix_to_dict_keys(
+                _KNET_CRYPTO_OPTIONS_PREFIX, crypto_options
+            ),
         )
         self.__remove_empty_sections(self.config)
-        self._need_stopped_cluster = True
+
+    def _filter_options(
+        self,
+        section_name: str,
+        allowed_options: Iterable[str],
+        prefix: str = "",
+    ) -> Dict[str, str]:
+        options = {}
+        for section in self.config.get_sections(section_name):
+            for name, value in section.get_attributes():
+                if (
+                    name.startswith(prefix)
+                    and name[len(prefix) :] in allowed_options
+                ):
+                    options[name[len(prefix) :]] = value
+        return options
+
+    def get_transport_options(self) -> Dict[str, str]:
+        """
+        Get configurable generic transport options
+        """
+        transport_type = self.get_transport()
+        if transport_type in constants.TRANSPORTS_KNET:
+            return self._filter_options(
+                "totem", constants.TRANSPORT_KNET_GENERIC_OPTIONS
+            )
+        if transport_type in constants.TRANSPORTS_UDP:
+            return self._filter_options(
+                "totem", constants.TRANSPORT_UDP_GENERIC_OPTIONS
+            )
+        return {}
+
+    def get_compression_options(self) -> Dict[str, str]:
+        """
+        Get configurable compression options
+        """
+        return self._filter_options(
+            "totem",
+            constants.TRANSPORT_KNET_COMPRESSION_OPTIONS,
+            _KNET_COMPRESSION_OPTIONS_PREFIX,
+        )
+
+    def get_crypto_options(self) -> Dict[str, str]:
+        """
+        Get configurable crypto options
+        """
+        return self._filter_options(
+            "totem",
+            constants.TRANSPORT_KNET_CRYPTO_OPTIONS,
+            _KNET_CRYPTO_OPTIONS_PREFIX,
+        )
 
     def set_totem_options(self, options):
         """
@@ -509,6 +556,14 @@ class ConfigFacade:
         # options are still written to the totem section. The options which pcs
         # keeps in the totem section for users do not currently need the
         # cluster to be stopped when updating them.
+        # Note: all options in totem section supported by pcs are runtime
+        # configurable.
+
+    def get_totem_options(self) -> Dict[str, str]:
+        """
+        Get configurable totem options
+        """
+        return self._filter_options("totem", constants.TOTEM_OPTIONS)
 
     def set_quorum_options(self, options):
         """
@@ -522,25 +577,17 @@ class ConfigFacade:
         self.__remove_empty_sections(self.config)
         self._need_stopped_cluster = True
 
-    def get_quorum_options(self):
+    def get_quorum_options(self) -> Dict[str, str]:
         """
         Get configurable options from the "quorum" section
         """
-        options = {}
-        for section in self.config.get_sections("quorum"):
-            for name, value in section.get_attributes():
-                if name in constants.QUORUM_OPTIONS:
-                    options[name] = value
-        return options
+        return self._filter_options("quorum", constants.QUORUM_OPTIONS)
 
     def is_enabled_auto_tie_breaker(self):
         """
         Returns True if auto tie braker option is enabled, False otherwise.
         """
-        atb = "0"
-        for quorum in self.config.get_sections("quorum"):
-            atb = quorum.get_attribute_value("auto_tie_breaker", atb)
-        return atb == "1"
+        return self._get_option_value("quorum", "auto_tie_breaker", "0") == "1"
 
     def has_quorum_device(self):
         """
