@@ -1,8 +1,9 @@
 import os.path
 
 from pcs import settings
-from pcs.common.tools import join_multilines
-from pcs.lib import reports
+from pcs.common import reports
+from pcs.common.reports.item import ReportItem
+from pcs.common.str_tools import join_multilines
 from pcs.lib.errors import LibraryError
 
 
@@ -13,15 +14,17 @@ def get_status_text(runner, verbose=False):
     """
     cmd = [
         os.path.join(settings.corosync_binaries, "corosync-qdevice-tool"),
-        "-s"
+        "-s",
     ]
     if verbose:
         cmd.append("-v")
     stdout, stderr, retval = runner.run(cmd)
     if retval != 0:
         raise LibraryError(
-            reports.corosync_quorum_get_status_error(
-                join_multilines([stderr, stdout])
+            ReportItem.error(
+                reports.messages.CorosyncQuorumGetStatusError(
+                    join_multilines([stderr, stdout])
+                )
             )
         )
     return stdout
