@@ -1,12 +1,13 @@
-import functools
 import os
 import os.path
 import re
 import shutil
 
 from pcs import settings
-from pcs.common.tools import join_multilines
-from pcs.lib import external, reports
+from pcs.common import reports
+from pcs.common.str_tools import join_multilines
+from pcs.common.reports.item import ReportItem
+from pcs.lib import external
 from pcs.lib.communication import qdevice_net as qdevice_net_com
 from pcs.lib.communication.tools import run_and_raise
 from pcs.lib.errors import LibraryError
@@ -16,16 +17,13 @@ from pcs.lib.tools import write_tmpfile
 __model = "net"
 __service_name = "corosync-qnetd"
 __qnetd_certutil = os.path.join(
-    settings.corosync_qnet_binaries,
-    "corosync-qnetd-certutil"
+    settings.corosync_qnet_binaries, "corosync-qnetd-certutil"
 )
 __qnetd_tool = os.path.join(
-    settings.corosync_qnet_binaries,
-    "corosync-qnetd-tool"
+    settings.corosync_qnet_binaries, "corosync-qnetd-tool"
 )
 __qdevice_certutil = os.path.join(
-    settings.corosync_binaries,
-    "corosync-qdevice-net-certutil"
+    settings.corosync_binaries, "corosync-qdevice-net-certutil"
 )
 __nss_certificate_db_files = (
     # old NSS DB format
@@ -38,12 +36,20 @@ __nss_certificate_db_files = (
     "pkcs11.txt",
 )
 
+
 class QnetdNotRunningException(Exception):
     pass
 
+
 def set_up_client_certificates(
-    runner, reporter, communicator_factory, qnetd_target, cluster_name,
-    cluster_nodes_target_list, skip_offline_nodes, allow_skip_offline=True
+    runner,
+    reporter,
+    communicator_factory,
+    qnetd_target,
+    cluster_name,
+    cluster_nodes_target_list,
+    skip_offline_nodes,
+    allow_skip_offline=True,
 ):
     """
     setup cluster nodes for using qdevice model net
@@ -57,7 +63,9 @@ def set_up_client_certificates(
     bool allow_skip_offline -- enables forcing errors by skip_offline_nodes
     """
     reporter.report(
-        reports.qdevice_certificate_distribution_started()
+        ReportItem.info(
+            reports.messages.QdeviceCertificateDistributionStarted()
+        )
     )
     # get qnetd CA certificate
     com_cmd = qdevice_net_com.GetCaCert(reporter)
@@ -72,10 +80,7 @@ def set_up_client_certificates(
     com_cmd.set_targets(cluster_nodes_target_list)
     run_and_raise(communicator_factory.get_communicator(), com_cmd)
     # create client certificate request
-    cert_request = client_generate_certificate_request(
-        runner,
-        cluster_name
-    )
+    cert_request = client_generate_certificate_request(runner, cluster_name)
     # sign the request on qnetd host
     com_cmd = qdevice_net_com.SignCertificate(reporter)
     com_cmd.add_request(qnetd_target, cert_request, cluster_name)
@@ -91,24 +96,30 @@ def set_up_client_certificates(
     com_cmd.set_targets(cluster_nodes_target_list)
     run_and_raise(communicator_factory.get_communicator(), com_cmd)
 
+
 def qdevice_setup(runner):
     """
     initialize qdevice on local host
     """
     if qdevice_initialized():
-        raise LibraryError(reports.qdevice_already_initialized(__model))
-
-    stdout, stderr, retval = runner.run([
-        __qnetd_certutil, "-i"
-    ])
-    if retval != 0:
         raise LibraryError(
-            reports.qdevice_initialization_error(
-                __model,
-                join_multilines([stderr, stdout])
+            ReportItem.error(
+                reports.messages.QdeviceAlreadyInitialized(__model)
             )
         )
 
+    stdout, stderr, retval = runner.run([__qnetd_certutil, "-i"])
+    if retval != 0:
+        raise LibraryError(
+            ReportItem.error(
+                reports.messages.QdeviceInitializationError(
+                    __model,
+                    join_multilines([stderr, stdout]),
+                )
+            )
+        )
+
+
 def qdevice_initialized():
     """
     check if qdevice server certificate database has been initialized
@@ -117,6 +128,7 @@ def qdevice_initialized():
         settings.corosync_qdevice_net_server_certs_dir
     )
 
+
 def qdevice_destroy():
     """
     delete qdevice configuration on local host
@@ -126,8 +138,11 @@ def qdevice_destroy():
             shutil.rmtree(settings.corosync_qdevice_net_server_certs_dir)
     except EnvironmentError as e:
         raise LibraryError(
-            reports.qdevice_destroy_error(__model, e.strerror)
-        )
+            ReportItem.error(
+                reports.messages.QdeviceDestroyError(__model, e.strerror)
+            )
+        ) from e
+
 
 def qdevice_status_generic_text(runner, verbose=False):
     """
@@ -140,13 +155,16 @@ def qdevice_status_generic_text(runner, verbose=False):
     stdout, stderr, retval = _qdevice_run_tool(runner, args)
     if retval != 0:
         raise LibraryError(
-            reports.qdevice_get_status_error(
-                __model,
-                join_multilines([stderr, stdout])
+            ReportItem.error(
+                reports.messages.QdeviceGetStatusError(
+                    __model,
+                    join_multilines([stderr, stdout]),
+                )
             )
         )
     return stdout
 
+
 def qdevice_status_cluster_text(runner, cluster=None, verbose=False):
     """
     get qdevice runtime status in plain text
@@ -161,13 +179,16 @@ def qdevice_status_cluster_text(runner, cluster=None, verbose=False):
     stdout, stderr, retval = _qdevice_run_tool(runner, args)
     if retval != 0:
         raise LibraryError(
-            reports.qdevice_get_status_error(
-                __model,
-                join_multilines([stderr, stdout])
+            ReportItem.error(
+                reports.messages.QdeviceGetStatusError(
+                    __model,
+                    join_multilines([stderr, stdout]),
+                )
             )
         )
     return stdout
 
+
 def qdevice_connected_clusters(status_cluster_text):
     """
     parse qnetd cluster status listing and return connected clusters' names
@@ -181,6 +202,7 @@ def qdevice_connected_clusters(status_cluster_text):
             connected_clusters.append(match.group("cluster"))
     return connected_clusters
 
+
 def _qdevice_run_tool(runner, args):
     """
     run corosync-qnetd-tool, raise QnetdNotRunningException if qnetd not running
@@ -192,36 +214,42 @@ def _qdevice_run_tool(runner, args):
         raise QnetdNotRunningException()
     return stdout, stderr, retval
 
+
 def qdevice_enable(runner):
     """
     make qdevice start automatically on boot on local host
     """
     external.enable_service(runner, __service_name)
 
+
 def qdevice_disable(runner):
     """
     make qdevice not start automatically on boot on local host
     """
     external.disable_service(runner, __service_name)
 
+
 def qdevice_start(runner):
     """
     start qdevice now on local host
     """
     external.start_service(runner, __service_name)
 
+
 def qdevice_stop(runner):
     """
     stop qdevice now on local host
     """
     external.stop_service(runner, __service_name)
 
+
 def qdevice_kill(runner):
     """
     kill qdevice now on local host
     """
     external.kill_services(runner, [__service_name])
 
+
 def qdevice_sign_certificate_request(runner, cert_request, cluster_name):
     """
     sign client certificate request
@@ -229,29 +257,34 @@ def qdevice_sign_certificate_request(runner, cert_request, cluster_name):
     string cluster_name name of the cluster to which qdevice is being added
     """
     if not qdevice_initialized():
-        raise LibraryError(reports.qdevice_not_initialized(__model))
+        raise LibraryError(
+            ReportItem.error(reports.messages.QdeviceNotInitialized(__model))
+        )
     # save the certificate request, corosync tool only works with files
     tmpfile = _store_to_tmpfile(
-        cert_request,
-        reports.qdevice_certificate_sign_error
+        cert_request, reports.messages.QdeviceCertificateSignError
     )
     # sign the request
-    stdout, stderr, retval = runner.run([
-        __qnetd_certutil, "-s", "-c", tmpfile.name, "-n", cluster_name
-    ])
-    tmpfile.close() # temp file is deleted on close
+    stdout, stderr, retval = runner.run(
+        [__qnetd_certutil, "-s", "-c", tmpfile.name, "-n", cluster_name]
+    )
+    tmpfile.close()  # temp file is deleted on close
     if retval != 0:
         raise LibraryError(
-            reports.qdevice_certificate_sign_error(
-                join_multilines([stderr, stdout])
+            ReportItem.error(
+                reports.messages.QdeviceCertificateSignError(
+                    join_multilines([stderr, stdout]),
+                )
             )
         )
     # get signed certificate, corosync tool only works with files
     return _get_output_certificate(
         stdout,
-        reports.qdevice_certificate_sign_error
+        # pylint: disable=unnecessary-lambda
+        lambda reason: reports.messages.QdeviceCertificateSignError(reason),
     )
 
+
 def client_setup(runner, ca_certificate):
     """
     initialize qdevice client on local host
@@ -261,32 +294,39 @@ def client_setup(runner, ca_certificate):
     # save CA certificate, corosync tool only works with files
     ca_file_path = os.path.join(
         settings.corosync_qdevice_net_client_certs_dir,
-        settings.corosync_qdevice_net_client_ca_file_name
+        settings.corosync_qdevice_net_client_ca_file_name,
     )
     try:
         if not os.path.exists(ca_file_path):
             os.makedirs(
-                settings.corosync_qdevice_net_client_certs_dir,
-                mode=0o700
+                settings.corosync_qdevice_net_client_certs_dir, mode=0o700
             )
         with open(ca_file_path, "wb") as ca_file:
             ca_file.write(ca_certificate)
     except EnvironmentError as e:
         raise LibraryError(
-            reports.qdevice_initialization_error(__model, e.strerror)
-        )
+            ReportItem.error(
+                reports.messages.QdeviceInitializationError(
+                    __model,
+                    e.strerror,
+                )
+            )
+        ) from e
     # initialize client's certificate storage
-    stdout, stderr, retval = runner.run([
-        __qdevice_certutil, "-i", "-c", ca_file_path
-    ])
+    stdout, stderr, retval = runner.run(
+        [__qdevice_certutil, "-i", "-c", ca_file_path]
+    )
     if retval != 0:
         raise LibraryError(
-            reports.qdevice_initialization_error(
-                __model,
-                join_multilines([stderr, stdout])
+            ReportItem.error(
+                reports.messages.QdeviceInitializationError(
+                    __model,
+                    join_multilines([stderr, stdout]),
+                )
             )
         )
 
+
 def client_initialized():
     """
     check if qdevice net client certificate database has been initialized
@@ -295,6 +335,7 @@ def client_initialized():
         settings.corosync_qdevice_net_client_certs_dir
     )
 
+
 def client_destroy():
     """
     delete qdevice client config files on local host
@@ -304,8 +345,11 @@ def client_destroy():
             shutil.rmtree(settings.corosync_qdevice_net_client_certs_dir)
     except EnvironmentError as e:
         raise LibraryError(
-            reports.qdevice_destroy_error(__model, e.strerror)
-        )
+            ReportItem.error(
+                reports.messages.QdeviceDestroyError(__model, e.strerror)
+            )
+        ) from e
+
 
 def client_generate_certificate_request(runner, cluster_name):
     """
@@ -313,22 +357,30 @@ def client_generate_certificate_request(runner, cluster_name):
     string cluster_name name of the cluster to which qdevice is being added
     """
     if not client_initialized():
-        raise LibraryError(reports.qdevice_not_initialized(__model))
-    stdout, stderr, retval = runner.run([
-        __qdevice_certutil, "-r", "-n", cluster_name
-    ])
+        raise LibraryError(
+            ReportItem.error(reports.messages.QdeviceNotInitialized(__model))
+        )
+    stdout, stderr, retval = runner.run(
+        [__qdevice_certutil, "-r", "-n", cluster_name]
+    )
     if retval != 0:
         raise LibraryError(
-            reports.qdevice_initialization_error(
-                __model,
-                join_multilines([stderr, stdout])
+            ReportItem.error(
+                reports.messages.QdeviceInitializationError(
+                    __model,
+                    join_multilines([stderr, stdout]),
+                )
             )
         )
     return _get_output_certificate(
         stdout,
-        functools.partial(reports.qdevice_initialization_error, __model)
+        lambda reason: reports.messages.QdeviceInitializationError(
+            __model,
+            reason,
+        ),
     )
 
+
 def client_cert_request_to_pk12(runner, cert_request):
     """
     transform signed certificate request to pk12 certificate which can be
@@ -336,64 +388,79 @@ def client_cert_request_to_pk12(runner, cert_request):
     cert_request signed certificate request
     """
     if not client_initialized():
-        raise LibraryError(reports.qdevice_not_initialized(__model))
+        raise LibraryError(
+            ReportItem.error(reports.messages.QdeviceNotInitialized(__model))
+        )
     # save the signed certificate request, corosync tool only works with files
     tmpfile = _store_to_tmpfile(
         cert_request,
-        reports.qdevice_certificate_import_error
+        reports.messages.QdeviceCertificateImportError,
     )
     # transform it
-    stdout, stderr, retval = runner.run([
-        __qdevice_certutil, "-M", "-c", tmpfile.name
-    ])
-    tmpfile.close() # temp file is deleted on close
+    stdout, stderr, retval = runner.run(
+        [__qdevice_certutil, "-M", "-c", tmpfile.name]
+    )
+    tmpfile.close()  # temp file is deleted on close
     if retval != 0:
         raise LibraryError(
-            reports.qdevice_certificate_import_error(
-                join_multilines([stderr, stdout])
+            ReportItem.error(
+                reports.messages.QdeviceCertificateImportError(
+                    join_multilines([stderr, stdout]),
+                )
             )
         )
     # get resulting pk12, corosync tool only works with files
     return _get_output_certificate(
         stdout,
-        reports.qdevice_certificate_import_error
+        # pylint: disable=unnecessary-lambda
+        lambda reason: reports.messages.QdeviceCertificateImportError(reason),
     )
 
+
 def client_import_certificate_and_key(runner, pk12_certificate):
     """
     import qdevice client certificate to the local node certificate storage
     """
     if not client_initialized():
-        raise LibraryError(reports.qdevice_not_initialized(__model))
+        raise LibraryError(
+            ReportItem.error(reports.messages.QdeviceNotInitialized(__model))
+        )
     # save the certificate, corosync tool only works with files
     tmpfile = _store_to_tmpfile(
         pk12_certificate,
-        reports.qdevice_certificate_import_error
+        reports.messages.QdeviceCertificateImportError,
     )
-    stdout, stderr, retval = runner.run([
-        __qdevice_certutil, "-m", "-c", tmpfile.name
-    ])
-    tmpfile.close() # temp file is deleted on close
+    stdout, stderr, retval = runner.run(
+        [__qdevice_certutil, "-m", "-c", tmpfile.name]
+    )
+    tmpfile.close()  # temp file is deleted on close
     if retval != 0:
         raise LibraryError(
-            reports.qdevice_certificate_import_error(
-                join_multilines([stderr, stdout])
+            ReportItem.error(
+                reports.messages.QdeviceCertificateImportError(
+                    join_multilines([stderr, stdout]),
+                )
             )
         )
 
+
 def _nss_certificate_db_initialized(cert_db_path):
     for filename in __nss_certificate_db_files:
         if os.path.exists(os.path.join(cert_db_path, filename)):
             return True
     return False
 
-def _store_to_tmpfile(data, report_func):
+
+def _store_to_tmpfile(data, report_item_message):
     try:
         return write_tmpfile(data, binary=True)
     except EnvironmentError as e:
-        raise LibraryError(report_func(e.strerror))
+        raise LibraryError(
+            ReportItem.error(report_item_message(e.strerror))
+        ) from e
 
-def _get_output_certificate(cert_tool_output, report_func):
+
+def _get_output_certificate(cert_tool_output, report_message_func):
     regexp = re.compile(r"^Certificate( request)? stored in (?P<path>.+)$")
     filename = None
     for line in cert_tool_output.splitlines():
@@ -401,11 +468,17 @@ def _get_output_certificate(cert_tool_output, report_func):
         if match:
             filename = match.group("path")
     if not filename:
-        raise LibraryError(report_func(cert_tool_output))
+        raise LibraryError(
+            ReportItem.error(report_message_func(cert_tool_output))
+        )
     try:
         with open(filename, "rb") as cert_file:
             return cert_file.read()
     except EnvironmentError as e:
-        raise LibraryError(report_func(
-            "{path}: {error}".format(path=filename, error=e.strerror)
-        ))
+        raise LibraryError(
+            ReportItem.error(
+                report_message_func(
+                    "{path}: {error}".format(path=filename, error=e.strerror)
+                )
+            )
+        ) from e
