@@ -1,13 +1,19 @@
 from typing import (
     Optional,
+    cast,
 )
-from xml.etree.ElementTree import Element
 
+from lxml.etree import _Element
+
+from pcs.common import file_type_codes
+from pcs.common import reports
 from pcs.common.node_communicator import Communicator, NodeCommunicatorFactory
+from pcs.common.reports import ReportProcessor
+from pcs.common.reports.item import ReportItem
 from pcs.common.tools import Version
-from pcs.lib import reports
 from pcs.lib.booth.env import BoothEnv
 from pcs.lib.cib.tools import get_cib_crm_feature_set
+from pcs.lib.dr.env import DrEnv
 from pcs.lib.node import get_existing_nodes_names
 from pcs.lib.communication import qdevice
 from pcs.lib.communication.corosync import (
@@ -21,11 +27,13 @@ from pcs.lib.communication.tools import (
 )
 from pcs.lib.corosync.config_facade import ConfigFacade as CorosyncConfigFacade
 from pcs.lib.corosync.config_parser import (
-    verify_section as verify_corosync_section
+    verify_section as verify_corosync_section,
 )
 from pcs.lib.corosync.live import get_local_corosync_conf
 from pcs.lib.external import CommandRunner
 from pcs.lib.errors import LibraryError
+from pcs.lib.file.instance import FileInstance
+from pcs.lib.interface.config import ParserErrorException
 from pcs.lib.node_communication import (
     LibCommunicatorLogger,
     NodeTargetLibFactory,
@@ -33,7 +41,6 @@ from pcs.lib.node_communication import (
 from pcs.lib.pacemaker.live import (
     diff_cibs_xml,
     ensure_cib_version,
-    ensure_wait_for_idle_support,
     get_cib,
     get_cib_xml,
     get_cluster_status_xml,
@@ -48,6 +55,7 @@ from pcs.lib.xml_tools import etree_to_str
 
 MIN_FEATURE_SET_VERSION_FOR_DIFF = Version(3, 0, 9)
 
+
 class LibraryEnvironment:
     # pylint: disable=too-many-instance-attributes, too-many-public-methods
 
@@ -86,9 +94,10 @@ class LibraryEnvironment:
             LibCommunicatorLogger(self.logger, self.report_processor),
             self.user_login,
             self.user_groups,
-            self._request_timeout
+            self._request_timeout,
         )
         self.__loaded_booth_env = None
+        self.__loaded_dr_env = None
 
         self.__timeout_cache = {}
 
@@ -97,7 +106,7 @@ class LibraryEnvironment:
         return self._logger
 
     @property
-    def report_processor(self):
+    def report_processor(self) -> ReportProcessor:
         return self._report_processor
 
     @property
@@ -108,33 +117,58 @@ class LibraryEnvironment:
     def user_groups(self):
         return self._user_groups
 
-    def get_cib(self, minimal_version: Optional[Version] = None) -> Element:
+    @property
+    def ghost_file_codes(self):
+        codes = set()
+        if not self.is_cib_live:
+            codes.add(file_type_codes.CIB)
+        if not self.is_corosync_conf_live:
+            codes.add(file_type_codes.COROSYNC_CONF)
+        return sorted(codes)
+
+    def get_cib(
+        self,
+        minimal_version: Optional[Version] = None,
+        nice_to_have_version: Optional[Version] = None,
+    ) -> _Element:
         if self.__loaded_cib_diff_source is not None:
             raise AssertionError("CIB has already been loaded")
+
         self.__loaded_cib_diff_source = get_cib_xml(self.cmd_runner())
         self.__loaded_cib_to_modify = get_cib(self.__loaded_cib_diff_source)
-        if minimal_version is not None:
-            upgraded_cib = ensure_cib_version(
-                self.cmd_runner(),
-                self.__loaded_cib_to_modify,
-                minimal_version
-            )
-            if upgraded_cib is not None:
-                self.__loaded_cib_to_modify = upgraded_cib
-                self.__loaded_cib_diff_source = etree_to_str(upgraded_cib)
-                if not self._cib_upgrade_reported:
-                    self.report_processor.process(
-                        reports.cib_upgrade_successful()
-                    )
-                self._cib_upgrade_reported = True
-        self.__loaded_cib_diff_source_feature_set = (
-            get_cib_crm_feature_set(
-                self.__loaded_cib_to_modify,
-                none_if_missing=True
-            )
-            or
-            Version(0, 0, 0)
-        )
+
+        if (
+            nice_to_have_version is not None
+            and minimal_version is not None
+            and minimal_version >= nice_to_have_version
+        ):
+            nice_to_have_version = None
+
+        for version, mandatory in (
+            (nice_to_have_version, False),
+            (minimal_version, True),
+        ):
+            if version is not None:
+                upgraded_cib, was_upgraded = ensure_cib_version(
+                    self.cmd_runner(),
+                    self.__loaded_cib_to_modify,
+                    version,
+                    fail_if_version_not_met=mandatory,
+                )
+                if was_upgraded:
+                    self.__loaded_cib_to_modify = upgraded_cib
+                    self.__loaded_cib_diff_source = etree_to_str(upgraded_cib)
+                    if not self._cib_upgrade_reported:
+                        self.report_processor.report(
+                            ReportItem.info(
+                                reports.messages.CibUpgradeSuccessful()
+                            )
+                        )
+                    self._cib_upgrade_reported = True
+
+        self.__loaded_cib_diff_source_feature_set = get_cib_crm_feature_set(
+            self.__loaded_cib_to_modify, none_if_missing=True
+        ) or Version(0, 0, 0)
         return self.__loaded_cib_to_modify
 
     @property
@@ -152,12 +186,14 @@ class LibraryEnvironment:
 
         if wait not in self.__timeout_cache:
             if not self.is_cib_live:
-                raise LibraryError(reports.wait_for_idle_not_live_cluster())
-            ensure_wait_for_idle_support(self.cmd_runner())
+                raise LibraryError(
+                    ReportItem.error(
+                        reports.messages.WaitForIdleNotLiveCluster()
+                    )
+                )
             self.__timeout_cache[wait] = get_valid_timeout_seconds(wait)
         return self.__timeout_cache[wait]
 
-
     def ensure_wait_satisfiable(self, wait):
         """
         Raise when wait is not supported or when wait is not valid wait value.
@@ -189,15 +225,19 @@ class LibraryEnvironment:
         # only check the version if a CIB has been loaded, otherwise the push
         # fails anyway. By my testing it seems that only the source CIB's
         # version matters.
-        if(
+        if (
             self.__loaded_cib_diff_source_feature_set
-            <
-            MIN_FEATURE_SET_VERSION_FOR_DIFF
+            < MIN_FEATURE_SET_VERSION_FOR_DIFF
         ):
-            self.report_processor.process(
-                reports.cib_push_forced_full_due_to_crm_feature_set(
-                    MIN_FEATURE_SET_VERSION_FOR_DIFF,
-                    self.__loaded_cib_diff_source_feature_set
+            current_set = str(
+                self.__loaded_cib_diff_source_feature_set.normalize()
+            )
+            self.report_processor.report(
+                ReportItem.warning(
+                    reports.messages.CibPushForcedFullDueToCrmFeatureSet(
+                        str(MIN_FEATURE_SET_VERSION_FOR_DIFF.normalize()),
+                        current_set,
+                    )
                 )
             )
             return self.__push_cib_full(self.__loaded_cib_to_modify, wait=wait)
@@ -208,15 +248,13 @@ class LibraryEnvironment:
         self.__do_push_cib(
             cmd_runner,
             lambda: replace_cib_configuration(cmd_runner, cib_to_push),
-            wait
+            wait,
         )
 
     def __push_cib_diff(self, wait=False):
         cmd_runner = self.cmd_runner()
         self.__do_push_cib(
-            cmd_runner,
-            lambda: self.__main_push_cib_diff(cmd_runner),
-            wait
+            cmd_runner, lambda: self.__main_push_cib_diff(cmd_runner), wait
         )
 
     def __main_push_cib_diff(self, cmd_runner):
@@ -224,7 +262,7 @@ class LibraryEnvironment:
             cmd_runner,
             self.report_processor,
             self.__loaded_cib_diff_source,
-            etree_to_str(self.__loaded_cib_to_modify)
+            etree_to_str(self.__loaded_cib_to_modify),
         )
         if cib_diff_xml:
             push_cib_diff_xml(cmd_runner, cib_diff_xml)
@@ -256,14 +294,41 @@ class LibraryEnvironment:
 
         return self._cib_data
 
-
     def get_corosync_conf_data(self):
         if self._corosync_conf_data is None:
             return get_local_corosync_conf()
         return self._corosync_conf_data
 
     def get_corosync_conf(self) -> CorosyncConfigFacade:
-        return CorosyncConfigFacade.from_string(self.get_corosync_conf_data())
+        # TODO The architecture of working with corosync.conf needs to be
+        # overhauled to match the new file framework. The code below is
+        # complicated, because we read corosync.conf data at one place outside
+        # of the file framework or get it from outside (from CLI) and then we
+        # put them back into the framework.
+        corosync_instance = FileInstance.for_corosync_conf()
+        try:
+            facade = cast(
+                CorosyncConfigFacade,
+                corosync_instance.raw_to_facade(
+                    self.get_corosync_conf_data().encode("utf-8")
+                ),
+            )
+        except ParserErrorException as e:
+            if self.report_processor.report_list(
+                corosync_instance.toolbox.parser.exception_to_report_list(
+                    e,
+                    corosync_instance.toolbox.file_type_code,
+                    (
+                        corosync_instance.raw_file.metadata.path
+                        if self.is_corosync_conf_live
+                        else None
+                    ),
+                    force_code=None,
+                    is_forced_or_warning=False,
+                )
+            ).has_errors:
+                raise LibraryError() from e
+        return facade
 
     def push_corosync_conf(
         self, corosync_conf_facade, skip_offline_nodes=False
@@ -273,8 +338,12 @@ class LibraryEnvironment:
         )
         if bad_sections or bad_attr_names or bad_attr_values:
             raise LibraryError(
-                reports.corosync_config_cannot_save_invalid_names_values(
-                    bad_sections, bad_attr_names, bad_attr_values
+                ReportItem.error(
+                    reports.messages.CorosyncConfigCannotSaveInvalidNamesValues(
+                        bad_sections,
+                        bad_attr_names,
+                        bad_attr_values,
+                    )
                 )
             )
         corosync_conf_data = corosync_conf_facade.config.export()
@@ -284,9 +353,10 @@ class LibraryEnvironment:
                 # Pcs is unable to communicate with nodes missing names. It
                 # cannot send new corosync.conf to them. That might break the
                 # cluster. Hence we error out.
-                error_on_missing_name=True
+                error_on_missing_name=True,
             )
-            self.report_processor.process_list(report_list)
+            if self.report_processor.report_list(report_list).has_errors:
+                raise LibraryError()
 
             self._push_corosync_conf_live(
                 self.get_node_target_factory().get_target_list(
@@ -302,9 +372,20 @@ class LibraryEnvironment:
             self._corosync_conf_data = corosync_conf_data
 
     def _push_corosync_conf_live(
-        self, target_list, corosync_conf_data, need_stopped_cluster,
-        need_qdevice_reload, skip_offline_nodes
+        self,
+        target_list,
+        corosync_conf_data,
+        need_stopped_cluster,
+        need_qdevice_reload,
+        skip_offline_nodes,
     ):
+        # TODO
+        # * check for online nodes and run all commands on them only
+        # * if those commands fail, exit with an error
+        # * add support for allow_skip_offline=False
+        # * use simple report procesor
+        # Correct reloading is done in pcs.lib.cluster.remove_nodes for example.
+
         # Check if the cluster is stopped when needed
         if need_stopped_cluster:
             com_cmd = CheckCorosyncOffline(
@@ -328,18 +409,18 @@ class LibraryEnvironment:
             run_and_raise(self.get_node_communicator(), com_cmd)
         # Reload qdevice if needed
         if need_qdevice_reload:
-            self.report_processor.process(
-                reports.qdevice_client_reload_started()
+            self.report_processor.report(
+                ReportItem.info(reports.messages.QdeviceClientReloadStarted())
             )
             com_cmd = qdevice.Stop(self.report_processor, skip_offline_nodes)
             com_cmd.set_targets(target_list)
             run(self.get_node_communicator(), com_cmd)
-            report_list = com_cmd.error_list
+            has_errors = com_cmd.has_errors
             com_cmd = qdevice.Start(self.report_processor, skip_offline_nodes)
             com_cmd.set_targets(target_list)
             run(self.get_node_communicator(), com_cmd)
-            report_list += com_cmd.error_list
-            if report_list:
+            has_errors = has_errors or com_cmd.has_errors
+            if has_errors:
                 raise LibraryError()
 
     @property
@@ -363,14 +444,19 @@ class LibraryEnvironment:
                 try:
                     cib_data = self._cib_data
                     self._cib_data_tmp_file = write_tmpfile(cib_data)
-                    self.report_processor.process(
-                        reports.tmp_file_write(
-                            self._cib_data_tmp_file.name,
-                            cib_data
+                    self.report_processor.report(
+                        ReportItem.debug(
+                            reports.messages.TmpFileWrite(
+                                self._cib_data_tmp_file.name, cib_data
+                            )
                         )
                     )
                 except EnvironmentError as e:
-                    raise LibraryError(reports.cib_save_tmp_error(str(e)))
+                    raise LibraryError(
+                        ReportItem.error(
+                            reports.messages.CibSaveTmpError(str(e))
+                        )
+                    ) from e
             runner_env["CIB_file"] = self._cib_data_tmp_file.name
 
         return CommandRunner(self.logger, self.report_processor, runner_env)
@@ -412,3 +498,8 @@ class LibraryEnvironment:
         if self.__loaded_booth_env is None:
             self.__loaded_booth_env = BoothEnv(name, self._booth_files_data)
         return self.__loaded_booth_env
+
+    def get_dr_env(self) -> DrEnv:
+        if self.__loaded_dr_env is None:
+            self.__loaded_dr_env = DrEnv()
+        return self.__loaded_dr_env
