@@ -1,9 +1,15 @@
 import base64
 from collections import namedtuple
+from typing import (
+    Any,
+    Dict,
+)
 
-from pcs.lib import reports
+from pcs.common import reports
+from pcs.common.reports.item import ReportItem
 from pcs.lib.errors import LibraryError
 
+
 def create_pcmk_remote_actions(action_list):
     return {
         "pacemaker_remote {0}".format(action): service_cmd_format(
@@ -12,6 +18,7 @@ def create_pcmk_remote_actions(action_list):
         for action in action_list
     }
 
+
 def pcmk_authkey_format(authkey_content):
     """
     Return a dict usable in the communication with a remote/put_file
@@ -23,6 +30,7 @@ def pcmk_authkey_format(authkey_content):
         "rewrite_existing": True,
     }
 
+
 def corosync_authkey_format(authkey_content):
     """
     Return a dict usable in the communication with a remote/put_file
@@ -34,15 +42,14 @@ def corosync_authkey_format(authkey_content):
         "rewrite_existing": True,
     }
 
+
 def pcmk_authkey_file(authkey_content):
-    return {
-        "pacemaker_remote authkey": pcmk_authkey_format(authkey_content)
-    }
+    return {"pacemaker_remote authkey": pcmk_authkey_format(authkey_content)}
+
 
 def corosync_authkey_file(authkey_content):
-    return {
-        "corosync authkey": corosync_authkey_format(authkey_content)
-    }
+    return {"corosync authkey": corosync_authkey_format(authkey_content)}
+
 
 def corosync_conf_format(corosync_conf_content):
     return {
@@ -50,11 +57,23 @@ def corosync_conf_format(corosync_conf_content):
         "data": corosync_conf_content,
     }
 
+
 def corosync_conf_file(corosync_conf_content):
+    return {"corosync.conf": corosync_conf_format(corosync_conf_content)}
+
+
+def pcs_dr_config_format(dr_conf_content: bytes) -> Dict[str, Any]:
     return {
-        "corosync.conf": corosync_conf_format(corosync_conf_content)
+        "type": "pcs_disaster_recovery_conf",
+        "data": base64.b64encode(dr_conf_content).decode("utf-8"),
+        "rewrite_existing": True,
     }
 
+
+def pcs_dr_config_file(dr_conf_content: bytes) -> Dict[str, Any]:
+    return {"disaster-recovery config": pcs_dr_config_format(dr_conf_content)}
+
+
 def pcs_settings_conf_format(content):
     return {
         "data": content,
@@ -62,10 +81,10 @@ def pcs_settings_conf_format(content):
         "rewrite_existing": True,
     }
 
+
 def pcs_settings_conf_file(content):
-    return {
-        "pcs_settings.conf": pcs_settings_conf_format(content)
-    }
+    return {"pcs_settings.conf": pcs_settings_conf_format(content)}
+
 
 def service_cmd_format(service, command):
     """
@@ -79,9 +98,11 @@ def service_cmd_format(service, command):
         "command": command,
     }
 
+
 class Result(namedtuple("Result", "code message")):
     """ Wrapper over some call results """
 
+
 def unpack_items_from_response(main_response, main_key, node_label):
     """
     Check format of main_response and return main_response[main_key].
@@ -97,17 +118,18 @@ def unpack_items_from_response(main_response, main_key, node_label):
     """
     is_in_expected_format = (
         isinstance(main_response, dict)
-        and
-        main_key in main_response
-        and
-        isinstance(main_response[main_key], dict)
+        and main_key in main_response
+        and isinstance(main_response[main_key], dict)
     )
 
     if not is_in_expected_format:
-        raise LibraryError(reports.invalid_response_format(node_label))
+        raise LibraryError(
+            ReportItem.error(reports.messages.InvalidResponseFormat(node_label))
+        )
 
     return main_response[main_key]
 
+
 def response_items_to_result(response_items, expected_keys, node_label):
     """
     Check format of response_items and return dict where keys are transformed to
@@ -121,17 +143,21 @@ def response_items_to_result(response_items, expected_keys, node_label):
     string node_label is a node label for reporting an invalid format
     """
     if set(expected_keys) != set(response_items.keys()):
-        raise LibraryError(reports.invalid_response_format(node_label))
+        raise LibraryError(
+            ReportItem.error(reports.messages.InvalidResponseFormat(node_label))
+        )
 
     for result in response_items.values():
-        if(
+        if (
             not isinstance(result, dict)
-            or
-            "code" not in result
-            or
-            "message" not in result
+            or "code" not in result
+            or "message" not in result
         ):
-            raise LibraryError(reports.invalid_response_format(node_label))
+            raise LibraryError(
+                ReportItem.error(
+                    reports.messages.InvalidResponseFormat(node_label)
+                )
+            )
 
     return {
         file_key: Result(raw_result["code"], raw_result["message"])
@@ -139,9 +165,7 @@ def response_items_to_result(response_items, expected_keys, node_label):
     }
 
 
-def response_to_result(
-    main_response, main_key, expected_keys, node_label
-):
+def response_to_result(main_response, main_key, expected_keys, node_label):
     """
     Validate response (from remote/put_file or remote/run_action) and transform
     results from dict to Result.
@@ -160,13 +184,15 @@ def response_to_result(
     return response_items_to_result(
         unpack_items_from_response(main_response, main_key, node_label),
         expected_keys,
-        node_label
+        node_label,
     )
 
+
 def get_format_result(code_message_map):
     def format_result(result):
         if result.code in code_message_map:
             return code_message_map[result.code]
 
         return result.message
+
     return format_result
