@@ -1,19 +1,26 @@
 import os.path
 import re
 from typing import (
+    Iterable,
     List,
+    Optional,
     Tuple,
 )
 
 from lxml import etree
+from lxml.etree import _Element
 
 from pcs import settings
+from pcs.common import reports
+from pcs.common.reports import ReportProcessor
+from pcs.common.reports.item import ReportItem
+from pcs.common.str_tools import join_multilines
 from pcs.common.tools import (
     format_os_error,
-    join_multilines,
-    xml_fromstring
+    xml_fromstring,
+    Version,
 )
-from pcs.lib import reports
+from pcs.common.types import CibRuleInEffectStatus
 from pcs.lib.cib.tools import get_pacemaker_version_by_which_cib_was_validated
 from pcs.lib.errors import LibraryError
 from pcs.lib.external import CommandRunner
@@ -22,28 +29,41 @@ from pcs.lib.tools import write_tmpfile
 from pcs.lib.xml_tools import etree_to_str
 
 
-__EXITCODE_WAIT_TIMEOUT = 124
+__EXITCODE_NOT_CONNECTED = 102
 __EXITCODE_CIB_SCOPE_VALID_BUT_NOT_PRESENT = 105
+__EXITCODE_WAIT_TIMEOUT = 124
 __RESOURCE_REFRESH_OPERATION_COUNT_THRESHOLD = 100
 
-class CrmMonErrorException(LibraryError):
+
+class PacemakerNotConnectedException(LibraryError):
     pass
 
+
 class FenceHistoryCommandErrorException(Exception):
     pass
 
+
 ### status
 
+
 def get_cluster_status_xml(runner):
     stdout, stderr, retval = runner.run(
         [__exec("crm_mon"), "--one-shot", "--as-xml", "--inactive"]
     )
     if retval != 0:
-        raise CrmMonErrorException(
-            reports.cluster_state_cannot_load(join_multilines([stderr, stdout]))
+        klass = (
+            PacemakerNotConnectedException
+            if retval == __EXITCODE_NOT_CONNECTED
+            else LibraryError
+        )
+        raise klass(
+            ReportItem.error(
+                reports.messages.CrmMonError(join_multilines([stderr, stdout]))
+            )
         )
     return stdout
 
+
 def get_cluster_status_text(
     runner: CommandRunner,
     hide_inactive_resources: bool,
@@ -56,13 +76,15 @@ def get_cluster_status_text(
         cmd.extend(["--show-detail", "--show-node-attributes", "--failcounts"])
         # by default, pending and failed actions are displayed
         # with verbose==True, we display the whole history
-        if is_fence_history_supported():
+        if is_fence_history_supported_status(runner):
             cmd.append("--fence-history=3")
     stdout, stderr, retval = runner.run(cmd)
 
     if retval != 0:
-        raise CrmMonErrorException(
-            reports.cluster_state_cannot_load(join_multilines([stderr, stdout]))
+        raise LibraryError(
+            ReportItem.error(
+                reports.messages.CrmMonError(join_multilines([stderr, stdout]))
+            )
         )
     warnings: List[str] = []
     if stderr.strip():
@@ -74,12 +96,15 @@ def get_cluster_status_text(
 
     return stdout.strip(), warnings
 
+
 def get_ticket_status_text(runner: CommandRunner) -> Tuple[str, str, int]:
     stdout, stderr, retval = runner.run([__exec("crm_ticket"), "--details"])
     return stdout.strip(), stderr.strip(), retval
 
+
 ### cib
 
+
 def get_cib_xml_cmd_results(runner, scope=None):
     command = [__exec("cibadmin"), "--local", "--query"]
     if scope:
@@ -87,29 +112,38 @@ def get_cib_xml_cmd_results(runner, scope=None):
     stdout, stderr, returncode = runner.run(command)
     return stdout, stderr, returncode
 
+
 def get_cib_xml(runner, scope=None):
     stdout, stderr, retval = get_cib_xml_cmd_results(runner, scope)
     if retval != 0:
         if retval == __EXITCODE_CIB_SCOPE_VALID_BUT_NOT_PRESENT and scope:
             raise LibraryError(
-                reports.cib_load_error_scope_missing(
-                    scope,
-                    join_multilines([stderr, stdout])
+                ReportItem.error(
+                    reports.messages.CibLoadErrorScopeMissing(
+                        scope, join_multilines([stderr, stdout])
+                    )
                 )
             )
         raise LibraryError(
-            reports.cib_load_error(join_multilines([stderr, stdout]))
+            ReportItem.error(
+                reports.messages.CibLoadError(join_multilines([stderr, stdout]))
+            )
         )
     return stdout
 
+
 def parse_cib_xml(xml):
     return xml_fromstring(xml)
 
+
 def get_cib(xml):
     try:
         return parse_cib_xml(xml)
     except (etree.XMLSyntaxError, etree.DocumentInvalid) as e:
-        raise LibraryError(reports.cib_load_error_invalid_format(str(e)))
+        raise LibraryError(
+            ReportItem.error(reports.messages.CibLoadErrorBadFormat(str(e)))
+        ) from e
+
 
 def verify(runner, verbose=False):
     crm_verify_cmd = [__exec("crm_verify")]
@@ -117,11 +151,11 @@ def verify(runner, verbose=False):
     # more than two. We stick with two -V options if verbose mode was enabled.
     if verbose:
         crm_verify_cmd.extend(["-V", "-V"])
-    #With the `crm_verify` command it is not possible simply use the environment
-    #variable CIB_file because `crm_verify` simply tries to connect to cib file
-    #via tool that can fail because: Update does not conform to the configured
-    #schema
-    #So we use the explicit flag `--xml-file`.
+    # With the `crm_verify` command it is not possible simply use the
+    # environment variable CIB_file because `crm_verify` simply tries to
+    # connect to cib file via tool that can fail because: Update does not
+    # conform to the configured schema
+    # So we use the explicit flag `--xml-file`.
     cib_tmp_file = runner.env_vars.get("CIB_file", None)
     if cib_tmp_file is None:
         crm_verify_cmd.append("--live-check")
@@ -146,21 +180,27 @@ def verify(runner, verbose=False):
         stderr = "".join(new_lines)
     return stdout, stderr, returncode, can_be_more_verbose
 
+
 def replace_cib_configuration_xml(runner, xml):
     cmd = [
         __exec("cibadmin"),
         "--replace",
         "--verbose",
         "--xml-pipe",
-        "--scope", "configuration",
+        "--scope",
+        "configuration",
     ]
     stdout, stderr, retval = runner.run(cmd, stdin_string=xml)
     if retval != 0:
-        raise LibraryError(reports.cib_push_error(stderr, stdout))
+        raise LibraryError(
+            ReportItem.error(reports.messages.CibPushError(stderr, stdout))
+        )
+
 
 def replace_cib_configuration(runner, tree):
     return replace_cib_configuration_xml(runner, etree_to_str(tree))
 
+
 def push_cib_diff_xml(runner, cib_diff_xml):
     cmd = [
         __exec("cibadmin"),
@@ -170,26 +210,46 @@ def push_cib_diff_xml(runner, cib_diff_xml):
     ]
     stdout, stderr, retval = runner.run(cmd, stdin_string=cib_diff_xml)
     if retval != 0:
-        raise LibraryError(reports.cib_push_error(stderr, stdout))
+        raise LibraryError(
+            ReportItem.error(reports.messages.CibPushError(stderr, stdout))
+        )
 
-def diff_cibs_xml(runner, reporter, cib_old_xml, cib_new_xml):
+
+def diff_cibs_xml(
+    runner: CommandRunner,
+    reporter: ReportProcessor,
+    cib_old_xml,
+    cib_new_xml,
+):
     """
     Return xml diff of two CIBs
-    CommandRunner runner
+
+    runner
+    reporter
     string cib_old_xml -- original CIB
     string cib_new_xml -- modified CIB
     """
     try:
         cib_old_tmp_file = write_tmpfile(cib_old_xml)
-        reporter.process(
-            reports.tmp_file_write(cib_old_tmp_file.name, cib_old_xml)
+        reporter.report(
+            ReportItem.debug(
+                reports.messages.TmpFileWrite(
+                    cib_old_tmp_file.name, cib_old_xml
+                )
+            )
         )
         cib_new_tmp_file = write_tmpfile(cib_new_xml)
-        reporter.process(
-            reports.tmp_file_write(cib_new_tmp_file.name, cib_new_xml)
+        reporter.report(
+            ReportItem.debug(
+                reports.messages.TmpFileWrite(
+                    cib_new_tmp_file.name, cib_new_xml
+                )
+            )
         )
     except EnvironmentError as e:
-        raise LibraryError(reports.cib_save_tmp_error(str(e)))
+        raise LibraryError(
+            ReportItem.error(reports.messages.CibSaveTmpError(str(e)))
+        ) from e
     command = [
         __exec("crm_diff"),
         "--original",
@@ -207,25 +267,41 @@ def diff_cibs_xml(runner, reporter, cib_old_xml, cib_new_xml):
         return ""
     if retval > 1:
         raise LibraryError(
-            reports.cib_diff_error(stderr.strip(), cib_old_xml, cib_new_xml)
+            ReportItem.error(
+                reports.messages.CibDiffError(
+                    stderr.strip(), cib_old_xml, cib_new_xml
+                )
+            )
         )
     return stdout.strip()
 
-def ensure_cib_version(runner, cib, version):
+
+def ensure_cib_version(
+    runner: CommandRunner,
+    cib: _Element,
+    version: Version,
+    fail_if_version_not_met: bool = True,
+) -> Tuple[_Element, bool]:
     """
+    Make sure CIB complies to specified schema version (or newer), upgrade CIB
+    if necessary. Raise on error. Raise if CIB cannot be upgraded enough to
+    meet the required version unless fail_if_version_not_met is set to False.
+    Return tuple(upgraded_cib, was_upgraded)
+
     This method ensures that specified cib is verified by pacemaker with
     version 'version' or newer. If cib doesn't correspond to this version,
     method will try to upgrade cib.
     Returns cib which was verified by pacemaker version 'version' or later.
     Raises LibraryError on any failure.
 
-    CommandRunner runner -- runner
-    etree cib -- cib tree
-    pcs.common.tools.Version version -- required cib version
+    runner -- runner
+    cib -- cib tree
+    version -- required cib version
+    fail_if_version_not_met -- allows a 'nice to have' cib upgrade
     """
-    current_version = get_pacemaker_version_by_which_cib_was_validated(cib)
-    if current_version >= version:
-        return None
+    version_pre_upgrade = get_pacemaker_version_by_which_cib_was_validated(cib)
+    if version_pre_upgrade >= version:
+        return cib, False
 
     _upgrade_cib(runner)
     new_cib_xml = get_cib_xml(runner)
@@ -233,15 +309,24 @@ def ensure_cib_version(runner, cib, version):
     try:
         new_cib = parse_cib_xml(new_cib_xml)
     except (etree.XMLSyntaxError, etree.DocumentInvalid) as e:
-        raise LibraryError(reports.cib_upgrade_failed(str(e)))
+        raise LibraryError(
+            ReportItem.error(reports.messages.CibUpgradeFailed(str(e)))
+        ) from e
 
-    current_version = get_pacemaker_version_by_which_cib_was_validated(new_cib)
-    if current_version >= version:
-        return new_cib
+    version_post_upgrade = get_pacemaker_version_by_which_cib_was_validated(
+        new_cib
+    )
+    if version_post_upgrade >= version or not fail_if_version_not_met:
+        return new_cib, version_post_upgrade > version_pre_upgrade
+
+    raise LibraryError(
+        ReportItem.error(
+            reports.messages.CibUpgradeFailedToMinimalRequiredVersion(
+                str(version_post_upgrade), str(version)
+            )
+        )
+    )
 
-    raise LibraryError(reports.unable_to_upgrade_cib_to_required_version(
-        current_version, version
-    ))
 
 def _upgrade_cib(runner):
     """
@@ -256,9 +341,14 @@ def _upgrade_cib(runner):
     # caller knows that and is responsible for dealing with it.
     if retval != 0:
         raise LibraryError(
-            reports.cib_upgrade_failed(join_multilines([stderr, stdout]))
+            ReportItem.error(
+                reports.messages.CibUpgradeFailed(
+                    join_multilines([stderr, stdout])
+                )
+            )
         )
 
+
 def simulate_cib_xml(runner, cib_xml):
     """
     Run crm_simulate to get effects the cib would have on the live cluster
@@ -271,20 +361,24 @@ def simulate_cib_xml(runner, cib_xml):
         transitions_file = write_tmpfile(None)
     except OSError as e:
         raise LibraryError(
-            reports.cib_simulate_error(format_os_error(e), cib_xml)
-        )
+            ReportItem.error(
+                reports.messages.CibSimulateError(format_os_error(e))
+            )
+        ) from e
 
     cmd = [
         __exec("crm_simulate"),
         "--simulate",
-        "--save-output", new_cib_file.name,
-        "--save-graph", transitions_file.name,
+        "--save-output",
+        new_cib_file.name,
+        "--save-graph",
+        transitions_file.name,
         "--xml-pipe",
     ]
     stdout, stderr, retval = runner.run(cmd, stdin_string=cib_xml)
     if retval != 0:
         raise LibraryError(
-            reports.cib_simulate_error(stderr.strip(), cib_xml)
+            ReportItem.error(reports.messages.CibSimulateError(stderr.strip()))
         )
 
     try:
@@ -297,8 +391,11 @@ def simulate_cib_xml(runner, cib_xml):
         return stdout, transitions_xml, new_cib_xml
     except OSError as e:
         raise LibraryError(
-            reports.cib_simulate_error(format_os_error(e), cib_xml)
-        )
+            ReportItem.error(
+                reports.messages.CibSimulateError(format_os_error(e))
+            )
+        ) from e
+
 
 def simulate_cib(runner, cib):
     """
@@ -315,21 +412,16 @@ def simulate_cib(runner, cib):
         return (
             plaintext_result.strip(),
             xml_fromstring(transitions_xml),
-            xml_fromstring(new_cib_xml)
+            xml_fromstring(new_cib_xml),
         )
     except (etree.XMLSyntaxError, etree.DocumentInvalid) as e:
         raise LibraryError(
-            reports.cib_simulate_error(str(e), cib_xml)
-        )
+            ReportItem.error(reports.messages.CibSimulateError(str(e)))
+        ) from e
+
 
 ### wait for idle
 
-def has_wait_for_idle_support(runner):
-    return __is_in_crm_resource_help(runner, "--wait")
-
-def ensure_wait_for_idle_support(runner):
-    if not has_wait_for_idle_support(runner):
-        raise LibraryError(reports.wait_for_idle_not_supported())
 
 def wait_for_idle(runner, timeout=None):
     """
@@ -348,67 +440,105 @@ def wait_for_idle(runner, timeout=None):
         # We use stdout just to be sure if that's get changed.
         if retval == __EXITCODE_WAIT_TIMEOUT:
             raise LibraryError(
-                reports.wait_for_idle_timed_out(
-                    join_multilines([stderr, stdout])
+                ReportItem.error(
+                    reports.messages.WaitForIdleTimedOut(
+                        join_multilines([stderr, stdout])
+                    )
                 )
             )
         raise LibraryError(
-            reports.wait_for_idle_error(
-                join_multilines([stderr, stdout])
+            ReportItem.error(
+                reports.messages.WaitForIdleError(
+                    join_multilines([stderr, stdout])
+                )
             )
         )
 
+
 ### nodes
 
+
 def get_local_node_name(runner):
     stdout, stderr, retval = runner.run([__exec("crm_node"), "--name"])
     if retval != 0:
-        raise LibraryError(
-            reports.pacemaker_local_node_name_not_found(
-                join_multilines([stderr, stdout])
+        klass = (
+            PacemakerNotConnectedException
+            if retval == __EXITCODE_NOT_CONNECTED
+            else LibraryError
+        )
+        raise klass(
+            ReportItem.error(
+                reports.messages.PacemakerLocalNodeNameNotFound(
+                    join_multilines([stderr, stdout])
+                )
             )
         )
     return stdout.strip()
 
+
 def get_local_node_status(runner):
     try:
         cluster_status = ClusterState(get_cluster_status_xml(runner))
-    except CrmMonErrorException:
+        node_name = get_local_node_name(runner)
+    except PacemakerNotConnectedException:
         return {"offline": True}
-    node_name = get_local_node_name(runner)
     for node_status in cluster_status.node_section.nodes:
         if node_status.attrs.name == node_name:
             result = {
                 "offline": False,
             }
             for attr in (
-                'id', 'name', 'type', 'online', 'standby', 'standby_onfail',
-                'maintenance', 'pending', 'unclean', 'shutdown', 'expected_up',
-                'is_dc', 'resources_running',
+                "id",
+                "name",
+                "type",
+                "online",
+                "standby",
+                "standby_onfail",
+                "maintenance",
+                "pending",
+                "unclean",
+                "shutdown",
+                "expected_up",
+                "is_dc",
+                "resources_running",
             ):
                 result[attr] = getattr(node_status.attrs, attr)
             return result
-    raise LibraryError(reports.node_not_found(node_name))
+    raise LibraryError(
+        ReportItem.error(reports.messages.NodeNotFound(node_name))
+    )
+
 
 def remove_node(runner, node_name):
-    stdout, stderr, retval = runner.run([
-        __exec("crm_node"),
-        "--force",
-        "--remove",
-        node_name,
-    ])
+    stdout, stderr, retval = runner.run(
+        [
+            __exec("crm_node"),
+            "--force",
+            "--remove",
+            node_name,
+        ]
+    )
     if retval != 0:
         raise LibraryError(
-            reports.node_remove_in_pacemaker_failed(
-                [node_name],
-                reason=join_multilines([stderr, stdout])
+            ReportItem.error(
+                reports.messages.NodeRemoveInPacemakerFailed(
+                    node_list_to_remove=[node_name],
+                    reason=join_multilines([stderr, stdout]),
+                )
             )
         )
 
+
 ### resources
 
+
 def resource_cleanup(
-    runner, resource=None, node=None, operation=None, interval=None
+    runner: CommandRunner,
+    resource: Optional[str] = None,
+    node: Optional[str] = None,
+    operation: Optional[str] = None,
+    interval: Optional[str] = None,
+    strict: bool = False,
 ):
     cmd = [__exec("crm_resource"), "--cleanup"]
     if resource:
@@ -419,28 +549,42 @@ def resource_cleanup(
         cmd.extend(["--operation", operation])
     if interval:
         cmd.extend(["--interval", interval])
+    if strict:
+        cmd.extend(["--force"])
 
     stdout, stderr, retval = runner.run(cmd)
 
     if retval != 0:
         raise LibraryError(
-            reports.resource_cleanup_error(
-                join_multilines([stderr, stdout]),
-                resource,
-                node
+            ReportItem.error(
+                reports.messages.ResourceCleanupError(
+                    join_multilines([stderr, stdout]), resource, node
+                )
             )
         )
     # usefull output (what has been done) goes to stderr
     return join_multilines([stdout, stderr])
 
-def resource_refresh(runner, resource=None, node=None, full=False, force=None):
+
+def resource_refresh(
+    runner: CommandRunner,
+    resource: Optional[str] = None,
+    node: Optional[str] = None,
+    strict: bool = False,
+    force: bool = False,
+):
     if not force and not node and not resource:
         summary = ClusterState(get_cluster_status_xml(runner)).summary
         operations = summary.nodes.attrs.count * summary.resources.attrs.count
         if operations > __RESOURCE_REFRESH_OPERATION_COUNT_THRESHOLD:
             raise LibraryError(
-                reports.resource_refresh_too_time_consuming(
-                    __RESOURCE_REFRESH_OPERATION_COUNT_THRESHOLD
+                ReportItem(
+                    reports.item.ReportItemSeverity.error(
+                        reports.codes.FORCE_LOAD_THRESHOLD
+                    ),
+                    reports.messages.ResourceRefreshTooTimeConsuming(
+                        __RESOURCE_REFRESH_OPERATION_COUNT_THRESHOLD
+                    ),
                 )
             )
 
@@ -449,22 +593,23 @@ def resource_refresh(runner, resource=None, node=None, full=False, force=None):
         cmd.extend(["--resource", resource])
     if node:
         cmd.extend(["--node", node])
-    if full:
+    if strict:
         cmd.extend(["--force"])
 
     stdout, stderr, retval = runner.run(cmd)
 
     if retval != 0:
         raise LibraryError(
-            reports.resource_refresh_error(
-                join_multilines([stderr, stdout]),
-                resource,
-                node
+            ReportItem.error(
+                reports.messages.ResourceRefreshError(
+                    join_multilines([stderr, stdout]), resource, node
+                )
             )
         )
     # usefull output (what has been done) goes to stderr
     return join_multilines([stdout, stderr])
 
+
 def resource_move(runner, resource_id, node=None, master=False, lifetime=None):
     return _resource_move_ban_clear(
         runner,
@@ -475,6 +620,7 @@ def resource_move(runner, resource_id, node=None, master=False, lifetime=None):
         lifetime=lifetime,
     )
 
+
 def resource_ban(runner, resource_id, node=None, master=False, lifetime=None):
     return _resource_move_ban_clear(
         runner,
@@ -485,6 +631,7 @@ def resource_ban(runner, resource_id, node=None, master=False, lifetime=None):
         lifetime=lifetime,
     )
 
+
 def resource_unmove_unban(
     runner, resource_id, node=None, master=False, expired=False
 ):
@@ -497,12 +644,19 @@ def resource_unmove_unban(
         expired=expired,
     )
 
+
 def has_resource_unmove_unban_expired_support(runner):
-    return __is_in_crm_resource_help(runner, "--expired")
+    return _is_in_pcmk_tool_help(runner, "crm_resource", ["--expired"])
+
 
 def _resource_move_ban_clear(
-    runner, action, resource_id, node=None, master=False, lifetime=None,
-    expired=False
+    runner,
+    action,
+    resource_id,
+    node=None,
+    master=False,
+    lifetime=None,
+    expired=False,
 ):
     command = [
         __exec("crm_resource"),
@@ -521,48 +675,38 @@ def _resource_move_ban_clear(
     stdout, stderr, retval = runner.run(command)
     return stdout, stderr, retval
 
+
 ### fence history
 
-def is_fence_history_supported():
-    try:
-        crm_mon_rng = xml_fromstring(open(settings.crm_mon_schema, "r").read())
-        # Namespaces must be provided otherwise xpath won't match anything.
-        # 'None' namespace is not supported, so we rename it.
-        namespaces_map = {
-            "ns": crm_mon_rng.nsmap.pop(None)
-        }
-        history_elements = crm_mon_rng.xpath(
-            ".//ns:element[@name='fence_history']",
-            namespaces=namespaces_map
-        )
-        if history_elements:
-            return True
-    except (EnvironmentError, etree.XMLSyntaxError):
-        # if we cannot tell for sure fence_history is supported, we will
-        # continue as if it was not supported
-        pass
-    return False
+
+def is_fence_history_supported_status(runner: CommandRunner) -> bool:
+    return _is_in_pcmk_tool_help(runner, "crm_mon", ["--fence-history"])
+
+
+def is_fence_history_supported_management(runner: CommandRunner) -> bool:
+    return _is_in_pcmk_tool_help(
+        runner, "stonith_admin", ["--history", "--broadcast", "--cleanup"]
+    )
+
 
 def fence_history_cleanup(runner, node=None):
     return _run_fence_history_command(runner, "--cleanup", node)
 
+
 def fence_history_text(runner, node=None):
     return _run_fence_history_command(runner, "--verbose", node)
 
+
 def fence_history_update(runner):
     # Pacemaker always prints "gather fencing-history from all nodes" even if a
     # node is specified. However, --history expects a value, so we must provide
     # it. Otherwise "--broadcast" would be considered a value of "--history".
     return _run_fence_history_command(runner, "--broadcast", node=None)
 
+
 def _run_fence_history_command(runner, command, node=None):
     stdout, stderr, retval = runner.run(
-        [
-            __exec("stonith_admin"),
-            "--history",
-            node if node else "*",
-            command
-        ]
+        [__exec("stonith_admin"), "--history", node if node else "*", command]
     )
     if retval != 0:
         raise FenceHistoryCommandErrorException(
@@ -570,16 +714,52 @@ def _run_fence_history_command(runner, command, node=None):
         )
     return stdout.strip()
 
+
 ### tools
 
+
+def has_rule_in_effect_status_tool() -> bool:
+    return os.path.isfile(__exec("crm_rule"))
+
+
+def get_rule_in_effect_status(
+    runner: CommandRunner, cib_xml: str, rule_id: str
+) -> CibRuleInEffectStatus:
+    """
+    Figure out if a rule is in effect, expired or not yet in effect
+
+    runner -- a class for running external processes
+    cib_xml -- CIB containing rules
+    rule_id -- ID of the rule to be checked
+    """
+    # TODO Once crm_rule is capable of evaluating more than one rule per go, we
+    # should make use of it. Running the tool for each rule may really slow pcs
+    # down.
+    translation_map = {
+        0: CibRuleInEffectStatus.IN_EFFECT,
+        110: CibRuleInEffectStatus.EXPIRED,
+        111: CibRuleInEffectStatus.NOT_YET_IN_EFFECT,
+        # 105:non-existent
+        # 112: undetermined (rule is too complicated for current implementation)
+    }
+    dummy_stdout, dummy_stderr, retval = runner.run(
+        [__exec("crm_rule"), "--check", "--rule", rule_id, "--xml-text", "-"],
+        stdin_string=cib_xml,
+    )
+    return translation_map.get(retval, CibRuleInEffectStatus.UNKNOWN)
+
+
 # shortcut for getting a full path to a pacemaker executable
 def __exec(name):
     return os.path.join(settings.pacemaker_binaries, name)
 
-def __is_in_crm_resource_help(runner, text):
-    # returns 1 on success so we don't care about retval
-    stdout, stderr, dummy_retval = runner.run(
-        [__exec("crm_resource"), "-?"]
+
+def _is_in_pcmk_tool_help(
+    runner: CommandRunner, tool: str, text_list: Iterable[str]
+) -> bool:
+    stdout, stderr, dummy_retval = runner.run([__exec(tool), "--help-all"])
+    # Help goes to stderr but we check stdout as well if that gets changed. Use
+    # generators in all to return early.
+    return all(text in stderr for text in text_list) or all(
+        text in stdout for text in text_list
     )
-    # help goes to stderr but we check stdout as well if that gets changed
-    return text in stderr or text in stdout
