@@ -346,19 +346,20 @@ def _find_valid_agent_by_name(
     try:
         return PresentAgentClass(runner, name).validate_metadata()
     except (InvalidResourceAgentName, InvalidStonithAgentName) as e:
-        raise LibraryError(resource_agent_error_to_report_item(e))
+        raise LibraryError(resource_agent_error_to_report_item(e)) from e
     except UnableToGetAgentMetadata as e:
         if not absent_agent_supported:
-            raise LibraryError(resource_agent_error_to_report_item(e))
+            raise LibraryError(resource_agent_error_to_report_item(e)) from e
 
         if not AbsentAgentClass:
             raise LibraryError(
                 resource_agent_error_to_report_item(e, forceable=True)
-            )
+            ) from e
 
         report_processor.report(
             resource_agent_error_to_report_item(
-                e, severity=ReportItemSeverity.WARNING,
+                e,
+                severity=ReportItemSeverity.WARNING,
             )
         )
 
@@ -569,7 +570,9 @@ class Agent:
             validate.NamesIn(
                 {param["name"] for param in self.get_parameters()},
                 option_type=self._agent_type_label,
-                **validate.set_warning(reports.codes.FORCE_OPTIONS, force),
+                severity=reports.item.get_severity(
+                    reports.codes.FORCE_OPTIONS, force
+                ),
             ).validate(parameters)
         )
         # TODO remove this "if", see pcs.lib.cib.commands.remote_node.create
@@ -602,7 +605,8 @@ class Agent:
                 ReportItem(
                     severity=self._validate_report_severity(force),
                     message=reports.messages.RequiredOptionsAreMissing(
-                        sorted(missing_parameters), self._agent_type_label,
+                        sorted(missing_parameters),
+                        self._agent_type_label,
                     ),
                 )
             )
@@ -639,7 +643,9 @@ class Agent:
             validate.NamesIn(
                 {param["name"] for param in self.get_parameters()},
                 option_type=self._agent_type_label,
-                **validate.set_warning(reports.codes.FORCE_OPTIONS, force),
+                severity=reports.item.get_severity(
+                    reports.codes.FORCE_OPTIONS, force
+                ),
             ).validate(
                 # Do not report unknown parameters already set in the CIB. They
                 # have been reported already when the were added to the CIB.
@@ -660,7 +666,8 @@ class Agent:
                 ReportItem(
                     severity=self._validate_report_severity(force),
                     message=reports.messages.RequiredOptionsAreMissing(
-                        sorted(missing_parameters), self._agent_type_label,
+                        sorted(missing_parameters),
+                        self._agent_type_label,
                     ),
                 )
             )
@@ -780,7 +787,7 @@ class Agent:
             #    etree.DTD(file=settings.agent_metadata_schema).assertValid(dom)
             return dom
         except (etree.XMLSyntaxError, etree.DocumentInvalid) as e:
-            raise UnableToGetAgentMetadata(self.get_name(), str(e))
+            raise UnableToGetAgentMetadata(self.get_name(), str(e)) from e
 
     def _get_text_from_dom_element(self, element):
         if element is None or element.text is None:
@@ -816,9 +823,7 @@ class FencedMetadata(FakeAgentMetadata):
         return "pacemaker-fenced"
 
     def _get_parameter(self, parameter_element):
-        parameter = super(FencedMetadata, self)._get_parameter(
-            parameter_element
-        )
+        parameter = super()._get_parameter(parameter_element)
         # Metadata are written in such a way that a longdesc text is a
         # continuation of a shortdesc text.
         parameter["longdesc"] = "{0}\n{1}".format(
@@ -846,7 +851,7 @@ class CrmAgent(Agent):
         init
         CommandRunner runner
         """
-        super(CrmAgent, self).__init__(runner)
+        super().__init__(runner)
         self._name_parts = self._prepare_name_parts(name)
 
     def _prepare_name_parts(self, name):
@@ -900,7 +905,9 @@ class CrmAgent(Agent):
                 "--show-metadata",
                 self._get_full_name(),
             ],
-            env_extend={"PATH": env_path,},
+            env_extend={
+                "PATH": env_path,
+            },
         )
         if retval != 0:
             raise UnableToGetAgentMetadata(self.get_name(), stderr.strip())
@@ -921,7 +928,7 @@ class ResourceAgent(CrmAgent):
         return self._get_full_name()
 
     def get_parameters(self):
-        parameters = super(ResourceAgent, self).get_parameters()
+        parameters = super().get_parameters()
         if self.get_standard() == "ocf" and (
             self.get_provider() in ("heartbeat", "pacemaker")
         ):
@@ -1046,7 +1053,7 @@ class StonithAgent(CrmAgent):
 
     def get_parameters(self):
         return (
-            self._filter_parameters(super(StonithAgent, self).get_parameters())
+            self._filter_parameters(super().get_parameters())
             + self._get_fenced_metadata().get_parameters()
         )
 
@@ -1058,7 +1065,7 @@ class StonithAgent(CrmAgent):
         # for details
         do_not_report_instance_attribute_server_exists=False,
     ):
-        report_list = super(StonithAgent, self).validate_parameters_create(
+        report_list = super().validate_parameters_create(
             parameters, force=force
         )
         report_list.extend(
@@ -1069,7 +1076,7 @@ class StonithAgent(CrmAgent):
     def validate_parameters_update(
         self, current_parameters, new_parameters, force=False
     ):
-        report_list = super(StonithAgent, self).validate_parameters_update(
+        report_list = super().validate_parameters_update(
             current_parameters, new_parameters, force=force
         )
         report_list.extend(
@@ -1097,7 +1104,12 @@ class StonithAgent(CrmAgent):
         """
         # We don't allow the user to change these options which are only
         # intended to be used interactively on command line.
-        remove_parameters = frozenset(["help", "version",])
+        remove_parameters = frozenset(
+            [
+                "help",
+                "version",
+            ]
+        )
         filtered = []
         for param in parameters:
             if param["name"] in remove_parameters:
