@@ -6,6 +6,7 @@ from pcs import settings
 from pcs import utils
 from pcs.cli.common.errors import CmdLineInputError
 
+
 def pcsd_certkey(lib, argv, modifiers):
     """
     Options:
@@ -20,9 +21,9 @@ def pcsd_certkey(lib, argv, modifiers):
     keyfile = argv[1]
 
     try:
-        with open(certfile, 'r') as myfile:
+        with open(certfile, "r") as myfile:
             cert = myfile.read()
-        with open(keyfile, 'r') as myfile:
+        with open(keyfile, "r") as myfile:
             key = myfile.read()
     except IOError as e:
         utils.err(e)
@@ -32,14 +33,9 @@ def pcsd_certkey(lib, argv, modifiers):
             utils.err(err, False)
         sys.exit(1)
 
-    if (
-        not modifiers.get("--force")
-        and
-        (
-            os.path.exists(settings.pcsd_cert_location)
-            or
-            os.path.exists(settings.pcsd_key_location)
-        )
+    if not modifiers.get("--force") and (
+        os.path.exists(settings.pcsd_cert_location)
+        or os.path.exists(settings.pcsd_key_location)
     ):
         utils.err(
             "certificate and/or key already exists, use --force to overwrite"
@@ -48,21 +44,21 @@ def pcsd_certkey(lib, argv, modifiers):
     try:
         try:
             os.chmod(settings.pcsd_cert_location, 0o700)
-        except OSError: # If the file doesn't exist, we don't care
+        except OSError:  # If the file doesn't exist, we don't care
             pass
 
         try:
             os.chmod(settings.pcsd_key_location, 0o700)
-        except OSError: # If the file doesn't exist, we don't care
+        except OSError:  # If the file doesn't exist, we don't care
             pass
 
         with os.fdopen(
             os.open(
                 settings.pcsd_cert_location,
                 os.O_WRONLY | os.O_CREAT | os.O_TRUNC,
-                0o700
+                0o700,
             ),
-            'w'
+            "w",
         ) as myfile:
             myfile.write(cert)
 
@@ -70,9 +66,9 @@ def pcsd_certkey(lib, argv, modifiers):
             os.open(
                 settings.pcsd_key_location,
                 os.O_WRONLY | os.O_CREAT | os.O_TRUNC,
-                0o700
+                0o700,
             ),
-            'w'
+            "w",
         ) as myfile:
             myfile.write(key)
 
@@ -81,9 +77,10 @@ def pcsd_certkey(lib, argv, modifiers):
 
     print(
         "Certificate and key updated, you may need to restart pcsd for new "
-            "settings to take effect"
+        "settings to take effect"
     )
 
+
 def pcsd_sync_certs(lib, argv, modifiers):
     """
     Options:
@@ -96,6 +93,7 @@ def pcsd_sync_certs(lib, argv, modifiers):
         skip_offline=modifiers.get("--skip-offline")
     )
 
+
 def pcsd_deauth(lib, argv, modifiers):
     """
     Options: No options
@@ -111,8 +109,7 @@ def pcsd_deauth(lib, argv, modifiers):
         except EnvironmentError as e:
             utils.err(
                 "Unable to edit data in {file}: {err}".format(
-                    file=filepath,
-                    err=e
+                    file=filepath, err=e
                 )
             )
         return
@@ -130,9 +127,11 @@ def pcsd_deauth(lib, argv, modifiers):
                 new_data.append(old_item)
         tokens_not_found = sorted(tokens_to_remove - removed_tokens)
         if tokens_not_found:
-            utils.err("Following tokens were not found: '{tokens}'".format(
-                tokens="', '".join(tokens_not_found)
-            ))
+            utils.err(
+                "Following tokens were not found: '{tokens}'".format(
+                    tokens="', '".join(tokens_not_found)
+                )
+            )
         if removed_tokens:
             users_file.seek(0)
             users_file.truncate()
@@ -152,3 +151,11 @@ def pcsd_deauth(lib, argv, modifiers):
         utils.err(
             "Unable to edit data in {file}: {err}".format(file=filepath, err=e)
         )
+
+
+def accept_token_cmd(lib, argv, modifiers):
+    del lib
+    modifiers.ensure_only_supported()
+    if len(argv) != 1:
+        raise CmdLineInputError("1 argument required")
+    utils.set_token_to_accept(utils.get_token_from_file(argv[0]))
