@@ -5,18 +5,17 @@ from pcs import (
     utils,
 )
 from pcs.cli.common import parse_args
-from pcs.cli.common.console_report import error
 from pcs.cli.common.errors import CmdLineInputError
-from pcs.cli.common.reports import process_library_reports
 from pcs.cli.fencing_topology import target_type_map_cli_to_lib
+from pcs.cli.reports import process_library_reports
+from pcs.cli.reports.output import error
 from pcs.cli.resource.parse_args import parse_create_simple as parse_create_args
-from pcs.common import report_codes
 from pcs.common.fencing_topology import (
     TARGET_TYPE_NODE,
     TARGET_TYPE_REGEXP,
     TARGET_TYPE_ATTRIBUTE,
 )
-from pcs.common.tools import indent
+from pcs.common.str_tools import indent
 from pcs.lib.errors import LibraryError
 import pcs.lib.resource_agent as lib_ra
 
@@ -41,12 +40,11 @@ def stonith_config_cmd(lib, argv, modifiers):
 
 
 def print_stonith_levels(lib):
-    levels = stonith_level_config_to_str(
-        lib.fencing_topology.get_config()
-    )
+    levels = stonith_level_config_to_str(lib.fencing_topology.get_config())
     if levels:
         print("\n".join(indent(levels, 1)))
 
+
 def stonith_list_available(lib, argv, modifiers):
     """
     Options:
@@ -74,12 +72,14 @@ def stonith_list_available(lib, argv, modifiers):
         name = agent_info["name"]
         shortdesc = agent_info["shortdesc"]
         if shortdesc:
-            print("{0} - {1}".format(
-                name,
-                resource._format_desc(
-                    len(name + " - "), shortdesc.replace("\n", " ")
+            print(
+                "{0} - {1}".format(
+                    name,
+                    resource._format_desc(
+                        len(name + " - "), shortdesc.replace("\n", " ")
+                    ),
                 )
-            ))
+            )
         else:
             print(name)
 
@@ -94,11 +94,14 @@ def stonith_list_options(lib, argv, modifiers):
         raise CmdLineInputError()
     agent_name = argv[0]
 
-    print(resource._format_agent_description(
-        lib.stonith_agent.describe_agent(agent_name),
-        stonith=True,
-        show_all=modifiers.get("--full"),
-    ))
+    print(
+        resource._format_agent_description(
+            lib.stonith_agent.describe_agent(agent_name),
+            stonith=True,
+            show_all=modifiers.get("--full"),
+        )
+    )
+
 
 def stonith_create(lib, argv, modifiers):
     """
@@ -116,14 +119,23 @@ def stonith_create(lib, argv, modifiers):
       * -f - CIB file
     """
     modifiers.ensure_only_supported(
-        "--before", "--after", "--group", "--force", "--disabled",
-        "--no-default-ops", "--wait", "-f",
+        "--before",
+        "--after",
+        "--group",
+        "--force",
+        "--disabled",
+        "--no-default-ops",
+        "--wait",
+        "-f",
     )
     if modifiers.is_specified("--before") and modifiers.is_specified("--after"):
-        raise error("you cannot specify both --before and --after{0}".format(
-            "" if modifiers.is_specified("--group")
-            else " and you have to specify --group"
-        ))
+        raise error(
+            "you cannot specify both --before and --after{0}".format(
+                ""
+                if modifiers.is_specified("--group")
+                else " and you have to specify --group"
+            )
+        )
 
     if not modifiers.is_specified("--group"):
         if modifiers.is_specified("--before"):
@@ -150,10 +162,12 @@ def stonith_create(lib, argv, modifiers):
 
     if not modifiers.get("--group"):
         lib.stonith.create(
-            stonith_id, stonith_type, parts["op"],
+            stonith_id,
+            stonith_type,
+            parts["op"],
             parts["meta"],
             parts["options"],
-            **settings
+            **settings,
         )
     else:
         adjacent_resource_id = None
@@ -166,22 +180,24 @@ def stonith_create(lib, argv, modifiers):
             put_after_adjacent = False
 
         lib.stonith.create_in_group(
-            stonith_id, stonith_type, modifiers.get("--group"), parts["op"],
+            stonith_id,
+            stonith_type,
+            modifiers.get("--group"),
+            parts["op"],
             parts["meta"],
             parts["options"],
             adjacent_resource_id=adjacent_resource_id,
             put_after_adjacent=put_after_adjacent,
-            **settings
+            **settings,
         )
 
+
 def stonith_level_parse_node(arg):
     """
     Commandline options: no options
     """
     target_type_candidate, target_value_candidate = parse_args.parse_typed_arg(
-        arg,
-        target_type_map_cli_to_lib.keys(),
-        "node"
+        arg, target_type_map_cli_to_lib.keys(), "node"
     )
     target_type = target_type_map_cli_to_lib[target_type_candidate]
     if target_type == TARGET_TYPE_ATTRIBUTE:
@@ -190,6 +206,7 @@ def stonith_level_parse_node(arg):
         target_value = target_value_candidate
     return target_type, target_value
 
+
 def stonith_level_normalize_devices(argv):
     """
     Commandline options: no options
@@ -198,6 +215,7 @@ def stonith_level_normalize_devices(argv):
     # a comma and a space
     return ",".join(argv).split(",")
 
+
 def stonith_level_add_cmd(lib, argv, modifiers):
     """
     Options:
@@ -218,6 +236,7 @@ def stonith_level_add_cmd(lib, argv, modifiers):
         force_node=modifiers.get("--force"),
     )
 
+
 def stonith_level_clear_cmd(lib, argv, modifiers):
     """
     Options:
@@ -240,7 +259,7 @@ def stonith_level_clear_cmd(lib, argv, modifiers):
     # code tried both. It deleted all levels having the first parameter as
     # either a node or a device list. Since it was only possible to specify
     # node as a target back then, this is enabled only in that case.
-    report_item_list = []
+    was_error = False
     try:
         lib.fencing_topology.remove_levels_by_params(
             None,
@@ -248,10 +267,10 @@ def stonith_level_clear_cmd(lib, argv, modifiers):
             target_value,
             None,
             # pre-lib code didn't return any error when no level was found
-            ignore_if_missing=True
+            ignore_if_missing=True,
         )
-    except LibraryError as e:
-        report_item_list.extend(e.args)
+    except LibraryError:
+        was_error = True
     if target_type == TARGET_TYPE_NODE:
         try:
             lib.fencing_topology.remove_levels_by_params(
@@ -260,12 +279,13 @@ def stonith_level_clear_cmd(lib, argv, modifiers):
                 None,
                 argv[0].split(","),
                 # pre-lib code didn't return any error when no level was found
-                ignore_if_missing=True
+                ignore_if_missing=True,
             )
-        except LibraryError as e:
-            report_item_list.extend(e.args)
-    if report_item_list:
-        raise LibraryError(*report_item_list)
+        except LibraryError:
+            was_error = True
+    if was_error:
+        raise LibraryError()
+
 
 def stonith_level_config_to_str(config):
     """
@@ -281,27 +301,35 @@ def stonith_level_config_to_str(config):
 
     lines = []
     for target_type in [
-        TARGET_TYPE_NODE, TARGET_TYPE_REGEXP, TARGET_TYPE_ATTRIBUTE
+        TARGET_TYPE_NODE,
+        TARGET_TYPE_REGEXP,
+        TARGET_TYPE_ATTRIBUTE,
     ]:
         if not target_type in config_data:
             continue
         for target_value in sorted(config_data[target_type].keys()):
-            lines.append("Target: {0}".format(
-                "=".join(target_value) if target_type == TARGET_TYPE_ATTRIBUTE
-                else target_value
-            ))
+            lines.append(
+                "Target: {0}".format(
+                    "=".join(target_value)
+                    if target_type == TARGET_TYPE_ATTRIBUTE
+                    else target_value
+                )
+            )
             level_lines = []
             for target_level in sorted(
                 config_data[target_type][target_value],
-                key=lambda level: level["level"]
+                key=lambda level: level["level"],
             ):
-                level_lines.append("Level {level} - {devices}".format(
-                    level=target_level["level"],
-                    devices=",".join(target_level["devices"])
-                ))
+                level_lines.append(
+                    "Level {level} - {devices}".format(
+                        level=target_level["level"],
+                        devices=",".join(target_level["devices"]),
+                    )
+                )
             lines.extend(indent(level_lines))
     return lines
 
+
 def stonith_level_config_cmd(lib, argv, modifiers):
     """
     Options:
@@ -315,6 +343,7 @@ def stonith_level_config_cmd(lib, argv, modifiers):
     if lines:
         print("\n".join(lines))
 
+
 def stonith_level_remove_cmd(lib, argv, modifiers):
     """
     Options:
@@ -330,49 +359,15 @@ def stonith_level_remove_cmd(lib, argv, modifiers):
     if len(argv) > 2:
         devices = stonith_level_normalize_devices(argv[2:])
 
-    try:
-        lib.fencing_topology.remove_levels_by_params(
-            level,
-            target_type,
-            target_value,
-            devices
-        )
-    except LibraryError as e:
-        # backward compatibility mode
-        # Command parameters are: level, node, stonith, stonith...
-        # Both the node and the stonith list are optional. If the node is
-        # ommited and the stonith list is present, there is no way to figure it
-        # out, since there is no specification of what the parameter is. Hence
-        # the pre-lib code tried both. First it assumed the first parameter is
-        # a node. If that fence level didn't exist, it assumed the first
-        # parameter is a device. Since it was only possible to specify node as
-        # a target back then, this is enabled only in that case.
-        if target_type != TARGET_TYPE_NODE:
-            raise e
-        level_not_found = False
-        for report_item in e.args:
-            if (
-                # pylint: disable=no-member
-                report_item.code
-                ==
-                report_codes.CIB_FENCING_LEVEL_DOES_NOT_EXIST
-            ):
-                level_not_found = True
-                break
-        if not level_not_found:
-            raise e
-        target_and_devices = [target_value]
-        if devices:
-            target_and_devices.extend(devices)
-        try:
-            lib.fencing_topology.remove_levels_by_params(
-                level,
-                None,
-                None,
-                target_and_devices
-            )
-        except LibraryError as e_second:
-            raise LibraryError(*(e.args + e_second.args))
+    lib.fencing_topology.remove_levels_by_params(
+        level,
+        target_type,
+        target_value,
+        devices,
+        # backward compatibility mode, see lib command for details
+        target_may_be_a_device=True,
+    )
+
 
 def stonith_level_verify_cmd(lib, argv, modifiers):
     """
@@ -385,6 +380,7 @@ def stonith_level_verify_cmd(lib, argv, modifiers):
     # raises LibraryError in case of problems, else we don't want to do anything
     lib.fencing_topology.verify()
 
+
 def stonith_fence(lib, argv, modifiers):
     """
     Options:
@@ -407,6 +403,7 @@ def stonith_fence(lib, argv, modifiers):
     else:
         print("Node: %s fenced" % node)
 
+
 def stonith_confirm(lib, argv, modifiers):
     """
     Options:
@@ -456,14 +453,12 @@ def get_fence_agent_info(lib, argv, modifiers):
     runner = utils.cmd_runner()
 
     try:
-        metadata = lib_ra.StonithAgent(runner, agent[len("stonith:"):])
+        metadata = lib_ra.StonithAgent(runner, agent[len("stonith:") :])
         info = metadata.get_full_info()
         info["name"] = "stonith:{0}".format(info["name"])
         print(json.dumps(info))
     except lib_ra.ResourceAgentError as e:
-        process_library_reports(
-            [lib_ra.resource_agent_error_to_report_item(e)]
-        )
+        process_library_reports([lib_ra.resource_agent_error_to_report_item(e)])
     except LibraryError as e:
         process_library_reports(e.args)
 
@@ -485,6 +480,7 @@ def sbd_watchdog_list(lib, argv, modifiers):
     else:
         print("No available watchdog")
 
+
 def sbd_watchdog_list_json(lib, argv, modifiers):
     """
     Options: no options
@@ -523,12 +519,13 @@ def sbd_enable(lib, argv, modifiers):
       * --no-watchdog-validation - do not validate watchdog
     """
     modifiers.ensure_only_supported(
-        "--request-timeout", "--force", "--skip-offline",
+        "--request-timeout",
+        "--force",
+        "--skip-offline",
         "--no-watchdog-validation",
     )
     options = parse_args.prepare_options(
-        argv,
-        allowed_repeatable_options=("device", "watchdog")
+        argv, allowed_repeatable_options=("device", "watchdog")
     )
     default_watchdog, watchdog_dict = _sbd_parse_watchdogs(
         options.get("watchdog", [])
@@ -541,7 +538,8 @@ def sbd_enable(lib, argv, modifiers):
         default_watchdog,
         watchdog_dict,
         {
-            name: value for name, value in options.items()
+            name: value
+            for name, value in options.items()
             if name not in ("device", "watchdog")
         },
         default_device_list=(
@@ -553,6 +551,7 @@ def sbd_enable(lib, argv, modifiers):
         no_watchdog_validation=modifiers.get("--no-watchdog-validation"),
     )
 
+
 def _sbd_parse_node_specific_options(arg_list):
     """
     Commandline options: no options
@@ -577,8 +576,10 @@ def _sbd_parse_watchdogs(watchdog_list):
     """
     Commandline options: no options
     """
-    default_watchdog_list, node_specific_watchdog_dict =\
-        _sbd_parse_node_specific_options(watchdog_list)
+    (
+        default_watchdog_list,
+        node_specific_watchdog_dict,
+    ) = _sbd_parse_node_specific_options(watchdog_list)
     if not default_watchdog_list:
         default_watchdog = None
     elif len(default_watchdog_list) == 1:
@@ -619,6 +620,7 @@ def sbd_status(lib, argv, modifiers):
       * --full - display SBD device header
     """
     modifiers.ensure_only_supported("--request-timeout", "--full")
+
     def _bool_to_str(val):
         if val is None:
             return "N/A"
@@ -635,12 +637,14 @@ def sbd_status(lib, argv, modifiers):
     print("<node name>: <installed> | <enabled> | <running>")
     for node_status in status_list:
         status = node_status["status"]
-        print("{node}: {installed} | {enabled} | {running}".format(
-            node=node_status["node"],
-            installed=_bool_to_str(status.get("installed")),
-            enabled=_bool_to_str(status.get("enabled")),
-            running=_bool_to_str(status.get("running"))
-        ))
+        print(
+            "{node}: {installed} | {enabled} | {running}".format(
+                node=node_status["node"],
+                installed=_bool_to_str(status.get("installed")),
+                enabled=_bool_to_str(status.get("enabled")),
+                running=_bool_to_str(status.get("running")),
+            )
+        )
     device_list = lib.sbd.get_local_devices_info(modifiers.get("--full"))
     for device in device_list:
         print()
@@ -651,6 +655,7 @@ def sbd_status(lib, argv, modifiers):
             print("SBD header on device '{0}':".format(device["device"]))
             print("<unknown>" if device["dump"] is None else device["dump"])
 
+
 def _print_per_node_option(config_list, config_option):
     """
     Commandline options: no options
@@ -680,7 +685,10 @@ def sbd_config(lib, argv, modifiers):
     config = config_list[0]["config"]
 
     filtered_options = [
-        "SBD_WATCHDOG_DEV", "SBD_OPTS", "SBD_PACEMAKER", "SBD_DEVICE"
+        "SBD_WATCHDOG_DEV",
+        "SBD_OPTS",
+        "SBD_PACEMAKER",
+        "SBD_DEVICE",
     ]
     with_device = False
     for key, val in config.items():
@@ -717,8 +725,7 @@ def sbd_setup_block_device(lib, argv, modifiers):
     """
     modifiers.ensure_only_supported("--force")
     options = parse_args.prepare_options(
-        argv,
-        allowed_repeatable_options=("device",)
+        argv, allowed_repeatable_options=("device",)
     )
     device_list = options.get("device", [])
     if not device_list:
@@ -737,10 +744,7 @@ def sbd_setup_block_device(lib, argv, modifiers):
 
     lib.sbd.initialize_block_devices(
         device_list,
-        {
-            name: value for name, value in options.items()
-            if name != "device"
-        }
+        {name: value for name, value in options.items() if name != "device"},
     )
 
 
