@@ -3,100 +3,246 @@ from unittest import TestCase
 from pcs.cli.resource import parse_args
 from pcs.cli.common.errors import CmdLineInputError
 
+
+class ParseCloneArgs(TestCase):
+    def assert_produce(self, arg_list, result, promotable=False):
+        self.assertEqual(
+            parse_args.parse_clone(arg_list, promotable=promotable),
+            result,
+        )
+
+    def assert_raises_cmdline(self, args, expected_msg, promotable=False):
+        with self.assertRaises(CmdLineInputError) as cm:
+            parse_args.parse_clone(args, promotable=promotable)
+        self.assertEqual(cm.exception.message, expected_msg)
+
+    def test_no_args(self):
+        self.assert_produce([], {"clone_id": None, "meta": {}})
+
+    def test_clone_id(self):
+        self.assert_produce(
+            ["CustomCloneId"],
+            {"clone_id": "CustomCloneId", "meta": {}},
+        )
+
+    def test_clone_options(self):
+        self.assert_produce(
+            ["a=b", "c=d"],
+            {"clone_id": None, "meta": {"a": "b", "c": "d"}},
+        )
+
+    def test_meta_options(self):
+        self.assert_produce(
+            ["meta", "a=b", "c=d"],
+            {"clone_id": None, "meta": {"a": "b", "c": "d"}},
+        )
+
+    def test_clone_id_and_clone_meta_options(self):
+        self.assert_produce(
+            ["CustomCloneId", "a=b", "c=d", "meta", "e=f", "g=h"],
+            {
+                "clone_id": "CustomCloneId",
+                "meta": {"a": "b", "c": "d", "e": "f", "g": "h"},
+            },
+        )
+
+    def test_op_options(self):
+        self.assert_raises_cmdline(
+            ["op", "start", "timeout=30s"],
+            "op settings must be changed on base resource, not the clone",
+        )
+
+    def test_op_options_and_clone_id(self):
+        self.assert_raises_cmdline(
+            ["CloneId", "op", "start", "timeout=30s"],
+            "op settings must be changed on base resource, not the clone",
+        )
+
+    def test_missing_option_value(self):
+        self.assert_raises_cmdline(
+            ["CloneId", "a"], "missing value of 'a' option"
+        )
+
+    def test_missing_meta_option_value(self):
+        self.assert_raises_cmdline(["meta", "m"], "missing value of 'm' option")
+
+    def test_promotable_keyword_and_option(self):
+        self.assert_raises_cmdline(
+            ["CloneId", "promotable=true", "meta", "promotable=true"],
+            "you cannot specify both promotable option and promotable keyword",
+            promotable=True,
+        )
+
+    def test_different_values_of_option_and_meta_option(self):
+        self.assert_raises_cmdline(
+            ["CloneId", "promotable=true", "meta", "promotable=false"],
+            (
+                "duplicate option 'promotable' with different values 'true' and"
+                " 'false'"
+            ),
+            promotable=True,
+        )
+
+
 class ParseCreateArgs(TestCase):
     def assert_produce(self, arg_list, result):
         self.assertEqual(parse_args.parse_create(arg_list), result)
 
     def test_no_args(self):
-        self.assert_produce([], {
-            "meta": {},
-            "options": {},
-            "op": [],
-        })
+        self.assert_produce(
+            [],
+            {
+                "meta": {},
+                "options": {},
+                "op": [],
+            },
+        )
 
     def test_only_instance_attributes(self):
-        self.assert_produce(["a=b", "c=d"], {
-            "meta": {},
-            "options": {
-                "a": "b",
-                "c": "d",
+        self.assert_produce(
+            ["a=b", "c=d"],
+            {
+                "meta": {},
+                "options": {
+                    "a": "b",
+                    "c": "d",
+                },
+                "op": [],
             },
-            "op": [],
-        })
+        )
 
     def test_only_meta(self):
-        self.assert_produce(["meta", "a=b", "c=d"], {
-            "options": {},
-            "op": [],
-            "meta": {
-                "a": "b",
-                "c": "d",
+        self.assert_produce(
+            ["meta", "a=b", "c=d"],
+            {
+                "options": {},
+                "op": [],
+                "meta": {
+                    "a": "b",
+                    "c": "d",
+                },
             },
-        })
+        )
 
     def test_only_clone(self):
-        self.assert_produce(["clone", "a=b", "c=d"], {
-            "meta": {},
-            "options": {},
-            "op": [],
-            "clone": {
-                "a": "b",
-                "c": "d",
+        self.assert_produce(
+            ["clone", "a=b", "c=d"],
+            {
+                "meta": {},
+                "options": {},
+                "op": [],
+                "clone": {
+                    "a": "b",
+                    "c": "d",
+                },
             },
-        })
+        )
+
+    def test_only_clone_with_custom_id(self):
+        self.assert_produce(
+            ["clone", "CustomCloneId", "a=b", "c=d"],
+            {
+                "meta": {},
+                "options": {},
+                "op": [],
+                "clone": {
+                    "a": "b",
+                    "c": "d",
+                },
+                "clone_id": "CustomCloneId",
+            },
+        )
 
     def test_only_promotable(self):
-        self.assert_produce(["promotable", "a=b", "c=d"], {
-            "meta": {},
-            "options": {},
-            "op": [],
-            "promotable": {
-                "a": "b",
-                "c": "d",
+        self.assert_produce(
+            ["promotable", "a=b", "c=d"],
+            {
+                "meta": {},
+                "options": {},
+                "op": [],
+                "promotable": {
+                    "a": "b",
+                    "c": "d",
+                },
             },
-        })
+        )
+
+    def test_only_promotable_with_custom_id(self):
+        self.assert_produce(
+            ["promotable", "CustomCloneId", "a=b", "c=d"],
+            {
+                "meta": {},
+                "options": {},
+                "op": [],
+                "promotable": {
+                    "a": "b",
+                    "c": "d",
+                },
+                "clone_id": "CustomCloneId",
+            },
+        )
 
     def test_only_operations(self):
-        self.assert_produce([
-            "op", "monitor", "a=b", "c=d", "start", "e=f",
-        ], {
-            "meta": {},
-            "options": {},
-            "op": [
-                {"name": "monitor", "a": "b", "c": "d"},
-                {"name": "start", "e": "f"},
+        self.assert_produce(
+            [
+                "op",
+                "monitor",
+                "a=b",
+                "c=d",
+                "start",
+                "e=f",
             ],
-        })
+            {
+                "meta": {},
+                "options": {},
+                "op": [
+                    {"name": "monitor", "a": "b", "c": "d"},
+                    {"name": "start", "e": "f"},
+                ],
+            },
+        )
 
     def test_args_op_clone_meta(self):
-        self.assert_produce([
-            "a=b", "c=d",
-            "meta", "e=f", "g=h",
-            "op", "monitor", "i=j", "k=l", "start", "m=n",
-            "clone", "o=p", "q=r",
-        ], {
-            "options": {
-                "a": "b",
-                "c": "d",
-            },
-            "op": [
-                {"name": "monitor", "i": "j", "k": "l"},
-                {"name": "start", "m": "n"},
+        self.assert_produce(
+            [
+                "a=b",
+                "c=d",
+                "meta",
+                "e=f",
+                "g=h",
+                "op",
+                "monitor",
+                "i=j",
+                "k=l",
+                "start",
+                "m=n",
+                "clone",
+                "o=p",
+                "q=r",
             ],
-            "meta": {
-                "e": "f",
-                "g": "h",
+            {
+                "options": {
+                    "a": "b",
+                    "c": "d",
+                },
+                "op": [
+                    {"name": "monitor", "i": "j", "k": "l"},
+                    {"name": "start", "m": "n"},
+                ],
+                "meta": {
+                    "e": "f",
+                    "g": "h",
+                },
+                "clone": {
+                    "o": "p",
+                    "q": "r",
+                },
             },
-            "clone": {
-                "o": "p",
-                "q": "r",
-            },
-        })
+        )
 
     def assert_raises_cmdline(self, args):
         self.assertRaises(
-            CmdLineInputError,
-            lambda: parse_args.parse_create(args)
+            CmdLineInputError, lambda: parse_args.parse_create(args)
         )
 
     def test_raises_when_operation_name_does_not_follow_op_keyword(self):
@@ -112,17 +258,25 @@ class ParseCreateArgs(TestCase):
         )
 
     def test_allow_to_repeat_op(self):
-        self.assert_produce([
-            "op", "monitor", "a=b", "c=d",
-            "op", "start", "e=f",
-        ], {
-            "meta": {},
-            "options": {},
-            "op": [
-                {"name": "monitor", "a": "b", "c": "d"},
-                {"name": "start", "e": "f"},
+        self.assert_produce(
+            [
+                "op",
+                "monitor",
+                "a=b",
+                "c=d",
+                "op",
+                "start",
+                "e=f",
             ],
-        })
+            {
+                "meta": {},
+                "options": {},
+                "op": [
+                    {"name": "monitor", "a": "b", "c": "d"},
+                    {"name": "start", "e": "f"},
+                ],
+            },
+        )
 
     def test_deal_with_empty_operatins(self):
         self.assert_raises_cmdline(["op", "monitoring", "a=b", "op"])
@@ -133,48 +287,64 @@ class ParseCreateSimple(TestCase):
         self.assertEqual(parse_args.parse_create_simple(arg_list), result)
 
     def test_without_args(self):
-        self.assert_produce([], {
-            "meta": {},
-            "options": {},
-            "op": [],
-        })
+        self.assert_produce(
+            [],
+            {
+                "meta": {},
+                "options": {},
+                "op": [],
+            },
+        )
 
     def test_only_instance_attributes(self):
-        self.assert_produce(["a=b", "c=d"], {
-            "meta": {},
-            "options": {
-                "a": "b",
-                "c": "d",
+        self.assert_produce(
+            ["a=b", "c=d"],
+            {
+                "meta": {},
+                "options": {
+                    "a": "b",
+                    "c": "d",
+                },
+                "op": [],
             },
-            "op": [],
-        })
+        )
 
     def test_only_meta(self):
-        self.assert_produce(["meta", "a=b", "c=d"], {
-            "options": {},
-            "op": [],
-            "meta": {
-                "a": "b",
-                "c": "d",
+        self.assert_produce(
+            ["meta", "a=b", "c=d"],
+            {
+                "options": {},
+                "op": [],
+                "meta": {
+                    "a": "b",
+                    "c": "d",
+                },
             },
-        })
+        )
 
     def test_only_operations(self):
-        self.assert_produce([
-            "op", "monitor", "a=b", "c=d", "start", "e=f",
-        ], {
-            "meta": {},
-            "options": {},
-            "op": [
-                {"name": "monitor", "a": "b", "c": "d"},
-                {"name": "start", "e": "f"},
+        self.assert_produce(
+            [
+                "op",
+                "monitor",
+                "a=b",
+                "c=d",
+                "start",
+                "e=f",
             ],
-        })
+            {
+                "meta": {},
+                "options": {},
+                "op": [
+                    {"name": "monitor", "a": "b", "c": "d"},
+                    {"name": "start", "e": "f"},
+                ],
+            },
+        )
 
     def assert_raises_cmdline(self, args):
         self.assertRaises(
-            CmdLineInputError,
-            lambda: parse_args.parse_create_simple(args)
+            CmdLineInputError, lambda: parse_args.parse_create_simple(args)
         )
 
     def test_raises_when_operation_name_does_not_follow_op_keyword(self):
@@ -190,31 +360,38 @@ class ParseCreateSimple(TestCase):
         )
 
     def test_allow_to_repeat_op(self):
-        self.assert_produce([
-            "op", "monitor", "a=b", "c=d",
-            "op", "start", "e=f",
-        ], {
-            "meta": {},
-            "options": {},
-            "op": [
-                {"name": "monitor", "a": "b", "c": "d"},
-                {"name": "start", "e": "f"},
+        self.assert_produce(
+            [
+                "op",
+                "monitor",
+                "a=b",
+                "c=d",
+                "op",
+                "start",
+                "e=f",
             ],
-        })
+            {
+                "meta": {},
+                "options": {},
+                "op": [
+                    {"name": "monitor", "a": "b", "c": "d"},
+                    {"name": "start", "e": "f"},
+                ],
+            },
+        )
 
 
 class ParseBundleCreateOptions(TestCase):
     # pylint: disable=too-many-public-methods
     def assert_produce(self, arg_list, result):
         self.assertEqual(
-            result,
-            parse_args.parse_bundle_create_options(arg_list)
+            result, parse_args.parse_bundle_create_options(arg_list)
         )
 
     def assert_raises_cmdline(self, arg_list):
         self.assertRaises(
             CmdLineInputError,
-            lambda: parse_args.parse_bundle_create_options(arg_list)
+            lambda: parse_args.parse_bundle_create_options(arg_list),
         )
 
     def test_no_args(self):
@@ -227,7 +404,7 @@ class ParseBundleCreateOptions(TestCase):
                 "port_map": [],
                 "storage_map": [],
                 "meta": {},
-            }
+            },
         )
 
     def test_container_empty(self):
@@ -243,7 +420,7 @@ class ParseBundleCreateOptions(TestCase):
                 "port_map": [],
                 "storage_map": [],
                 "meta": {},
-            }
+            },
         )
 
     def test_container_options(self):
@@ -256,7 +433,7 @@ class ParseBundleCreateOptions(TestCase):
                 "port_map": [],
                 "storage_map": [],
                 "meta": {},
-            }
+            },
         )
 
     def test_container_type_and_options(self):
@@ -269,7 +446,7 @@ class ParseBundleCreateOptions(TestCase):
                 "port_map": [],
                 "storage_map": [],
                 "meta": {},
-            }
+            },
         )
 
     def test_container_type_must_be_first(self):
@@ -291,7 +468,7 @@ class ParseBundleCreateOptions(TestCase):
                 "port_map": [],
                 "storage_map": [],
                 "meta": {},
-            }
+            },
         )
 
     def test_network_empty(self):
@@ -321,7 +498,7 @@ class ParseBundleCreateOptions(TestCase):
                 "port_map": [{"a": "b", "c": "d"}],
                 "storage_map": [],
                 "meta": {},
-            }
+            },
         )
 
     def test_port_map_more(self):
@@ -334,7 +511,7 @@ class ParseBundleCreateOptions(TestCase):
                 "port_map": [{"a": "b", "c": "d"}, {"e": "f"}],
                 "storage_map": [],
                 "meta": {},
-            }
+            },
         )
 
     def test_port_map_missing_value(self):
@@ -361,7 +538,7 @@ class ParseBundleCreateOptions(TestCase):
                 "port_map": [],
                 "storage_map": [{"a": "b", "c": "d"}],
                 "meta": {},
-            }
+            },
         )
 
     def test_storage_map_more(self):
@@ -374,7 +551,7 @@ class ParseBundleCreateOptions(TestCase):
                 "port_map": [],
                 "storage_map": [{"a": "b", "c": "d"}, {"e": "f"}],
                 "meta": {},
-            }
+            },
         )
 
     def test_storage_map_missing_value(self):
@@ -393,7 +570,7 @@ class ParseBundleCreateOptions(TestCase):
                 "port_map": [],
                 "storage_map": [],
                 "meta": {"a": "b", "c": "d"},
-            }
+            },
         )
 
     def test_meta_empty(self):
@@ -408,13 +585,28 @@ class ParseBundleCreateOptions(TestCase):
     def test_all(self):
         self.assert_produce(
             [
-                "container", "docker", "a=b", "c=d",
-                "network", "e=f", "g=h",
-                "port-map", "i=j", "k=l",
-                "port-map", "m=n", "o=p",
-                "storage-map", "q=r", "s=t",
-                "storage-map", "u=v", "w=x",
-                "meta", "y=z", "A=B",
+                "container",
+                "docker",
+                "a=b",
+                "c=d",
+                "network",
+                "e=f",
+                "g=h",
+                "port-map",
+                "i=j",
+                "k=l",
+                "port-map",
+                "m=n",
+                "o=p",
+                "storage-map",
+                "q=r",
+                "s=t",
+                "storage-map",
+                "u=v",
+                "w=x",
+                "meta",
+                "y=z",
+                "A=B",
             ],
             {
                 "container_type": "docker",
@@ -423,22 +615,37 @@ class ParseBundleCreateOptions(TestCase):
                 "port_map": [{"i": "j", "k": "l"}, {"m": "n", "o": "p"}],
                 "storage_map": [{"q": "r", "s": "t"}, {"u": "v", "w": "x"}],
                 "meta": {"y": "z", "A": "B"},
-            }
+            },
         )
 
     def test_all_mixed(self):
         self.assert_produce(
             [
-                "storage-map", "q=r", "s=t",
-                "meta", "y=z",
-                "port-map", "i=j", "k=l",
-                "network", "e=f",
-                "container", "docker", "a=b",
-                "storage-map", "u=v", "w=x",
-                "port-map", "m=n", "o=p",
-                "meta", "A=B",
-                "network", "g=h",
-                "container", "c=d",
+                "storage-map",
+                "q=r",
+                "s=t",
+                "meta",
+                "y=z",
+                "port-map",
+                "i=j",
+                "k=l",
+                "network",
+                "e=f",
+                "container",
+                "docker",
+                "a=b",
+                "storage-map",
+                "u=v",
+                "w=x",
+                "port-map",
+                "m=n",
+                "o=p",
+                "meta",
+                "A=B",
+                "network",
+                "g=h",
+                "container",
+                "c=d",
             ],
             {
                 "container_type": "docker",
@@ -447,7 +654,7 @@ class ParseBundleCreateOptions(TestCase):
                 "port_map": [{"i": "j", "k": "l"}, {"m": "n", "o": "p"}],
                 "storage_map": [{"q": "r", "s": "t"}, {"u": "v", "w": "x"}],
                 "meta": {"y": "z", "A": "B"},
-            }
+            },
         )
 
 
@@ -455,14 +662,13 @@ class ParseBundleUpdateOptions(TestCase):
     # pylint: disable=too-many-public-methods
     def assert_produce(self, arg_list, result):
         self.assertEqual(
-            result,
-            parse_args.parse_bundle_update_options(arg_list)
+            result, parse_args.parse_bundle_update_options(arg_list)
         )
 
     def assert_raises_cmdline(self, arg_list):
         self.assertRaises(
             CmdLineInputError,
-            lambda: parse_args.parse_bundle_update_options(arg_list)
+            lambda: parse_args.parse_bundle_update_options(arg_list),
         )
 
     def test_no_args(self):
@@ -476,7 +682,7 @@ class ParseBundleUpdateOptions(TestCase):
                 "storage_map_add": [],
                 "storage_map_remove": [],
                 "meta": {},
-            }
+            },
         )
 
     def test_container_options(self):
@@ -490,7 +696,7 @@ class ParseBundleUpdateOptions(TestCase):
                 "storage_map_add": [],
                 "storage_map_remove": [],
                 "meta": {},
-            }
+            },
         )
 
     def test_container_empty(self):
@@ -513,7 +719,7 @@ class ParseBundleUpdateOptions(TestCase):
                 "storage_map_add": [],
                 "storage_map_remove": [],
                 "meta": {},
-            }
+            },
         )
 
     def test_network_empty(self):
@@ -550,23 +756,38 @@ class ParseBundleUpdateOptions(TestCase):
     def test_port_map_more(self):
         self.assert_produce(
             [
-                "port-map", "add", "a=b",
-                "port-map", "remove", "c", "d",
-                "port-map", "add", "e=f", "g=h",
-                "port-map", "remove", "i",
+                "port-map",
+                "add",
+                "a=b",
+                "port-map",
+                "remove",
+                "c",
+                "d",
+                "port-map",
+                "add",
+                "e=f",
+                "g=h",
+                "port-map",
+                "remove",
+                "i",
             ],
             {
                 "container": {},
                 "network": {},
                 "port_map_add": [
-                    {"a": "b", },
-                    {"e": "f", "g": "h",},
+                    {
+                        "a": "b",
+                    },
+                    {
+                        "e": "f",
+                        "g": "h",
+                    },
                 ],
                 "port_map_remove": ["c", "d", "i"],
                 "storage_map_add": [],
                 "storage_map_remove": [],
                 "meta": {},
-            }
+            },
         )
 
     def test_storage_map_empty(self):
@@ -594,10 +815,20 @@ class ParseBundleUpdateOptions(TestCase):
     def test_storage_map_more(self):
         self.assert_produce(
             [
-                "storage-map", "add", "a=b",
-                "storage-map", "remove", "c", "d",
-                "storage-map", "add", "e=f", "g=h",
-                "storage-map", "remove", "i",
+                "storage-map",
+                "add",
+                "a=b",
+                "storage-map",
+                "remove",
+                "c",
+                "d",
+                "storage-map",
+                "add",
+                "e=f",
+                "g=h",
+                "storage-map",
+                "remove",
+                "i",
             ],
             {
                 "container": {},
@@ -605,12 +836,17 @@ class ParseBundleUpdateOptions(TestCase):
                 "port_map_add": [],
                 "port_map_remove": [],
                 "storage_map_add": [
-                    {"a": "b", },
-                    {"e": "f", "g": "h",},
+                    {
+                        "a": "b",
+                    },
+                    {
+                        "e": "f",
+                        "g": "h",
+                    },
                 ],
                 "storage_map_remove": ["c", "d", "i"],
                 "meta": {},
-            }
+            },
         )
 
     def test_meta(self):
@@ -624,7 +860,7 @@ class ParseBundleUpdateOptions(TestCase):
                 "storage_map_add": [],
                 "storage_map_remove": [],
                 "meta": {"a": "b", "c": "d"},
-            }
+            },
         )
 
     def test_meta_empty(self):
@@ -636,21 +872,46 @@ class ParseBundleUpdateOptions(TestCase):
     def test_meta_missing_key(self):
         self.assert_raises_cmdline(["meta", "=b", "c=d"])
 
-
     def test_all(self):
         self.assert_produce(
             [
-                "container", "a=b", "c=d",
-                "network", "e=f", "g=h",
-                "port-map", "add", "i=j", "k=l",
-                "port-map", "add", "m=n",
-                "port-map", "remove", "o", "p",
-                "port-map", "remove", "q",
-                "storage-map", "add", "r=s", "t=u",
-                "storage-map", "add", "v=w",
-                "storage-map", "remove", "x", "y",
-                "storage-map", "remove", "z",
-                "meta", "A=B", "C=D",
+                "container",
+                "a=b",
+                "c=d",
+                "network",
+                "e=f",
+                "g=h",
+                "port-map",
+                "add",
+                "i=j",
+                "k=l",
+                "port-map",
+                "add",
+                "m=n",
+                "port-map",
+                "remove",
+                "o",
+                "p",
+                "port-map",
+                "remove",
+                "q",
+                "storage-map",
+                "add",
+                "r=s",
+                "t=u",
+                "storage-map",
+                "add",
+                "v=w",
+                "storage-map",
+                "remove",
+                "x",
+                "y",
+                "storage-map",
+                "remove",
+                "z",
+                "meta",
+                "A=B",
+                "C=D",
             ],
             {
                 "container": {"a": "b", "c": "d"},
@@ -666,24 +927,50 @@ class ParseBundleUpdateOptions(TestCase):
                 ],
                 "storage_map_remove": ["x", "y", "z"],
                 "meta": {"A": "B", "C": "D"},
-            }
+            },
         )
 
     def test_all_mixed(self):
         self.assert_produce(
             [
-                "storage-map", "remove", "x", "y",
-                "meta", "A=B",
-                "port-map", "remove", "o", "p",
-                "network", "e=f", "g=h",
-                "storage-map", "add", "r=s", "t=u",
-                "port-map", "add", "i=j", "k=l",
-                "container", "a=b", "c=d",
-                "meta", "C=D",
-                "port-map", "remove", "q",
-                "storage-map", "remove", "z",
-                "storage-map", "add", "v=w",
-                "port-map", "add", "m=n",
+                "storage-map",
+                "remove",
+                "x",
+                "y",
+                "meta",
+                "A=B",
+                "port-map",
+                "remove",
+                "o",
+                "p",
+                "network",
+                "e=f",
+                "g=h",
+                "storage-map",
+                "add",
+                "r=s",
+                "t=u",
+                "port-map",
+                "add",
+                "i=j",
+                "k=l",
+                "container",
+                "a=b",
+                "c=d",
+                "meta",
+                "C=D",
+                "port-map",
+                "remove",
+                "q",
+                "storage-map",
+                "remove",
+                "z",
+                "storage-map",
+                "add",
+                "v=w",
+                "port-map",
+                "add",
+                "m=n",
             ],
             {
                 "container": {"a": "b", "c": "d"},
@@ -699,7 +986,7 @@ class ParseBundleUpdateOptions(TestCase):
                 ],
                 "storage_map_remove": ["x", "y", "z"],
                 "meta": {"A": "B", "C": "D"},
-            }
+            },
         )
 
 
@@ -709,8 +996,7 @@ class BuildOperations(TestCase):
 
     def assert_raises_cmdline(self, arg_list):
         self.assertRaises(
-            CmdLineInputError,
-            lambda: parse_args.build_operations(arg_list)
+            CmdLineInputError, lambda: parse_args.build_operations(arg_list)
         )
 
     def test_return_empty_list_on_empty_input(self):
@@ -718,13 +1004,11 @@ class BuildOperations(TestCase):
 
     def test_return_all_operations_specified_in_the_same_group(self):
         self.assert_produce(
-            [
-                ["monitor", "interval=10s", "start", "timeout=20s"]
-            ],
+            [["monitor", "interval=10s", "start", "timeout=20s"]],
             [
                 ["name=monitor", "interval=10s"],
                 ["name=start", "timeout=20s"],
-            ]
+            ],
         )
 
     def test_return_all_operations_specified_in_different_groups(self):
@@ -736,7 +1020,7 @@ class BuildOperations(TestCase):
             [
                 ["name=monitor", "interval=10s"],
                 ["name=start", "timeout=20s"],
-            ]
+            ],
         )
 
     def test_refuse_empty_operation(self):
