@@ -24,38 +24,6 @@ class RunParallelTestCase(TestCase):
         self.assertTrue(elapsed_time < sum([i + 1 for i in range(timeout)]))
 
 
-class JoinMultilinesTest(TestCase):
-    def test_empty_input(self):
-        self.assertEqual(
-            "",
-            tools.join_multilines([])
-        )
-
-    def test_two_strings(self):
-        self.assertEqual(
-            "a\nb",
-            tools.join_multilines(["a", "b"])
-        )
-
-    def test_strip(self):
-        self.assertEqual(
-            "a\nb",
-            tools.join_multilines(["  a\n", "  b\n"])
-        )
-
-    def test_skip_empty(self):
-        self.assertEqual(
-            "a\nb",
-            tools.join_multilines(["  a\n", "   \n", "  b\n"])
-        )
-
-    def test_multiline(self):
-        self.assertEqual(
-            "a\nA\nb\nB",
-            tools.join_multilines(["a\nA\n", "b\nB\n"])
-        )
-
-
 class VersionTest(TestCase):
     # pylint: disable=invalid-name
     def assert_asterisk(self, expected, major, minor=None, revision=None):
@@ -123,19 +91,17 @@ class VersionTest(TestCase):
         self.assertEqual(str(ver.normalize()), "2.3.4")
 
     def test_compare(self):
-        self.assert_eq_tuple((2, ), (2, ))
-        self.assert_lt_tuple((2, ), (3, ))
-
+        self.assert_eq_tuple((2,), (2,))
+        self.assert_lt_tuple((2,), (3,))
 
         self.assert_eq_tuple((2, 0), (2, 0))
         self.assert_lt_tuple((2, 0), (2, 5))
         self.assert_lt_tuple((2, 0), (3, 5))
 
-        self.assert_eq_tuple((2, 0), (2,  ))
-        self.assert_lt_tuple((2, 0), (3,  ))
-        self.assert_lt_tuple((2, 5), (3,  ))
-        self.assert_lt_tuple((3,  ), (3, 5))
-
+        self.assert_eq_tuple((2, 0), (2,))
+        self.assert_lt_tuple((2, 0), (3,))
+        self.assert_lt_tuple((2, 5), (3,))
+        self.assert_lt_tuple((3,), (3, 5))
 
         self.assert_eq_tuple((2, 0, 0), (2, 0, 0))
         self.assert_lt_tuple((2, 0, 0), (2, 0, 1))
@@ -147,24 +113,24 @@ class VersionTest(TestCase):
         self.assert_lt_tuple((2, 0, 0), (3, 5, 1))
 
         self.assert_eq_tuple((2, 0, 0), (2, 0))
-        self.assert_eq_tuple((2, 0, 0), (2,  ))
+        self.assert_eq_tuple((2, 0, 0), (2,))
         self.assert_lt_tuple((2, 0, 0), (2, 5))
-        self.assert_lt_tuple((2, 0, 0), (3,  ))
+        self.assert_lt_tuple((2, 0, 0), (3,))
 
-        self.assert_lt_tuple((2, 5, 0), (3,  ))
-        self.assert_lt_tuple((2,  ), (2, 5, 0))
+        self.assert_lt_tuple((2, 5, 0), (3,))
+        self.assert_lt_tuple((2,), (2, 5, 0))
         self.assert_eq_tuple((2, 5, 0), (2, 5))
         self.assert_lt_tuple((2, 5, 0), (3, 5))
 
         self.assert_lt_tuple((2, 0), (2, 5, 1))
         self.assert_lt_tuple((2, 5), (2, 5, 1))
         self.assert_lt_tuple((2, 5, 1), (3, 5))
-        self.assert_lt_tuple((2, 5, 1), (3,  ))
-        self.assert_lt_tuple((2,  ), (2, 5, 1))
-        self.assert_lt_tuple((2, 5, 1), (3,  ))
+        self.assert_lt_tuple((2, 5, 1), (3,))
+        self.assert_lt_tuple((2,), (2, 5, 1))
+        self.assert_lt_tuple((2, 5, 1), (3,))
 
-        self.assert_lt_tuple((2,  ), (3, 5, 1))
-        self.assert_lt_tuple((3,  ), (3, 5, 1))
+        self.assert_lt_tuple((2,), (3, 5, 1))
+        self.assert_lt_tuple((3,), (3, 5, 1))
         self.assert_lt_tuple((2, 0), (3, 5, 1))
         self.assert_lt_tuple((2, 5), (3, 5, 1))
         self.assert_lt_tuple((3, 5), (3, 5, 1))
