@@ -1,4 +1,4 @@
-from unittest import TestCase
+from unittest import mock, TestCase
 from lxml import etree
 
 from pcs_test.tools import fixture
@@ -7,9 +7,13 @@ from pcs_test.tools.assertions import (
     assert_xml_equal,
 )
 from pcs_test.tools.custom_mock import MockLibraryReportProcessor
-from pcs_test.tools.misc import create_patcher
+from pcs_test.tools.misc import (
+    create_patcher,
+    get_test_resource as rc,
+)
 from pcs_test.tools.xml import etree_to_str
 
+from pcs import settings
 from pcs.common import reports
 from pcs.common.reports import codes as report_codes
 from pcs.common.fencing_topology import (
@@ -82,7 +86,7 @@ class StatusNodesMixin:
     def get_status(self):
         return ClusterState(
             """
-            <crm_mon version="2.0.3">
+            <crm_mon version="2.0.5">
                 <summary>
                     <stack type="corosync" />
                     <current_dc present="true" />
@@ -94,7 +98,7 @@ class StatusNodesMixin:
                     <resources_configured number="0" disabled="0" blocked="0" />
                     <cluster_options stonith-enabled="true"
                         symmetric-cluster="true" no-quorum-policy="stop"
-                        maintenance-mode="false"
+                        maintenance-mode="false" stop-all-resources="false"
                     />
                 </summary>
                 <nodes>
@@ -503,7 +507,9 @@ class RemoveLevelsByParams(TestCase, CibMixin):
                     severity.ERROR,
                     report_codes.CIB_FENCING_LEVEL_DOES_NOT_EXIST,
                     {
-                        "devices": ["d3",],
+                        "devices": [
+                            "d3",
+                        ],
                         "target_type": TARGET_TYPE_NODE,
                         "target_value": "nodeB",
                         "level": 9,
@@ -685,6 +691,9 @@ class Verify(TestCase, CibMixin, StatusNodesMixin):
         el = etree.SubElement(tree, "primitive", id=name, type="fence_dummy")
         el.set("class", "stonith")
 
+    @mock.patch.object(
+        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+    )
     def test_empty(self):
         resources = etree.fromstring("<resources />")
         topology = etree.fromstring("<fencing-topology />")
@@ -693,6 +702,9 @@ class Verify(TestCase, CibMixin, StatusNodesMixin):
 
         assert_report_item_list_equal(report_list, [])
 
+    @mock.patch.object(
+        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+    )
     def test_success(self):
         resources = etree.fromstring("<resources />")
         for name in ["d1", "d2", "d3", "d4", "d5", "dR", "dR-special"]:
@@ -727,13 +739,19 @@ class Verify(TestCase, CibMixin, StatusNodesMixin):
             (
                 severity.ERROR,
                 report_codes.NODE_NOT_FOUND,
-                {"node": "nodeA", "searched_types": [],},
+                {
+                    "node": "nodeA",
+                    "searched_types": [],
+                },
                 None,
             ),
             (
                 severity.ERROR,
                 report_codes.NODE_NOT_FOUND,
-                {"node": "nodeB", "searched_types": [],},
+                {
+                    "node": "nodeB",
+                    "searched_types": [],
+                },
                 None,
             ),
         ]
@@ -834,69 +852,82 @@ class ValidateTargetTypewise(TestCase):
         assert_report_item_list_equal(report_list, report)
 
 
+@mock.patch.object(settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng"))
 class ValidateTargetValuewise(TestCase, StatusNodesMixin):
-    def setUp(self):
-        self.state = self.get_status()
-
     def test_node_valid(self):
+        state = self.get_status()
         assert_report_item_list_equal(
-            lib._validate_target_valuewise(
-                self.state, TARGET_TYPE_NODE, "nodeA"
-            ),
+            lib._validate_target_valuewise(state, TARGET_TYPE_NODE, "nodeA"),
             [],
         )
 
     def test_node_empty(self):
+        state = self.get_status()
         report_list = lib._validate_target_valuewise(
-            self.state, TARGET_TYPE_NODE, ""
+            state, TARGET_TYPE_NODE, ""
         )
         report = [
             (
                 severity.ERROR,
                 report_codes.NODE_NOT_FOUND,
-                {"node": "", "searched_types": [],},
+                {
+                    "node": "",
+                    "searched_types": [],
+                },
                 report_codes.FORCE_NODE_DOES_NOT_EXIST,
             )
         ]
         assert_report_item_list_equal(report_list, report)
 
     def test_node_invalid(self):
+        state = self.get_status()
         report_list = lib._validate_target_valuewise(
-            self.state, TARGET_TYPE_NODE, "rh7-x"
+            state, TARGET_TYPE_NODE, "rh7-x"
         )
         report = [
             (
                 severity.ERROR,
                 report_codes.NODE_NOT_FOUND,
-                {"node": "rh7-x", "searched_types": [],},
+                {
+                    "node": "rh7-x",
+                    "searched_types": [],
+                },
                 report_codes.FORCE_NODE_DOES_NOT_EXIST,
             )
         ]
         assert_report_item_list_equal(report_list, report)
 
     def test_node_invalid_force(self):
+        state = self.get_status()
         report_list = lib._validate_target_valuewise(
-            self.state, TARGET_TYPE_NODE, "rh7-x", force_node=True
+            state, TARGET_TYPE_NODE, "rh7-x", force_node=True
         )
         report = [
             (
                 severity.WARNING,
                 report_codes.NODE_NOT_FOUND,
-                {"node": "rh7-x", "searched_types": [],},
+                {
+                    "node": "rh7-x",
+                    "searched_types": [],
+                },
                 None,
             )
         ]
         assert_report_item_list_equal(report_list, report)
 
     def test_node_invalid_not_forceable(self):
+        state = self.get_status()
         report_list = lib._validate_target_valuewise(
-            self.state, TARGET_TYPE_NODE, "rh7-x", allow_force=False
+            state, TARGET_TYPE_NODE, "rh7-x", allow_force=False
         )
         report = [
             (
                 severity.ERROR,
                 report_codes.NODE_NOT_FOUND,
-                {"node": "rh7-x", "searched_types": [],},
+                {
+                    "node": "rh7-x",
+                    "searched_types": [],
+                },
                 None,
             )
         ]
@@ -933,7 +964,10 @@ class ValidateDevices(TestCase):
             (
                 severity.ERROR,
                 report_codes.REQUIRED_OPTIONS_ARE_MISSING,
-                {"option_type": None, "option_names": ["stonith devices"],},
+                {
+                    "option_type": None,
+                    "option_names": ["stonith devices"],
+                },
                 None,
             )
         ]
@@ -947,7 +981,9 @@ class ValidateDevices(TestCase):
             (
                 severity.ERROR,
                 report_codes.STONITH_RESOURCES_DO_NOT_EXIST,
-                {"stonith_ids": ["dummy", "fenceX"],},
+                {
+                    "stonith_ids": ["dummy", "fenceX"],
+                },
                 report_codes.FORCE_STONITH_RESOURCE_DOES_NOT_EXIST,
             )
         ]
@@ -961,7 +997,9 @@ class ValidateDevices(TestCase):
             (
                 severity.WARNING,
                 report_codes.STONITH_RESOURCES_DO_NOT_EXIST,
-                {"stonith_ids": ["dummy", "fenceX"],},
+                {
+                    "stonith_ids": ["dummy", "fenceX"],
+                },
                 None,
             )
         ]
@@ -975,7 +1013,9 @@ class ValidateDevices(TestCase):
             (
                 severity.ERROR,
                 report_codes.STONITH_RESOURCES_DO_NOT_EXIST,
-                {"stonith_ids": ["dummy", "fenceX"],},
+                {
+                    "stonith_ids": ["dummy", "fenceX"],
+                },
                 None,
             )
         ]
@@ -1060,7 +1100,11 @@ class AppendLevelElement(TestCase):
 
     def test_node_attribute(self):
         lib._append_level_element(
-            self.tree, 3, TARGET_TYPE_ATTRIBUTE, ("name%@x", "val%@x"), ["d1"],
+            self.tree,
+            3,
+            TARGET_TYPE_ATTRIBUTE,
+            ("name%@x", "val%@x"),
+            ["d1"],
         )
         assert_xml_equal(
             """
