@@ -1,9 +1,11 @@
-from unittest import TestCase
+from unittest import mock, TestCase
 
 from pcs_test.tools import fixture
 from pcs_test.tools.command_env import get_env_tools
+from pcs_test.tools.misc import get_test_resource as rc
 
-from pcs.common import report_codes
+from pcs import settings
+from pcs.common.reports import codes as report_codes
 from pcs.lib.commands.cluster import verify
 
 
@@ -30,6 +32,7 @@ BAD_FENCING_TOPOLOGY_REPORTS = [
     ),
 ]
 
+
 class AssertInvalidCibMixin:
     def assert_raises_invalid_cib_content(
         self,
@@ -37,41 +40,43 @@ class AssertInvalidCibMixin:
         extra_reports=None,
         can_be_more_verbose=True,
         verbose=False,
-     ):
+    ):
         extra_reports = extra_reports if extra_reports else []
         self.env_assist.assert_raise_library_error(
-            lambda: verify(self.env_assist.get_env(), verbose),
+            lambda: verify(self.env_assist.get_env(), verbose)
+        )
+        self.env_assist.assert_reports(
             [
                 fixture.error(
                     report_codes.INVALID_CIB_CONTENT,
                     report=report,
                     can_be_more_verbose=can_be_more_verbose,
                 ),
-            ] + extra_reports,
+            ]
+            + extra_reports,
         )
 
 
+@mock.patch.object(settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng"))
 class CibAsWholeValid(TestCase):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
         self.config.runner.pcmk.verify()
 
     def test_success_on_valid(self):
-        (self.config
-            .runner.cib.load()
-            .runner.pcmk.load_state()
-        )
+        (self.config.runner.cib.load().runner.pcmk.load_state())
         verify(self.env_assist.get_env())
 
     def test_fail_on_invalid_fence_topology(self):
-        (self.config
-            .runner.cib.load(optional_in_conf=BAD_FENCING_TOPOLOGY)
-            .runner.pcmk.load_state()
+        (
+            self.config.runner.cib.load(
+                optional_in_conf=BAD_FENCING_TOPOLOGY
+            ).runner.pcmk.load_state()
         )
         self.env_assist.assert_raise_library_error(
-            lambda: verify(self.env_assist.get_env()),
-            list(BAD_FENCING_TOPOLOGY_REPORTS)
+            lambda: verify(self.env_assist.get_env())
         )
+        self.env_assist.assert_reports(BAD_FENCING_TOPOLOGY_REPORTS)
 
 
 class CibAsWholeInvalid(TestCase, AssertInvalidCibMixin):
@@ -85,25 +90,31 @@ class CibAsWholeInvalid(TestCase, AssertInvalidCibMixin):
         self.config.runner.cib.load(returncode=1)
         self.assert_raises_invalid_cib_content(CRM_VERIFY_ERROR_REPORT_LINES[0])
 
+    @mock.patch.object(
+        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+    )
     def test_continue_on_loadable_cib(self):
-        (self.config
-            .runner.cib.load()
-            .runner.pcmk.load_state()
-        )
+        (self.config.runner.cib.load().runner.pcmk.load_state())
         self.assert_raises_invalid_cib_content(CRM_VERIFY_ERROR_REPORT_LINES[0])
 
+    @mock.patch.object(
+        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+    )
     def test_add_following_errors(self):
-        #More fencing topology tests are provided by tests of
-        #pcs.lib.commands.fencing_topology
-        (self.config
-            .runner.cib.load(optional_in_conf=BAD_FENCING_TOPOLOGY)
-            .runner.pcmk.load_state()
+        # More fencing topology tests are provided by tests of
+        # pcs.lib.commands.fencing_topology
+        (
+            self.config.runner.cib.load(
+                optional_in_conf=BAD_FENCING_TOPOLOGY
+            ).runner.pcmk.load_state()
         )
         self.assert_raises_invalid_cib_content(
             CRM_VERIFY_ERROR_REPORT_LINES[0],
-            extra_reports=list(BAD_FENCING_TOPOLOGY_REPORTS)
+            extra_reports=list(BAD_FENCING_TOPOLOGY_REPORTS),
         )
 
+
+@mock.patch.object(settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng"))
 class CibIsMocked(TestCase, AssertInvalidCibMixin):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
@@ -111,16 +122,16 @@ class CibIsMocked(TestCase, AssertInvalidCibMixin):
         self.config.env.set_cib_data("<cib/>", cib_tempfile=self.cib_tempfile)
 
     def test_success_on_valid_cib(self):
-        (self.config
-            .runner.pcmk.verify(cib_tempfile=self.cib_tempfile)
+        (
+            self.config.runner.pcmk.verify(cib_tempfile=self.cib_tempfile)
             .runner.cib.load()
             .runner.pcmk.load_state()
         )
         verify(self.env_assist.get_env())
 
     def test_fail_on_invalid_cib(self):
-        (self.config
-            .runner.pcmk.verify(
+        (
+            self.config.runner.pcmk.verify(
                 stderr="".join(CRM_VERIFY_ERROR_REPORT_LINES),
                 cib_tempfile=self.cib_tempfile,
             )
@@ -130,21 +141,22 @@ class CibIsMocked(TestCase, AssertInvalidCibMixin):
         self.assert_raises_invalid_cib_content(CRM_VERIFY_ERROR_REPORT_LINES[0])
 
 
+@mock.patch.object(settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng"))
 class VerboseMode(TestCase, AssertInvalidCibMixin):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
 
     def test_success_on_valid_cib(self):
-        (self.config
-            .runner.pcmk.verify(verbose=True)
+        (
+            self.config.runner.pcmk.verify(verbose=True)
             .runner.cib.load()
             .runner.pcmk.load_state()
         )
         verify(self.env_assist.get_env(), verbose=True)
 
     def test_fail_on_invalid_cib(self):
-        (self.config
-            .runner.pcmk.verify(
+        (
+            self.config.runner.pcmk.verify(
                 stderr=CRM_VERIFY_ERROR_REPORT_LINES[0],
                 verbose=True,
             )
