@@ -44,7 +44,8 @@ FIXTURE_RESOURCES = """
         </primitive>
     </resources>
 """.format(
-    NODE_NAME, REMOTE_HOST,
+    NODE_NAME,
+    REMOTE_HOST,
 )
 
 REPORTS = (
@@ -82,7 +83,9 @@ class RemoveRemote(TestCase):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(self)
         self.config.env.set_known_hosts_dests(
-            {NODE_NAME: NODE_DEST_LIST,}
+            {
+                NODE_NAME: NODE_DEST_LIST,
+            }
         )
         self.remove_resource = mock.Mock()
 
@@ -120,7 +123,9 @@ class RemoveRemoteOthers(TestCase):
         self.env_assist, self.config = get_env_tools(self)
         self.remove_resource = mock.Mock()
         self.config.env.set_known_hosts_dests(
-            {NODE_NAME: NODE_DEST_LIST,}
+            {
+                NODE_NAME: NODE_DEST_LIST,
+            }
         )
 
     def test_can_skip_all_offline(self):
@@ -208,15 +213,24 @@ class MultipleResults(TestCase):
             .error(
                 "multiple_result_found",
                 report_codes.MULTIPLE_RESULTS_FOUND,
-                result_identifier_list=[NODE_NAME, REMOTE_HOST,],
+                result_identifier_list=[
+                    NODE_NAME,
+                    REMOTE_HOST,
+                ],
                 result_type="resource",
                 search_description=REMOTE_HOST,
                 force_code=report_codes.FORCE_REMOVE_MULTIPLE_NODES,
             )
-            .as_warn("multiple_result_found", "multiple_result_found_warn",)
+            .as_warn(
+                "multiple_result_found",
+                "multiple_result_found_warn",
+            )
         )
         self.config.env.set_known_hosts_dests(
-            {NODE_NAME: NODE_DEST_LIST, REMOTE_HOST: REMOTE_DEST_LIST,}
+            {
+                NODE_NAME: NODE_DEST_LIST,
+                REMOTE_HOST: REMOTE_DEST_LIST,
+            }
         )
 
     def test_fail(self):
@@ -280,7 +294,9 @@ class AuthkeyRemove(TestCase):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(self)
         self.config.env.set_known_hosts_dests(
-            {NODE_NAME: NODE_DEST_LIST,}
+            {
+                NODE_NAME: NODE_DEST_LIST,
+            }
         )
         (
             self.config.runner.cib.load(
@@ -300,7 +316,8 @@ class AuthkeyRemove(TestCase):
         )
         self.env_assist.assert_raise_library_error(
             lambda: node_remove_remote(
-                self.env_assist.get_env(), remove_resource=self.remove_resource,
+                self.env_assist.get_env(),
+                remove_resource=self.remove_resource,
             )
         )
         self.env_assist.assert_reports(
@@ -313,11 +330,15 @@ class AuthkeyRemove(TestCase):
             communication_list=[
                 dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
             ],
-            result={"code": "unexpected", "message": "Access denied",},
+            result={
+                "code": "unexpected",
+                "message": "Access denied",
+            },
         )
         self.env_assist.assert_raise_library_error(
             lambda: node_remove_remote(
-                self.env_assist.get_env(), remove_resource=self.remove_resource,
+                self.env_assist.get_env(),
+                remove_resource=self.remove_resource,
             )
         )
         self.env_assist.assert_reports(
@@ -330,7 +351,10 @@ class AuthkeyRemove(TestCase):
             communication_list=[
                 dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
             ],
-            result={"code": "unexpected", "message": "Access denied",},
+            result={
+                "code": "unexpected",
+                "message": "Access denied",
+            },
         )
         node_remove_remote(
             self.env_assist.get_env(),
@@ -349,7 +373,9 @@ class PcmkRemoteServiceDestroy(TestCase):
         self.config.runner.cib.load(resources=FIXTURE_RESOURCES)
         self.remove_resource = mock.Mock()
         self.config.env.set_known_hosts_dests(
-            {NODE_NAME: NODE_DEST_LIST,}
+            {
+                NODE_NAME: NODE_DEST_LIST,
+            }
         )
 
     def test_fails_when_offline(self):
@@ -360,7 +386,8 @@ class PcmkRemoteServiceDestroy(TestCase):
         )
         self.env_assist.assert_raise_library_error(
             lambda: node_remove_remote(
-                self.env_assist.get_env(), remove_resource=self.remove_resource,
+                self.env_assist.get_env(),
+                remove_resource=self.remove_resource,
             )
         )
         self.env_assist.assert_reports(
@@ -373,18 +400,23 @@ class PcmkRemoteServiceDestroy(TestCase):
             self.config.local.destroy_pacemaker_remote(
                 label=NODE_NAME,
                 dest_list=NODE_DEST_LIST,
-                result={"code": "fail", "message": "Action failed",},
+                result={
+                    "code": "fail",
+                    "message": "Action failed",
+                },
             )
         )
         self.env_assist.assert_raise_library_error(
             lambda: node_remove_remote(
-                self.env_assist.get_env(), remove_resource=self.remove_resource,
+                self.env_assist.get_env(),
+                remove_resource=self.remove_resource,
             )
         )
         self.env_assist.assert_reports(
             REPORTS[:"pcmk_remote_disable_success"]
             + EXTRA_REPORTS.select(
-                "pcmk_remote_disable_failed", "pcmk_remote_stop_failed",
+                "pcmk_remote_disable_failed",
+                "pcmk_remote_stop_failed",
             )
         )
 
@@ -393,7 +425,10 @@ class PcmkRemoteServiceDestroy(TestCase):
             self.config.local.destroy_pacemaker_remote(
                 label=NODE_NAME,
                 dest_list=NODE_DEST_LIST,
-                result={"code": "fail", "message": "Action failed",},
+                result={
+                    "code": "fail",
+                    "message": "Action failed",
+                },
             ).local.remove_authkey(
                 communication_list=[
                     dict(label=NODE_NAME, dest_list=NODE_DEST_LIST)
@@ -407,7 +442,8 @@ class PcmkRemoteServiceDestroy(TestCase):
         )
         self.env_assist.assert_reports(
             REPORTS.remove(
-                "pcmk_remote_disable_success", "pcmk_remote_stop_success",
+                "pcmk_remote_disable_success",
+                "pcmk_remote_stop_success",
             )
             + EXTRA_REPORTS.select(
                 "pcmk_remote_disable_failed_warn",
