@@ -1,28 +1,30 @@
 from textwrap import dedent
+from unittest import mock
 
 from pcs_test.tools import fixture
 from pcs_test.tools.command_env import get_env_tools
-from pcs_test.tools.misc import skip_unless_pacemaker_supports_bundle
+from pcs_test.tools.misc import get_test_resource as rc
 
-from pcs.common import report_codes
-from pcs.lib import reports
+from pcs import settings
+from pcs.common import reports
+from pcs.common.reports import ReportItemSeverity as severities
+from pcs.common.reports import codes as report_codes
 from pcs.lib.cib.resource.bundle import (
     GENERIC_CONTAINER_OPTIONS,
     NETWORK_OPTIONS,
     PORT_MAP_OPTIONS,
     STORAGE_MAP_OPTIONS,
 )
-from pcs.lib.errors import (
-    LibraryError,
-    ReportItemSeverity as severities,
-)
+from pcs.lib.errors import LibraryError
 
 TIMEOUT = 10
 
+
 class FixturesMixin:
     container_type = None
     bundle_id = None
     image = None
+
     @property
     def fixture_resources_bundle_simple(self):
         return """
@@ -37,6 +39,7 @@ class FixturesMixin:
             image=self.image,
         )
 
+
 class SetUpMixin:
     initial_resources = "<resources/>"
     initial_cib_filename = "cib-empty.xml"
@@ -49,15 +52,16 @@ class SetUpMixin:
             resources=self.initial_resources,
         )
 
+
 class UpgradeMixin(FixturesMixin):
     old_version_cib_filename = None
 
     def test_cib_upgrade(self):
-        (self.config
-            .runner.cib.load(
+        (
+            self.config.runner.cib.load(
                 name="load_cib_old_version",
                 filename=self.old_version_cib_filename,
-                before="runner.cib.load"
+                before="runner.cib.load",
             )
             .runner.cib.upgrade(before="runner.cib.load")
             .env.push_cib(resources=self.fixture_resources_bundle_simple)
@@ -65,9 +69,10 @@ class UpgradeMixin(FixturesMixin):
 
         self.run_bundle_cmd()
 
-        self.env_assist.assert_reports([
-            fixture.info(report_codes.CIB_UPGRADE_SUCCESSFUL)
-        ])
+        self.env_assist.assert_reports(
+            [fixture.info(report_codes.CIB_UPGRADE_SUCCESSFUL)]
+        )
+
 
 class ParametrizedContainerMixin(SetUpMixin):
     container_type = None
@@ -91,8 +96,7 @@ class ParametrizedContainerMixin(SetUpMixin):
                         />
                     </bundle>
                 </resources>
-            """
-            .format(
+            """.format(
                 container_type=self.container_type,
                 bundle_id=self.bundle_id,
                 image=self.image,
@@ -111,8 +115,8 @@ class ParametrizedContainerMixin(SetUpMixin):
         )
 
     def test_cib_upgrade_promoted_max(self):
-        (self.config
-            .runner.cib.load(
+        (
+            self.config.runner.cib.load(
                 name="load_cib_old_version",
                 filename="cib-empty-2.8.xml",
                 resources=self.initial_resources,
@@ -129,8 +133,7 @@ class ParametrizedContainerMixin(SetUpMixin):
                             />
                         </bundle>
                     </resources>
-                """
-                .format(
+                """.format(
                     container_type=self.container_type,
                     bundle_id=self.bundle_id,
                     image=self.image,
@@ -145,15 +148,16 @@ class ParametrizedContainerMixin(SetUpMixin):
             }
         )
 
-        self.env_assist.assert_reports([
-            (
-                severities.INFO,
-                report_codes.CIB_UPGRADE_SUCCESSFUL,
-                {
-                },
-                None
-            ),
-        ])
+        self.env_assist.assert_reports(
+            [
+                (
+                    severities.INFO,
+                    report_codes.CIB_UPGRADE_SUCCESSFUL,
+                    {},
+                    None,
+                ),
+            ]
+        )
 
     def test_deprecated_options(self):
         # Setting both deprecated options and their new variants is tested in
@@ -166,8 +170,7 @@ class ParametrizedContainerMixin(SetUpMixin):
                         <{container_type} image="{image}" masters="1" />
                     </bundle>
                 </resources>
-            """
-            .format(
+            """.format(
                 container_type=self.container_type,
                 bundle_id=self.bundle_id,
                 image=self.image,
@@ -179,18 +182,20 @@ class ParametrizedContainerMixin(SetUpMixin):
                 "masters": "1",
             },
         )
-        self.env_assist.assert_reports([
-            (
-                severities.WARNING,
-                report_codes.DEPRECATED_OPTION,
-                {
-                    "option_name": "masters",
-                    "option_type": "container",
-                    "replaced_by": ["promoted-max"],
-                },
-                None
-            ),
-        ])
+        self.env_assist.assert_reports(
+            [
+                (
+                    severities.WARNING,
+                    report_codes.DEPRECATED_OPTION,
+                    {
+                        "option_name": "masters",
+                        "option_type": "container",
+                        "replaced_by": ["promoted-max"],
+                    },
+                    None,
+                ),
+            ]
+        )
 
     def test_invalid_container_options(self):
         self.env_assist.assert_raise_library_error(
@@ -201,17 +206,31 @@ class ParametrizedContainerMixin(SetUpMixin):
                     "masters": "-1",
                     "promoted-max": "-2",
                 },
-                force_options=True
-            ),
+                force_options=True,
+            )
+        )
+        self.env_assist.assert_reports(
             [
+                (
+                    severities.WARNING,
+                    report_codes.DEPRECATED_OPTION,
+                    {
+                        "option_name": "masters",
+                        "option_type": "container",
+                        "replaced_by": ["promoted-max"],
+                    },
+                    None,
+                ),
                 (
                     severities.ERROR,
                     report_codes.REQUIRED_OPTIONS_ARE_MISSING,
                     {
                         "option_type": "container",
-                        "option_names": ["image", ],
+                        "option_names": [
+                            "image",
+                        ],
                     },
-                    None
+                    None,
                 ),
                 fixture.error(
                     report_codes.INVALID_OPTION_VALUE,
@@ -233,10 +252,13 @@ class ParametrizedContainerMixin(SetUpMixin):
                     severities.ERROR,
                     report_codes.MUTUALLY_EXCLUSIVE_OPTIONS,
                     {
-                        "option_names": ["masters", "promoted-max", ],
+                        "option_names": [
+                            "masters",
+                            "promoted-max",
+                        ],
                         "option_type": "container",
                     },
-                    None
+                    None,
                 ),
                 fixture.error(
                     report_codes.INVALID_OPTION_VALUE,
@@ -256,18 +278,6 @@ class ParametrizedContainerMixin(SetUpMixin):
                 ),
             ]
         )
-        self.env_assist.assert_reports([
-            (
-                severities.WARNING,
-                report_codes.DEPRECATED_OPTION,
-                {
-                    "option_name": "masters",
-                    "option_type": "container",
-                    "replaced_by": ["promoted-max"],
-                },
-                None
-            ),
-        ])
 
     def test_empty_image(self):
         self.env_assist.assert_raise_library_error(
@@ -275,8 +285,10 @@ class ParametrizedContainerMixin(SetUpMixin):
                 container_options={
                     "image": "",
                 },
-                force_options=True
-            ),
+                force_options=True,
+            )
+        )
+        self.env_assist.assert_reports(
             [
                 fixture.error(
                     report_codes.INVALID_OPTION_VALUE,
@@ -296,18 +308,22 @@ class ParametrizedContainerMixin(SetUpMixin):
                     "image": self.image,
                     "extra": "option",
                 }
-            ),
+            )
+        )
+        self.env_assist.assert_reports(
             [
                 (
                     severities.ERROR,
                     report_codes.INVALID_OPTIONS,
                     {
-                        "option_names": ["extra", ],
+                        "option_names": [
+                            "extra",
+                        ],
                         "option_type": "container",
                         "allowed": sorted(list(GENERIC_CONTAINER_OPTIONS)),
                         "allowed_patterns": [],
                     },
-                    report_codes.FORCE_OPTIONS
+                    report_codes.FORCE_OPTIONS,
                 ),
             ]
         )
@@ -320,8 +336,7 @@ class ParametrizedContainerMixin(SetUpMixin):
                         <{container_type} image="{image}" extra="option" />
                     </bundle>
                 </resources>
-            """
-            .format(
+            """.format(
                 container_type=self.container_type,
                 bundle_id=self.bundle_id,
                 image=self.image,
@@ -332,21 +347,26 @@ class ParametrizedContainerMixin(SetUpMixin):
                 "image": self.image,
                 "extra": "option",
             },
-            force_options=True
+            force_options=True,
         )
-        self.env_assist.assert_reports([
-            (
-                severities.WARNING,
-                report_codes.INVALID_OPTIONS,
-                {
-                    "option_names": ["extra", ],
-                    "option_type": "container",
-                    "allowed": sorted(list(GENERIC_CONTAINER_OPTIONS)),
-                    "allowed_patterns": [],
-                },
-                None
-            ),
-        ])
+        self.env_assist.assert_reports(
+            [
+                (
+                    severities.WARNING,
+                    report_codes.INVALID_OPTIONS,
+                    {
+                        "option_names": [
+                            "extra",
+                        ],
+                        "option_type": "container",
+                        "allowed": sorted(list(GENERIC_CONTAINER_OPTIONS)),
+                        "allowed_patterns": [],
+                    },
+                    None,
+                ),
+            ]
+        )
+
 
 class NetworkMixin(SetUpMixin):
     container_type = None
@@ -367,8 +387,7 @@ class NetworkMixin(SetUpMixin):
                         />
                     </bundle>
                 </resources>
-            """
-            .format(
+            """.format(
                 container_type=self.container_type,
                 bundle_id=self.bundle_id,
                 image=self.image,
@@ -391,7 +410,9 @@ class NetworkMixin(SetUpMixin):
                     "host-netmask": "abc",
                     "extra": "option",
                 }
-            ),
+            )
+        )
+        self.env_assist.assert_reports(
             [
                 fixture.error(
                     report_codes.INVALID_OPTION_VALUE,
@@ -430,8 +451,7 @@ class NetworkMixin(SetUpMixin):
                         <network host-netmask="abc" extra="option" />
                     </bundle>
                 </resources>
-            """
-            .format(
+            """.format(
                 container_type=self.container_type,
                 bundle_id=self.bundle_id,
                 image=self.image,
@@ -442,30 +462,35 @@ class NetworkMixin(SetUpMixin):
                 "host-netmask": "abc",
                 "extra": "option",
             },
-            force_options=True
+            force_options=True,
+        )
+
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    report_codes.INVALID_OPTION_VALUE,
+                    option_name="host-netmask",
+                    option_value="abc",
+                    allowed_values="a number of bits of the mask (1..32)",
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
+                (
+                    severities.WARNING,
+                    report_codes.INVALID_OPTIONS,
+                    {
+                        "option_names": [
+                            "extra",
+                        ],
+                        "option_type": "network",
+                        "allowed": sorted(list(NETWORK_OPTIONS)),
+                        "allowed_patterns": [],
+                    },
+                    None,
+                ),
+            ]
         )
 
-        self.env_assist.assert_reports([
-            fixture.warn(
-                report_codes.INVALID_OPTION_VALUE,
-                option_name="host-netmask",
-                option_value="abc",
-                allowed_values="a number of bits of the mask (1..32)",
-                cannot_be_empty=False,
-                forbidden_characters=None,
-            ),
-            (
-                severities.WARNING,
-                report_codes.INVALID_OPTIONS,
-                {
-                    "option_names": ["extra", ],
-                    "option_type": "network",
-                    "allowed": sorted(list(NETWORK_OPTIONS)),
-                    "allowed_patterns": [],
-                },
-                None
-            ),
-        ])
 
 class PortMapMixin(SetUpMixin):
     container_type = None
@@ -495,8 +520,7 @@ class PortMapMixin(SetUpMixin):
                         </network>
                     </bundle>
                 </resources>
-            """
-            .format(
+            """.format(
                 container_type=self.container_type,
                 bundle_id=self.bundle_id,
                 image=self.image,
@@ -509,10 +533,9 @@ class PortMapMixin(SetUpMixin):
                 },
                 {
                     # use an autogenerated id of the previous item
-                    "id":
-                        "{bundle_id}-port-map-1001"
-                        .format(bundle_id=self.bundle_id)
-                    ,
+                    "id": "{bundle_id}-port-map-1001".format(
+                        bundle_id=self.bundle_id
+                    ),
                     "port": "2000",
                     "internal-port": "2002",
                 },
@@ -542,8 +565,10 @@ class PortMapMixin(SetUpMixin):
                         "internal-port": "def",
                     },
                 ],
-                force_options=True
-            ),
+                force_options=True,
+            )
+        )
+        self.env_assist.assert_reports(
             [
                 # first
                 (
@@ -553,19 +578,19 @@ class PortMapMixin(SetUpMixin):
                         "option_type": "port-map",
                         "option_names": ["port", "range"],
                     },
-                    None
+                    None,
                 ),
                 # second
                 (
                     severities.ERROR,
-                    report_codes.INVALID_ID,
+                    report_codes.INVALID_ID_BAD_CHAR,
                     {
                         "invalid_character": "#",
                         "id": "not#valid",
                         "id_description": "port-map id",
                         "is_first_char": False,
                     },
-                    None
+                    None,
                 ),
                 (
                     severities.ERROR,
@@ -574,7 +599,7 @@ class PortMapMixin(SetUpMixin):
                         "option_type": "port-map",
                         "option_names": ["port", "range"],
                     },
-                    None
+                    None,
                 ),
                 # third
                 (
@@ -586,7 +611,7 @@ class PortMapMixin(SetUpMixin):
                         "prerequisite_type": "port-map",
                         "prerequisite_name": "port",
                     },
-                    None
+                    None,
                 ),
                 (
                     severities.ERROR,
@@ -595,7 +620,7 @@ class PortMapMixin(SetUpMixin):
                         "option_type": "port-map",
                         "option_names": ["port", "range"],
                     },
-                    None
+                    None,
                 ),
                 # fourth
                 fixture.error(
@@ -611,10 +636,13 @@ class PortMapMixin(SetUpMixin):
                     severities.ERROR,
                     report_codes.MUTUALLY_EXCLUSIVE_OPTIONS,
                     {
-                        "option_names": ["port", "range", ],
+                        "option_names": [
+                            "port",
+                            "range",
+                        ],
                         "option_type": "port-map",
                     },
-                    None
+                    None,
                 ),
                 fixture.error(
                     report_codes.INVALID_OPTION_VALUE,
@@ -636,18 +664,22 @@ class PortMapMixin(SetUpMixin):
                         "extra": "option",
                     },
                 ]
-            ),
+            )
+        )
+        self.env_assist.assert_reports(
             [
                 (
                     severities.ERROR,
                     report_codes.INVALID_OPTIONS,
                     {
-                        "option_names": ["extra", ],
+                        "option_names": [
+                            "extra",
+                        ],
                         "option_type": "port-map",
                         "allowed": sorted(list(PORT_MAP_OPTIONS)),
                         "allowed_patterns": [],
                     },
-                    report_codes.FORCE_OPTIONS
+                    report_codes.FORCE_OPTIONS,
                 ),
                 fixture.error(
                     report_codes.INVALID_OPTION_VALUE,
@@ -676,8 +708,7 @@ class PortMapMixin(SetUpMixin):
                         </network>
                     </bundle>
                 </resources>
-            """
-            .format(
+            """.format(
                 container_type=self.container_type,
                 bundle_id=self.bundle_id,
                 image=self.image,
@@ -691,30 +722,34 @@ class PortMapMixin(SetUpMixin):
                     "extra": "option",
                 },
             ],
-            force_options=True
+            force_options=True,
         )
 
-        self.env_assist.assert_reports([
-            (
-                severities.WARNING,
-                report_codes.INVALID_OPTIONS,
-                {
-                    "option_names": ["extra", ],
-                    "option_type": "port-map",
-                    "allowed": sorted(list(PORT_MAP_OPTIONS)),
-                    "allowed_patterns": [],
-                },
-                None
-            ),
-            fixture.warn(
-                report_codes.INVALID_OPTION_VALUE,
-                option_name="range",
-                option_value="3000",
-                allowed_values="port-port",
-                cannot_be_empty=False,
-                forbidden_characters=None,
-            ),
-        ])
+        self.env_assist.assert_reports(
+            [
+                (
+                    severities.WARNING,
+                    report_codes.INVALID_OPTIONS,
+                    {
+                        "option_names": [
+                            "extra",
+                        ],
+                        "option_type": "port-map",
+                        "allowed": sorted(list(PORT_MAP_OPTIONS)),
+                        "allowed_patterns": [],
+                    },
+                    None,
+                ),
+                fixture.warn(
+                    report_codes.INVALID_OPTION_VALUE,
+                    option_name="range",
+                    option_value="3000",
+                    allowed_values="port-port",
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
+            ]
+        )
 
 
 class StorageMapMixin(SetUpMixin):
@@ -754,8 +789,7 @@ class StorageMapMixin(SetUpMixin):
                         </storage>
                     </bundle>
                 </resources>
-            """
-            .format(
+            """.format(
                 container_type=self.container_type,
                 bundle_id=self.bundle_id,
                 image=self.image,
@@ -770,13 +804,12 @@ class StorageMapMixin(SetUpMixin):
                 },
                 {
                     # use an autogenerated id of the previous item
-                    "id":
-                        "{bundle_id}-storage-map"
-                        .format(bundle_id=self.bundle_id)
-                    ,
+                    "id": "{bundle_id}-storage-map".format(
+                        bundle_id=self.bundle_id
+                    ),
                     "source-dir": "/tmp/bundle2a",
                     "target-dir": "/tmp/bundle2b",
-                    "options": "extra options 1"
+                    "options": "extra options 1",
                 },
                 {
                     "source-dir-root": "/tmp/bundle3a",
@@ -784,13 +817,12 @@ class StorageMapMixin(SetUpMixin):
                 },
                 {
                     # use an autogenerated id of the previous item
-                    "id":
-                        "{bundle_id}-storage-map-2"
-                        .format(bundle_id=self.bundle_id)
-                    ,
+                    "id": "{bundle_id}-storage-map-2".format(
+                        bundle_id=self.bundle_id
+                    ),
                     "source-dir-root": "/tmp/bundle4a",
                     "target-dir": "/tmp/bundle4b",
-                    "options": "extra options 2"
+                    "options": "extra options 2",
                 },
             ]
         )
@@ -799,8 +831,7 @@ class StorageMapMixin(SetUpMixin):
         self.env_assist.assert_raise_library_error(
             lambda: self.run_bundle_cmd(
                 storage_map=[
-                    {
-                    },
+                    {},
                     {
                         "id": "not#valid",
                         "source-dir": "/tmp/bundle1a",
@@ -808,8 +839,10 @@ class StorageMapMixin(SetUpMixin):
                         "target-dir": "/tmp/bundle1c",
                     },
                 ],
-                force_options=True
-            ),
+                force_options=True,
+            )
+        )
+        self.env_assist.assert_reports(
             [
                 # first
                 (
@@ -819,28 +852,30 @@ class StorageMapMixin(SetUpMixin):
                         "option_type": "storage-map",
                         "option_names": ["source-dir", "source-dir-root"],
                     },
-                    None
+                    None,
                 ),
                 (
                     severities.ERROR,
                     report_codes.REQUIRED_OPTIONS_ARE_MISSING,
                     {
                         "option_type": "storage-map",
-                        "option_names": ["target-dir", ],
+                        "option_names": [
+                            "target-dir",
+                        ],
                     },
-                    None
+                    None,
                 ),
                 # second
                 (
                     severities.ERROR,
-                    report_codes.INVALID_ID,
+                    report_codes.INVALID_ID_BAD_CHAR,
                     {
                         "invalid_character": "#",
                         "id": "not#valid",
                         "id_description": "storage-map id",
                         "is_first_char": False,
                     },
-                    None
+                    None,
                 ),
                 (
                     severities.ERROR,
@@ -849,7 +884,7 @@ class StorageMapMixin(SetUpMixin):
                         "option_type": "storage-map",
                         "option_names": ["source-dir", "source-dir-root"],
                     },
-                    None
+                    None,
                 ),
             ]
         )
@@ -864,18 +899,22 @@ class StorageMapMixin(SetUpMixin):
                         "extra": "option",
                     },
                 ]
-            ),
+            )
+        )
+        self.env_assist.assert_reports(
             [
                 (
                     severities.ERROR,
                     report_codes.INVALID_OPTIONS,
                     {
-                        "option_names": ["extra", ],
+                        "option_names": [
+                            "extra",
+                        ],
                         "option_type": "storage-map",
                         "allowed": sorted(list(STORAGE_MAP_OPTIONS)),
                         "allowed_patterns": [],
                     },
-                    report_codes.FORCE_OPTIONS
+                    report_codes.FORCE_OPTIONS,
                 ),
             ]
         )
@@ -896,8 +935,7 @@ class StorageMapMixin(SetUpMixin):
                         </storage>
                     </bundle>
                 </resources>
-            """
-            .format(
+            """.format(
                 container_type=self.container_type,
                 bundle_id=self.bundle_id,
                 image=self.image,
@@ -912,7 +950,7 @@ class StorageMapMixin(SetUpMixin):
                     "extra": "option",
                 },
             ],
-            force_options=True
+            force_options=True,
         )
 
         self.env_assist.assert_reports(
@@ -921,16 +959,19 @@ class StorageMapMixin(SetUpMixin):
                     severities.WARNING,
                     report_codes.INVALID_OPTIONS,
                     {
-                        "option_names": ["extra", ],
+                        "option_names": [
+                            "extra",
+                        ],
                         "option_type": "storage-map",
                         "allowed": sorted(list(STORAGE_MAP_OPTIONS)),
                         "allowed_patterns": [],
                     },
-                    None
+                    None,
                 ),
             ]
         )
 
+
 class MetaMixin(SetUpMixin):
     container_type = None
     bundle_id = None
@@ -950,8 +991,7 @@ class MetaMixin(SetUpMixin):
                         </meta_attributes>
                     </bundle>
                 </resources>
-            """
-            .format(
+            """.format(
                 container_type=self.container_type,
                 bundle_id=self.bundle_id,
                 image=self.image,
@@ -976,16 +1016,14 @@ class MetaMixin(SetUpMixin):
                         <{container_type} image="{image}" />
                     </bundle>
                 </resources>
-            """
-            .format(
+            """.format(
                 container_type=self.container_type,
                 bundle_id=self.bundle_id,
                 image=self.image,
             )
         )
-        self.run_bundle_cmd(
-            ensure_disabled=True
-        )
+        self.run_bundle_cmd(ensure_disabled=True)
+
 
 class AllOptionsMixin(SetUpMixin):
     container_type = None
@@ -1052,8 +1090,7 @@ class AllOptionsMixin(SetUpMixin):
                         </storage>
                     </bundle>
                 </resources>
-            """
-            .format(
+            """.format(
                 container_type=self.container_type,
                 bundle_id=self.bundle_id,
                 image=self.image,
@@ -1081,10 +1118,9 @@ class AllOptionsMixin(SetUpMixin):
                 },
                 {
                     # use an autogenerated id of the previous item
-                    "id":
-                        "{bundle_id}-port-map-1001"
-                        .format(bundle_id=self.bundle_id)
-                    ,
+                    "id": "{bundle_id}-port-map-1001".format(
+                        bundle_id=self.bundle_id
+                    ),
                     "port": "2000",
                     "internal-port": "2002",
                 },
@@ -1099,13 +1135,12 @@ class AllOptionsMixin(SetUpMixin):
                 },
                 {
                     # use an autogenerated id of the previous item
-                    "id":
-                        "{bundle_id}-storage-map"
-                        .format(bundle_id=self.bundle_id)
-                    ,
+                    "id": "{bundle_id}-storage-map".format(
+                        bundle_id=self.bundle_id
+                    ),
                     "source-dir": "/tmp/bundle2a",
                     "target-dir": "/tmp/bundle2b",
-                    "options": "extra options 1"
+                    "options": "extra options 1",
                 },
                 {
                     "source-dir-root": "/tmp/bundle3a",
@@ -1113,23 +1148,22 @@ class AllOptionsMixin(SetUpMixin):
                 },
                 {
                     # use an autogenerated id of the previous item
-                    "id":
-                        "{bundle_id}-port-map-1001-1"
-                        .format(bundle_id=self.bundle_id)
-                    ,
+                    "id": "{bundle_id}-port-map-1001-1".format(
+                        bundle_id=self.bundle_id
+                    ),
                     "source-dir-root": "/tmp/bundle4a",
                     "target-dir": "/tmp/bundle4b",
-                    "options": "extra options 2"
+                    "options": "extra options 2",
                 },
-            ]
+            ],
         )
 
-class WaitMixin(FixturesMixin):
+
+class WaitMixin(FixturesMixin, SetUpMixin):
     initial_resources = "<resources/>"
     bundle_id = None
     image = None
 
-
     @property
     def fixture_status_running(self):
         return """
@@ -1155,7 +1189,9 @@ class WaitMixin(FixturesMixin):
                     </replica>
                 </bundle>
             </resources>
-        """.format(bundle_id=self.bundle_id)
+        """.format(
+            bundle_id=self.bundle_id
+        )
 
     @property
     def fixture_status_not_running(self):
@@ -1178,7 +1214,9 @@ class WaitMixin(FixturesMixin):
                     </replica>
                 </bundle>
             </resources>
-        """.format(bundle_id=self.bundle_id)
+        """.format(
+            bundle_id=self.bundle_id
+        )
 
     @property
     def fixture_resources_bundle_simple_disabled(self):
@@ -1192,15 +1230,8 @@ class WaitMixin(FixturesMixin):
                     <docker image="{image}" />
                 </bundle>
             </resources>
-        """.format(bundle_id=self.bundle_id, image=self.image)
-
-
-    def setUp(self):
-        # pylint: disable=invalid-name
-        self.env_assist, self.config = get_env_tools(test_case=self)
-        (self.config
-            .runner.pcmk.can_wait()
-            .runner.cib.load(resources=self.initial_resources)
+        """.format(
+            bundle_id=self.bundle_id, image=self.image
         )
 
     def test_wait_fail(self):
@@ -1209,97 +1240,106 @@ class WaitMixin(FixturesMixin):
             Pending actions:
                     Action 12: {bundle_id}-node2-stop on node2
             Error performing operation: Timer expired
-            """
-            .format(bundle_id=self.bundle_id)
+            """.format(
+                bundle_id=self.bundle_id
+            )
         ).strip()
         self.config.env.push_cib(
             resources=self.fixture_resources_bundle_simple,
             wait=TIMEOUT,
             exception=LibraryError(
-                reports.wait_for_idle_timed_out(wait_error_message)
-            )
+                reports.item.ReportItem.error(
+                    reports.messages.WaitForIdleTimedOut(wait_error_message)
+                )
+            ),
         )
         self.env_assist.assert_raise_library_error(
             lambda: self.run_bundle_cmd(wait=TIMEOUT),
-            [
-                fixture.report_wait_for_idle_timed_out(wait_error_message)
-            ],
-            expected_in_processor=False
+            [fixture.report_wait_for_idle_timed_out(wait_error_message)],
+            expected_in_processor=False,
         )
 
-    @skip_unless_pacemaker_supports_bundle
+    @mock.patch.object(
+        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+    )
     def test_wait_ok_run_ok(self):
-        (self.config
-            .env.push_cib(
-                resources=self.fixture_resources_bundle_simple,
-                wait=TIMEOUT
-            )
-            .runner.pcmk.load_state(resources=self.fixture_status_running)
+        (
+            self.config.env.push_cib(
+                resources=self.fixture_resources_bundle_simple, wait=TIMEOUT
+            ).runner.pcmk.load_state(resources=self.fixture_status_running)
         )
         self.run_bundle_cmd(wait=TIMEOUT)
-        self.env_assist.assert_reports([
-            fixture.report_resource_running(
-                self.bundle_id,
-                {"Started": ["node1", "node2"]}
-            ),
-        ])
-
-    @skip_unless_pacemaker_supports_bundle
-    def test_wait_ok_run_fail(self):
-        (self.config
-            .env.push_cib(
-                resources=self.fixture_resources_bundle_simple,
-                wait=TIMEOUT
-            )
-            .runner.pcmk.load_state(resources=self.fixture_status_not_running)
-        )
-        self.env_assist.assert_raise_library_error(
-            lambda: self.run_bundle_cmd(wait=TIMEOUT),
+        self.env_assist.assert_reports(
             [
-                fixture.report_resource_not_running(
-                    self.bundle_id,
-                    severities.ERROR
+                fixture.report_resource_running(
+                    self.bundle_id, {"Started": ["node1", "node2"]}
                 ),
             ]
         )
 
-    @skip_unless_pacemaker_supports_bundle
-    def test_disabled_wait_ok_run_ok(self):
-        (self.config
-            .env.push_cib(
-                resources=self.fixture_resources_bundle_simple_disabled,
-                wait=TIMEOUT
-            )
-            .runner.pcmk.load_state(resources=self.fixture_status_not_running)
-        )
-        self.run_bundle_cmd(ensure_disabled=True, wait=TIMEOUT)
-        self.env_assist.assert_reports([
-            (
-                severities.INFO,
-                report_codes.RESOURCE_DOES_NOT_RUN,
-                {
-                    "resource_id": self.bundle_id,
-                },
-                None
-            )
-        ])
-
-    @skip_unless_pacemaker_supports_bundle
-    def test_disabled_wait_ok_run_fail(self):
-        (self.config
-            .env.push_cib(
-                resources=self.fixture_resources_bundle_simple_disabled,
-                wait=TIMEOUT
-            )
-            .runner.pcmk.load_state(resources=self.fixture_status_running)
+    @mock.patch.object(
+        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+    )
+    def test_wait_ok_run_fail(self):
+        (
+            self.config.env.push_cib(
+                resources=self.fixture_resources_bundle_simple, wait=TIMEOUT
+            ).runner.pcmk.load_state(resources=self.fixture_status_not_running)
         )
         self.env_assist.assert_raise_library_error(
-            lambda: self.run_bundle_cmd(ensure_disabled=True, wait=TIMEOUT),
+            lambda: self.run_bundle_cmd(wait=TIMEOUT)
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.report_resource_not_running(
+                    self.bundle_id, severities.ERROR
+                ),
+            ]
+        )
+
+    @mock.patch.object(
+        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+    )
+    def test_disabled_wait_ok_run_ok(self):
+        (
+            self.config.env.push_cib(
+                resources=self.fixture_resources_bundle_simple_disabled,
+                wait=TIMEOUT,
+            ).runner.pcmk.load_state(resources=self.fixture_status_not_running)
+        )
+        self.run_bundle_cmd(ensure_disabled=True, wait=TIMEOUT)
+        self.env_assist.assert_reports(
+            [
+                (
+                    severities.INFO,
+                    report_codes.RESOURCE_DOES_NOT_RUN,
+                    {
+                        "resource_id": self.bundle_id,
+                    },
+                    None,
+                )
+            ]
+        )
+
+    @mock.patch.object(
+        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+    )
+    def test_disabled_wait_ok_run_fail(self):
+        (
+            self.config.env.push_cib(
+                resources=self.fixture_resources_bundle_simple_disabled,
+                wait=TIMEOUT,
+            ).runner.pcmk.load_state(resources=self.fixture_status_running)
+        )
+        self.env_assist.assert_raise_library_error(
+            lambda: self.run_bundle_cmd(ensure_disabled=True, wait=TIMEOUT)
+        )
+        self.env_assist.assert_reports(
             [
                 fixture.report_resource_running(
                     self.bundle_id,
                     {"Started": ["node1", "node2"]},
-                    severities.ERROR
+                    severities.ERROR,
                 )
             ]
         )
