@@ -5,10 +5,9 @@ from unittest import mock, TestCase
 from pcs_test.tools.command_env import get_env_tools
 from pcs_test.tools.custom_mock import MockLibraryReportProcessor
 
-from pcs.common import report_codes
-from pcs.lib.errors import ReportItemSeverity as Severities
+from pcs.common.reports import ReportItemSeverity as Severities
+from pcs.common.reports import codes as report_codes
 from pcs.lib.env import LibraryEnvironment
-from pcs.lib.external import CommandRunner
 
 import pcs.lib.commands.alert as cmd_alert
 
@@ -19,6 +18,7 @@ get_env_tools = partial(
     exception_reports_in_processor_by_default=False,
 )
 
+
 class CreateAlertTest(TestCase):
     fixture_final_alerts = """
         <alerts>
@@ -58,34 +58,31 @@ class CreateAlertTest(TestCase):
                 (
                     Severities.ERROR,
                     report_codes.REQUIRED_OPTIONS_ARE_MISSING,
-                    {"option_names": ["path"]},
-                    None
+                    {"option_names": ["path"], "option_type": None},
+                    None,
                 ),
             ],
         )
 
     def test_create_no_upgrade(self):
-        (self.config
-            .runner.cib.load()
-            .env.push_cib(optional_in_conf=self.fixture_final_alerts)
+        (
+            self.config.runner.cib.load().env.push_cib(
+                optional_in_conf=self.fixture_final_alerts
+            )
         )
         cmd_alert.create_alert(
             self.env_assist.get_env(),
             "my-alert",
             "/my/path",
-            {
-                "instance": "value",
-                "another": "val"
-            },
+            {"instance": "value", "another": "val"},
             {"meta1": "val1"},
-            "my description"
+            "my description",
         )
 
     def test_create_upgrade(self):
-        (self.config
-            .runner.cib.load(
-                filename="cib-empty-2.0.xml",
-                name="load_cib_old_version"
+        (
+            self.config.runner.cib.load(
+                filename="cib-empty-2.0.xml", name="load_cib_old_version"
             )
             .runner.cib.upgrade()
             .runner.cib.load()
@@ -95,21 +92,20 @@ class CreateAlertTest(TestCase):
             self.env_assist.get_env(),
             "my-alert",
             "/my/path",
-            {
-                "instance": "value",
-                "another": "val"
-            },
+            {"instance": "value", "another": "val"},
             {"meta1": "val1"},
-            "my description"
+            "my description",
+        )
+        self.env_assist.assert_reports(
+            [
+                (
+                    Severities.INFO,
+                    report_codes.CIB_UPGRADE_SUCCESSFUL,
+                    {},
+                    None,
+                ),
+            ]
         )
-        self.env_assist.assert_reports([
-            (
-                Severities.INFO,
-                report_codes.CIB_UPGRADE_SUCCESSFUL,
-                {},
-                None
-            ),
-        ])
 
 
 class UpdateAlertTest(TestCase):
@@ -138,6 +134,7 @@ class UpdateAlertTest(TestCase):
             </alert>
         </alerts>
     """
+
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
 
@@ -167,9 +164,10 @@ class UpdateAlertTest(TestCase):
             </alert>
         </alerts>
         """
-        (self.config
-            .runner.cib.load(optional_in_conf=self.fixture_initial_alerts)
-            .env.push_cib(
+        (
+            self.config.runner.cib.load(
+                optional_in_conf=self.fixture_initial_alerts
+            ).env.push_cib(
                 replace={"./configuration/alerts": fixture_final_alerts}
             )
         )
@@ -177,22 +175,19 @@ class UpdateAlertTest(TestCase):
             self.env_assist.get_env(),
             "my-alert",
             "/another/one",
-            {
-                "instance": "",
-                "my-attr": "its_val"
-            },
+            {"instance": "", "my-attr": "its_val"},
             {"meta1": "val2"},
-            ""
+            "",
         )
 
     def test_update_instance_attribute(self):
-        (self.config
-            .runner.cib.load(optional_in_conf=self.fixture_initial_alerts)
-            .env.push_cib(
+        (
+            self.config.runner.cib.load(
+                optional_in_conf=self.fixture_initial_alerts
+            ).env.push_cib(
                 replace={
                     './configuration/alerts/alert[@id="my-alert"]/'
-                        'instance_attributes/nvpair[@name="instance"]'
-                    : """
+                    'instance_attributes/nvpair[@name="instance"]': """
                         <nvpair
                             id="my-alert-instance_attributes-instance"
                             name="instance"
@@ -208,12 +203,12 @@ class UpdateAlertTest(TestCase):
             None,
             {"instance": "new_val"},
             {},
-            None
+            None,
         )
 
     def test_alert_doesnt_exist(self):
-        (self.config
-            .runner.cib.load(
+        (
+            self.config.runner.cib.load(
                 optional_in_conf="""
                     <alerts>
                         <alert id="alert" path="path"/>
@@ -235,7 +230,7 @@ class UpdateAlertTest(TestCase):
                         "id": "unknown",
                         "expected_types": ["alert"],
                     },
-                    None
+                    None,
                 ),
             ],
         )
@@ -259,10 +254,7 @@ class RemoveAlertTest(TestCase):
         self.config.env.push_cib(
             remove="./configuration/alerts/alert[@id='alert2']"
         )
-        cmd_alert.remove_alert(
-            self.env_assist.get_env(),
-            ["alert2"]
-        )
+        cmd_alert.remove_alert(self.env_assist.get_env(), ["alert2"])
 
     def test_multiple_alerts(self):
         self.config.env.push_cib(
@@ -273,23 +265,21 @@ class RemoveAlertTest(TestCase):
             ]
         )
         cmd_alert.remove_alert(
-            self.env_assist.get_env(),
-            ["alert1", "alert3", "alert4"]
+            self.env_assist.get_env(), ["alert1", "alert3", "alert4"]
         )
 
     def test_no_alert(self):
         self.config.env.push_cib()
-        cmd_alert.remove_alert(
-            self.env_assist.get_env(),
-            []
-        )
+        cmd_alert.remove_alert(self.env_assist.get_env(), [])
 
     def test_alerts_dont_exist(self):
         self.env_assist.assert_raise_library_error(
             lambda: cmd_alert.remove_alert(
                 self.env_assist.get_env(),
-                ["unknown1", "alert1", "unknown2", "alert2"]
-            ),
+                ["unknown1", "alert1", "unknown2", "alert2"],
+            )
+        )
+        self.env_assist.assert_reports(
             [
                 (
                     Severities.ERROR,
@@ -300,7 +290,7 @@ class RemoveAlertTest(TestCase):
                         "id": "unknown1",
                         "expected_types": ["alert"],
                     },
-                    None
+                    None,
                 ),
                 (
                     Severities.ERROR,
@@ -311,10 +301,9 @@ class RemoveAlertTest(TestCase):
                         "id": "unknown2",
                         "expected_types": ["alert"],
                     },
-                    None
+                    None,
                 ),
-            ],
-            expected_in_processor=True
+            ]
         )
 
 
@@ -341,7 +330,7 @@ class AddRecipientTest(TestCase):
                 (
                     Severities.ERROR,
                     report_codes.REQUIRED_OPTIONS_ARE_MISSING,
-                    {"option_names": ["value"]}
+                    {"option_names": ["value"], "option_type": None},
                 )
             ],
         )
@@ -349,14 +338,18 @@ class AddRecipientTest(TestCase):
     def test_recipient_already_exists(self):
         self.env_assist.assert_raise_library_error(
             lambda: cmd_alert.add_recipient(
-                self.env_assist.get_env(), "alert", "value1", {}, {},
-                recipient_id="alert-recipient"
+                self.env_assist.get_env(),
+                "alert",
+                "value1",
+                {},
+                {},
+                recipient_id="alert-recipient",
             ),
             [
                 (
                     Severities.ERROR,
                     report_codes.ID_ALREADY_EXISTS,
-                    {"id": "alert-recipient"}
+                    {"id": "alert-recipient"},
                 )
             ],
         )
@@ -364,8 +357,7 @@ class AddRecipientTest(TestCase):
     def test_without_id(self):
         self.config.env.push_cib(
             replace={
-                './/alert[@id="alert"]' :
-                """
+                './/alert[@id="alert"]': """
                 <alert id="alert" path="path">
                     <recipient id="alert-recipient" value="value1"/>
                     <recipient id="alert-recipient-1" value="value">
@@ -402,17 +394,13 @@ class AddRecipientTest(TestCase):
             "alert",
             "value",
             {"attr1": "val1"},
-            {
-                "attr2": "val2",
-                "attr1": "val1"
-            }
+            {"attr2": "val2", "attr1": "val1"},
         )
 
     def test_with_id(self):
         self.config.env.push_cib(
             replace={
-                './/alert[@id="alert"]':
-                """
+                './/alert[@id="alert"]': """
                 <alert id="alert" path="path">
                     <recipient id="alert-recipient" value="value1"/>
                     <recipient id="my-recipient" value="value">
@@ -449,13 +437,11 @@ class AddRecipientTest(TestCase):
             "alert",
             "value",
             {"attr1": "val1"},
-            {
-                "attr2": "val2",
-                "attr1": "val1"
-            },
-            recipient_id="my-recipient"
+            {"attr2": "val2", "attr1": "val1"},
+            recipient_id="my-recipient",
         )
 
+
 class UpdateRecipientTest(TestCase):
     def setUp(self):
         self.env_assist, self.config = get_env_tools(test_case=self)
@@ -501,13 +487,16 @@ class UpdateRecipientTest(TestCase):
         self.env_assist.assert_raise_library_error(
             lambda: cmd_alert.update_recipient(
                 self.env_assist.get_env(),
-                "alert-recipient-1", {}, {}, recipient_value=""
+                "alert-recipient-1",
+                {},
+                {},
+                recipient_value="",
             ),
             [
                 (
                     Severities.ERROR,
                     report_codes.CIB_ALERT_RECIPIENT_VALUE_INVALID,
-                    {"recipient": ""}
+                    {"recipient": ""},
                 )
             ],
         )
@@ -527,7 +516,7 @@ class UpdateRecipientTest(TestCase):
                         "context_id": "",
                         "context_type": "alerts",
                     },
-                    None
+                    None,
                 )
             ],
         )
@@ -535,8 +524,7 @@ class UpdateRecipientTest(TestCase):
     def test_update_all(self):
         self.config.env.push_cib(
             replace={
-                './/alert[@id="alert"]':
-                """
+                './/alert[@id="alert"]': """
                 <alert id="alert" path="path">
                     <recipient id="alert-recipient" value="value1"/>
                     <recipient
@@ -576,12 +564,9 @@ class UpdateRecipientTest(TestCase):
             self.env_assist.get_env(),
             "alert-recipient-1",
             {"attr1": "value"},
-            {
-                "attr1": "",
-                "attr3": "new_val"
-            },
+            {"attr1": "", "attr3": "new_val"},
             recipient_value="new_val",
-            description="desc"
+            description="desc",
         )
 
 
@@ -609,33 +594,41 @@ class RemoveRecipientTest(TestCase):
         self.env_assist.assert_raise_library_error(
             lambda: cmd_alert.remove_recipient(
                 self.env_assist.get_env(),
-                ["recipient", "alert-recip1", "alert2-recip1"]
-            ),
+                ["recipient", "alert-recip1", "alert2-recip1"],
+            )
+        )
+        self.env_assist.assert_reports(
             [
                 (
                     Severities.ERROR,
                     report_codes.ID_NOT_FOUND,
-                    {"id": "recipient"},
-                    None
+                    {
+                        "id": "recipient",
+                        "expected_types": ["recipient"],
+                        "context_type": "alerts",
+                        "context_id": "",
+                    },
+                    None,
                 ),
                 (
                     Severities.ERROR,
                     report_codes.ID_NOT_FOUND,
-                    {"id": "alert2-recip1"},
-                    None
-                )
-            ],
-            expected_in_processor=True
+                    {
+                        "id": "alert2-recip1",
+                        "expected_types": ["recipient"],
+                        "context_type": "alerts",
+                        "context_id": "",
+                    },
+                    None,
+                ),
+            ]
         )
 
     def test_one_recipient(self):
         self.config.env.push_cib(
             remove="./configuration/alerts/alert/recipient[@id='alert-recip1']"
         )
-        cmd_alert.remove_recipient(
-            self.env_assist.get_env(),
-            ["alert-recip1"]
-        )
+        cmd_alert.remove_recipient(self.env_assist.get_env(), ["alert-recip1"])
 
     def test_multiple_recipients(self):
         self.config.env.push_cib(
@@ -647,31 +640,26 @@ class RemoveRecipientTest(TestCase):
         )
         cmd_alert.remove_recipient(
             self.env_assist.get_env(),
-            ["alert-recip1", "alert-recip2", "alert2-recip4"]
+            ["alert-recip1", "alert-recip2", "alert2-recip4"],
         )
 
     def test_no_recipient(self):
         self.config.env.push_cib()
-        cmd_alert.remove_recipient(
-            self.env_assist.get_env(),
-            []
-        )
+        cmd_alert.remove_recipient(self.env_assist.get_env(), [])
 
 
+@mock.patch.object(LibraryEnvironment, "get_cib")
 @mock.patch("pcs.lib.cib.alert.get_all_alerts")
 class GetAllAlertsTest(TestCase):
     def setUp(self):
         self.mock_log = mock.MagicMock(spec_set=logging.Logger)
-        self.mock_run = mock.MagicMock(spec_set=CommandRunner)
         self.mock_rep = MockLibraryReportProcessor()
-        self.mock_env = LibraryEnvironment(
-            self.mock_log, self.mock_rep, cib_data='<cib/>'
-        )
+        self.mock_env = LibraryEnvironment(self.mock_log, self.mock_rep)
 
-    def test_success(self, mock_alerts):
+    def test_success(self, mock_alerts, mock_get_cib):
         mock_alerts.return_value = [{"id": "alert"}]
+        mock_get_cib.return_value = "<cib/>"
         self.assertEqual(
-            [{"id": "alert"}],
-            cmd_alert.get_all_alerts(self.mock_env)
+            [{"id": "alert"}], cmd_alert.get_all_alerts(self.mock_env)
         )
         self.assertEqual(1, mock_alerts.call_count)
