@@ -11,13 +11,13 @@ from pcs_test.tools.integration_lib import Runner
 from pcs_test.tools.command_env.mock_runner import Call
 
 from pcs import settings
-from pcs.common import report_codes
+from pcs.common import reports
 from pcs.common.node_communicator import RequestTarget
-from pcs.lib.errors import (
-    ReportItemSeverity as Severities,
-    LibraryError,
+from pcs.common.reports import (
     ReportItem,
+    ReportItemSeverity as Severities,
 )
+from pcs.lib.errors import LibraryError
 from pcs.lib.env import LibraryEnvironment
 import pcs.lib.commands.sbd as cmd_sbd
 
@@ -38,16 +38,35 @@ def _assert_equal_list_of_dictionaries_without_order(expected, actual):
 
 class ValidateSbdOptionsTest(TestCase):
     def setUp(self):
-        self.allowed_sbd_options = sorted([
-            "SBD_DELAY_START", "SBD_STARTMODE", "SBD_WATCHDOG_TIMEOUT",
-            "SBD_TIMEOUT_ACTION",
-        ])
-        self.timeout_action_allowed_values = sorted([
-            "flush", "noflush", "off", "reboot", "crashdump", "flush,off",
-            "flush,reboot", "flush,crashdump", "noflush,off", "noflush,reboot",
-            "noflush,crashdump", "off,flush", "off,noflush", "reboot,flush",
-            "reboot,noflush", "crashdump,flush", "crashdump,noflush",
-        ])
+        self.allowed_sbd_options = sorted(
+            [
+                "SBD_DELAY_START",
+                "SBD_STARTMODE",
+                "SBD_WATCHDOG_TIMEOUT",
+                "SBD_TIMEOUT_ACTION",
+            ]
+        )
+        self.timeout_action_allowed_values = sorted(
+            [
+                "flush",
+                "noflush",
+                "off",
+                "reboot",
+                "crashdump",
+                "flush,off",
+                "flush,reboot",
+                "flush,crashdump",
+                "noflush,off",
+                "noflush,reboot",
+                "noflush,crashdump",
+                "off,flush",
+                "off,noflush",
+                "reboot,flush",
+                "reboot,noflush",
+                "crashdump,flush",
+                "crashdump,noflush",
+            ]
+        )
 
     def test_all_ok(self):
         config = {
@@ -66,15 +85,15 @@ class ValidateSbdOptionsTest(TestCase):
             cmd_sbd._validate_sbd_options(config),
             [
                 fixture.error(
-                    report_codes.INVALID_OPTION_VALUE,
-                    force_code=report_codes.FORCE_OPTIONS,
+                    reports.codes.INVALID_OPTION_VALUE,
+                    force_code=reports.codes.FORCE_OPTIONS,
                     option_name="SBD_TIMEOUT_ACTION",
                     option_value="flush,noflush",
                     allowed_values=self.timeout_action_allowed_values,
                     cannot_be_empty=False,
                     forbidden_characters=None,
                 ),
-            ]
+            ],
         )
 
     def test_invalid_value_forced(self):
@@ -87,14 +106,14 @@ class ValidateSbdOptionsTest(TestCase):
             ),
             [
                 fixture.warn(
-                    report_codes.INVALID_OPTION_VALUE,
+                    reports.codes.INVALID_OPTION_VALUE,
                     option_name="SBD_TIMEOUT_ACTION",
                     option_value="flush,noflush",
                     allowed_values=self.timeout_action_allowed_values,
                     cannot_be_empty=False,
                     forbidden_characters=None,
                 ),
-            ]
+            ],
         )
 
     def test_unknown_options(self):
@@ -103,22 +122,22 @@ class ValidateSbdOptionsTest(TestCase):
             "SBD_WATCHDOG_TIMEOUT": "5",
             "SBD_STARTMODE": "clean",
             "SBD_UNKNOWN": "",
-            "another_unknown_option": "some value"
+            "another_unknown_option": "some value",
         }
         assert_report_item_list_equal(
             cmd_sbd._validate_sbd_options(config),
             [
                 fixture.error(
-                    report_codes.INVALID_OPTIONS,
+                    reports.codes.INVALID_OPTIONS,
                     option_names=sorted(
                         ["SBD_UNKNOWN", "another_unknown_option"]
                     ),
                     option_type=None,
                     allowed=self.allowed_sbd_options,
                     allowed_patterns=[],
-                    force_code=report_codes.FORCE_OPTIONS
+                    force_code=reports.codes.FORCE_OPTIONS,
                 ),
-            ]
+            ],
         )
 
     def test_unknown_options_forced(self):
@@ -127,14 +146,14 @@ class ValidateSbdOptionsTest(TestCase):
             "SBD_WATCHDOG_TIMEOUT": "5",
             "SBD_STARTMODE": "clean",
             "SBD_UNKNOWN": "",
-            "another_unknown_option": "some value"
+            "another_unknown_option": "some value",
         }
         # just make sure there is no exception raised
         assert_report_item_list_equal(
             cmd_sbd._validate_sbd_options(config, allow_unknown_opts=True),
             [
                 fixture.warn(
-                    report_codes.INVALID_OPTIONS,
+                    reports.codes.INVALID_OPTIONS,
                     option_names=sorted(
                         ["SBD_UNKNOWN", "another_unknown_option"]
                     ),
@@ -142,10 +161,9 @@ class ValidateSbdOptionsTest(TestCase):
                     allowed=self.allowed_sbd_options,
                     allowed_patterns=[],
                 ),
-            ]
+            ],
         )
 
-
     def test_unsupported_options(self):
         config = {
             "SBD_DELAY_START": "yes",
@@ -160,7 +178,7 @@ class ValidateSbdOptionsTest(TestCase):
             cmd_sbd._validate_sbd_options(config),
             [
                 fixture.error(
-                    report_codes.INVALID_OPTIONS,
+                    reports.codes.INVALID_OPTIONS,
                     option_names=sorted(
                         ["SBD_WATCHDOG_DEV", "SBD_OPTS", "SBD_DEVICE"]
                     ),
@@ -168,7 +186,7 @@ class ValidateSbdOptionsTest(TestCase):
                     allowed=self.allowed_sbd_options,
                     allowed_patterns=[],
                 ),
-            ]
+            ],
         )
 
     def test_invalid_and_unsupported_options(self):
@@ -178,28 +196,28 @@ class ValidateSbdOptionsTest(TestCase):
             "SBD_STARTMODE": "clean",
             "SBD_WATCHDOG_DEV": "/dev/watchdog",
             "SBD_UNKNOWN": "",
-            "SBD_OPTS": "  "
+            "SBD_OPTS": "  ",
         }
 
         assert_report_item_list_equal(
             cmd_sbd._validate_sbd_options(config),
             [
                 fixture.error(
-                    report_codes.INVALID_OPTIONS,
+                    reports.codes.INVALID_OPTIONS,
                     option_names=sorted(["SBD_WATCHDOG_DEV", "SBD_OPTS"]),
                     option_type=None,
                     allowed=self.allowed_sbd_options,
                     allowed_patterns=[],
                 ),
                 fixture.error(
-                    report_codes.INVALID_OPTIONS,
+                    reports.codes.INVALID_OPTIONS,
                     option_names=["SBD_UNKNOWN"],
                     option_type=None,
                     allowed=self.allowed_sbd_options,
                     allowed_patterns=[],
-                    force_code=report_codes.FORCE_OPTIONS,
+                    force_code=reports.codes.FORCE_OPTIONS,
                 ),
-            ]
+            ],
         )
 
     def test_invalid_and_unsupported_options_forced(self):
@@ -217,7 +235,7 @@ class ValidateSbdOptionsTest(TestCase):
             cmd_sbd._validate_sbd_options(config, allow_unknown_opts=True),
             [
                 fixture.error(
-                    report_codes.INVALID_OPTIONS,
+                    reports.codes.INVALID_OPTIONS,
                     option_names=sorted(
                         ["SBD_WATCHDOG_DEV", "SBD_OPTS", "SBD_PACEMAKER"]
                     ),
@@ -226,20 +244,17 @@ class ValidateSbdOptionsTest(TestCase):
                     allowed_patterns=[],
                 ),
                 fixture.warn(
-                    report_codes.INVALID_OPTIONS,
+                    reports.codes.INVALID_OPTIONS,
                     option_names=["SBD_UNKNOWN"],
                     option_type=None,
                     allowed=self.allowed_sbd_options,
                     allowed_patterns=[],
                 ),
-            ]
+            ],
         )
 
     def test_watchdog_timeout_is_not_present(self):
-        config = {
-            "SBD_DELAY_START": "yes",
-            "SBD_STARTMODE": "clean"
-        }
+        config = {"SBD_DELAY_START": "yes", "SBD_STARTMODE": "clean"}
         self.assertEqual([], cmd_sbd._validate_sbd_options(config))
 
     def test_watchdog_timeout_is_nonnegative_int(self):
@@ -252,14 +267,14 @@ class ValidateSbdOptionsTest(TestCase):
             cmd_sbd._validate_sbd_options(config),
             [
                 fixture.error(
-                    report_codes.INVALID_OPTION_VALUE,
+                    reports.codes.INVALID_OPTION_VALUE,
                     option_name="SBD_WATCHDOG_TIMEOUT",
                     option_value="-1",
                     allowed_values="a non-negative integer",
                     cannot_be_empty=False,
                     forbidden_characters=None,
                 )
-            ]
+            ],
         )
 
     def test_watchdog_timeout_is_not_int(self):
@@ -272,14 +287,14 @@ class ValidateSbdOptionsTest(TestCase):
             cmd_sbd._validate_sbd_options(config),
             [
                 fixture.error(
-                    report_codes.INVALID_OPTION_VALUE,
+                    reports.codes.INVALID_OPTION_VALUE,
                     option_name="SBD_WATCHDOG_TIMEOUT",
                     option_value="not int",
                     allowed_values="a non-negative integer",
                     cannot_be_empty=False,
                     forbidden_characters=None,
                 )
-            ]
+            ],
         )
 
     def test_watchdog_timeout_is_none(self):
@@ -292,14 +307,14 @@ class ValidateSbdOptionsTest(TestCase):
             cmd_sbd._validate_sbd_options(config),
             [
                 fixture.error(
-                    report_codes.INVALID_OPTION_VALUE,
+                    reports.codes.INVALID_OPTION_VALUE,
                     option_name="SBD_WATCHDOG_TIMEOUT",
                     option_value=None,
                     allowed_values="a non-negative integer",
                     cannot_be_empty=False,
                     forbidden_characters=None,
                 )
-            ]
+            ],
         )
 
 
@@ -323,10 +338,11 @@ class ValidateWatchdogDictTest(TestCase):
             [
                 (
                     Severities.ERROR,
-                    report_codes.WATCHDOG_INVALID,
-                    {"watchdog": watchdog}
-                ) for watchdog in ["", None]
-            ]
+                    reports.codes.WATCHDOG_INVALID,
+                    {"watchdog": watchdog},
+                )
+                for watchdog in ["", None]
+            ],
         )
 
 
@@ -337,9 +353,7 @@ class GetFullTargetDictTest(TestCase):
         ]
 
     def test_not_using_default(self):
-        target_dict = {
-            "node" + str(i): "val" + str(i) for i in range(4)
-        }
+        target_dict = {"node" + str(i): "val" + str(i) for i in range(4)}
         expected = {
             self.target_list[0].label: "val1",
             self.target_list[1].label: "val2",
@@ -347,13 +361,11 @@ class GetFullTargetDictTest(TestCase):
         }
         self.assertEqual(
             expected,
-            cmd_sbd._get_full_target_dict(self.target_list, target_dict, None)
+            cmd_sbd._get_full_target_dict(self.target_list, target_dict, None),
         )
 
     def test_using_default(self):
-        target_dict = {
-            "node" + str(i): "val" + str(i) for i in range(3)
-        }
+        target_dict = {"node" + str(i): "val" + str(i) for i in range(3)}
         default = "default"
         expected = {
             self.target_list[0].label: "val1",
@@ -364,7 +376,7 @@ class GetFullTargetDictTest(TestCase):
             expected,
             cmd_sbd._get_full_target_dict(
                 self.target_list, target_dict, default
-            )
+            ),
         )
 
 
@@ -385,23 +397,30 @@ SBD_WATCHDOG_TIMEOUT=0
             {
                 "SBD_OPTS": '"-n node1"',
                 "SBD_WATCHDOG_DEV": "/dev/watchdog",
-                "SBD_WATCHDOG_TIMEOUT": "0"
+                "SBD_WATCHDOG_TIMEOUT": "0",
             },
-            cmd_sbd.get_local_sbd_config(self.mock_env)
+            cmd_sbd.get_local_sbd_config(self.mock_env),
         )
         self.assertEqual(1, mock_config.call_count)
 
     def test_file_error(self, mock_config):
-        mock_config.side_effect = LibraryError(ReportItem.error(
-            report_codes.UNABLE_TO_GET_SBD_CONFIG,
-        ))
+        node = "node"
+        reason = "reason"
+        mock_config.side_effect = LibraryError(
+            ReportItem.error(
+                reports.messages.UnableToGetSbdConfig(node, reason)
+            )
+        )
         assert_raise_library_error(
             lambda: cmd_sbd.get_local_sbd_config(self.mock_env),
             (
                 Severities.ERROR,
-                report_codes.UNABLE_TO_GET_SBD_CONFIG,
-                {}
-            )
+                reports.codes.UNABLE_TO_GET_SBD_CONFIG,
+                {
+                    "node": node,
+                    "reason": reason,
+                },
+            ),
         )
 
 
@@ -409,9 +428,7 @@ class CommonTest(TestCase):
     @classmethod
     def setUpClass(cls):
         cls.patcher = mock.patch.object(
-            LibraryEnvironment,
-            "cmd_runner",
-            lambda self: runner
+            LibraryEnvironment, "cmd_runner", lambda self: runner
         )
         cls.patcher.start()
 
@@ -421,8 +438,7 @@ class CommonTest(TestCase):
 
     def setUp(self):
         self.env = LibraryEnvironment(
-            mock.MagicMock(logging.Logger),
-            MockLibraryReportProcessor()
+            mock.MagicMock(logging.Logger), MockLibraryReportProcessor()
         )
 
 
@@ -439,12 +455,12 @@ class InitializeBlockDevicesTest(CommonTest):
             cmd += [opt, val]
 
         cmd.append("create")
-        return [Call(" ".join(cmd), stdout, stderr, return_code)]
+        return [Call(cmd, stdout, stderr, return_code)]
 
     @staticmethod
     def fixture_invalid_value(option, value):
         return fixture.error(
-            report_codes.INVALID_OPTION_VALUE,
+            reports.codes.INVALID_OPTION_VALUE,
             option_name=option,
             option_value=value,
             allowed_values="a non-negative integer",
@@ -459,49 +475,54 @@ class InitializeBlockDevicesTest(CommonTest):
             "loop-timeout": "10",
             "allocate-timeout": "3",
             "msgwait-timeout": "2",
-
         }
-        runner.set_runs(self.fixture_sbd_init(
-            device_list,
-            [
-                ("-2", "3"),
-                ("-3", "10"),
-                ("-4", "2"),
-                ("-1", "1"),
-            ]
-        ))
+        runner.set_runs(
+            self.fixture_sbd_init(
+                device_list,
+                [
+                    ("-2", "3"),
+                    ("-3", "10"),
+                    ("-4", "2"),
+                    ("-1", "1"),
+                ],
+            )
+        )
         cmd_sbd.initialize_block_devices(self.env, device_list, option_dict)
         runner.assert_everything_launched()
-        self.env.report_processor.assert_reports([
-            (
-                Severities.INFO,
-                report_codes.SBD_DEVICE_INITIALIZATION_STARTED,
-                {"device_list": device_list}
-            ),
-            (
-                Severities.INFO,
-                report_codes.SBD_DEVICE_INITIALIZATION_SUCCESS,
-                {"device_list": device_list}
-            ),
-        ])
+        self.env.report_processor.assert_reports(
+            [
+                (
+                    Severities.INFO,
+                    reports.codes.SBD_DEVICE_INITIALIZATION_STARTED,
+                    {"device_list": device_list},
+                ),
+                (
+                    Severities.INFO,
+                    reports.codes.SBD_DEVICE_INITIALIZATION_SUCCESS,
+                    {"device_list": device_list},
+                ),
+            ]
+        )
 
     def test_no_options(self):
         device_list = ["dev1", "dev2"]
         runner.set_runs(self.fixture_sbd_init(device_list, {}))
         cmd_sbd.initialize_block_devices(self.env, device_list, {})
         runner.assert_everything_launched()
-        self.env.report_processor.assert_reports([
-            (
-                Severities.INFO,
-                report_codes.SBD_DEVICE_INITIALIZATION_STARTED,
-                {"device_list": device_list}
-            ),
-            (
-                Severities.INFO,
-                report_codes.SBD_DEVICE_INITIALIZATION_SUCCESS,
-                {"device_list": device_list}
-            ),
-        ])
+        self.env.report_processor.assert_reports(
+            [
+                (
+                    Severities.INFO,
+                    reports.codes.SBD_DEVICE_INITIALIZATION_STARTED,
+                    {"device_list": device_list},
+                ),
+                (
+                    Severities.INFO,
+                    reports.codes.SBD_DEVICE_INITIALIZATION_SUCCESS,
+                    {"device_list": device_list},
+                ),
+            ]
+        )
 
     def test_validation_failed(self):
         option_dict = {
@@ -513,33 +534,40 @@ class InitializeBlockDevicesTest(CommonTest):
             "msgwait-timeout": "-2",
         }
         allowed_options = [
-            "watchdog-timeout", "loop-timeout", "allocate-timeout",
+            "watchdog-timeout",
+            "loop-timeout",
+            "allocate-timeout",
             "msgwait-timeout",
         ]
         assert_raise_library_error(
-            lambda: cmd_sbd.initialize_block_devices(self.env, [], option_dict),
-            (
-                Severities.ERROR,
-                report_codes.REQUIRED_OPTIONS_ARE_MISSING,
-                {
-                    "option_names": ["device"],
-                    "option_type": None,
-                }
-            ),
-            (
-                Severities.ERROR,
-                report_codes.INVALID_OPTIONS,
-                {
-                    "option_names": sorted(["another_one", "unknown_option"]),
-                    "option_type": None,
-                    "allowed": sorted(allowed_options),
-                    "allowed_patterns": [],
-                }
-            ),
-            *[
+            lambda: cmd_sbd.initialize_block_devices(self.env, [], option_dict)
+        )
+        assert_report_item_list_equal(
+            self.env.report_processor.report_item_list,
+            [
+                (
+                    Severities.ERROR,
+                    reports.codes.REQUIRED_OPTIONS_ARE_MISSING,
+                    {
+                        "option_names": ["device"],
+                        "option_type": None,
+                    },
+                ),
+                (
+                    Severities.ERROR,
+                    reports.codes.INVALID_OPTIONS,
+                    {
+                        "option_names": ["another_one", "unknown_option"],
+                        "option_type": None,
+                        "allowed": sorted(allowed_options),
+                        "allowed_patterns": [],
+                    },
+                ),
+            ]
+            + [
                 self.fixture_invalid_value(opt, option_dict[opt])
                 for opt in allowed_options
-            ]
+            ],
         )
 
 
@@ -550,17 +578,17 @@ class GetLocalDevicesInfoTest(CommonTest):
     @staticmethod
     def fixture_sbd_enabled(enabled):
         cmd = [settings.systemctl_binary, "is-enabled", "sbd.service"]
-        return [Call(" ".join(cmd), returncode=0 if enabled else 1)]
+        return [Call(cmd, returncode=0 if enabled else 1)]
 
     @staticmethod
     def fixture_sbd_info(device, stdout="", return_code=0):
         cmd = ["sbd", "-d", device, "list"]
-        return [Call(" ".join(cmd), stdout, returncode=return_code)]
+        return [Call(cmd, stdout, returncode=return_code)]
 
     @staticmethod
     def fixture_sbd_dump(device, stdout="", return_code=0):
         cmd = ["sbd", "-d", device, "dump"]
-        return [Call(" ".join(cmd), stdout, returncode=return_code)]
+        return [Call(cmd, stdout, returncode=return_code)]
 
     def test_success(self, mock_config, mock_config_exists):
         mock_config_exists.return_value = True
@@ -568,9 +596,9 @@ class GetLocalDevicesInfoTest(CommonTest):
 SBD_DEVICE="/dev1;/dev2"
         """
         runner.set_runs(
-            self.fixture_sbd_enabled(True) +
-            self.fixture_sbd_info("/dev1", "1") +
-            self.fixture_sbd_info("/dev2", "2")
+            self.fixture_sbd_enabled(True)
+            + self.fixture_sbd_info("/dev1", "1")
+            + self.fixture_sbd_info("/dev2", "2")
         )
         expected_output = [
             {
@@ -597,11 +625,11 @@ SBD_DEVICE="/dev1;/dev2"
 SBD_DEVICE="/dev1;/dev2"
         """
         runner.set_runs(
-            self.fixture_sbd_enabled(True) +
-            self.fixture_sbd_info("/dev1", "1") +
-            self.fixture_sbd_dump("/dev1", "3") +
-            self.fixture_sbd_info("/dev2", "2") +
-            self.fixture_sbd_dump("/dev2", "4")
+            self.fixture_sbd_enabled(True)
+            + self.fixture_sbd_info("/dev1", "1")
+            + self.fixture_sbd_dump("/dev1", "3")
+            + self.fixture_sbd_info("/dev2", "2")
+            + self.fixture_sbd_dump("/dev2", "4")
         )
         expected_output = [
             {
@@ -644,12 +672,12 @@ SBD_DEVICE="/dev1;/dev2"
 SBD_DEVICE="/dev1;/dev2;/dev3"
         """
         runner.set_runs(
-            self.fixture_sbd_enabled(True) +
-            self.fixture_sbd_info("/dev1", "1", 1) +
-            self.fixture_sbd_info("/dev2", "2") +
-            self.fixture_sbd_dump("/dev2", "4", 1) +
-            self.fixture_sbd_info("/dev3", "5") +
-            self.fixture_sbd_dump("/dev3", "6")
+            self.fixture_sbd_enabled(True)
+            + self.fixture_sbd_info("/dev1", "1", 1)
+            + self.fixture_sbd_info("/dev2", "2")
+            + self.fixture_sbd_dump("/dev2", "4", 1)
+            + self.fixture_sbd_info("/dev3", "5")
+            + self.fixture_sbd_dump("/dev3", "6")
         )
         expected_output = [
             {
@@ -671,24 +699,20 @@ SBD_DEVICE="/dev1;/dev2;/dev3"
         self.assertEqual(
             expected_output, cmd_sbd.get_local_devices_info(self.env, dump=True)
         )
-        self.env.report_processor.assert_reports([
-            (
-                Severities.WARNING,
-                report_codes.SBD_DEVICE_LIST_ERROR,
-                {
-                    "device": "/dev1",
-                    "reason": "1"
-                }
-            ),
-            (
-                Severities.WARNING,
-                report_codes.SBD_DEVICE_DUMP_ERROR,
-                {
-                    "device": "/dev2",
-                    "reason": "4"
-                }
-            ),
-        ])
+        self.env.report_processor.assert_reports(
+            [
+                (
+                    Severities.WARNING,
+                    reports.codes.SBD_DEVICE_LIST_ERROR,
+                    {"device": "/dev1", "reason": "1"},
+                ),
+                (
+                    Severities.WARNING,
+                    reports.codes.SBD_DEVICE_DUMP_ERROR,
+                    {"device": "/dev2", "reason": "4"},
+                ),
+            ]
+        )
         runner.assert_everything_launched()
         mock_config.assert_called_once_with()
         mock_config_exists.assert_called_once_with(settings.sbd_config)
@@ -699,44 +723,56 @@ class SetMessageTest(CommonTest):
     def fixture_call_sbd_message(
         device, node, message, stderr="", return_code=0
     ):
-        return [Call(
-            "sbd -d {0} message {1} {2}".format(device, node, message),
-            stderr=stderr,
-            returncode=return_code
-        )]
+        return [
+            Call(
+                ["sbd", "-d", device, "message", node, message],
+                stderr=stderr,
+                returncode=return_code,
+            )
+        ]
 
     def test_empty_options(self):
         assert_raise_library_error(
-            lambda: cmd_sbd.set_message(self.env, "", "", ""),
-            (
-                Severities.ERROR,
-                report_codes.REQUIRED_OPTIONS_ARE_MISSING,
-                {
-                    "option_names": ["device", "node"],
-                    "option_type": None,
-                }
-            ),
-            fixture.error(
-                report_codes.INVALID_OPTION_VALUE,
-                option_name="message",
-                option_value="",
-                allowed_values=settings.sbd_message_types,
-                cannot_be_empty=False,
-                forbidden_characters=None,
-            )
+            lambda: cmd_sbd.set_message(self.env, "", "", "")
+        )
+        assert_report_item_list_equal(
+            self.env.report_processor.report_item_list,
+            [
+                (
+                    Severities.ERROR,
+                    reports.codes.REQUIRED_OPTIONS_ARE_MISSING,
+                    {
+                        "option_names": ["device", "node"],
+                        "option_type": None,
+                    },
+                ),
+                fixture.error(
+                    reports.codes.INVALID_OPTION_VALUE,
+                    option_name="message",
+                    option_value="",
+                    allowed_values=settings.sbd_message_types,
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
+            ],
         )
 
     def test_invalid_message_type(self):
         assert_raise_library_error(
-            lambda: cmd_sbd.set_message(self.env, "device", "node1", "message"),
-            fixture.error(
-                report_codes.INVALID_OPTION_VALUE,
-                option_name="message",
-                option_value="message",
-                allowed_values=settings.sbd_message_types,
-                cannot_be_empty=False,
-                forbidden_characters=None,
-            )
+            lambda: cmd_sbd.set_message(self.env, "device", "node1", "message")
+        )
+        assert_report_item_list_equal(
+            self.env.report_processor.report_item_list,
+            [
+                fixture.error(
+                    reports.codes.INVALID_OPTION_VALUE,
+                    option_name="message",
+                    option_value="message",
+                    allowed_values=settings.sbd_message_types,
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                )
+            ],
         )
 
     def test_success(self):
@@ -752,13 +788,13 @@ class SetMessageTest(CommonTest):
             lambda: cmd_sbd.set_message(self.env, "device", "node", "test"),
             (
                 Severities.ERROR,
-                report_codes.SBD_DEVICE_MESSAGE_ERROR,
+                reports.codes.SBD_DEVICE_MESSAGE_ERROR,
                 {
                     "device": "device",
                     "node": "node",
-                    "message": "test",
+                    "sbd_message": "test",
                     "reason": "error",
-                }
-            )
+                },
+            ),
         )
         runner.assert_everything_launched()
