@@ -1,33 +1,70 @@
 from textwrap import dedent
-from unittest import mock, TestCase
+from unittest import TestCase
 
 from pcs import settings
-from pcs.common import file_type_codes, report_codes
+from pcs.common import file_type_codes
+from pcs.common.reports import codes as report_codes
 from pcs.lib.commands import status
 from pcs_test.tools import fixture
 from pcs_test.tools.command_env import get_env_tools
 from pcs_test.tools.misc import read_test_resource as rc_read
 
-crm_mon_rng_with_history = rc_read("crm_mon.rng.with_fence_history.xml")
-crm_mon_rng_without_history = rc_read("crm_mon.rng.without_fence_history.xml")
 
 class FullClusterStatusPlaintext(TestCase):
+    # pylint: disable=too-many-public-methods
     def setUp(self):
         self.env_assist, self.config = get_env_tools(self)
         self.node_name_list = ["node1", "node2", "node3"]
         self.maxDiff = None
 
+    @staticmethod
+    def _fixture_xml_clustername(name):
+        return """
+            <crm_config>
+                <cluster_property_set id="cib-bootstrap-options">
+                    <nvpair
+                        id="cib-bootstrap-options-cluster-name"
+                        name="cluster-name" value="{name}"
+                    />
+                </cluster_property_set>
+            </crm_config>
+            """.format(
+            name=name
+        )
+
     def _fixture_config_live_minimal(self):
-        (self.config
-            .runner.pcmk.load_state_plaintext(
+        (
+            self.config.runner.pcmk.load_state_plaintext(
                 stdout="crm_mon cluster status",
             )
+            .fs.exists(settings.corosync_conf_file, return_value=True)
             .corosync_conf.load()
-            .runner.cib.load(resources="""
+            .runner.cib.load(
+                resources="""
                 <resources>
                     <primitive id="S" class="stonith" type="fence_dummy" />
                 </resources>
-            """)
+            """
+            )
+            .runner.systemctl.is_active(
+                "sbd", is_active=False, name="runner.systemctl.is_active.sbd"
+            )
+        )
+
+    def _fixture_config_live_remote_minimal(self):
+        (
+            self.config.runner.pcmk.load_state_plaintext(
+                stdout="crm_mon cluster status",
+            )
+            .fs.exists(settings.corosync_conf_file, return_value=False)
+            .runner.cib.load(
+                optional_in_conf=self._fixture_xml_clustername("test-cib"),
+                resources="""
+                <resources>
+                    <primitive id="S" class="stonith" type="fence_dummy" />
+                </resources>
+            """,
+            )
             .runner.systemctl.is_active(
                 "sbd", is_active=False, name="runner.systemctl.is_active.sbd"
             )
@@ -35,15 +72,20 @@ class FullClusterStatusPlaintext(TestCase):
 
     def _fixture_config_local_daemons(
         self,
-        corosync_enabled=True, corosync_active=True,
-        pacemaker_enabled=True, pacemaker_active=True,
-        pacemaker_remote_enabled=False, pacemaker_remote_active=False,
-        pcsd_enabled=True, pcsd_active=True,
-        sbd_enabled=False, sbd_active=False,
+        corosync_enabled=True,
+        corosync_active=True,
+        pacemaker_enabled=True,
+        pacemaker_active=True,
+        pacemaker_remote_enabled=False,
+        pacemaker_remote_active=False,
+        pcsd_enabled=True,
+        pcsd_active=True,
+        sbd_enabled=False,
+        sbd_active=False,
     ):
         # pylint: disable=too-many-arguments
-        (self.config
-            .runner.systemctl.is_enabled(
+        (
+            self.config.runner.systemctl.is_enabled(
                 "corosync",
                 name="runner.systemctl.is_enabled.corosync",
                 is_enabled=corosync_enabled,
@@ -108,7 +150,7 @@ class FullClusterStatusPlaintext(TestCase):
                     required_files=[file_type_codes.CIB],
                 ),
             ],
-            expected_in_processor=False
+            expected_in_processor=False,
         )
 
     def test_mocked_cib_life_corosync(self):
@@ -124,12 +166,12 @@ class FullClusterStatusPlaintext(TestCase):
                     required_files=[file_type_codes.COROSYNC_CONF],
                 ),
             ],
-            expected_in_processor=False
+            expected_in_processor=False,
         )
 
     def test_fail_getting_cluster_status(self):
-        (self.config
-            .runner.pcmk.load_state_plaintext(
+        (
+            self.config.runner.pcmk.load_state_plaintext(
                 stdout="some stdout",
                 stderr="some stderr",
                 returncode=1,
@@ -145,34 +187,36 @@ class FullClusterStatusPlaintext(TestCase):
                     reason="some stderr\nsome stdout",
                 ),
             ],
-            expected_in_processor=False
+            expected_in_processor=False,
         )
 
     def test_fail_getting_corosync_conf(self):
-        (self.config
-            .runner.pcmk.load_state_plaintext(
+        (
+            self.config.runner.pcmk.load_state_plaintext(
                 stdout="crm_mon cluster status",
             )
+            .fs.exists(settings.corosync_conf_file, return_value=True)
             .corosync_conf.load_content("invalid corosync conf")
         )
         self.env_assist.assert_raise_library_error(
             lambda: status.full_cluster_status_plaintext(
                 self.env_assist.get_env()
-            ),
+            )
+        )
+        self.env_assist.assert_reports(
             [
                 fixture.error(
-                    # pylint: disable=line-too-long
                     report_codes.PARSE_ERROR_COROSYNC_CONF_LINE_IS_NOT_SECTION_NOR_KEY_VALUE,
                 ),
-            ],
-            expected_in_processor=False
+            ]
         )
 
     def test_fail_getting_cib(self):
-        (self.config
-            .runner.pcmk.load_state_plaintext(
+        (
+            self.config.runner.pcmk.load_state_plaintext(
                 stdout="crm_mon cluster status",
             )
+            .fs.exists(settings.corosync_conf_file, return_value=True)
             .corosync_conf.load()
             .runner.cib.load_content(
                 "some stdout", stderr="cib load error", returncode=1
@@ -188,17 +232,16 @@ class FullClusterStatusPlaintext(TestCase):
                     reason="cib load error",
                 ),
             ],
-            expected_in_processor=False
+            expected_in_processor=False,
         )
 
     def test_success_live(self):
         self._fixture_config_live_minimal()
         self._fixture_config_local_daemons()
         self.assertEqual(
-            status.full_cluster_status_plaintext(
-                self.env_assist.get_env()
-            ),
-            dedent("""\
+            status.full_cluster_status_plaintext(self.env_assist.get_env()),
+            dedent(
+                """\
                 Cluster name: test99
                 crm_mon cluster status
 
@@ -206,43 +249,44 @@ class FullClusterStatusPlaintext(TestCase):
                   corosync: active/enabled
                   pacemaker: active/enabled
                   pcsd: active/enabled"""
-            )
+            ),
         )
 
     def test_success_live_verbose(self):
-        (self.config
-            .env.set_known_nodes(self.node_name_list)
-            .fs.open(
-                settings.crm_mon_schema,
-                mock.mock_open(read_data=crm_mon_rng_without_history)(),
-                name="fs.open.crm_mon_rng"
-            )
+        (
+            self.config.env.set_known_nodes(self.node_name_list)
+            .runner.pcmk.can_fence_history_status(stderr="not supported")
             .runner.pcmk.load_state_plaintext(
                 verbose=True,
                 stdout="crm_mon cluster status",
             )
+            .fs.exists(settings.corosync_conf_file, return_value=True)
             .corosync_conf.load(node_name_list=self.node_name_list)
-            .runner.cib.load(resources="""
+            .runner.cib.load(
+                resources="""
                 <resources>
                     <primitive id="S" class="stonith" type="fence_dummy" />
                 </resources>
-            """)
+            """
+            )
             .runner.pcmk.load_ticket_state_plaintext(stdout="ticket status")
             .runner.systemctl.is_active(
                 "sbd", is_active=False, name="runner.systemctl.is_active.sbd"
             )
         )
         self._fixture_config_local_daemons()
-        (self.config
-            .http.host.check_reachability(node_labels=self.node_name_list)
+        (
+            self.config.http.host.check_reachability(
+                node_labels=self.node_name_list
+            )
         )
 
         self.assertEqual(
             status.full_cluster_status_plaintext(
-                self.env_assist.get_env(),
-                verbose=True
+                self.env_assist.get_env(), verbose=True
             ),
-            dedent("""\
+            dedent(
+                """\
                 Cluster name: test99
                 crm_mon cluster status
 
@@ -258,93 +302,171 @@ class FullClusterStatusPlaintext(TestCase):
                   corosync: active/enabled
                   pacemaker: active/enabled
                   pcsd: active/enabled"""
+            ),
+        )
+
+    def test_success_live_remote_node(self):
+        self._fixture_config_live_remote_minimal()
+        self._fixture_config_local_daemons(
+            corosync_enabled=False,
+            corosync_active=False,
+            pacemaker_enabled=False,
+            pacemaker_active=False,
+            pacemaker_remote_enabled=True,
+            pacemaker_remote_active=True,
+        )
+        self.assertEqual(
+            status.full_cluster_status_plaintext(self.env_assist.get_env()),
+            dedent(
+                """\
+                Cluster name: test-cib
+                crm_mon cluster status
+
+                Daemon Status:
+                  corosync: inactive/disabled
+                  pacemaker: inactive/disabled
+                  pacemaker_remote: active/enabled
+                  pcsd: active/enabled"""
+            ),
+        )
+
+    def test_success_live_remote_node_verbose(self):
+        (
+            self.config.runner.pcmk.can_fence_history_status(
+                stderr="not supported"
             )
+            .runner.pcmk.load_state_plaintext(
+                verbose=True,
+                stdout="crm_mon cluster status",
+            )
+            .fs.exists(settings.corosync_conf_file, return_value=False)
+            .runner.cib.load(
+                optional_in_conf=self._fixture_xml_clustername("test-cib"),
+                resources="""
+                <resources>
+                    <primitive id="S" class="stonith" type="fence_dummy" />
+                </resources>
+            """,
+            )
+            .runner.pcmk.load_ticket_state_plaintext(stdout="ticket status")
+            .runner.systemctl.is_active(
+                "sbd", is_active=False, name="runner.systemctl.is_active.sbd"
+            )
+        )
+        self._fixture_config_local_daemons(
+            corosync_enabled=False,
+            corosync_active=False,
+            pacemaker_enabled=False,
+            pacemaker_active=False,
+            pacemaker_remote_enabled=True,
+            pacemaker_remote_active=True,
+        )
+
+        self.assertEqual(
+            status.full_cluster_status_plaintext(
+                self.env_assist.get_env(), verbose=True
+            ),
+            dedent(
+                """\
+                Cluster name: test-cib
+                crm_mon cluster status
+
+                Tickets:
+                  ticket status
+
+                Daemon Status:
+                  corosync: inactive/disabled
+                  pacemaker: inactive/disabled
+                  pacemaker_remote: active/enabled
+                  pcsd: active/enabled"""
+            ),
         )
 
     def test_succes_mocked(self):
-        (self.config
-            .env.set_corosync_conf_data(rc_read("corosync.conf"))
+        (
+            self.config.env.set_corosync_conf_data(rc_read("corosync.conf"))
             .env.set_cib_data("<cib/>")
             .runner.pcmk.load_state_plaintext(
                 stdout="crm_mon cluster status",
             )
-            .runner.cib.load(resources="""
+            .runner.cib.load(
+                resources="""
                 <resources>
                     <primitive id="S" class="stonith" type="fence_dummy" />
                 </resources>
-            """)
+            """
+            )
         )
         self.assertEqual(
-            status.full_cluster_status_plaintext(
-                self.env_assist.get_env()
-            ),
-            dedent("""\
+            status.full_cluster_status_plaintext(self.env_assist.get_env()),
+            dedent(
+                """\
                 Cluster name: test99
                 crm_mon cluster status"""
-            )
+            ),
         )
 
     def test_succes_mocked_verbose(self):
-        (self.config
-            .env.set_corosync_conf_data(rc_read("corosync.conf"))
+        (
+            self.config.env.set_corosync_conf_data(rc_read("corosync.conf"))
             .env.set_cib_data("<cib/>")
-            .fs.open(
-                settings.crm_mon_schema,
-                mock.mock_open(read_data=crm_mon_rng_without_history)(),
-                name="fs.open.crm_mon_rng"
-            )
+            .runner.pcmk.can_fence_history_status(stderr="not supported")
             .runner.pcmk.load_state_plaintext(
-                verbose=True, stdout="crm_mon cluster status",
+                verbose=True,
+                stdout="crm_mon cluster status",
             )
-            .runner.cib.load(resources="""
+            .runner.cib.load(
+                resources="""
                 <resources>
                     <primitive id="S" class="stonith" type="fence_dummy" />
                 </resources>
-            """)
+            """
+            )
             .runner.pcmk.load_ticket_state_plaintext(stdout="ticket status")
         )
         self.assertEqual(
             status.full_cluster_status_plaintext(
-                self.env_assist.get_env(),
-                verbose=True
+                self.env_assist.get_env(), verbose=True
             ),
-            dedent("""\
+            dedent(
+                """\
                 Cluster name: test99
                 crm_mon cluster status
 
                 Tickets:
                   ticket status"""
-            )
+            ),
         )
 
     def test_success_verbose_inactive_and_fence_history(self):
-        (self.config
-            .env.set_known_nodes(self.node_name_list)
-            .fs.open(
-                settings.crm_mon_schema,
-                mock.mock_open(read_data=crm_mon_rng_with_history)(),
-                name="fs.open.crm_mon_rng"
-            )
+        (
+            self.config.env.set_known_nodes(self.node_name_list)
+            .runner.pcmk.can_fence_history_status()
             .runner.pcmk.load_state_plaintext(
                 verbose=True,
                 inactive=False,
                 fence_history=True,
                 stdout="crm_mon cluster status",
             )
+            .fs.exists(settings.corosync_conf_file, return_value=True)
             .corosync_conf.load(node_name_list=self.node_name_list)
-            .runner.cib.load(resources="""
+            .runner.cib.load(
+                resources="""
                 <resources>
                     <primitive id="S" class="stonith" type="fence_dummy" />
                 </resources>
-            """)
+            """
+            )
             .runner.pcmk.load_ticket_state_plaintext(stdout="ticket status")
             .runner.systemctl.is_active(
                 "sbd", is_active=False, name="runner.systemctl.is_active.sbd"
             )
         )
         self._fixture_config_local_daemons()
-        (self.config
-            .http.host.check_reachability(node_labels=self.node_name_list)
+        (
+            self.config.http.host.check_reachability(
+                node_labels=self.node_name_list
+            )
         )
 
         self.assertEqual(
@@ -353,7 +475,8 @@ class FullClusterStatusPlaintext(TestCase):
                 verbose=True,
                 hide_inactive_resources=True,
             ),
-            dedent("""\
+            dedent(
+                """\
                 Cluster name: test99
                 crm_mon cluster status
 
@@ -369,27 +492,26 @@ class FullClusterStatusPlaintext(TestCase):
                   corosync: active/enabled
                   pacemaker: active/enabled
                   pcsd: active/enabled"""
-            )
+            ),
         )
 
     def _assert_success_with_ticket_status_failure(self, stderr="", msg=""):
-        (self.config
-            .env.set_known_nodes(self.node_name_list)
-            .fs.open(
-                settings.crm_mon_schema,
-                mock.mock_open(read_data=crm_mon_rng_without_history)(),
-                name="fs.open.crm_mon_rng"
-            )
+        (
+            self.config.env.set_known_nodes(self.node_name_list)
+            .runner.pcmk.can_fence_history_status(stderr="not supported")
             .runner.pcmk.load_state_plaintext(
                 verbose=True,
                 stdout="crm_mon cluster status",
             )
+            .fs.exists(settings.corosync_conf_file, return_value=True)
             .corosync_conf.load(node_name_list=self.node_name_list)
-            .runner.cib.load(resources="""
+            .runner.cib.load(
+                resources="""
                 <resources>
                     <primitive id="S" class="stonith" type="fence_dummy" />
                 </resources>
-            """)
+            """
+            )
             .runner.pcmk.load_ticket_state_plaintext(
                 stdout="ticket stdout", stderr=stderr, returncode=1
             )
@@ -398,16 +520,18 @@ class FullClusterStatusPlaintext(TestCase):
             )
         )
         self._fixture_config_local_daemons()
-        (self.config
-            .http.host.check_reachability(node_labels=self.node_name_list)
+        (
+            self.config.http.host.check_reachability(
+                node_labels=self.node_name_list
+            )
         )
 
         self.assertEqual(
             status.full_cluster_status_plaintext(
-                self.env_assist.get_env(),
-                verbose=True
+                self.env_assist.get_env(), verbose=True
             ),
-            dedent("""\
+            dedent(
+                """\
                 Cluster name: test99
                 crm_mon cluster status
 
@@ -423,7 +547,7 @@ class FullClusterStatusPlaintext(TestCase):
                   corosync: active/enabled
                   pacemaker: active/enabled
                   pcsd: active/enabled"""
-            ).format(msg=msg)
+            ).format(msg=msg),
         )
 
     def test_success_with_ticket_status_failure(self):
@@ -436,10 +560,11 @@ class FullClusterStatusPlaintext(TestCase):
         )
 
     def test_stonith_warning_no_devices(self):
-        (self.config
-            .runner.pcmk.load_state_plaintext(
+        (
+            self.config.runner.pcmk.load_state_plaintext(
                 stdout="crm_mon cluster status",
             )
+            .fs.exists(settings.corosync_conf_file, return_value=True)
             .corosync_conf.load()
             .runner.cib.load()
             .runner.systemctl.is_active(
@@ -449,10 +574,9 @@ class FullClusterStatusPlaintext(TestCase):
         self._fixture_config_local_daemons()
 
         self.assertEqual(
-            status.full_cluster_status_plaintext(
-                self.env_assist.get_env()
-            ),
-            dedent("""\
+            status.full_cluster_status_plaintext(self.env_assist.get_env()),
+            dedent(
+                """\
                 Cluster name: test99
 
                 WARNINGS:
@@ -464,14 +588,15 @@ class FullClusterStatusPlaintext(TestCase):
                   corosync: active/enabled
                   pacemaker: active/enabled
                   pcsd: active/enabled"""
-            )
+            ),
         )
 
     def test_stonith_warning_no_devices_sbd_enabled(self):
-        (self.config
-            .runner.pcmk.load_state_plaintext(
+        (
+            self.config.runner.pcmk.load_state_plaintext(
                 stdout="crm_mon cluster status",
             )
+            .fs.exists(settings.corosync_conf_file, return_value=True)
             .corosync_conf.load()
             .runner.cib.load()
             .runner.systemctl.is_active(
@@ -481,10 +606,9 @@ class FullClusterStatusPlaintext(TestCase):
         self._fixture_config_local_daemons()
 
         self.assertEqual(
-            status.full_cluster_status_plaintext(
-                self.env_assist.get_env()
-            ),
-            dedent("""\
+            status.full_cluster_status_plaintext(self.env_assist.get_env()),
+            dedent(
+                """\
                 Cluster name: test99
                 crm_mon cluster status
 
@@ -492,16 +616,18 @@ class FullClusterStatusPlaintext(TestCase):
                   corosync: active/enabled
                   pacemaker: active/enabled
                   pcsd: active/enabled"""
-            )
+            ),
         )
 
     def test_stonith_warnings_regarding_devices_configuration(self):
-        (self.config
-            .runner.pcmk.load_state_plaintext(
+        (
+            self.config.runner.pcmk.load_state_plaintext(
                 stdout="crm_mon cluster status",
             )
+            .fs.exists(settings.corosync_conf_file, return_value=True)
             .corosync_conf.load()
-            .runner.cib.load(resources="""
+            .runner.cib.load(
+                resources="""
                 <resources>
                     <primitive id="S1" class="stonith" type="fence_dummy">
                         <instance_attributes>
@@ -521,7 +647,8 @@ class FullClusterStatusPlaintext(TestCase):
                         </instance_attributes>
                     </primitive>
                 </resources>
-            """)
+            """
+            )
             .runner.systemctl.is_active(
                 "sbd", is_active=False, name="runner.systemctl.is_active.sbd"
             )
@@ -529,10 +656,10 @@ class FullClusterStatusPlaintext(TestCase):
         self._fixture_config_local_daemons()
 
         self.assertEqual(
-            status.full_cluster_status_plaintext(
-                self.env_assist.get_env()
-            ),
-            dedent("""\
+            # pylint: disable=line-too-long
+            status.full_cluster_status_plaintext(self.env_assist.get_env()),
+            dedent(
+                """\
                 Cluster name: test99
 
                 WARNINGS:
@@ -545,66 +672,67 @@ class FullClusterStatusPlaintext(TestCase):
                   corosync: active/enabled
                   pacemaker: active/enabled
                   pcsd: active/enabled"""
-            )
+            ),
         )
 
     def test_pcsd_status_issues(self):
         self.node_name_list = ["node1", "node2", "node3", "node4", "node5"]
 
-        (self.config
-            .env.set_known_nodes(self.node_name_list[1:])
-            .fs.open(
-                settings.crm_mon_schema,
-                mock.mock_open(read_data=crm_mon_rng_without_history)(),
-                name="fs.open.crm_mon_rng"
-            )
+        (
+            self.config.env.set_known_nodes(self.node_name_list[1:])
+            .runner.pcmk.can_fence_history_status(stderr="not supported")
             .runner.pcmk.load_state_plaintext(
                 verbose=True,
                 stdout="crm_mon cluster status",
             )
+            .fs.exists(settings.corosync_conf_file, return_value=True)
             .corosync_conf.load(node_name_list=self.node_name_list)
-            .runner.cib.load(resources="""
+            .runner.cib.load(
+                resources="""
                 <resources>
                     <primitive id="S" class="stonith" type="fence_dummy" />
                 </resources>
-            """)
+            """
+            )
             .runner.pcmk.load_ticket_state_plaintext(stdout="ticket status")
             .runner.systemctl.is_active(
                 "sbd", is_active=False, name="runner.systemctl.is_active.sbd"
             )
         )
         self._fixture_config_local_daemons()
-        (self.config
-            .http.host.check_reachability(communication_list=[
-                # node1 has no record in known-hosts
-                dict(
-                    label="node2",
-                    was_connected=False,
-                    errno=7,
-                    error_msg="node2 error"
-                ),
-                dict(
-                    label="node3",
-                    response_code=401,
-                    output="node3 output",
-                ),
-                dict(
-                    label="node4",
-                    response_code=500,
-                    output="node4 output",
-                ),
-                dict(
-                    label="node5",
-                )
-            ])
+        (
+            self.config.http.host.check_reachability(
+                communication_list=[
+                    # node1 has no record in known-hosts
+                    dict(
+                        label="node2",
+                        was_connected=False,
+                        errno=7,
+                        error_msg="node2 error",
+                    ),
+                    dict(
+                        label="node3",
+                        response_code=401,
+                        output="node3 output",
+                    ),
+                    dict(
+                        label="node4",
+                        response_code=500,
+                        output="node4 output",
+                    ),
+                    dict(
+                        label="node5",
+                    ),
+                ]
+            )
         )
 
         self.assertEqual(
             status.full_cluster_status_plaintext(
-                self.env_assist.get_env(),
-                verbose=True
+                self.env_assist.get_env(), verbose=True
             ),
-            dedent("""\
+            dedent(
+                """\
                 Cluster name: test99
                 crm_mon cluster status
 
@@ -622,23 +750,27 @@ class FullClusterStatusPlaintext(TestCase):
                   corosync: active/enabled
                   pacemaker: active/enabled
                   pcsd: active/enabled"""
-            )
+            ),
         )
 
     def test_daemon_status_all_on(self):
         self._fixture_config_live_minimal()
         self._fixture_config_local_daemons(
-            corosync_enabled=True, corosync_active=True,
-            pacemaker_enabled=True, pacemaker_active=True,
-            pacemaker_remote_enabled=True, pacemaker_remote_active=True,
-            pcsd_enabled=True, pcsd_active=True,
-            sbd_enabled=True, sbd_active=True,
+            corosync_enabled=True,
+            corosync_active=True,
+            pacemaker_enabled=True,
+            pacemaker_active=True,
+            pacemaker_remote_enabled=True,
+            pacemaker_remote_active=True,
+            pcsd_enabled=True,
+            pcsd_active=True,
+            sbd_enabled=True,
+            sbd_active=True,
         )
         self.assertEqual(
-            status.full_cluster_status_plaintext(
-                self.env_assist.get_env()
-            ),
-            dedent("""\
+            status.full_cluster_status_plaintext(self.env_assist.get_env()),
+            dedent(
+                """\
                 Cluster name: test99
                 crm_mon cluster status
 
@@ -648,23 +780,27 @@ class FullClusterStatusPlaintext(TestCase):
                   pacemaker_remote: active/enabled
                   pcsd: active/enabled
                   sbd: active/enabled"""
-            )
+            ),
         )
 
     def test_daemon_status_all_off(self):
         self._fixture_config_live_minimal()
         self._fixture_config_local_daemons(
-            corosync_enabled=False, corosync_active=False,
-            pacemaker_enabled=False, pacemaker_active=False,
-            pacemaker_remote_enabled=False, pacemaker_remote_active=False,
-            pcsd_enabled=False, pcsd_active=False,
-            sbd_enabled=False, sbd_active=False,
+            corosync_enabled=False,
+            corosync_active=False,
+            pacemaker_enabled=False,
+            pacemaker_active=False,
+            pacemaker_remote_enabled=False,
+            pacemaker_remote_active=False,
+            pcsd_enabled=False,
+            pcsd_active=False,
+            sbd_enabled=False,
+            sbd_active=False,
         )
         self.assertEqual(
-            status.full_cluster_status_plaintext(
-                self.env_assist.get_env()
-            ),
-            dedent("""\
+            status.full_cluster_status_plaintext(self.env_assist.get_env()),
+            dedent(
+                """\
                 Cluster name: test99
                 crm_mon cluster status
 
@@ -672,5 +808,5 @@ class FullClusterStatusPlaintext(TestCase):
                   corosync: inactive/disabled
                   pacemaker: inactive/disabled
                   pcsd: inactive/disabled"""
-            )
+            ),
         )
