@@ -1,10 +1,12 @@
 from functools import partial
-from unittest import TestCase
+from unittest import mock, TestCase
 
 from pcs_test.tools import fixture
 from pcs_test.tools.command_env import get_env_tools
+from pcs_test.tools.misc import get_test_resource as rc
 
-from pcs.common import report_codes
+from pcs import settings
+from pcs.common.reports import codes as report_codes
 from pcs.lib.commands import stonith
 from pcs.lib.resource_agent import StonithAgent
 
@@ -84,7 +86,8 @@ expected_cib_unknown = """
     </primitive>
 """
 
-class CreateMixin():
+
+class CreateMixin:
     def setUp(self):
         # pylint does not know this method is defined in TestCase
         # pylint: disable=invalid-name
@@ -99,10 +102,10 @@ class CreateMixin():
     def test_minimal_success(self):
         agent_name = "test_simple"
 
-        (self.config
-            .runner.pcmk.load_agent(
+        (
+            self.config.runner.pcmk.load_agent(
                 agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_simple.xml"
+                agent_filename="stonith_agent_fence_simple.xml",
             )
             .runner.cib.load()
             .runner.pcmk.load_fenced_metadata()
@@ -118,16 +121,16 @@ class CreateMixin():
             instance_attributes={
                 "must-set": "value",
                 "must-set-new": "B",
-            }
+            },
         )
 
     def test_unfencing(self):
         agent_name = "test_unfencing"
 
-        (self.config
-            .runner.pcmk.load_agent(
+        (
+            self.config.runner.pcmk.load_agent(
                 agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_unfencing.xml"
+                agent_filename="stonith_agent_fence_unfencing.xml",
             )
             .runner.cib.load()
             .runner.pcmk.load_fenced_metadata()
@@ -140,7 +143,7 @@ class CreateMixin():
             agent_name,
             operations=[],
             meta_attributes={},
-            instance_attributes={}
+            instance_attributes={},
         )
 
     def test_disabled(self):
@@ -154,13 +157,13 @@ class CreateMixin():
                     />
                 </meta_attributes>
                 <instance_attributes id="stonith-test-instance_attributes">
-            """
+            """,
         )
 
-        (self.config
-            .runner.pcmk.load_agent(
+        (
+            self.config.runner.pcmk.load_agent(
                 agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_simple.xml"
+                agent_filename="stonith_agent_fence_simple.xml",
             )
             .runner.cib.load()
             .runner.pcmk.load_fenced_metadata()
@@ -177,7 +180,7 @@ class CreateMixin():
                 "must-set": "value",
                 "must-set-new": "B",
             },
-            ensure_disabled=True
+            ensure_disabled=True,
         )
 
     def _assert_default_operations(self, use_default_operations):
@@ -187,10 +190,10 @@ class CreateMixin():
         # updated to test new behaviour.
         agent_name = "test_custom_actions"
 
-        (self.config
-            .runner.pcmk.load_agent(
+        (
+            self.config.runner.pcmk.load_agent(
                 agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_custom_actions.xml"
+                agent_filename="stonith_agent_fence_custom_actions.xml",
             )
             .runner.cib.load()
             .runner.pcmk.load_fenced_metadata()
@@ -204,7 +207,7 @@ class CreateMixin():
             operations=[],
             meta_attributes={},
             instance_attributes={},
-            use_default_operations=use_default_operations
+            use_default_operations=use_default_operations,
         )
 
     def test_default_operations_yes(self):
@@ -216,12 +219,11 @@ class CreateMixin():
     def test_id_already_exists(self):
         agent_name = "test_simple"
 
-        (self.config
-            .runner.pcmk.load_agent(
+        (
+            self.config.runner.pcmk.load_agent(
                 agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_simple.xml"
-            )
-            .runner.cib.load(resources=self._expected_cib(expected_cib_simple))
+                agent_filename="stonith_agent_fence_simple.xml",
+            ).runner.cib.load(resources=self._expected_cib(expected_cib_simple))
         )
 
         self.env_assist.assert_raise_library_error(
@@ -234,21 +236,19 @@ class CreateMixin():
                 instance_attributes={
                     "must-set": "value",
                     "must-set-new": "B",
-                }
+                },
             ),
-            [
-                fixture.error(report_codes.ID_ALREADY_EXISTS, id="stonith-test")
-            ],
-            expected_in_processor=False
+            [fixture.error(report_codes.ID_ALREADY_EXISTS, id="stonith-test")],
+            expected_in_processor=False,
         )
 
     def test_instance_meta_and_operations(self):
         agent_name = "test_simple"
 
-        (self.config
-            .runner.pcmk.load_agent(
+        (
+            self.config.runner.pcmk.load_agent(
                 agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_simple.xml"
+                agent_filename="stonith_agent_fence_simple.xml",
             )
             .runner.cib.load()
             .runner.pcmk.load_fenced_metadata()
@@ -267,54 +267,82 @@ class CreateMixin():
             meta_attributes={
                 "metaname": "metavalue",
             },
-            instance_attributes={
-                "undefined": "attribute"
-            },
+            instance_attributes={"undefined": "attribute"},
             allow_invalid_operation=True,
             allow_invalid_instance_attributes=True,
         )
 
-        self.env_assist.assert_reports([
-            fixture.warn(
-                report_codes.INVALID_OPTION_VALUE,
-                option_value="bad-action",
-                option_name="operation name",
-                allowed_values=[
-                    "on", "off", "reboot", "status", "list", "list-status",
-                    "monitor", "metadata", "validate-all",
-                ],
-            ),
-            fixture.warn(
-                report_codes.INVALID_OPTIONS,
-                option_names=["undefined"],
-                option_type="stonith",
-                allowed=[
-                    "may-set", "must-set", "must-set-new", "must-set-old",
-                    "pcmk_action_limit", "pcmk_delay_base", "pcmk_delay_max",
-                    "pcmk_host_argument", "pcmk_host_check", "pcmk_host_list",
-                    "pcmk_host_map", "pcmk_list_action", "pcmk_list_retries",
-                    "pcmk_list_timeout", "pcmk_monitor_action",
-                    "pcmk_monitor_retries", "pcmk_monitor_timeout",
-                    "pcmk_off_action", "pcmk_off_retries", "pcmk_off_timeout",
-                    "pcmk_on_action", "pcmk_on_retries", "pcmk_on_timeout",
-                    "pcmk_reboot_action", "pcmk_reboot_retries",
-                    "pcmk_reboot_timeout", "pcmk_status_action",
-                    "pcmk_status_retries", "pcmk_status_timeout", "priority",
-                ],
-                allowed_patterns=[]
-            ),
-            fixture.warn(
-                report_codes.REQUIRED_OPTIONS_ARE_MISSING,
-                option_names=["must-set", "must-set-new"],
-                option_type="stonith",
-            ),
-        ])
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    report_codes.INVALID_OPTION_VALUE,
+                    option_value="bad-action",
+                    option_name="operation name",
+                    allowed_values=[
+                        "on",
+                        "off",
+                        "reboot",
+                        "status",
+                        "list",
+                        "list-status",
+                        "monitor",
+                        "metadata",
+                        "validate-all",
+                    ],
+                    cannot_be_empty=False,
+                    forbidden_characters=None,
+                ),
+                fixture.warn(
+                    report_codes.INVALID_OPTIONS,
+                    option_names=["undefined"],
+                    option_type="stonith",
+                    allowed=[
+                        "may-set",
+                        "must-set",
+                        "must-set-new",
+                        "must-set-old",
+                        "pcmk_action_limit",
+                        "pcmk_delay_base",
+                        "pcmk_delay_max",
+                        "pcmk_host_argument",
+                        "pcmk_host_check",
+                        "pcmk_host_list",
+                        "pcmk_host_map",
+                        "pcmk_list_action",
+                        "pcmk_list_retries",
+                        "pcmk_list_timeout",
+                        "pcmk_monitor_action",
+                        "pcmk_monitor_retries",
+                        "pcmk_monitor_timeout",
+                        "pcmk_off_action",
+                        "pcmk_off_retries",
+                        "pcmk_off_timeout",
+                        "pcmk_on_action",
+                        "pcmk_on_retries",
+                        "pcmk_on_timeout",
+                        "pcmk_reboot_action",
+                        "pcmk_reboot_retries",
+                        "pcmk_reboot_timeout",
+                        "pcmk_status_action",
+                        "pcmk_status_retries",
+                        "pcmk_status_timeout",
+                        "priority",
+                    ],
+                    allowed_patterns=[],
+                ),
+                fixture.warn(
+                    report_codes.REQUIRED_OPTIONS_ARE_MISSING,
+                    option_names=["must-set", "must-set-new"],
+                    option_type="stonith",
+                ),
+            ]
+        )
 
     def test_unknown_agent_forced(self):
         agent_name = "test_unknown"
 
-        (self.config
-            .runner.pcmk.load_agent(
+        (
+            self.config.runner.pcmk.load_agent(
                 agent_name=f"stonith:{agent_name}",
                 agent_is_missing=True,
             )
@@ -332,19 +360,24 @@ class CreateMixin():
             allow_absent_agent=True,
         )
 
-        self.env_assist.assert_reports([
-            fixture.warn(
-                report_codes.UNABLE_TO_GET_AGENT_METADATA,
-                agent="test_unknown",
-                reason=(
-                    "Agent stonith:test_unknown not found or does not support "
-                        "meta-data: Invalid argument (22)\n"
-                    "Metadata query for stonith:test_unknown failed: "
+        self.env_assist.assert_reports(
+            [
+                fixture.warn(
+                    report_codes.UNABLE_TO_GET_AGENT_METADATA,
+                    agent="test_unknown",
+                    reason=(
+                        "Agent stonith:test_unknown not found or does not "
+                        "support meta-data: Invalid argument (22)\n"
+                        "Metadata query for stonith:test_unknown failed: "
                         "Input/output error"
-                )
-            ),
-        ])
+                    ),
+                ),
+            ]
+        )
 
+    @mock.patch.object(
+        settings, "crm_mon_schema", rc("crm_mon_rng/crm_mon.rng")
+    )
     def test_minimal_wait_ok_run_ok(self):
         agent_name = "test_simple"
         instance_name = "stonith-test"
@@ -362,19 +395,19 @@ class CreateMixin():
                     <node name="node1" id="1" cached="false"/>
                 </resource>
             </resources>
-            """.format(id=instance_name, agent=agent_name)
+            """.format(
+            id=instance_name, agent=agent_name
+        )
 
-        (self.config
-            .runner.pcmk.load_agent(
+        (
+            self.config.runner.pcmk.load_agent(
                 agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_simple.xml"
+                agent_filename="stonith_agent_fence_simple.xml",
             )
             .runner.cib.load()
             .runner.pcmk.load_fenced_metadata()
-            .runner.pcmk.can_wait(before="runner.cib.load")
             .env.push_cib(
-                resources=self._expected_cib(expected_cib_simple),
-                wait=timeout
+                resources=self._expected_cib(expected_cib_simple), wait=timeout
             )
             .runner.pcmk.load_state(resources=expected_status)
         )
@@ -389,15 +422,17 @@ class CreateMixin():
                 "must-set": "value",
                 "must-set-new": "B",
             },
-            wait=timeout
+            wait=timeout,
+        )
+        self.env_assist.assert_reports(
+            [
+                fixture.info(
+                    report_codes.RESOURCE_RUNNING_ON_NODES,
+                    roles_with_nodes={"Started": ["node1"]},
+                    resource_id=instance_name,
+                ),
+            ]
         )
-        self.env_assist.assert_reports([
-            fixture.info(
-                report_codes.RESOURCE_RUNNING_ON_NODES,
-                roles_with_nodes={"Started": ["node1"]},
-                resource_id=instance_name,
-            ),
-        ])
 
 
 class Create(CreateMixin, TestCase):
@@ -427,10 +462,10 @@ class CreateInGroup(CreateMixin, TestCase):
     def test_group_not_valid(self):
         agent_name = "test_simple"
 
-        (self.config
-            .runner.pcmk.load_agent(
+        (
+            self.config.runner.pcmk.load_agent(
                 agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_simple.xml"
+                agent_filename="stonith_agent_fence_simple.xml",
             )
             .runner.cib.load()
             .runner.pcmk.load_fenced_metadata()
@@ -447,47 +482,40 @@ class CreateInGroup(CreateMixin, TestCase):
                 instance_attributes={
                     "must-set": "value",
                     "must-set-new": "B",
-                }
+                },
             ),
             [
                 fixture.error(
-                    report_codes.INVALID_ID,
+                    report_codes.INVALID_ID_BAD_CHAR,
                     id="0-group",
                     id_description="group name",
                     is_first_char=True,
                     invalid_character="0",
                 )
             ],
-            expected_in_processor=False
+            expected_in_processor=False,
         )
 
     def _assert_adjacent(self, adjacent, after):
         agent_name = "test_simple"
         original_cib = (
             "<resources><group id='my-group'>"
-            +
-            self._dummy("dummy1")
-            +
-            self._dummy("dummy2")
-            +
-            "</group></resources>"
+            + self._dummy("dummy1")
+            + self._dummy("dummy2")
+            + "</group></resources>"
         )
         expected_cib = (
             "<resources><group id='my-group'>"
-            +
-            self._dummy("dummy1")
-            +
-            expected_cib_simple
-            +
-            self._dummy("dummy2")
-            +
-            "</group></resources>"
+            + self._dummy("dummy1")
+            + expected_cib_simple
+            + self._dummy("dummy2")
+            + "</group></resources>"
         )
 
-        (self.config
-            .runner.pcmk.load_agent(
+        (
+            self.config.runner.pcmk.load_agent(
                 agent_name=f"stonith:{agent_name}",
-                agent_filename="stonith_agent_fence_simple.xml"
+                agent_filename="stonith_agent_fence_simple.xml",
             )
             .runner.cib.load(resources=original_cib)
             .runner.pcmk.load_fenced_metadata()
