@@ -5,10 +5,16 @@ from unittest import TestCase
 from pcs_test.tools.assertions import ac
 
 import pcs.lib.corosync.config_facade as lib
+from pcs.lib.corosync.config_parser import Parser
+
+
+def _get_facade(config_text):
+    return lib.ConfigFacade(Parser.parse(config_text.encode("utf-8")))
+
 
 class GetLinkOptions(TestCase):
     def _assert_options(self, config, options):
-        facade = lib.ConfigFacade.from_string(config)
+        facade = _get_facade(config)
         self.assertEqual(options, facade.get_links_options())
         self.assertFalse(facade.need_stopped_cluster)
         self.assertFalse(facade.need_qdevice_reload)
@@ -17,27 +23,32 @@ class GetLinkOptions(TestCase):
         self._assert_options("", {})
 
         self._assert_options(
-            dedent("""\
+            dedent(
+                """\
                 totem {
                 }
-            """),
-            {}
+            """
+            ),
+            {},
         )
 
     def test_no_linknumber(self):
         self._assert_options(
-            dedent("""\
+            dedent(
+                """\
                 totem {
                     interface {
                     }
                 }
-            """),
-            {"0": {"linknumber": "0"}}
+            """
+            ),
+            {"0": {"linknumber": "0"}},
         )
 
     def test_no_linknumber_more_sections(self):
         self._assert_options(
-            dedent("""\
+            dedent(
+                """\
                 totem {
                     transport: knet
                     interface {
@@ -51,16 +62,18 @@ class GetLinkOptions(TestCase):
                         mcastport: 3456
                     }
                 }
-            """),
+            """
+            ),
             {
                 "0": {"linknumber": "0", "mcastport": "3456"},
                 "1": {"linknumber": "1", "mcastport": "2345"},
-            }
+            },
         )
 
     def test_all_options_knet(self):
         self._assert_options(
-            dedent("""\
+            dedent(
+                """\
                 totem {
                     transport: knet
                     interface {
@@ -75,7 +88,8 @@ class GetLinkOptions(TestCase):
                         unknown: option
                     }
                 }
-            """),
+            """
+            ),
             {
                 "1": {
                     "linknumber": "1",
@@ -87,12 +101,13 @@ class GetLinkOptions(TestCase):
                     "pong_count": "6",
                     "transport": "sctp",
                 },
-            }
+            },
         )
 
     def test_all_options_udp(self):
         self._assert_options(
-            dedent("""\
+            dedent(
+                """\
                 totem {
                     transport: udp
                     interface {
@@ -103,21 +118,23 @@ class GetLinkOptions(TestCase):
                         ttl: 123
                     }
                 }
-            """),
+            """
+            ),
             {
                 "0": {
-                   "bindnetaddr": "10.0.0.1",
-                   "broadcast": "1",
-                   "mcastaddr": "10.0.0.2",
-                   "mcastport": "1234",
-                   "ttl": "123",
+                    "bindnetaddr": "10.0.0.1",
+                    "broadcast": "1",
+                    "mcastaddr": "10.0.0.2",
+                    "mcastport": "1234",
+                    "ttl": "123",
                 },
-            }
+            },
         )
 
     def test_translate_conflict(self):
         self._assert_options(
-            dedent("""\
+            dedent(
+                """\
                 totem {
                     transport: knet
                     interface {
@@ -131,18 +148,20 @@ class GetLinkOptions(TestCase):
                         link_priority: 4
                     }
                 }
-            """),
+            """
+            ),
             {
                 "1": {
                     "linknumber": "1",
                     "link_priority": "2",
                 },
-            }
+            },
         )
 
     def test_more_sections_and_conflicting_options(self):
         self._assert_options(
-            dedent("""\
+            dedent(
+                """\
                 totem {
                     transport: knet
                     interface {
@@ -166,7 +185,8 @@ class GetLinkOptions(TestCase):
                         knet_transport: udp
                     }
                 }
-            """),
+            """
+            ),
             {
                 "0": {
                     "linknumber": "0",
@@ -178,11 +198,13 @@ class GetLinkOptions(TestCase):
                     "linknumber": "1",
                     "transport": "udp",
                 },
-            }
+            },
         )
 
+
 class AddLink(TestCase):
-    before = dedent("""\
+    before = dedent(
+        """\
         totem {
             transport: knet
 
@@ -207,11 +229,12 @@ class AddLink(TestCase):
                 nodeid: 2
             }
         }
-    """)
+    """
+    )
 
     @staticmethod
     def _assert_add(node_addr_map, options, before, after):
-        facade = lib.ConfigFacade.from_string(before)
+        facade = _get_facade(before)
         facade.add_link(node_addr_map, options)
         ac(after, facade.config.export())
 
@@ -220,7 +243,8 @@ class AddLink(TestCase):
             {"node1": "node1-addr2", "node2": "node2-addr2"},
             {},
             self.before,
-            dedent("""\
+            dedent(
+                """\
                 totem {
                     transport: knet
 
@@ -247,7 +271,8 @@ class AddLink(TestCase):
                         ring2_addr: node2-addr2
                     }
                 }
-            """)
+            """
+            ),
         )
 
     def test_options_no_linknumber(self):
@@ -263,7 +288,8 @@ class AddLink(TestCase):
                 "transport": "sctp",
             },
             self.before,
-            dedent("""\
+            dedent(
+                """\
                 totem {
                     transport: knet
 
@@ -301,7 +327,8 @@ class AddLink(TestCase):
                         ring2_addr: node2-addr2
                     }
                 }
-            """)
+            """
+            ),
         )
 
     def test_custom_link_number_no_options(self):
@@ -309,7 +336,8 @@ class AddLink(TestCase):
             {"node1": "node1-addr2", "node2": "node2-addr2"},
             {"linknumber": "4"},
             self.before,
-            dedent("""\
+            dedent(
+                """\
                 totem {
                     transport: knet
 
@@ -336,7 +364,8 @@ class AddLink(TestCase):
                         ring4_addr: node2-addr2
                     }
                 }
-            """)
+            """
+            ),
         )
 
     def test_custom_link_number_options(self):
@@ -344,7 +373,8 @@ class AddLink(TestCase):
             {"node1": "node1-addr2", "node2": "node2-addr2"},
             {"linknumber": "4", "transport": "sctp"},
             self.before,
-            dedent("""\
+            dedent(
+                """\
                 totem {
                     transport: knet
 
@@ -376,11 +406,13 @@ class AddLink(TestCase):
                         ring4_addr: node2-addr2
                     }
                 }
-            """)
+            """
+            ),
         )
 
     def test_set_as_link_0_if_available(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -405,8 +437,10 @@ class AddLink(TestCase):
                     nodeid: 2
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -438,16 +472,18 @@ class AddLink(TestCase):
                     ring0_addr: node2-addr0
                 }
             }
-        """)
+        """
+        )
         self._assert_add(
             {"node1": "node1-addr0", "node2": "node2-addr0"},
             {"transport": "sctp"},
             before,
-            after
+            after,
         )
 
     def test_set_as_first_available_link(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -472,8 +508,10 @@ class AddLink(TestCase):
                     nodeid: 2
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -500,16 +538,15 @@ class AddLink(TestCase):
                     ring1_addr: node2-addr1
                 }
             }
-        """)
+        """
+        )
         self._assert_add(
-            {"node1": "node1-addr1", "node2": "node2-addr1"},
-            {},
-            before,
-            after
+            {"node1": "node1-addr1", "node2": "node2-addr1"}, {}, before, after
         )
 
     def test_no_linknumber_available(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 transport: knet
             }
@@ -541,18 +578,20 @@ class AddLink(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         with self.assertRaises(AssertionError) as cm:
             self._assert_add(
                 {"node1": "node1-addr-new", "node2": "node2-addr-new"},
                 {},
                 before,
-                "does not matter"
+                "does not matter",
             )
         self.assertEqual(str(cm.exception), "No link number available")
 
     def test_more_sections(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 interface {
                     linknumber: 1
@@ -581,12 +620,14 @@ class AddLink(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         self._assert_add(
             {"node1": "node1-addr4", "node2": "node2-addr4"},
             {"linknumber": "4", "transport": "sctp"},
             before,
-            dedent("""\
+            dedent(
+                """\
                 totem {
                     interface {
                         linknumber: 1
@@ -622,19 +663,21 @@ class AddLink(TestCase):
                         ring4_addr: node2-addr4
                     }
                 }
-            """)
+            """
+            ),
         )
 
 
 class RemoveLinks(TestCase):
     @staticmethod
     def assert_remove(links, before, after):
-        facade = lib.ConfigFacade.from_string(before)
+        facade = _get_facade(before)
         facade.remove_links(links)
         ac(after, facade.config.export())
 
     def test_nonexistent_links(self):
-        config = dedent("""\
+        config = dedent(
+            """\
             totem {
                 interface {
                     linknumber: 0
@@ -662,11 +705,13 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         self.assert_remove(["1"], config, config)
 
     def test_link_without_options(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 interface {
                     linknumber: 0
@@ -689,8 +734,10 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 interface {
                     linknumber: 0
@@ -711,11 +758,13 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         self.assert_remove(["1"], before, after)
 
     def test_link_with_options(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 interface {
                     linknumber: 0
@@ -738,8 +787,10 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             nodelist {
                 node {
                     ring1_addr: node1-addr1
@@ -753,11 +804,13 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         self.assert_remove(["0"], before, after)
 
     def test_link_without_addrs(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 interface {
                     linknumber: 0
@@ -778,8 +831,10 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             nodelist {
                 node {
                     ring1_addr: node1-addr1
@@ -793,11 +848,13 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         self.assert_remove(["0"], before, after)
 
     def test_more_links(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 interface {
                     linknumber: 0
@@ -822,8 +879,10 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             nodelist {
                 node {
                     ring1_addr: node1-addr1
@@ -837,11 +896,13 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         self.assert_remove(["0", "2"], before, after)
 
     def test_more_occurences(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 interface {
                     linknumber: 1
@@ -897,8 +958,10 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 interface {
                     linknumber: 2
@@ -935,11 +998,13 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         self.assert_remove(["1"], before, after)
 
     def test_link_with_options_nonumbered(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 interface {
                     knet_transport: udp
@@ -966,8 +1031,10 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 interface {
                     linknumber: 1
@@ -988,11 +1055,13 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         self.assert_remove(["0"], before, after)
 
     def test_more_linknumbers(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 interface {
                     linknumber: 0
@@ -1016,8 +1085,10 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 interface {
                     linknumber: 0
@@ -1039,19 +1110,22 @@ class RemoveLinks(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         self.assert_remove(["0"], before, after)
 
+
 class UpdateLink(TestCase):
     def _assert_update(self, before, after, linknumber, options, node_addr_map):
-        facade = lib.ConfigFacade.from_string(before)
+        facade = _get_facade(before)
         facade.update_link(linknumber, node_addr_map, options)
         ac(after, facade.config.export())
         self.assertTrue(facade.need_stopped_cluster)
         self.assertFalse(facade.need_qdevice_reload)
 
     def test_no_changes(self):
-        config = dedent("""\
+        config = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -1076,11 +1150,13 @@ class UpdateLink(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         self._assert_update(config, config, "1", {}, {})
 
     def test_wrong_linknumber(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -1105,8 +1181,10 @@ class UpdateLink(TestCase):
                     nodeid: 2
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -1137,17 +1215,15 @@ class UpdateLink(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         self._assert_update(
-            before,
-            after,
-            "2",
-            {"transport": "sctp"},
-            {"node1": "new-addr"}
+            before, after, "2", {"transport": "sctp"}, {"node1": "new-addr"}
         )
 
     def test_do_not_allow_linknumber_change(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -1172,8 +1248,10 @@ class UpdateLink(TestCase):
                     nodeid: 2
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -1198,17 +1276,19 @@ class UpdateLink(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         self._assert_update(
             before,
             after,
             "1",
             {"linknumber": "2", "transport": "sctp"},
-            {"node1": "new-addr"}
+            {"node1": "new-addr"},
         )
 
     def test_addresses(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 transport: knet
             }
@@ -1228,8 +1308,10 @@ class UpdateLink(TestCase):
                     nodeid: 2
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 transport: knet
             }
@@ -1249,17 +1331,15 @@ class UpdateLink(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         self._assert_update(
-            before,
-            after,
-            "1",
-            {},
-            {"node1": "new-addr", "nodeX": "addrX"}
+            before, after, "1", {}, {"node1": "new-addr", "nodeX": "addrX"}
         )
 
     def test_addresses_more_sections(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 transport: knet
             }
@@ -1288,8 +1368,10 @@ class UpdateLink(TestCase):
                     nodeid: 1
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 transport: knet
             }
@@ -1317,17 +1399,13 @@ class UpdateLink(TestCase):
                     nodeid: 1
                 }
             }
-        """)
-        self._assert_update(
-            before,
-            after,
-            "0",
-            {},
-            {"node1": "new-addr"}
+        """
         )
+        self._assert_update(before, after, "0", {}, {"node1": "new-addr"})
 
     def test_options(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -1342,8 +1420,10 @@ class UpdateLink(TestCase):
                     mcastport: 1234
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -1358,17 +1438,19 @@ class UpdateLink(TestCase):
                     knet_pong_count: 10
                 }
             }
-        """)
+        """
+        )
         self._assert_update(
             before,
             after,
             "1",
             {"transport": "sctp", "mcastport": "", "pong_count": "10"},
-            {}
+            {},
         )
 
     def test_options_more_interface_sections(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -1395,8 +1477,10 @@ class UpdateLink(TestCase):
                     mcastport: 3456
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -1417,17 +1501,13 @@ class UpdateLink(TestCase):
                     mcastport: 9876
                 }
             }
-        """)
-        self._assert_update(
-            before,
-            after,
-            "1",
-            {"mcastport": "9876"},
-            {}
+        """
         )
+        self._assert_update(before, after, "1", {"mcastport": "9876"}, {})
 
     def test_remove_all_options_removes_linknumber_and_section(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -1441,8 +1521,10 @@ class UpdateLink(TestCase):
                     knet_transport: udp
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -1451,17 +1533,13 @@ class UpdateLink(TestCase):
                     knet_transport: udp
                 }
             }
-        """)
-        self._assert_update(
-            before,
-            after,
-            "0",
-            {"transport": ""},
-            {}
+        """
         )
+        self._assert_update(before, after, "0", {"transport": ""}, {})
 
     def test_create_interface_section(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -1470,8 +1548,10 @@ class UpdateLink(TestCase):
                     knet_transport: udp
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 transport: knet
 
@@ -1485,17 +1565,13 @@ class UpdateLink(TestCase):
                     knet_transport: sctp
                 }
             }
-        """)
-        self._assert_update(
-            before,
-            after,
-            "1",
-            {"transport": "sctp"},
-            {}
+        """
         )
+        self._assert_update(before, after, "1", {"transport": "sctp"}, {})
 
     def test_enable_broadcast(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 transport: udp
 
@@ -1503,8 +1579,10 @@ class UpdateLink(TestCase):
                     mcastport: 1234
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 transport: udp
 
@@ -1513,17 +1591,13 @@ class UpdateLink(TestCase):
                     broadcast: yes
                 }
             }
-        """)
-        self._assert_update(
-            before,
-            after,
-            "0",
-            {"broadcast": "1"},
-            {}
+        """
         )
+        self._assert_update(before, after, "0", {"broadcast": "1"}, {})
 
     def test_disable_broadcast(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 transport: udp
 
@@ -1532,8 +1606,10 @@ class UpdateLink(TestCase):
                     broadcast: yes
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 transport: udp
 
@@ -1541,17 +1617,13 @@ class UpdateLink(TestCase):
                     mcastport: 1234
                 }
             }
-        """)
-        self._assert_update(
-            before,
-            after,
-            "0",
-            {"broadcast": "0"},
-            {}
+        """
         )
+        self._assert_update(before, after, "0", {"broadcast": "0"}, {})
 
     def test_default_broadcast(self):
-        before = dedent("""\
+        before = dedent(
+            """\
             totem {
                 transport: udp
 
@@ -1560,8 +1632,10 @@ class UpdateLink(TestCase):
                     broadcast: yes
                 }
             }
-        """)
-        after = dedent("""\
+        """
+        )
+        after = dedent(
+            """\
             totem {
                 transport: udp
 
@@ -1569,11 +1643,6 @@ class UpdateLink(TestCase):
                     mcastport: 1234
                 }
             }
-        """)
-        self._assert_update(
-            before,
-            after,
-            "0",
-            {"broadcast": ""},
-            {}
+        """
         )
+        self._assert_update(before, after, "0", {"broadcast": ""}, {})
