@@ -4,6 +4,12 @@ from unittest import TestCase
 from pcs_test.tools.assertions import ac
 
 import pcs.lib.corosync.config_facade as lib
+from pcs.lib.corosync.config_parser import Parser
+
+
+def _get_facade(config_text):
+    return lib.ConfigFacade(Parser.parse(config_text.encode("utf-8")))
+
 
 class GetNodesTest(TestCase):
     def assert_equal_nodelist(self, expected, real):
@@ -18,7 +24,7 @@ class GetNodesTest(TestCase):
         self.assertEqual(expected, real_nodes)
 
     def nodes_from_config(self, config):
-        facade = lib.ConfigFacade.from_string(config)
+        facade = _get_facade(config)
         nodes = facade.get_nodes()
         self.assertFalse(facade.need_stopped_cluster)
         self.assertFalse(facade.need_qdevice_reload)
@@ -30,15 +36,18 @@ class GetNodesTest(TestCase):
         self.assertEqual(0, len(nodes))
 
     def test_empty_nodelist(self):
-        config = dedent("""\
+        config = dedent(
+            """\
             nodelist {
             }
-        """)
+        """
+        )
         nodes = self.nodes_from_config(config)
         self.assertEqual(0, len(nodes))
 
     def test_one_nodelist(self):
-        config = dedent("""\
+        config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: n1a
@@ -52,7 +61,8 @@ class GetNodesTest(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         nodes = self.nodes_from_config(config)
         self.assert_equal_nodelist(
             [
@@ -63,11 +73,12 @@ class GetNodesTest(TestCase):
                     "addrs": [("0", "n2a"), ("1", "n2b")],
                 },
             ],
-            nodes
+            nodes,
         )
 
     def test_more_nodelists(self):
-        config = dedent("""\
+        config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: n1a
@@ -83,7 +94,8 @@ class GetNodesTest(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         nodes = self.nodes_from_config(config)
         self.assert_equal_nodelist(
             [
@@ -94,11 +106,13 @@ class GetNodesTest(TestCase):
                     "addrs": [("0", "n2a"), ("1", "n2b")],
                 },
             ],
-            nodes
+            nodes,
         )
 
     def test_missing_values(self):
-        config = dedent("""\
+        # pylint: disable=trailing-whitespace
+        config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: n1a
@@ -127,7 +141,8 @@ class GetNodesTest(TestCase):
                     name: n5n
                 }
             }
-        """)
+        """
+        )
         nodes = self.nodes_from_config(config)
         self.assert_equal_nodelist(
             [
@@ -141,7 +156,7 @@ class GetNodesTest(TestCase):
                     "addrs": [("1", "n5b"), ("3", "n5d")],
                 },
             ],
-            nodes
+            nodes,
         )
         self.assertEqual(["n1a"], nodes[0].addrs_plain())
         self.assertEqual(["n2a"], nodes[1].addrs_plain())
@@ -150,7 +165,8 @@ class GetNodesTest(TestCase):
         self.assertEqual(["n5b", "n5d"], nodes[4].addrs_plain())
 
     def test_sort_rings(self):
-        config = dedent("""\
+        config = dedent(
+            """\
             nodelist {
                 node {
                     ring3_addr: n1d
@@ -160,21 +176,23 @@ class GetNodesTest(TestCase):
                     name: n1n
                 }
             }
-        """)
+        """
+        )
         nodes = self.nodes_from_config(config)
         self.assert_equal_nodelist(
             [
                 {
                     "id": "1",
                     "name": "n1n",
-                    "addrs": [("0", "n1a"), ("1", "n1b"), ("3", "n1d")]
+                    "addrs": [("0", "n1a"), ("1", "n1b"), ("3", "n1d")],
                 },
             ],
-            nodes
+            nodes,
         )
 
     def test_addr_type(self):
-        config = dedent("""\
+        config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: 10.0.0.1
@@ -189,7 +207,8 @@ class GetNodesTest(TestCase):
                     nodeid: 2
                 }
             }
-        """)
+        """
+        )
         nodes = self.nodes_from_config(config)
         self.assertEqual(nodes[0].addrs[0].type, "IPv4")
         self.assertEqual(nodes[0].addrs[1].type, "FQDN")
@@ -200,7 +219,8 @@ class GetNodesTest(TestCase):
 class AddNodesTest(TestCase):
     def test_adding_two_nodes(self):
         # pylint: disable=no-self-use
-        config = dedent("""\
+        config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: node1-addr1
@@ -209,20 +229,24 @@ class AddNodesTest(TestCase):
                     name: node1
                 }
             }
-        """)
-        facade = lib.ConfigFacade.from_string(config)
-        facade.add_nodes([
-            dict(
-                name="node3",
-                addrs=["node3-addr1", "node3-addr2"],
-            ),
-            dict(
-                name="node2",
-                addrs=["node2-addr1", "node2-addr2"],
-            ),
-        ])
+        """
+        )
+        facade = _get_facade(config)
+        facade.add_nodes(
+            [
+                dict(
+                    name="node3",
+                    addrs=["node3-addr1", "node3-addr2"],
+                ),
+                dict(
+                    name="node2",
+                    addrs=["node2-addr1", "node2-addr2"],
+                ),
+            ]
+        )
 
-        expected_config = dedent("""\
+        expected_config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: node1-addr1
@@ -245,12 +269,14 @@ class AddNodesTest(TestCase):
                     nodeid: 3
                 }
             }
-        """)
+        """
+        )
         ac(expected_config, facade.config.export())
 
     def test_skipped_and_out_of_order_links_and_nodes_ids(self):
         # pylint: disable=no-self-use
-        config = dedent("""\
+        config = dedent(
+            """\
             nodelist {
                 node {
                     ring1_addr: node1-addr1
@@ -276,24 +302,28 @@ class AddNodesTest(TestCase):
                     name: node2
                 }
             }
-        """)
-        facade = lib.ConfigFacade.from_string(config)
-        facade.add_nodes([
-            dict(
-                name="node6",
-                addrs=["node6-addr1", "node6-addr2", "node6-addr5"],
-            ),
-            dict(
-                name="node3",
-                addrs=["node3-addr1", "node3-addr2", "node3-addr5"],
-            ),
-            dict(
-                name="node5",
-                addrs=["node5-addr1", "node5-addr2", "node5-addr5"],
-            ),
-        ])
+        """
+        )
+        facade = _get_facade(config)
+        facade.add_nodes(
+            [
+                dict(
+                    name="node6",
+                    addrs=["node6-addr1", "node6-addr2", "node6-addr5"],
+                ),
+                dict(
+                    name="node3",
+                    addrs=["node3-addr1", "node3-addr2", "node3-addr5"],
+                ),
+                dict(
+                    name="node5",
+                    addrs=["node5-addr1", "node5-addr2", "node5-addr5"],
+                ),
+            ]
+        )
 
-        expected_config = dedent("""\
+        expected_config = dedent(
+            """\
             nodelist {
                 node {
                     ring1_addr: node1-addr1
@@ -343,12 +373,14 @@ class AddNodesTest(TestCase):
                     nodeid: 6
                 }
             }
-        """)
+        """
+        )
         ac(expected_config, facade.config.export())
 
     def test_enable_two_node(self):
         # pylint: disable=no-self-use
-        config = dedent("""\
+        config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: node1-addr1
@@ -360,12 +392,16 @@ class AddNodesTest(TestCase):
             quorum {
                 provider: corosync_votequorum
             }
-        """)
-        facade = lib.ConfigFacade.from_string(config)
-        facade.add_nodes([
-            dict(name="node2", addrs=["node2-addr1"]),
-        ])
-        expected_config = dedent("""\
+        """
+        )
+        facade = _get_facade(config)
+        facade.add_nodes(
+            [
+                dict(name="node2", addrs=["node2-addr1"]),
+            ]
+        )
+        expected_config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: node1-addr1
@@ -384,12 +420,14 @@ class AddNodesTest(TestCase):
                 provider: corosync_votequorum
                 two_node: 1
             }
-        """)
+        """
+        )
         ac(expected_config, facade.config.export())
 
     def test_disable_two_node(self):
         # pylint: disable=no-self-use
-        config = dedent("""\
+        config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: node1-addr1
@@ -408,12 +446,16 @@ class AddNodesTest(TestCase):
                 provider: corosync_votequorum
                 two_node: 1
             }
-        """)
-        facade = lib.ConfigFacade.from_string(config)
-        facade.add_nodes([
-            dict(name="node3", addrs=["node3-addr1"]),
-        ])
-        expected_config = dedent("""\
+        """
+        )
+        facade = _get_facade(config)
+        facade.add_nodes(
+            [
+                dict(name="node3", addrs=["node3-addr1"]),
+            ]
+        )
+        expected_config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: node1-addr1
@@ -437,14 +479,16 @@ class AddNodesTest(TestCase):
             quorum {
                 provider: corosync_votequorum
             }
-        """)
+        """
+        )
         ac(expected_config, facade.config.export())
 
 
 class RemoveNodes(TestCase):
     def test_remove(self):
         # pylint: disable=no-self-use
-        config = dedent("""\
+        config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: node1-addr1
@@ -490,10 +534,12 @@ class RemoveNodes(TestCase):
             quorum {
                 provider: corosync_votequorum
             }
-        """)
-        facade = lib.ConfigFacade.from_string(config)
+        """
+        )
+        facade = _get_facade(config)
         facade.remove_nodes(["node3", "node4", "nodeX"])
-        expected_config = dedent("""\
+        expected_config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: node1-addr1
@@ -517,12 +563,14 @@ class RemoveNodes(TestCase):
             quorum {
                 provider: corosync_votequorum
             }
-        """)
+        """
+        )
         ac(expected_config, facade.config.export())
 
     def test_enable_two_nodes(self):
         # pylint: disable=no-self-use
-        config = dedent("""\
+        config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: node1-addr1
@@ -546,10 +594,12 @@ class RemoveNodes(TestCase):
             quorum {
                 provider: corosync_votequorum
             }
-        """)
-        facade = lib.ConfigFacade.from_string(config)
+        """
+        )
+        facade = _get_facade(config)
         facade.remove_nodes(["node3"])
-        expected_config = dedent("""\
+        expected_config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: node1-addr1
@@ -568,12 +618,14 @@ class RemoveNodes(TestCase):
                 provider: corosync_votequorum
                 two_node: 1
             }
-        """)
+        """
+        )
         ac(expected_config, facade.config.export())
 
     def test_disable_two_nodes(self):
         # pylint: disable=no-self-use
-        config = dedent("""\
+        config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: node1-addr1
@@ -592,10 +644,12 @@ class RemoveNodes(TestCase):
                 provider: corosync_votequorum
                 two_node: 1
             }
-        """)
-        facade = lib.ConfigFacade.from_string(config)
+        """
+        )
+        facade = _get_facade(config)
         facade.remove_nodes(["node2"])
-        expected_config = dedent("""\
+        expected_config = dedent(
+            """\
             nodelist {
                 node {
                     ring0_addr: node1-addr1
@@ -607,5 +661,6 @@ class RemoveNodes(TestCase):
             quorum {
                 provider: corosync_votequorum
             }
-        """)
+        """
+        )
         ac(expected_config, facade.config.export())
