@@ -24,6 +24,10 @@ AGENT_FILENAME_MAP = {
     "ocf:pacemaker:booth-site": "resource_agent_ocf_pacemaker_booth-site.xml",
 }
 
+RULE_IN_EFFECT_RETURNCODE = 0
+RULE_EXPIRED_RETURNCODE = 110
+RULE_NOT_YET_IN_EFFECT_RETURNCODE = 111
+
 
 def _fixture_state_resources_xml(
     resource_id="A",
@@ -107,7 +111,7 @@ class PcmkShortcuts:
         """
         self.__calls.place(
             name,
-            RunnerCall("stonith_admin --help-all", stderr=stderr),
+            RunnerCall(["stonith_admin", "--help-all"], stderr=stderr),
             instead=instead,
         )
 
@@ -127,7 +131,7 @@ class PcmkShortcuts:
         """
         self.__calls.place(
             name,
-            RunnerCall("crm_mon --help-all", stderr=stderr),
+            RunnerCall(["crm_mon", "--help-all"], stderr=stderr),
             instead=instead,
         )
 
@@ -151,7 +155,7 @@ class PcmkShortcuts:
         self.__calls.place(
             name,
             RunnerCall(
-                "stonith_admin --history {0} --verbose".format(node),
+                ["stonith_admin", "--history", node, "--verbose"],
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
@@ -178,7 +182,7 @@ class PcmkShortcuts:
         self.__calls.place(
             name,
             RunnerCall(
-                "stonith_admin --history {0} --cleanup".format(node),
+                ["stonith_admin", "--history", node, "--cleanup"],
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
@@ -203,7 +207,7 @@ class PcmkShortcuts:
         self.__calls.place(
             name,
             RunnerCall(
-                "stonith_admin --history * --broadcast",
+                ["stonith_admin", "--history", "*", "--broadcast"],
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
@@ -249,7 +253,7 @@ class PcmkShortcuts:
             self.__calls.place(
                 name,
                 RunnerCall(
-                    "crm_mon --one-shot --as-xml --inactive",
+                    ["crm_mon", "--one-shot", "--as-xml", "--inactive"],
                     stdout=stdout,
                     stderr=stderr,
                     returncode=returncode,
@@ -294,7 +298,7 @@ class PcmkShortcuts:
         self.__calls.place(
             name,
             RunnerCall(
-                "crm_mon --one-shot --as-xml --inactive",
+                ["crm_mon", "--one-shot", "--as-xml", "--inactive"],
                 stdout=etree_to_str(state),
             ),
         )
@@ -332,7 +336,7 @@ class PcmkShortcuts:
         self.__calls.place(
             name,
             RunnerCall(
-                "crm_mon {}".format(" ".join(flags)),
+                ["crm_mon"] + flags,
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
@@ -357,7 +361,7 @@ class PcmkShortcuts:
         self.__calls.place(
             name,
             RunnerCall(
-                "crm_ticket --details",
+                ["crm_ticket", "--details"],
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
@@ -413,7 +417,7 @@ class PcmkShortcuts:
             self.__calls.place(
                 name,
                 RunnerCall(
-                    "crm_resource --show-metadata {0}".format(agent_name),
+                    ["crm_resource", "--show-metadata", agent_name],
                     stdout="",
                     stderr=stderr,
                     returncode=74,
@@ -426,7 +430,7 @@ class PcmkShortcuts:
             self.__calls.place(
                 name,
                 RunnerCall(
-                    "crm_resource --show-metadata {0}".format(agent_name),
+                    ["crm_resource", "--show-metadata", agent_name],
                     stdout=a_file.read(),
                     stderr=stderr,
                 ),
@@ -460,7 +464,7 @@ class PcmkShortcuts:
         self.__calls.place(
             name,
             RunnerCall(
-                f"{settings.pacemaker_fenced} metadata",
+                [settings.pacemaker_fenced, "metadata"],
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
@@ -497,11 +501,10 @@ class PcmkShortcuts:
                 "Cannot specify node_name when stdout, stderr or returncode is "
                 "specified"
             )
-        cmd = ["crm_node", "--name"]
         self.__calls.place(
             name,
             RunnerCall(
-                " ".join(cmd),
+                ["crm_node", "--name"],
                 stdout=(node_name if node_name else stdout),
                 stderr=stderr,
                 returncode=returncode,
@@ -547,7 +550,7 @@ class PcmkShortcuts:
         self.__calls.place(
             name,
             RunnerCall(
-                " ".join(cmd),
+                cmd,
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
@@ -693,7 +696,7 @@ class PcmkShortcuts:
         self.__calls.place(
             name,
             RunnerCall(
-                " ".join(cmd),
+                cmd,
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
@@ -712,7 +715,8 @@ class PcmkShortcuts:
         string stderr -- crm_resource help text
         """
         self.__calls.place(
-            name, RunnerCall("crm_resource -?", stderr=stderr),
+            name,
+            RunnerCall(["crm_resource", "--help-all"], stderr=stderr),
         )
 
     def wait(
@@ -732,27 +736,20 @@ class PcmkShortcuts:
         self.__calls.place(
             name,
             RunnerCall(
-                "crm_resource --wait --timeout={0}".format(
-                    timeout if timeout else self.default_wait_timeout
-                ),
+                [
+                    "crm_resource",
+                    "--wait",
+                    "--timeout={0}".format(
+                        timeout
+                        if timeout is not None
+                        else self.default_wait_timeout
+                    ),
+                ],
                 stderr=stderr,
                 returncode=returncode,
             ),
         )
 
-    def can_wait(
-        self, name="runner.pcmk.can_wait", before=None, stdout="--wait"
-    ):
-        """
-        Create call that checks that wait for idle is supported
-
-        string name -- key of the call
-        string before -- key of call before which this new call is to be placed
-        """
-        self.__calls.place(
-            name, RunnerCall("crm_resource -?", stdout=stdout), before=before
-        )
-
     def verify(
         self,
         name="runner.pcmk.verify",
@@ -766,15 +763,17 @@ class PcmkShortcuts:
         string name -- key of the call
         string before -- key of call before which this new call is to be placed
         """
+        cmd = ["crm_verify"]
+        if verbose:
+            cmd.extend(["-V", "-V"])
+        if cib_tempfile:
+            cmd.extend(["--xml-file", cib_tempfile])
+        else:
+            cmd.append("--live-check")
         self.__calls.place(
             name,
             RunnerCall(
-                "crm_verify{0} {1}".format(
-                    " -V -V" if verbose else "",
-                    "--xml-file {0}".format(cib_tempfile)
-                    if cib_tempfile
-                    else "--live-check",
-                ),
+                cmd,
                 stderr=("" if stderr is None else stderr),
                 returncode=(0 if stderr is None else 55),
             ),
@@ -790,7 +789,7 @@ class PcmkShortcuts:
         self.__calls.place(
             name,
             RunnerCall(
-                "crm_node --force --remove {0}".format(node_name),
+                ["crm_node", "--force", "--remove", node_name],
                 stderr=stderr,
                 returncode=returncode,
             ),
@@ -845,10 +844,37 @@ class PcmkShortcuts:
         self.__calls.place(
             name,
             RunnerCall(
-                " ".join(cmd),
+                cmd,
                 stdout=stdout,
                 stderr=stderr,
                 returncode=returncode,
                 check_stdin=CheckStdinEqualXml(cib_xml),
             ),
         )
+
+    def get_rule_in_effect_status(
+        self,
+        rule_id,
+        returncode=0,
+        name="runner.pcmk.get_rule_in_effect_status",
+        cib_load_name="runner.cib.load",
+    ):
+        """
+        Create a call for running a tool to get rule expired status
+
+        string rule_id -- id of the rule to be checked
+        int returncode -- result of the check
+        sting name -- key of the call
+        string cib_load_name -- key of a call from whose stdout the cib is taken
+        """
+        cib_xml = self.__calls.get(cib_load_name).stdout
+        self.__calls.place(
+            name,
+            RunnerCall(
+                ["crm_rule", "--check", "--rule", rule_id, "--xml-text", "-"],
+                check_stdin=CheckStdinEqualXml(cib_xml),
+                stdout="",
+                stderr="",
+                returncode=returncode,
+            ),
+        )
