@@ -41,9 +41,22 @@ def complete_state_resources(resource_status):
                 "role": "Started",
             },
         )
+    for group in resource_status.xpath(".//group"):
+        _default_element_attributes(
+            group,
+            {
+                "disabled": "false",
+                "managed": "true",
+            },
+        )
     for clone in resource_status.xpath(".//clone"):
         _default_element_attributes(
-            clone, {"failed": "false", "failure_ignored": "false",}
+            clone,
+            {
+                "disabled": "false",
+                "failed": "false",
+                "failure_ignored": "false",
+            },
         )
     for bundle in resource_status.xpath(".//bundle"):
         _default_element_attributes(
@@ -207,9 +220,12 @@ def report_not_found(
     )
 
 
-def report_not_resource_or_tag(element_id):
+def report_not_resource_or_tag(element_id, context_type="cib", context_id=""):
     return report_not_found(
-        element_id, expected_types=sorted(ALL_RESOURCE_XML_TAGS + ["tag"])
+        element_id,
+        context_type=context_type,
+        expected_types=sorted(ALL_RESOURCE_XML_TAGS + ["tag"]),
+        context_id=context_id,
     )
 
 
@@ -227,11 +243,23 @@ def report_invalid_id(_id, invalid_char, id_description="id"):
     )
 
 
+def report_id_already_exist(_id):
+    return (
+        severities.ERROR,
+        report_codes.ID_ALREADY_EXISTS,
+        {
+            "id": _id,
+        },
+    )
+
+
 def report_resource_not_running(resource, severity=severities.INFO):
     return (
         severity,
         report_codes.RESOURCE_DOES_NOT_RUN,
-        {"resource_id": resource,},
+        {
+            "resource_id": resource,
+        },
         None,
     )
 
@@ -240,19 +268,22 @@ def report_resource_running(resource, roles, severity=severities.INFO):
     return (
         severity,
         report_codes.RESOURCE_RUNNING_ON_NODES,
-        {"resource_id": resource, "roles_with_nodes": roles,},
+        {
+            "resource_id": resource,
+            "roles_with_nodes": roles,
+        },
         None,
     )
 
 
-def report_unexpected_element(element_id, elemet_type, expected_types):
+def report_unexpected_element(element_id, element_type, expected_types):
     return (
         severities.ERROR,
         report_codes.ID_BELONGS_TO_UNEXPECTED_TYPE,
         {
             "id": element_id,
             "expected_types": expected_types,
-            "current_type": elemet_type,
+            "current_type": element_type,
         },
         None,
     )
@@ -268,7 +299,9 @@ def report_wait_for_idle_timed_out(reason):
     return (
         severities.ERROR,
         report_codes.WAIT_FOR_IDLE_TIMED_OUT,
-        {"reason": reason.strip(),},
+        {
+            "reason": reason.strip(),
+        },
         None,
     )
 
@@ -278,7 +311,9 @@ def check_sbd_comm_success_fixture(node, watchdog, device_list):
         label=node,
         output=json.dumps(
             {
-                "sbd": {"installed": True,},
+                "sbd": {
+                    "installed": True,
+                },
                 "watchdog": {
                     "exist": True,
                     "path": watchdog,
