@@ -11,35 +11,44 @@ from pcs.lib.external import CommandRunner
 
 # pylint: disable=line-too-long
 
+
 def wrap_element_by_master(cib_file, resource_id, master_id=None):
+    cib_file.seek(0)
     cib_tree = etree.parse(cib_file, etree.XMLParser(huge_tree=True)).getroot()
     element = cib_tree.find(f'.//*[@id="{resource_id}"]')
     final_master_id = (
         master_id if master_id is not None else f"{resource_id}-master"
     )
-    master_element = _xml_to_element(f"""
+    master_element = _xml_to_element(
+        f"""
         <master id="{final_master_id}">
         </master>
-    """)
+    """
+    )
     element.getparent().append(master_element)
     master_element.append(element)
     final_xml = etree_to_str(cib_tree)
 
     environ = dict(os.environ)
-    environ["CIB_file"] = cib_file
+    environ["CIB_file"] = cib_file.name
     runner = CommandRunner(
-        mock.MagicMock(logging.Logger),
-        MockLibraryReportProcessor(),
-        environ
+        mock.MagicMock(logging.Logger), MockLibraryReportProcessor(), environ
+    )
+    stdout, stderr, retval = runner.run(
+        [
+            os.path.join(settings.pacemaker_binaries, "cibadmin"),
+            "--replace",
+            "--scope",
+            "resources",
+            "--xml-pipe",
+        ],
+        stdin_string=final_xml,
     )
-    stdout, stderr, retval = runner.run([
-        os.path.join(settings.pacemaker_binaries, "cibadmin"),
-        "--replace", "--scope", "resources", "--xml-pipe",
-    ], stdin_string=final_xml)
     assert retval == 0, (
         "Error running wrap_element_by_master:\n" + stderr + "\n" + stdout
     )
 
+
 def fixture_master_xml(name, all_ops=True, meta_dict=None):
     default_ops = f"""
             <op id="{name}-notify-interval-0s" interval="0s" name="notify"
@@ -52,17 +61,15 @@ def fixture_master_xml(name, all_ops=True, meta_dict=None):
                 timeout="20"
             />
     """
-    meta_xml = ''
+    meta_xml = ""
     if meta_dict:
         meta_lines = (
             [f'<meta_attributes id="{name}-master-meta_attributes">']
-            +
-            [
+            + [
                 f'<nvpair id="{name}-master-meta_attributes-{key}" name="{key}" value="{val}"/>'
                 for key, val in meta_dict.items()
             ]
-            +
-            ['</meta_attributes>']
+            + ["</meta_attributes>"]
         )
         meta_xml = "\n".join(meta_lines)
     master = f"""
@@ -86,22 +93,28 @@ def fixture_master_xml(name, all_ops=True, meta_dict=None):
     """
     return master
 
+
 def fixture_to_cib(cib_file, xml):
     environ = dict(os.environ)
     environ["CIB_file"] = cib_file
     runner = CommandRunner(
-        mock.MagicMock(logging.Logger),
-        MockLibraryReportProcessor(),
-        environ
+        mock.MagicMock(logging.Logger), MockLibraryReportProcessor(), environ
+    )
+    stdout, stderr, retval = runner.run(
+        [
+            os.path.join(settings.pacemaker_binaries, "cibadmin"),
+            "--create",
+            "--scope",
+            "resources",
+            "--xml-text",
+            xml,
+        ]
     )
-    stdout, stderr, retval = runner.run([
-        os.path.join(settings.pacemaker_binaries, "cibadmin"),
-        "--create", "--scope", "resources", "--xml-text", xml
-    ])
     assert retval == 0, (
         "Error running fixture_to_cib:\n" + stderr + "\n" + stdout
     )
 
+
 def _replace(element_to_replace, new_element):
     parent = element_to_replace.getparent()
     for child in parent:
@@ -111,38 +124,39 @@ def _replace(element_to_replace, new_element):
             parent.insert(index, new_element)
             return
 
+
 def _xml_to_element(xml):
     try:
         new_element = etree.fromstring(xml)
-    except etree.XMLSyntaxError:
+    except etree.XMLSyntaxError as e:
         raise AssertionError(
-            "Cannot put to the cib a non-xml fragment:\n'{0}'"
-            .format(xml)
-        )
+            "Cannot put to the cib a non-xml fragment:\n'{0}'".format(xml)
+        ) from e
     return new_element
 
+
 def _find_all_in(cib_tree, element_xpath):
     element_list = cib_tree.xpath(element_xpath)
     if not element_list:
         raise AssertionError(
             "Cannot find '{0}' in given cib:\n{1}".format(
-                element_xpath,
-                etree_to_str(cib_tree)
+                element_xpath, etree_to_str(cib_tree)
             )
         )
     return element_list
 
+
 def _find_in(cib_tree, element_xpath):
     element_list = _find_all_in(cib_tree, element_xpath)
     if len(element_list) > 1:
         raise AssertionError(
             "Found more than one '{0}' in given cib:\n{1}".format(
-                element_xpath,
-                etree_to_str(cib_tree)
+                element_xpath, etree_to_str(cib_tree)
             )
         )
     return element_list[0]
 
+
 def remove(element_xpath):
     def _remove(cib_tree):
         xpath_list = (
@@ -151,16 +165,18 @@ def remove(element_xpath):
         for xpath in xpath_list:
             for element_to_remove in _find_all_in(cib_tree, xpath):
                 element_to_remove.getparent().remove(element_to_remove)
+
     return _remove
 
+
 def put_or_replace(parent_xpath, new_content):
-    #This tranformation makes sense in "configuration" section only. In this
-    #section there are sub-tags (optional or mandatory) that can occure max 1x.
+    # This tranformation makes sense in "configuration" section only. In this
+    # section there are sub-tags (optional or mandatory) that can occure max 1x.
     #
-    #In other sections it is possible to have more occurences of sub-tags. For
-    #such cases it is better to use `replace_all` - the difference is that in
-    #`replace_all` the element to be replaced is specified by full xpath
-    #whilst in `put_or_replace` the xpath to the parent element is specified.
+    # In other sections it is possible to have more occurences of sub-tags. For
+    # such cases it is better to use `replace_all` - the difference is that in
+    # `replace_all` the element to be replaced is specified by full xpath
+    # whilst in `put_or_replace` the xpath to the parent element is specified.
     def replace_optional(cib_tree):
         element = _xml_to_element(new_content)
         parent = _find_in(cib_tree, parent_xpath)
@@ -176,6 +192,7 @@ def put_or_replace(parent_xpath, new_content):
 
     return replace_optional
 
+
 def replace_all(replacements):
     """
     Return a function that replace more elements (defined by replacement_dict)
@@ -187,37 +204,42 @@ def replace_all(replacements):
         value is new content -contains a content that have to be placed instead
         of an element found by element_xpath
     """
+
     def replace(cib_tree):
         for xpath, new_content in replacements.items():
             _replace(_find_in(cib_tree, xpath), _xml_to_element(new_content))
+
     return replace
 
+
 def append_all(append_map):
     """
     Return a function that appends more elements after specified (xpath) element
     dict append_map -- a key is an xpath pointing to a target element (for
         appending), value is appended content
     """
+
     def append(cib_tree):
         for xpath, new_content in append_map.items():
             _find_in(cib_tree, xpath).append(_xml_to_element(new_content))
+
     return append
 
 
-#Possible modifier shortcuts are defined here.
-#Keep in mind that every key will be named parameter in config function
-#(see modifier_shortcuts param in some of pcs_test.tools.command_env.config_*
-#modules)
+# Possible modifier shortcuts are defined here.
+# Keep in mind that every key will be named parameter in config function
+# (see modifier_shortcuts param in some of pcs_test.tools.command_env.config_*
+# modules)
 #
-#DO NOT USE CONFLICTING KEYS HERE!
-#1) args of pcs_test.tools.command_env.calls#CallListBuilder.place:
+# DO NOT USE CONFLICTING KEYS HERE!
+# 1) args of pcs_test.tools.command_env.calls#CallListBuilder.place:
 #  name, before, instead
-#2) args of pcs_test.tools.command_env.mock_runner#Call.__init__
+# 2) args of pcs_test.tools.command_env.mock_runner#Call.__init__
 #  command, stdout, stderr, returncode, check_stdin
-#3) special args of pcs_test.tools.command_env.config_*
+# 3) special args of pcs_test.tools.command_env.config_*
 #  modifiers, filename, load_key, wait, exception
-#It would be not aplied. Not even mention that the majority of these names do
-#not make sense for a cib modifying ;)
+# It would be not aplied. Not even mention that the majority of these names do
+# not make sense for a cib modifying ;)
 MODIFIER_GENERATORS = {
     "remove": remove,
     "replace": replace_all,
@@ -226,11 +248,14 @@ MODIFIER_GENERATORS = {
     "constraints": lambda xml: replace_all(
         {"./configuration/constraints": xml}
     ),
+    "fencing_topology": lambda xml: put_or_replace("./configuration", xml),
+    "tags": lambda xml: put_or_replace("./configuration", xml),
     "optional_in_conf": lambda xml: put_or_replace("./configuration", xml),
-    #common modifier `put_or_replace` makes not sense - see explanation inside
-    #this function - all occurences should be satisfied by `optional_in_conf`
+    # common modifier `put_or_replace` makes not sense - see explanation inside
+    # this function - all occurences should be satisfied by `optional_in_conf`
 }
 
+
 def create_modifiers(**modifier_shortcuts):
     """
     Return list of modifiers: list of functions that transform cib
@@ -241,8 +266,8 @@ def create_modifiers(**modifier_shortcuts):
         Value is passed into appropriate generator from MODIFIER_GENERATORS.
 
     """
-    unknown_shortcuts = (
-        set(modifier_shortcuts.keys()) - set(MODIFIER_GENERATORS.keys())
+    unknown_shortcuts = set(modifier_shortcuts.keys()) - set(
+        MODIFIER_GENERATORS.keys()
     )
     if unknown_shortcuts:
         raise AssertionError(
@@ -257,6 +282,7 @@ def create_modifiers(**modifier_shortcuts):
         for name, param in modifier_shortcuts.items()
     ]
 
+
 def modify_cib(cib_xml, modifiers=None, **modifier_shortcuts):
     """
     Apply modifiers to cib_xml and return the result cib_xml
@@ -280,6 +306,7 @@ def modify_cib(cib_xml, modifiers=None, **modifier_shortcuts):
 
     return etree_to_str(cib_tree)
 
+
 def _cannot_multireplace(tag, parent_xpath, cib_tree):
     return AssertionError(
         (
