@@ -2,11 +2,10 @@ from pcs_test.tools.command_env.calls import Queue, CallListBuilder
 from pcs_test.tools.command_env.mock_runner import Runner as NewRunner
 
 
-#TODO please remove this module when Runner  is not used. The only usage is
+# TODO please remove this module when Runner  is not used. The only usage is
 # in the module pcs_test.test_lib_commands_sbd currently.
 
 
-
 class Runner:
     def __init__(self):
         self.set_runs([])
@@ -15,10 +14,9 @@ class Runner:
         if self.__call_queue.remaining:
             raise AssertionError(
                 "There are remaining expected commands: \n    '{0}'".format(
-                    "'\n    '".join([
-                        call.command
-                        for call in self.__call_queue.remaining
-                    ])
+                    "'\n    '".join(
+                        [call.command for call in self.__call_queue.remaining]
+                    )
                 )
             )
 
