@@ -29,7 +29,8 @@ end
 auth_user = {}
 PCS = get_pcs_path()
 $logger_device = StringIO.new
-$logger = configure_logger($logger_device)
+$logger = Logger.new($logger_device)
+early_log($logger)
 
 capabilities, capabilities_pcsd = get_capabilities($logger)
 CAPABILITIES = capabilities.freeze
@@ -97,6 +98,22 @@ allowed_commands = {
       }
     },
   },
+  'auth_with_token' => {
+    'only_superuser' => false,
+    'permissions' => nil,
+    'call' => lambda { |params, auth_user_|
+      pcs_auth_token(params.fetch('nodes'))
+      return {}
+    },
+  },
+  'set_token_to_accept' => {
+    'only_superuser' => true,
+    'permissions' => nil,
+    'call' => lambda { |params, auth_user_|
+      PCSAuth.addToken(SUPERUSER, params.fetch('token'))
+      return {}
+    },
+  },
   'send_local_configs' => {
     'only_superuser' => false,
     'permissions' => Permissions::FULL,
