@@ -34,10 +34,6 @@ Pcs = Ember.Application.createWithMixins({
     if (this.cur_page == "permissions") return "display: table-row;";
     else return "display: none;";
   }.property("cur_page"),
-  wizards_page: function() {
-    if (this.cur_page == "wizards") return "display: table-row;";
-    else return "display: none;";
-  }.property("cur_page"),
   available_features: [], /* deprecated capability list */
   pcsd_capabilities: [], /* new capability list */
   is_sbd_supported: function() {
@@ -81,7 +77,16 @@ Pcs = Ember.Application.createWithMixins({
     );
   }.property("available_features", "pcsd_capabilities"),
   is_supported_resource_refresh_one_resource: function() {
-    return this.get("pcsd_capabilities").indexOf("pcmk.resource.refresh.one-resource") != -1
+    return this.get("pcsd_capabilities").indexOf("pcmk.resource.refresh.one-resource") != -1;
+  }.property("pcsd_capabilities"),
+  is_supported_resource_create_promotable: function() {
+    return this.get("pcsd_capabilities").indexOf("pcmk.resource.create.promotable") != -1;
+  }.property("pcsd_capabilities"),
+  is_supported_resource_promotable: function() {
+    return this.get("pcsd_capabilities").indexOf("pcmk.resource.promotable") != -1;
+  }.property("pcsd_capabilities"),
+  pcmk_constraints_no_autocorrect: function() {
+    return this.get("pcsd_capabilities").indexOf("pcmk.constraint.no-autocorrect") != -1;
   }.property("pcsd_capabilities"),
   is_sbd_running: false,
   is_sbd_enabled: false,
@@ -273,7 +278,7 @@ Pcs = Ember.Application.createWithMixins({
             location.reload();
           }
         } catch(e) {
-          console.log("Error: Unable to parse json for cluster_status")
+          console.log("Error: Unable to parse json for cluster_status");
         }
       },
       complete: function() {
@@ -445,10 +450,10 @@ Pcs.ValueSelectorComponent = Ember.Component.extend({
       content = this.get('content'),
       prompt = this.get('show_prompt');
 
-    if (!content || !content.get('length')) { return; }
-    if (prompt && selectedIndex === 0) { this.set('value', ""); return; }
+    if (!content || !content.get('length')) { return }
+    if (prompt && selectedIndex === 0) { this.set('value', ""); return }
 
-    if (prompt) { selectedIndex -= 1; }
+    if (prompt) { selectedIndex -= 1 }
     this.set('value', content.objectAt(selectedIndex)['value']);
   },
   init: function() {
@@ -1217,12 +1222,13 @@ Pcs.MultiInstanceObj = Pcs.ResourceObj.extend({
 });
 
 Pcs.CloneObj = Pcs.MultiInstanceObj.extend({
-  is_clone: true
+  promotable: false,
+  resource_type: function() { // this property is just for displaying resource type in GUI
+    return this.get("promotable") ? "Promotable Clone" : "Clone";
+  }.property("promotable")
 });
 
 Pcs.MasterSlaveObj = Pcs.MultiInstanceObj.extend({
-  masters: [],
-  slaves: [],
   resource_type: 'Master/Slave'
 });
 
@@ -1240,6 +1246,9 @@ Pcs.ResourceAgentParameter = Ember.Object.extend({
   cur_val: Ember.computed.oneWay("value"),
   required: false,
   advanced: false,
+  deprecated: false,
+  deprecated_by: [],
+  obsoletes: null,
   longdesc: "",
   longdesc_html: function() {
     return nl2br(htmlEncode(this.get("longdesc")));
@@ -1273,7 +1282,7 @@ Pcs.ResourceAgent = Ember.Object.extend({
     var self = this;
     var args = [];
     $.each(self.get("parameters"), function(_, arg) {
-      if (arg.get("required")) {
+      if (arg.get("required") && !arg.get("deprecated")) {
         args.pushObject(arg);
       }
     });
@@ -1283,7 +1292,9 @@ Pcs.ResourceAgent = Ember.Object.extend({
     var self = this;
     var args = [];
     $.each(self.get("parameters"), function(_, arg) {
-      if (!arg.get("required") && !arg.get("advanced")) {
+      if (
+        !arg.get("required") && !arg.get("advanced") && !arg.get("deprecated")
+      ) {
         args.pushObject(arg);
       }
     });
@@ -1293,7 +1304,19 @@ Pcs.ResourceAgent = Ember.Object.extend({
     var self = this;
     var args = [];
     $.each(self.get("parameters"), function(_, arg) {
-      if (!arg.get("required") && arg.get("advanced")) {
+      if (
+        !arg.get("required") && arg.get("advanced") && !arg.get("deprecated")
+      ) {
+        args.pushObject(arg);
+      }
+    });
+    return args;
+  }.property("parameters.@each"),
+  deprecated_parameters: function() {
+    var self = this;
+    var args = [];
+    $.each(self.get("parameters"), function(_, arg) {
+      if (arg.get("deprecated")) {
         args.pushObject(arg);
       }
     });
@@ -1345,7 +1368,6 @@ Pcs.Router.map(function() {
 
 //  this.resource("Resource", {path: 'resources/:resource_id'});
   this.route("Manage", {path: "manage"});
-  this.route("Wizards", {path: "wizards"});
   this.route("Default Route", { path: "*x" });
 });
 
@@ -1355,12 +1377,6 @@ Pcs.ManageRoute = Ember.Route.extend({
   }
 });
 
-Pcs.WizardsRoute = Ember.Route.extend({
-  setupController: function(controller, model) {
-    select_menu("WIZARDS");
-  }
-});
-
 Pcs.IndexRoute = Ember.Route.extend({
   setupController: function(controller, model) {
     if (
@@ -1551,7 +1567,7 @@ Pcs.Clusternode = Ember.Object.extend({
   cur_node: false,
   checked: false,
   resources_running: [],
-  url: function() { return "window.location='/nodes/" + this.get("name")+"'"
+  url: function() { return "window.location='/nodes/" + this.get("name")+"'";
   }.property(),
   trclass: function(){
     if (this.cur_node == true)
@@ -1559,21 +1575,21 @@ Pcs.Clusternode = Ember.Object.extend({
   }.property("cur_node"),
   onmouseover: function(){
     if (this.cur_node == true)
-      return ""
+      return "";
     else
-      return "hover_over(this);"
+      return "hover_over(this);";
   }.property("cur_node"),
   onmouseout: function(){
     if (this.cur_node == true)
-      return ""
+      return "";
     else
-      return "hover_out(this);"
+      return "hover_out(this);";
   }.property("cur_node"),
   showArrow: function(){
     if (this.cur_node != true)
-      return "display:none;"
+      return "display:none;";
     else
-      return ""
+      return "";
   }.property("cur_node"),
   node_name_style: function() {
     if (this.up && !this.get('pacemaker_maintenance')) {
@@ -1699,10 +1715,10 @@ Pcs.Aclrole = Ember.Object.extend({
     return this.cur_role ? "node_selected" : "";
   }.property("cur_role"),
   onmouseover: function() {
-    return this.cur_role ? "" : "hover_over(this);"
+    return this.cur_role ? "" : "hover_over(this);";
   }.property("cur_role"),
   onmouseout: function() {
-    return this.cur_role ? "" : "hover_out(this);"
+    return this.cur_role ? "" : "hover_out(this);";
   }.property("cur_role"),
   showArrow: function(){
     return this.cur_role ? "" : "display:none";
@@ -1711,8 +1727,8 @@ Pcs.Aclrole = Ember.Object.extend({
 
 Pcs.Cluster = Ember.Object.extend({
   name: null,
-  url_link: function(){return get_cluster_remote_url(this.name) + "main";}.property("name"),
-  input_name: function(){return "clusterid-" + this.name;}.property("name"),
+  url_link: function(){return get_cluster_remote_url(this.name) + "main"}.property("name"),
+  input_name: function(){return "clusterid-" + this.name}.property("name"),
   div_id: function(){return "cluster_info_" + this.name}.property("name"),
   status: "unknown",
   status_unknown: function() {
@@ -1733,11 +1749,11 @@ Pcs.Cluster = Ember.Object.extend({
   }.property("status"),
   quorum_show: function() {
     if (this.get('status') == "unknown") {
-      return "<span style='color:orange'>(quorate unknown)</span>"
+      return "<span style='color:orange'>(quorate unknown)</span>";
     } else if (!this.get('quorate')) {
-      return "<span style='color: red'>(doesn't have quorum)</span>"
+      return "<span style='color: red'>(doesn't have quorum)</span>";
     } else {
-      return ""
+      return "";
     }
   }.property("status", "quorate"),
   nodes: [],
@@ -1748,6 +1764,7 @@ Pcs.Cluster = Ember.Object.extend({
   fence_failed: 0,
   error_list: [],
   warning_list: [],
+  pcsd_capabilities: [],
   need_reauth: false,
   quorate: false,
 
@@ -1768,7 +1785,11 @@ Pcs.Cluster = Ember.Object.extend({
   status_sort: function(a,b) {
     if (a.get("status_val") == b.get("status_val"))
       return ((a.status == b.status) ? a.get('name').localeCompare(b.get('name')) : ((a.status > b.status) ? 1 : -1));
-    return status_comparator(a.status, b.status)
+    return status_comparator(a.status, b.status);
+  },
+
+  isCapable: function(capabilityCode){
+    return this.get("pcsd_capabilities").indexOf(capabilityCode) != -1;
   },
 
   add_resources: function(data) {
@@ -1917,6 +1938,7 @@ Pcs.clusterController = Ember.Object.create({
         cluster = Pcs.Cluster.create({
           name: value["cluster_name"],
           status: value["status"],
+          pcsd_capabilities: value["pcsd_capabilities"] || [],
           quorate: value["quorate"],
           error_list: value["error_list"],
           warning_list: value["warning_list"]
@@ -1938,20 +1960,20 @@ Pcs.clusterController = Ember.Object.create({
         });
       }
 
-      var nodes_to_auth = {};
+      var nodes_to_auth = [];
       $.each(cluster.get('warning_list'), function(key, val){
         if (val.hasOwnProperty("type") && val.type == "nodes_not_authorized"){
           $.each(val['node_list'], function(i, node) {
-            nodes_to_auth[node] = '';
+            nodes_to_auth.push(node);
           });
         }
       });
 
-      if (cluster.get('need_reauth') || Object.keys(nodes_to_auth).length > 0) {
+      if (cluster.get('need_reauth') || nodes_to_auth.length > 0) {
         cluster.get('warning_list').pushObject({
           message: "There are few authentication problems. To fix them, click <a href='#' onclick='auth_nodes_dialog(" + JSON.stringify(nodes_to_auth) + ", null, function() {fix_auth_of_cluster();}, true)'>here</a>.",
           type: "nodes_not_authorized",
-          node_list: Object.keys(nodes_to_auth)
+          node_list: nodes_to_auth
         });
       }
 
@@ -2282,7 +2304,7 @@ Pcs.nodesController = Ember.ArrayController.createWithMixins({
       if (data["constraints"] && data["constraints"]["rsc_location"]) {
         $.each(data["constraints"]["rsc_location"], function(key, constraint) {
           if (constraint["node"] == node.name)
-            lc_on_nodes[node.name].push(constraint)
+            lc_on_nodes[node.name].push(constraint);
         });
       }
     });
@@ -2337,9 +2359,9 @@ Pcs.nodesController = Ember.ArrayController.createWithMixins({
       }
 
       if (node_obj["status"] == 'unknown') {
-        pcsd_daemon = false
+        pcsd_daemon = false;
       } else {
-        pcsd_daemon = true
+        pcsd_daemon = true;
       }
 
       if (node_obj["notauthorized"] == "true" || node_obj["notoken"] == true) {
@@ -2480,7 +2502,7 @@ Pcs.set('updater', Pcs.Updater.create({
 }));
 
 function constraint_extend(){
-  var new_object = {}
+  var new_object = {};
   for(var i in arguments){
     var extension = arguments[i];
     Object.keys(extension).forEach(function(key){
@@ -2491,11 +2513,11 @@ function constraint_extend(){
 }
 
 function constraint_set_create_resource_keyed_map(constraint){
-  groups = {}
+  groups = {};
   constraint.sets.forEach(function(resource_set){
     resource_set.resources.forEach(function(resource_id){
-      groups[resource_id] = constraint
-    })
+      groups[resource_id] = constraint;
+    });
   });
   return groups;
 }
@@ -2514,7 +2536,7 @@ function constraint_order_create_resource_keyed_map(constraint){
 }
 
 function constraint_colocation_create_resource_keyed_map(constraint){
-  var together = {}
+  var together = {};
   if(constraint.score == "INFINITY" || constraint.score >= 0){
     together.together = "Together";
   }
@@ -2560,7 +2582,7 @@ function constraint_ticket_distribute_to_resource(constraint){
     distribution methods. If attribute undefined, constraint is not distributed
 */
 function constraint_resort_part(constraint_list, group_distributors){
-  var constraint_groups = {with_sets: {}, plain: {}}
+  var constraint_groups = {with_sets: {}, plain: {}};
 
   if( ! constraint_list){
     return constraint_groups;
