@@ -548,7 +548,7 @@ function resource_stonith_cleanup_refresh(
   }
   data = {"resource": resource};
   if (full_refresh) {
-    data["full"] = 1;
+    data["strict"] = 1;
   }
   fade_in_out(action_button_id);
   ajax_wrapper({
@@ -1164,7 +1164,7 @@ function remove_resource(ids, force) {
         error == "timeout" ||
         xhr.responseText == '{"noresponse":true}'
       ) {
-        message = "Operation takes longer to complete than expected.";
+        message = "Operation takes longer to complete than expected but it will continue in the background.";
       } else {
         message = "Unable to remove resources (" + error + ")";
         if (
