@@ -60,7 +60,7 @@ def getResourcesGroups(auth_user, get_fence_devices = false, get_all_options = f
   resource_list = resource_list.sort_by{|a| (a.group ? "1" : "0").to_s + a.group.to_s + "-" +  a.id}
 
   if get_all_options or get_operations
-    stdout, stderror, retval = run_cmd(auth_user, "cibadmin", "-Q", "-l")
+    stdout, stderror, retval = run_cmd(auth_user, CIBADMIN, "-Q", "-l")
     cib_output = stdout
     resources_inst_attr_map = {}
     resources_meta_attr_map = {}
@@ -127,8 +127,12 @@ def getAllConstraints(constraints_dom)
       e.elements.each('rule') { |rule|
         rule_info = {
           'rule_string' => rule_export.export(rule),
-          'rsc' => e.attributes['rsc'],
         }
+        if e.attributes["rsc-pattern"]
+          rule_info["rsc-pattern"] = e.attributes["rsc-pattern"]
+        else
+          rule_info["rsc"] = e.attributes["rsc"]
+        end
         rule.attributes.each { |name, value|
           rule_info[name] = value unless name == 'boolean-op'
         }
@@ -168,23 +172,16 @@ def getAllConstraints(constraints_dom)
 end
 
 def getResourceAgents(auth_user)
-  resource_agent_list = {}
   stdout, stderr, retval = run_cmd(
     auth_user, PCS, "resource", "list", "--nodesc"
   )
   if retval != 0
     $logger.error("Error running 'pcs resource list --nodesc")
     $logger.error(stdout + stderr)
-    return {}
+    return []
   end
 
-  agents = stdout
-  agents.each { |a|
-    ra = ResourceAgent.new
-    ra.name = a.chomp
-    resource_agent_list[ra.name] = ra
-  }
-  return resource_agent_list
+  return stdout.map{|agent_name| agent_name.chomp}
 end
 
 class Resource
@@ -239,48 +236,28 @@ class Resource
 end
 
 
-class ResourceAgent
-  attr_accessor :name, :resource_class, :required_options, :optional_options, :info
-  def initialize(name=nil, required_options={}, optional_options={}, resource_class=nil)
-    @name = name
-    @required_options = required_options
-    @optional_options = optional_options
-    @resource_class = nil
-  end
-
-  def provider
-    name.gsub(/::.*/,"")
-  end
-
-  def class
-    name.gsub(/.*::(.*):.*/,"$1")
-  end
-
-  def type
-    name.gsub(/.*:/,"")
-  end
-
-  def name
-    @name
-  end
-
-  def to_json(options = {})
-    JSON.generate({"type" => type})
-  end
-
-  def long_desc 
-    if info && info.length >= 2
-      return info[1]
+def get_resource_agent_name_structure(agent_name)
+  [
+    # full_agent_name could be for example systemd:lvm2-pvscan@252:2
+    # note that the second colon is not separator of provider and type
+    /^(?<standard>systemd|service):(?<type>[^:@]+@.*)$/,
+    /^(?<standard>[^:]+)(:(?<provider>[^:]+))?:(?<type>[^:]+)$/,
+  ].each{|expression|
+    match = expression.match(agent_name)
+    if match
+      provider = match.names.include?('provider') ? match[:provider] : nil
+      class_provider = provider.nil? ? match[:standard] : "#{match[:standard]}:#{provider}"
+      return {
+        :full_name => agent_name,
+        # TODO remove, this is only used by the old web UI
+        :class_provider => class_provider,
+        :class => match[:standard],
+        :provider => provider,
+        :type => match[:type],
+      }
     end
-    return ""
-  end
-
-  def short_desc
-    if info && info.length >= 1
-      return info[0]
-    end
-    return ""
-  end
+  }
+  return nil
 end
 
 
